Description
"Amazon.com, Inc. engages in the retail sale of consumer products and subscriptions in North America and internationally. The company operates through three segments: North America, International, and Amazon Web Services (AWS) segments. It sells merchandise and content purchased for resale from third-party sellers through physical stores and online stores. The company also manufactures and sells electronic devices, including Kindle e-readers, Fire tablets, Fire TVs, and Echo devices; provides Kindle Direct Publishing, an online service that allows independent authors and publishers to make their books available in the Kindle Store; and develops and produces media content. In addition, it offers programs that enable sellers to sell their products on its Websites, as well as their own branded Websites; and programs that allow authors, musicians, filmmakers, skill and app developers, and others to publish and sell content. Further, the company provides compute, storage, database, and other AWS services, as well as compute, storage, database offerings, fulfillment, publishing, digital content subscriptions, advertising, and co-branded credit card agreement services. Additionally, it offers Amazon Prime, a membership program, which provides free shipping of various items; access to streaming of movies and TV episodes; and other services. It serves consumers, sellers, developers, enterprises, and content creators. Amazon.com, Inc. has a strategic partnership with Volkswagen AG. The company was founded in 1994 and is headquartered in Seattle, Washington."
