"Symbol","Name","LastSale","MarketCap","ADR TSO","IPOyear","Sector","Industry","Summary Quote",
"YI","111, Inc.","6.55","52298835.25","7984555","2018","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/yi",
"PIH","1347 Property Insurance Holdings, Inc.","5.29","31807521.56","n/a","2014","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/pih",
"PIHPP","1347 Property Insurance Holdings, Inc.","24.5","17150000","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/pihpp",
"TURN","180 Degree Capital Corp.","1.97","61309477.14","n/a","n/a","Finance","Finance/Investors Services","https://www.nasdaq.com/symbol/turn",
"FLWS","1-800 FLOWERS.COM, Inc.","18.29","1173455087.52","n/a","1999","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/flws",
"BCOW","1895 Bancorp of Wisconsin, Inc.","9.895","31668452.75","n/a","2019","Finance","Banks","https://www.nasdaq.com/symbol/bcow",
"FCCY","1st Constitution Bancorp (NJ)","18.07","155606949.94","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/fccy",
"SRCE","1st Source Corporation","45.58","1176173485.68","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/srce",
"VNET","21Vianet Group, Inc.","7.8","485767846.2","62277929","2011","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/vnet",
"TWOU","2U, Inc.","72.39","4208889245.4","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/twou",
"QFIN","360 Finance, Inc.","15.6","48360000","3100000","2018","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/qfin",
"TPNL","3PEA International, Inc.","7.7","359835722.4","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/tpnl",
"JOBS","51job, Inc.","86.43","3085989113.67","35705069","2004","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/jobs",
"JFKKU","8i Enterprises Acquisition Corp","10.04","50200000","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/jfkku",
"EGHT","8x8 Inc","20.66","1976226060.68","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/eght",
"AAON","AAON, Inc.","45.33","2356092705.15","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/aaon",
"ABEO","Abeona Therapeutics Inc.","7.47","358184214.18","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/abeo",
"ABEOW","Abeona Therapeutics Inc.","3.07","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/abeow",
"ABIL","Ability Inc.","1.69","6193304.13","n/a","2014","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/abil",
"ABMD","ABIOMED, Inc.","284.2","12813386065.2","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/abmd",
"AXAS","Abraxas Petroleum Corporation","1.34","223692712.4","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/axas",
"ACIU","AC Immune SA","4.88","329704185.04","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aciu",
"ACIA","Acacia Communications, Inc.","59.08","2378454515.08","n/a","2016","Technology","Semiconductors","https://www.nasdaq.com/symbol/acia",
"ACTG","Acacia Research Corporation","3.25","161355002.25","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/actg",
"ACHC","Acadia Healthcare Company, Inc.","29.65","2622434218.2","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/achc",
"ACAD","ACADIA Pharmaceuticals Inc.","27.32","3930866648.92","n/a","1985","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/acad",
"ACAMU","Acamar Partners Acquisition Corp.","10.02","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/acamu",
"ACST","Acasti Pharma, Inc.","1.01","78914061.34","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/acst",
"AXDX","Accelerate Diagnostics, Inc.","20.29","1142400064.29","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/axdx",
"XLRN","Acceleron Pharma Inc.","46.9","2461911710.3","n/a","2013","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/xlrn",
"ARAY","Accuray Incorporated","4.55","399851911.55","n/a","2007","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/aray",
"ACRX","AcelRx Pharmaceuticals, Inc.","3.46","272502437.8","n/a","2011","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/acrx",
"ACER","Acer Therapeutics Inc.","24.18","243912437.34","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/acer",
"ACET","Aceto Corporation","0.1345","4147908.715","n/a","n/a","Health Care","Other Pharmaceuticals","https://www.nasdaq.com/symbol/acet",
"AKAO","Achaogen, Inc.","0.4338","27418861.2726","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/akao",
"ACHV","Achieve Life Sciences, Inc. ","3.19","21440628","n/a","n/a","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/achv",
"ACHN","Achillion Pharmaceuticals, Inc.","3.14","435567219.5","n/a","2006","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/achn",
"ACIW","ACI Worldwide, Inc.","33.43","3882671789.34","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/aciw",
"ACRS","Aclaris Therapeutics, Inc.","6.34","261649536.62","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/acrs",
"ACMR","ACM Research, Inc.","15.28","245627726.64","n/a","2017","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/acmr",
"ACNB","ACNB Corporation","37.36","263239307.2","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/acnb",
"ACOR","Acorda Therapeutics, Inc.","13.26","631618976.82","n/a","2006","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/acor",
"ATVI","Activision Blizzard, Inc","47.46","36251555612.58","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/atvi",
"ADMS","Adamas Pharmaceuticals, Inc.","7.1","194887829","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/adms",
"ADMP","Adamis Pharmaceuticals Corporation","2.11","99784765.38","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/admp",
"ADAP","Adaptimmune Therapeutics plc","4.7","377272741.2","80270796","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/adap",
"ADUS","Addus HomeCare Corporation","64.2","846001791.6","n/a","2009","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/adus",
"AEY","ADDvantage Technologies Group, Inc.","1.39","14402195.88","n/a","n/a","Consumer Services","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/aey",
"IOTS","Adesto Technologies Corporation","6.22","184390575.14","n/a","2015","Technology","Semiconductors","https://www.nasdaq.com/symbol/iots",
"ADIL","Adial Pharmaceuticals, Inc","3.22","32438257.46","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/adil",
"ADILW","Adial Pharmaceuticals, Inc","0.4","0","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/adilw",
"ADMA","ADMA Biologics Inc","5.06","234546524.08","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/adma",
"ADBE","Adobe Inc.","271.35","132405488383.05","n/a","1986","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/adbe",
"ADOM","ADOMANI, Inc.","0.32","23306731.84","n/a","2017","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/adom",
"ADTN","ADTRAN, Inc.","14.07","672222995.01","n/a","1994","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/adtn",
"ADRO","Aduro Biotech, Inc.","4.03","321803741.35","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/adro",
"ADES","Advanced Emissions Solutions, Inc.","11.8","218466120.4","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/ades",
"AEIS","Advanced Energy Industries, Inc.","51.02","1949165835.12","n/a","1995","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/aeis",
"AMD","Advanced Micro Devices, Inc.","26.75","28931829590.25","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/amd",
"ADXS","Advaxis, Inc.","5.9","2165866.4","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/adxs",
"ADVM","Adverum Biotechnologies, Inc.","5.55","350765599.95","n/a","2014","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/advm",
"DWMC","AdvisorShares Dorsey Wright Micro-Cap ETF","21.9258","1644435","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwmc",
"DWSH","AdvisorShares Dorsey Wright Short ETF","24.3809","14628540","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwsh",
"BKCH","AdvisorShares Sabretooth ETF","26.5","2650000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bkch",
"ACT","AdvisorShares Vice ETF","25.485","14016750","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/act",
"AEGN","Aegion Corp","18.33","582050343.42","n/a","n/a","Basic Industries","Water Supply","https://www.nasdaq.com/symbol/aegn",
"AGLE","Aeglea BioTherapeutics, Inc.","8.2","236323180","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/agle",
"AEHR","Aehr Test Systems","1.45","32415954.95","n/a","1997","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/aehr",
"AMTX","Aemetis, Inc","0.8497","17313008.8189","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/amtx",
"AERI","Aerie Pharmaceuticals, Inc.","48.13","2209702446.25","n/a","2013","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/aeri",
"AVAV","AeroVironment, Inc.","69.07","1653009555.67","n/a","2007","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/avav",
"ARPO","Aerpio Pharmaceuticals, Inc.","0.9999","40583945.1996","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/arpo",
"AEZS","AEterna Zentaris Inc.","5.19","85327648.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aezs",
"AEMD","Aethlon Medical, Inc.","0.916","17367822.58","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/aemd",
"GNMX","Aevi Genomic Medicine, Inc.","0.1895","12273324.139","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/gnmx",
"AFMD","Affimed N.V.","4.15","259084939.9","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/afmd",
"AGEN","Agenus Inc.","2.89","387853530.86","n/a","2000","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/agen",
"AGRX","Agile Therapeutics, Inc.","1.51","65253718.33","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/agrx",
"AGYS","Agilysys, Inc.","20.54","483411303.18","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/agys",
"AGIO","Agios Pharmaceuticals, Inc.","66.66","3892638630.54","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/agio",
"AGMH","AGM Group Holdings Inc.","20.65","685911535.75","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/agmh",
"AGNC","AGNC Investment Corp.","18.11","9713100956.12","n/a","2008","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/agnc",
"AGNCB","AGNC Investment Corp.","25.2","176400","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/agncb",
"AGNCM","AGNC Investment Corp.","24.99","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/agncm",
"AGNCN","AGNC Investment Corp.","25.8707","336319.1","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/agncn",
"AGFS","AgroFresh Solutions, Inc.","3.31","169032008.32","n/a","2014","Finance","Business Services","https://www.nasdaq.com/symbol/agfs",
"AGFSW","AgroFresh Solutions, Inc.","0.08","0","n/a","2014","Finance","Business Services","https://www.nasdaq.com/symbol/agfsw",
"ALRN","Aileron Therapeutics, Inc.","1.82","27072563.7","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/alrn",
"AIMT","Aimmune Therapeutics, Inc.","22.43","1394836331.42","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aimt",
"AIRT","Air T, Inc.","28.809","58318951.779","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/airt",
"ATSG","Air Transport Services Group, Inc","22.57","1339559427.82","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/atsg",
"AIRG","Airgain, Inc.","12.73","127672747.13","n/a","2016","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/airg",
"AMCN","AirMedia Group Inc","0.444","20058920.556","45177749","2007","Technology","Advertising","https://www.nasdaq.com/symbol/amcn",
"AKAM","Akamai Technologies, Inc.","72.73","11870444906.81","n/a","1999","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/akam",
"AKTX","Akari Therapeutics Plc","3.08","46841801.16","15208377","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aktx",
"AKCA","Akcea Therapeutics, Inc.","28.86","2581041776.82","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/akca",
"AKBA","Akebia Therapeutics, Inc.","7","819855834","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/akba",
"AKER","Akers Biosciences Inc.","0.9393","11725007.6244","n/a","2014","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/aker",
"AKRX","Akorn, Inc.","3.37","423200936.81","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/akrx",
"AKTS","Akoustis Technologies, Inc.","6.4","191444499.2","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/akts",
"ALRM","Alarm.com Holdings, Inc.","65.15","3139077301.05","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/alrm",
"ALSK","Alaska Communications Systems Group, Inc.","1.97","104937627.07","n/a","1999","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/alsk",
"ALAC","Alberton Acquisition Corporation","9.97","146456807.5","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/alac",
"ALACR","Alberton Acquisition Corporation","0.18","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/alacr",
"ALACU","Alberton Acquisition Corporation","10.17","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/alacu",
"ALACW","Alberton Acquisition Corporation","0.0801","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/alacw",
"ALBO","Albireo Pharma, Inc.","33.52","403112358","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/albo",
"ABDC","Alcentra Capital Corp.","7.5","96566745","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/abdc",
"ALDR","Alder BioPharmaceuticals, Inc.","14.14","968585263.1","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aldr",
"ALDX","Aldeyra Therapeutics, Inc.","8.6","235600655","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aldx",
"ALEC","Alector, Inc.","21.28","1465591733.76","n/a","2019","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/alec",
"ALXN","Alexion Pharmaceuticals, Inc.","138.92","31159756000","n/a","1996","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/alxn",
"ALCO","Alico, Inc.","27.35","204107662.05","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/alco",
"ALIT","Alight Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/alit",
"ALGN","Align Technology, Inc.","292.03","23359289004.41","n/a","2001","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/algn",
"ALIM","Alimera Sciences, Inc.","0.98","69549257.4","n/a","2010","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/alim",
"ALYA","Alithya Group inc.","3.29","159376983.08","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/alya",
"ALJJ","ALJ Regional Holdings, Inc.","1.57","59701502.95","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/aljj",
"ALKS","Alkermes plc","35.74","5576841436.88","n/a","1991","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/alks",
"ALLK","Allakos Inc.","42.3","1823214557.7","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/allk",
"ABTX","Allegiance Bancshares, Inc.","35.16","761985937.8","n/a","2015","Finance","Major Banks","https://www.nasdaq.com/symbol/abtx",
"ALGT","Allegiant Travel Company","133.28","2169936744.64","n/a","2006","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/algt",
"ALGR","Allegro Merger Corp.","9.93","189265800","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/algr",
"ALGRR","Allegro Merger Corp.","0.26","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/algrr",
"ALGRU","Allegro Merger Corp.","10.48","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/algru",
"ALGRW","Allegro Merger Corp.","0.25","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/algrw",
"ALNA","Allena Pharmaceuticals, Inc.","6.66","138627993.24","n/a","2017","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/alna",
"ARLP","Alliance Resource Partners, L.P.","19.92","2557552524.72","n/a","1999","Energy","Coal Mining","https://www.nasdaq.com/symbol/arlp",
"LNT","Alliant Energy Corporation","46.55","10989266811.25","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/lnt",
"AHPI","Allied Healthcare Products, Inc.","1.79","7184231.23","n/a","1992","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/ahpi",
"AMOT","Allied Motion Technologies, Inc.","34.82","332004695.7","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/amot",
"ALQA","Alliqua BioMedical, Inc.","2.74","13714278.14","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/alqa",
"ALLO","Allogene Therapeutics, Inc.","28.12","3416092708.52","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/allo",
"ALLT","Allot Ltd.","8.12","276379563.04","n/a","2006","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/allt",
"MDRX","Allscripts Healthcare Solutions, Inc.","9.5","1627652062","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/mdrx",
"ALNY","Alnylam Pharmaceuticals, Inc.","92.57","9840602195.94","n/a","2004","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/alny",
"AOSL","Alpha and Omega Semiconductor Limited","11.74","281060941.7","n/a","2010","Technology","Semiconductors","https://www.nasdaq.com/symbol/aosl",
"GOOG","Alphabet Inc.","1200.49","834564316534.04","n/a","2004","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/goog",
"GOOGL","Alphabet Inc.","1205.54","838075007833.84","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/googl",
"SMCP","AlphaMark Actively Managed Small Cap ETF","23.62","23619929.14","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/smcp",
"ATEC","Alphatec Holdings, Inc.","2.74","128362566.48","n/a","2006","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/atec",
"ALPN","Alpine Immune Sciences, Inc.","6.77","125658166.33","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/alpn",
"AMR","Alta Mesa Resources, Inc.","0.2434","92705965.8814","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/amr",
"AMRWW","Alta Mesa Resources, Inc.","0.036","0","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/amrww",
"AABA","Altaba Inc.","73.94","41958308123.8","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/aaba",
"ALTR","Altair Engineering Inc.","39.47","2789662515.09","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/altr",
"ALT","Altimmune, Inc.","3","27234714","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/alt",
"ASPS","Altisource Portfolio Solutions S.A.","24.69","402529588.05","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/asps",
"AIMC","Altra Industrial Motion Corp.","32.34","2085756398.88","n/a","2006","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/aimc",
"ALTM","Altus Midstream Company","6.01","1952825123.05","n/a","2017","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/altm",
"AMAG","AMAG Pharmaceuticals, Inc.","12.83","445369457.9","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/amag",
"AMAL","Amalgamated Bank","15.52","493094999.2","n/a","2018","Consumer Non-Durables","Textiles","https://www.nasdaq.com/symbol/amal",
"AMRN","Amarin Corporation plc","20.33","6556648426.7","322510990","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/amrn",
"AMRK","A-Mark Precious Metals, Inc.","11.42","80299159","n/a","n/a","Basic Industries","Other Specialty Stores","https://www.nasdaq.com/symbol/amrk",
"AMZN","Amazon.com, Inc.","1813.98","891032218402.2","n/a","1997","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/amzn",
"AMBC","Ambac Financial Group, Inc.","18.07","819326940.38","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/ambc",
"AMBCW","Ambac Financial Group, Inc.","8.94","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/ambcw",
"AMBA","Ambarella, Inc.","43.28","1416329084.32","n/a","2012","Technology","Semiconductors","https://www.nasdaq.com/symbol/amba",
"AMCX","AMC Networks Inc.","56.95","3201421583.9","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/amcx",
"AMCI","AMCI Acquisition Corp.","9.84","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/amci",
"AMCIU","AMCI Acquisition Corp.","10.12","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/amciu",
"AMCIW","AMCI Acquisition Corp.","0.28","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/amciw",
"DOX","Amdocs Limited","54.34","7553912080","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/dox",
"AMED","Amedisys Inc","124.2","3975678266.4","n/a","n/a","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/amed",
"UHAL","Amerco","369.73","7249587457.24","n/a","n/a","Consumer Services","Rental/Leasing Companies","https://www.nasdaq.com/symbol/uhal",
"AMRH","Ameri Holdings, Inc.","0.3228","15180778.1724","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/amrh",
"AMRHW","Ameri Holdings, Inc.","0.06","0","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/amrhw",
"ATAX","America First Multifamily Investors, L.P.","6.74","409060487.58","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/atax",
"AMOV","America Movil, S.A.B. de C.V.","14.26","47074793916.44","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/amov",
"AAL","American Airlines Group, Inc.","32.99","14814342528.52","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/aal",
"AETI","American Electric Technologies, Inc.","0.82","7436850.6","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/aeti",
"AFIN","American Finance Trust, Inc.","10.71","1136066580.81","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/afin",
"AFINP","American Finance Trust, Inc.","24.894","29872800","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/afinp",
"AMNB","American National Bankshares, Inc.","34.4","301225973.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/amnb",
"ANAT","American National Insurance Company","121.34","3262280381.66","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/anat",
"AOBC","American Outdoor Brands Corporation","9.17","500296383.16","n/a","n/a","Capital Goods","Ordnance And Accessories","https://www.nasdaq.com/symbol/aobc",
"APEI","American Public Education, Inc.","31.21","517654053.6","n/a","2007","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/apei",
"AREC","American Resources Corporation","4.05","71725374.45","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/arec",
"AMRB","American River Bankshares","13.3","77932254.4","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/amrb",
"AMSWA","American Software, Inc.","12.14","377855339.08","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/amswa",
"AMSC","American Superconductor Corporation","12.69","271792161.18","n/a","1991","Consumer Durables","Metal Fabrications","https://www.nasdaq.com/symbol/amsc",
"AMWD","American Woodmark Corporation","81.88","1381256073.24","n/a","1986","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/amwd",
"CRMT","America&#39;s Car-Mart, Inc.","88.66","594599531.24","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/crmt",
"ABCB","Ameris Bancorp","35.07","1668816786.63","n/a","1994","Finance","Major Banks","https://www.nasdaq.com/symbol/abcb",
"AMSF","AMERISAFE, Inc.","57.9","1115731842","n/a","2005","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/amsf",
"ASRV","AmeriServ Financial Inc.","4.03","70955557.14","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/asrv",
"ASRVP","AmeriServ Financial Inc.","29.77","625170","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/asrvp",
"ATLO","Ames National Corporation","26.89","248539483.58","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/atlo",
"AMGN","Amgen Inc.","192.43","119744962082.62","n/a","1983","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/amgn",
"FOLD","Amicus Therapeutics, Inc.","13.65","3057791782.5","n/a","2007","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/fold",
"AMKR","Amkor Technology, Inc.","8.74","2093863947.16","n/a","1998","Technology","Semiconductors","https://www.nasdaq.com/symbol/amkr",
"AMPH","Amphastar Pharmaceuticals, Inc.","21.34","998473226.74","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/amph",
"IBUY","Amplify Online Retail ETF","49.55","279957500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ibuy",
"ASYS","Amtech Systems, Inc.","5.54","78820793.2","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/asys",
"AMRS","Amyris, Inc.","2.13","156675321.57","n/a","2010","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/amrs",
"ADI","Analog Devices, Inc.","108.11","39818460486.54","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/adi",
"ANAB","AnaptysBio, Inc.","75.72","2043424140.48","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/anab",
"AVXL","Anavex Life Sciences Corp.","2.98","141490972.16","n/a","n/a","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/avxl",
"ANCN","Anchiano Therapeutics Ltd.","6.69","17743044.06","2652174","2019","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ancn",
"ANDA","Andina Acquisition Corp. III","9.76","135615200","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/anda",
"ANDAR","Andina Acquisition Corp. III","0.38","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/andar",
"ANDAU","Andina Acquisition Corp. III","10.18","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/andau",
"ANDAW","Andina Acquisition Corp. III","0.18","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/andaw",
"ANGI","ANGI Homeservices Inc.","15.56","7842844365.96","n/a","n/a","Consumer Services","Advertising","https://www.nasdaq.com/symbol/angi",
"ANGO","AngioDynamics, Inc.","24.69","916917542.07","n/a","2004","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/ango",
"ANIP","ANI Pharmaceuticals, Inc.","69.54","824896901.22","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/anip",
"ANIK","Anika Therapeutics Inc.","30.7","436298330.4","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/anik",
"ANIX","Anixa Biosciences, Inc.","4.53","88915424.37","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/anix",
"ANSS","ANSYS, Inc.","187.61","15716432651.08","n/a","1996","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/anss",
"ATRS","Antares Pharma, Inc.","3.02","484807579.22","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/atrs",
"APLS","Apellis Pharmaceuticals, Inc.","20.44","1150553435.08","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/apls",
"APOG","Apogee Enterprises, Inc.","38.24","1039202592","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/apog",
"APEN","Apollo Endosurgery, Inc.","3.52","77134615.36","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/apen",
"AINV","Apollo Investment Corporation","15.22","1053038376.88","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/ainv",
"AMEH","Apollo Medical Holdings, Inc.","19.7","705241344.1","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/ameh",
"APPF","AppFolio, Inc.","80.1","2715813088.2","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/appf",
"APPN","Appian Corporation","34.21","2198161257.93","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/appn",
"AAPL","Apple Inc.","194.02","914858625600","n/a","1980","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/aapl",
"ARCI","Appliance Recycling Centers of America, Inc.","0.4769","4040607.2619","n/a","n/a","Consumer Services","Home Furnishings","https://www.nasdaq.com/symbol/arci",
"APDN","Applied DNA Sciences Inc","0.67","24362578.19","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/apdn",
"APDNW","Applied DNA Sciences Inc","0.0071","0","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/apdnw",
"AGTC","Applied Genetic Technologies Corporation","4.39","79744587.06","n/a","2014","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/agtc",
"AMAT","Applied Materials, Inc.","40.99","38915603042.91","n/a","1972","Technology","Semiconductors","https://www.nasdaq.com/symbol/amat",
"AAOI","Applied Optoelectronics, Inc.","12.13","241176095.69","n/a","2013","Technology","Semiconductors","https://www.nasdaq.com/symbol/aaoi",
"AREX","Approach Resources Inc.","0.4327","40962843.6","n/a","2007","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/arex",
"APVO","Aptevo Therapeutics Inc.","0.9155","39311770.4945","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/apvo",
"APTX","Aptinyx Inc.","4.1","137605065.1","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aptx",
"APM","Aptorum Group Limited","13.39","403258261.25","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/apm",
"APTO","Aptose Biosciences, Inc.","1.98","79693241.76","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/apto",
"APYX","Apyx Medical Corporation","4.46","151808672.74","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/apyx",
"AQMS","Aqua Metals, Inc.","3.02","133966266.82","n/a","2015","Basic Industries","Metal Fabrications","https://www.nasdaq.com/symbol/aqms",
"AQB","AquaBounty Technologies, Inc.","2.45","45761763.95","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aqb",
"AQST","Aquestive Therapeutics, Inc.","6.95","173576298.65","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aqst",
"AQXP","Aquinox Pharmaceuticals, Inc.","2.67","62844772.56","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aqxp",
"PETX","Aratana Therapeutics, Inc.","3.64","178266189.92","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/petx",
"ARAV","Aravive, Inc.","7.2","81190800","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/arav",
"ABUS","Arbutus Biopharma Corporation","4.01","229712320.68","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/abus",
"ARCW","ARC Group Worldwide, Inc.","0.924","21574917.672","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/arcw",
"ABIO","ARCA biopharma, Inc.","0.336","6167317.296","n/a","n/a","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/abio",
"RKDA","Arcadia Biosciences, Inc.","7.43","35477648.17","n/a","2015","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/rkda",
"ARCB","ArcBest Corporation","32.12","820290003.28","n/a","n/a","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/arcb",
"ACGL","Arch Capital Group Ltd.","32.42","13082076643.04","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/acgl",
"ACGLO","Arch Capital Group Ltd.","24.42","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/acglo",
"ACGLP","Arch Capital Group Ltd.","23.39","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/acglp",
"FUV","Arcimoto, Inc.","5","81693825","n/a","2017","Consumer Non-Durables","Motor Vehicles","https://www.nasdaq.com/symbol/fuv",
"ARCE","Arco Platform Limited","31.59","714020461.83","n/a","2018","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/arce",
"ARCT","Arcturus Therapeutics Ltd.","7.65","82325650.95","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/arct",
"ARDX","Ardelyx, Inc.","3.005","188112017.365","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ardx",
"ARNA","Arena Pharmaceuticals, Inc.","44.68","2210000093.32","n/a","2000","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/arna",
"ARCC","Ares Capital Corporation","17.48","7451692536","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/arcc",
"ARGX","argenx SE","128.91","2685590538.06","20833066","2017","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/argx",
"ARDS","Aridis Pharmaceuticals Inc.","11.1","89990919","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ards",
"ARKR","Ark Restaurants Corp.","20.01","69568386.81","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/arkr",
"ARTX","Arotech Corporation","3.07","81673030.51","n/a","1994","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/artx",
"ARQL","ArQule, Inc.","4.77","520386770.43","n/a","1996","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/arql",
"ARRY","Array BioPharma Inc.","24.58","5363689206.48","n/a","2000","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/arry",
"ARRS","ARRIS International plc","31.66","5560386975.72","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/arrs",
"DWCR","Arrow DWA Country Rotation ETF","26.9399","16163940","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwcr",
"DWAT","Arrow DWA Tactical ETF","10.88","5440000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwat",
"AROW","Arrow Financial Corporation","33.36","482667625.44","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/arow",
"ARWR","Arrowhead Pharmaceuticals, Inc.","18.78","1769214840.54","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/arwr",
"ARTNA","Artesian Resources Corporation","35.94","300927093.54","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/artna",
"ARTW","Art&#39;s-Way Manufacturing Co., Inc.","2.11","9066043.33","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/artw",
"ARVN","Arvinas, Inc.","17.29","558964882.84","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/arvn",
"ARYA","ARYA Sciences Acquisition Corp.","9.84","141450000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/arya",
"ARYAU","ARYA Sciences Acquisition Corp.","10.45","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/aryau",
"ARYAW","ARYA Sciences Acquisition Corp.","1.45","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/aryaw",
"ASNA","Ascena Retail Group, Inc.","0.9936","196302897.1008","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/asna",
"ASND","Ascendis Pharma A/S","113.18","4559190327","40282650","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/asnd",
"ASCMA","Ascent Capital Group, Inc.","0.5688","7081573.6512","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/ascma",
"APWC","Asia Pacific Wire & Cable Corporation Limited","2.2975","31750689.5275","n/a","n/a","Basic Industries","Telecommunications Equipment","https://www.nasdaq.com/symbol/apwc",
"ASLN","ASLAN Pharmaceuticals Limited","4.1428","24748287.6396","5973807","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/asln",
"ASML","ASML Holding N.V.","193.84","13900416432.16","71710774","1995","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/asml",
"ASPU","Aspen Group Inc.","5.03","93000686.06","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/aspu",
"AZPN","Aspen Technology, Inc.","105.99","7381762687.59","n/a","1994","Technology","EDP Services","https://www.nasdaq.com/symbol/azpn",
"ASMB","Assembly Biosciences, Inc.","19.53","498810984.21","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/asmb",
"ASRT","Assertio Therapeutics, Inc.","5.16","331602178.08","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/asrt",
"ASFI","Asta Funding, Inc.","4.4027","29433876.6205","n/a","1995","Finance","Finance Companies","https://www.nasdaq.com/symbol/asfi",
"ASTE","Astec Industries, Inc.","38.84","874599857.96","n/a","1986","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/aste",
"ATRO","Astronics Corporation","32.9","1072416065.7","n/a","n/a","Capital Goods","Military/Government/Technical","https://www.nasdaq.com/symbol/atro",
"ALOT","AstroNova, Inc.","21.32","148233568.08","n/a","1983","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/alot",
"ASTC","Astrotech Corporation","3.57","20221772.34","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/astc",
"ASUR","Asure Software Inc","6.22","95818260.3","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/asur",
"ASV","ASV Holdings, Inc.","2.71","26820539.38","n/a","2017","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/asv",
"ATAI","ATA Inc.","0.995","10509352.185","10562163","2008","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/atai",
"ATRA","Atara Biotherapeutics, Inc.","39.98","1845543046.86","n/a","2014","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/atra",
"ATNX","Athenex, Inc.","11.93","799590331.14","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/atnx",
"ATHX","Athersys, Inc.","1.53","224669390.67","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/athx",
"AAME","Atlantic American Corporation","2.59","52316223.26","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/aame",
"ACBI","Atlantic Capital Bancshares, Inc.","18.02","447292349.9","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/acbi",
"AY","Atlantica Yield plc","19.45","1949225707","n/a","2014","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ay",
"ATLC","Atlanticus Holdings Corporation","3.57","56963184.18","n/a","1995","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/atlc",
"AAWW","Atlas Air Worldwide Holdings","50.55","1301611343.4","n/a","n/a","Transportation","Transportation Services","https://www.nasdaq.com/symbol/aaww",
"AFH","Atlas Financial Holdings, Inc.","2.39","28529358.3","n/a","2013","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/afh",
"AFHBL","Atlas Financial Holdings, Inc.","16.21","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/afhbl",
"TEAM","Atlassian Corporation Plc","115.6","27686779156","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/team",
"ATNI","ATN International, Inc.","56.7","907389661.5","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/atni",
"ATOM","Atomera Incorporated","2.97","45534563.91","n/a","2016","Technology","Semiconductors","https://www.nasdaq.com/symbol/atom",
"ATOS","Atossa Genetics Inc.","3.54","32272374.6","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/atos",
"ATRC","AtriCure, Inc.","28.21","1089067840.77","n/a","2005","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/atrc",
"ATRI","Atrion Corporation","882.31","1634705146.36","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/atri",
"ATIS","Attis Industries Inc.","2.57","8842876.56","n/a","n/a","Basic Industries","Miscellaneous","https://www.nasdaq.com/symbol/atis",
"ATISW","Attis Industries Inc.","0.5499","0","n/a","n/a","Basic Industries","Miscellaneous","https://www.nasdaq.com/symbol/atisw",
"ATTU","Attunity Ltd.","23.32","511496146.04","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/attu",
"LIFE","aTyr Pharma, Inc.","0.5605","19486978.0465","n/a","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/life",
"AUBN","Auburn National Bancorporation, Inc.","38.15","137090613.45","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/aubn",
"BOLD","Audentes Therapeutics, Inc.","38.14","1662664328.24","n/a","2016","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/bold",
"AUDC","AudioCodes Ltd.","15.69","460459795.98","n/a","1999","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/audc",
"AEYE","AudioEye, Inc.","9.1","69371365.7","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/aeye",
"AUPH","Aurinia Pharmaceuticals Inc","6.75","616890168","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/auph",
"EARS","Auris Medical Holding Ltd.","0.3434","12876077.9806","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ears",
"JG","Aurora Mobile Limited","6.7","74868279","11174370","2018","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/jg",
"ADSK","Autodesk, Inc.","164.35","36080612749.6","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/adsk",
"AUTL","Autolus Therapeutics plc","29.82","538483774.92","18057806","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/autl",
"ADP","Automatic Data Processing, Inc.","161.44","70328051664.64","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/adp",
"AUTO","AutoWeb, Inc.","3.6","46749420","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/auto",
"AVDL","Avadel Pharmaceuticals plc","1.38","58631877.84","42486868","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/avdl",
"AVCO","Avalon GloboCare Corp.","5.17","381652186.63","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/avco",
"AVDR","Avedro, Inc","12.61","215186787.53","n/a","2019","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/avdr",
"ATXI","Avenue Therapeutics, Inc.","5.05","83336665.5","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/atxi",
"AVEO","AVEO Pharmaceuticals, Inc.","1.58","219620537.2","n/a","2010","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aveo",
"AVNW","Aviat Networks, Inc.","14.9","80163907.2","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/avnw",
"CDMO","Avid Bioservices, Inc.","4.21","236073682.89","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cdmo",
"CDMOP","Avid Bioservices, Inc.","25.8923","42664296.248","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cdmop",
"AVID","Avid Technology, Inc.","8.23","345667160.1","n/a","1993","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/avid",
"AVGR","Avinger, Inc.","0.9825","47286788.6775","n/a","2015","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/avgr",
"CAR","Avis Budget Group, Inc.","35.25","2675805292.5","n/a","n/a","Consumer Services","Rental/Leasing Companies","https://www.nasdaq.com/symbol/car",
"AVT","Avnet, Inc.","44.14","4786006579.06","n/a","n/a","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/avt",
"AVRO","AVROBIO, Inc.","22.31","537088173.56","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/avro",
"AWRE","Aware, Inc.","3.55","76577582.5","n/a","1996","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/awre",
"ACLS","Axcelis Technologies, Inc.","20.17","662115204.61","n/a","2000","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/acls",
"AXGN","AxoGen, Inc.","20.94","815508907.26","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/axgn",
"AAXN","Axon Enterprise, Inc.","54.38","3199141901.92","n/a","n/a","Capital Goods","Ordnance And Accessories","https://www.nasdaq.com/symbol/aaxn",
"AXNX","Axonics Modulation Technologies, Inc.","23.63","657880845.08","n/a","2018","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/axnx",
"AXGT","Axovant Sciences Ltd.","1.31","203780277.84","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/axgt",
"AXSM","Axsome Therapeutics, Inc.","13.66","454609649.3","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/axsm",
"AXTI","AXT Inc","4.94","197520757.46","n/a","1998","Technology","Semiconductors","https://www.nasdaq.com/symbol/axti",
"AYTU","Aytu BioScience, Inc.","1.72","21423348.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/aytu",
"AZRX","AzurRx BioPharma, Inc.","2.55","45071058.75","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/azrx",
"BCOM","B Communications Ltd.","2.05","76413022.25","n/a","n/a","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/bcom",
"RILY","B. Riley Financial, Inc.","17.17","457512558.31","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rily",
"RILYG","B. Riley Financial, Inc.","24.7","0","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rilyg",
"RILYH","B. Riley Financial, Inc.","25.95","0","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rilyh",
"RILYI","B. Riley Financial, Inc.","25.3119","0","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rilyi",
"RILYL","B. Riley Financial, Inc.","25.57","0","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rilyl",
"RILYZ","B. Riley Financial, Inc.","25.1808","0","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rilyz",
"BOSC","B.O.S. Better Online Solutions","2.8","10235470","n/a","n/a","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/bosc",
"BIDU","Baidu, Inc.","170.98","47646102374.6","278664770","2005","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/bidu",
"BCPC","Balchem Corporation","94.56","3051797384.16","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/bcpc",
"BLDP","Ballard Power Systems, Inc.","3.04","705034699.36","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/bldp",
"BANF","BancFirst Corporation","53.41","1741849007.08","n/a","1993","Finance","Major Banks","https://www.nasdaq.com/symbol/banf",
"BANFP","BancFirst Corporation","26.907","26907000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/banfp",
"BCTF","Bancorp 34, Inc.","15.16","50879309.8","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/bctf",
"BAND","Bandwidth Inc.","67.76","1351493866.8","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/band",
"BFC","Bank First National Corporation","58","381522434","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bfc",
"BOCH","Bank of Commerce Holdings (CA)","10.74","195611207.16","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/boch",
"BMRC","Bank of Marin Bancorp","41.59","574208841.44","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bmrc",
"BMLP","Bank Of Montreal","48.71","48710000","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bmlp",
"BKSC","Bank of South Carolina Corp.","18.65","102864354.75","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bksc",
"BOTJ","Bank of the James Financial Group, Inc.","14","61298104","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/botj",
"OZK","Bank OZK","29.85","3848764077","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ozk",
"BSVN","Bank7 Corp.","17.34","176651250","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/bsvn",
"BFIN","BankFinancial Corporation","14.76","242915238.72","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/bfin",
"BFL","BankFlorida","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bfl",
"BWFG","Bankwell Financial Group, Inc.","29.34","230307880.14","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/bwfg",
"BANR","Banner Corporation","55.41","1943721904.41","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/banr",
"BZUN","Baozun Inc.","42","1819657434","43325177","2015","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/bzun",
"DFVL","Barclays PLC","60.34","4296208","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/dfvl",
"DFVS","Barclays PLC","30","3480000","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/dfvs",
"DLBS","Barclays PLC","16.49","12211850.89","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/dlbs",
"DTUL","Barclays PLC","55.0347","4564192.7751","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/dtul",
"DTUS","Barclays PLC","36","4669200","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/dtus",
"DTYL","Barclays PLC","80","5103440","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/dtyl",
"DTYS","Barclays PLC","17.67","45015067.14","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/dtys",
"FLAT","Barclays PLC","65","4448730","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/flat",
"STPP","Barclays PLC","28.6","4241380","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/stpp",
"TAPR","Barclays PLC","22.65","13757610","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/tapr",
"BBSI","Barrett Business Services, Inc.","77","570377808","n/a","1993","Technology","Professional Services","https://www.nasdaq.com/symbol/bbsi",
"GOLD","Barrick Gold Corporation","13.46","23581675014.54","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/gold",
"BSET","Bassett Furniture Industries, Incorporated","16.3","171728747.8","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/bset",
"ZTEST","BATS BZX Exchange","10.1","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ztest",
"BCML","BayCom Corp","22.87","249090068.68","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/bcml",
"BCBP","BCB Bancorp, Inc. (NJ)","13.19","216295674.21","n/a","2005","Finance","Savings Institutions","https://www.nasdaq.com/symbol/bcbp",
"BECN","Beacon Roofing Supply, Inc.","33.19","2271469201.59","n/a","2004","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/becn",
"BBGI","Beasley Broadcast Group, Inc.","3.89","107249933.53","n/a","2000","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/bbgi",
"BBBY","Bed Bath & Beyond Inc.","16.92","2326033904.76","n/a","1992","Consumer Services","Home Furnishings","https://www.nasdaq.com/symbol/bbby",
"BGNE","BeiGene, Ltd.","141.85","5499267184.1","38768186","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bgne",
"BELFA","Bel Fuse Inc.","21.1","258786520.4","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/belfa",
"BELFB","Bel Fuse Inc.","26.41","323912417.24","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/belfb",
"BLPH","Bellerophon Therapeutics, Inc.","0.6592","45423339.488","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/blph",
"BLCM","Bellicum Pharmaceuticals, Inc.","3.45","152905928.55","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/blcm",
"BNFT","Benefitfocus, Inc.","45.95","1472279079.3","n/a","2013","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/bnft",
"BNTC","Benitec Biopharma Limited","1.902","3905325.246","2053273","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bntc",
"BNTCW","Benitec Biopharma Limited","0.1607","0","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bntcw",
"BRY","Berry Petroleum Corporation","12.13","995407814.5","n/a","2018","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/bry",
"BYSI","BeyondSpring, Inc.","16.28","377285695.16","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bysi",
"BGCP","BGC Partners, Inc.","5.59","1887854425.47","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/bgcp",
"BGFV","Big 5 Sporting Goods Corporation","3","64352853","n/a","2002","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/bgfv",
"BRPA","Big Rock Partners Acquisition Corp.","10.33","93336715","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/brpa",
"BRPAR","Big Rock Partners Acquisition Corp.","0.26","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/brpar",
"BRPAU","Big Rock Partners Acquisition Corp.","10.65","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/brpau",
"BRPAW","Big Rock Partners Acquisition Corp.","0.18","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/brpaw",
"BILI","Bilibili Inc.","18.05","1568069310.3","86873646","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/bili",
"BASI","Bioanalytical Systems, Inc.","2.1","21609023.1","n/a","1997","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/basi",
"BIOC","Biocept, Inc.","1.11","20886954.36","n/a","2014","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/bioc",
"BCRX","BioCryst Pharmaceuticals, Inc.","8.65","953027823.55","n/a","1994","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/bcrx",
"BDSI","BioDelivery Sciences International, Inc.","5.04","357602837.76","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bdsi",
"BFRA","Biofrontera AG","12.7136","7438206.1024","585059","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bfra",
"BIIB","Biogen Inc.","233.27","45886258043.68","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/biib",
"BHTG","BioHiTech Global, Inc.","2.95","43668720.2","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/bhtg",
"BKYI","BIO-key International, Inc.","1.37","19149679.16","n/a","n/a","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/bkyi",
"BIOL","Biolase, Inc.","2.43","51336573.66","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/biol",
"BLFS","BioLife Solutions, Inc.","17.88","333492002.64","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/blfs",
"BLRX","BioLineRx Ltd.","0.4321","37080455.3883","85814523","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/blrx",
"BMRN","BioMarin Pharmaceutical Inc.","91.23","16272895988.46","n/a","1999","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bmrn",
"BMRA","Biomerica, Inc.","2.51","23404889.07","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/bmra",
"BNGO","Bionano Genomics, Inc.","4.5","47263936.5","n/a","2018","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/bngo",
"BNGOW","Bionano Genomics, Inc.","1.15","0","n/a","2018","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/bngow",
"BVXV","BiondVax Pharmaceuticals Ltd.","5.8","32972292.4","5684878","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/bvxv",
"BVXVW","BiondVax Pharmaceuticals Ltd.","0.435","0","n/a","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/bvxvw",
"BPTH","Bio-Path Holdings, Inc.","19.68","49342463.52","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bpth",
"BIOS","BioScrip, Inc.","1.99","255038979.09","n/a","n/a","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/bios",
"BSGM","BioSig Technologies, Inc.","6.08","121531873.6","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/bsgm",
"BSTC","BioSpecifics Technologies Corp","63.77","464126924.03","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bstc",
"TECH","Bio-Techne Corp","200.2","7560753200","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/tech",
"BEAT","BioTelemetry, Inc.","59.5","2008339081","n/a","2008","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/beat",
"BTAI","BioXcel Therapeutics, Inc.","8.99","140812356.79","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/btai",
"BCAC","Bison Capital Acquisition Corp.","10.65","84975679.05","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bcac",
"BCACR","Bison Capital Acquisition Corp.","0.39","0","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bcacr",
"BCACU","Bison Capital Acquisition Corp.","10.7027","0","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bcacu",
"BCACW","Bison Capital Acquisition Corp.","0.2","0","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bcacw",
"BJRI","BJ&#39;s Restaurants, Inc.","46.45","979077884.35","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/bjri",
"BRAC","Black Ridge Acquisition Corp.","10.2","180489000","n/a","2017","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/brac",
"BRACR","Black Ridge Acquisition Corp.","0.3405","0","n/a","2017","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/bracr",
"BRACU","Black Ridge Acquisition Corp.","10.61","0","n/a","2017","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/bracu",
"BRACW","Black Ridge Acquisition Corp.","0.29","0","n/a","2017","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/bracw",
"BLKB","Blackbaud, Inc.","82.99","4030682802.05","n/a","2004","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/blkb",
"BL","BlackLine, Inc.","45.8","2520158419.4","n/a","2016","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/bl",
"BKCC","BlackRock Capital Investment Corporation","6.03","415082617.65","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/bkcc",
"TCPC","BlackRock TCP Capital Corp.","14.33","842111148.31","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/tcpc",
"BLNK","Blink Charging Co.","3.05","78444734.25","n/a","n/a","Consumer Durables","Electrical Products","https://www.nasdaq.com/symbol/blnk",
"BLNKW","Blink Charging Co.","1.2457","0","n/a","n/a","Consumer Durables","Electrical Products","https://www.nasdaq.com/symbol/blnkw",
"BLMN","Bloomin&#39; Brands, Inc.","20.3","1860140379.3","n/a","2012","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/blmn",
"BCOR","Blucora, Inc.","34.5","1663015782","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/bcor",
"BLBD","Blue Bird Corporation","17.19","453598718.4","n/a","2014","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/blbd",
"BLUE","bluebird bio, Inc.","160","8792188320","n/a","2013","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/blue",
"BKEP","Blueknight Energy Partners L.P., L.L.C.","1.04","42343451.28","n/a","2011","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/bkep",
"BKEPP","Blueknight Energy Partners L.P., L.L.C.","5.24","184056058.48","n/a","n/a","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/bkepp",
"BPMC","Blueprint Medicines Corporation","83.4","3677892378.6","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bpmc",
"ITEQ","BlueStar Israel Technology ETF","37.8397","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iteq",
"BMCH","BMC Stock Holdings, Inc.","18.07","1201789458.87","n/a","2013","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/bmch",
"WIFI","Boingo Wireless, Inc.","22.66","995242359.54","n/a","2011","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/wifi",
"BOKF","BOK Financial Corporation","83.16","5963237280","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bokf",
"BOKFL","BOK Financial Corporation","25.29","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bokfl",
"BNSO","Bonso Electronics International, Inc.","3","14038857","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/bnso",
"BKNG","Booking Holdings Inc.","1763.55","79382191173.75","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/bkng",
"BRQS","Borqs Technologies, Inc. ","4.61","144308443.5","n/a","2015","Technology","EDP Services","https://www.nasdaq.com/symbol/brqs",
"BOMN","Boston Omaha Corporation","25.28","535348543.36","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/bomn",
"BPFH","Boston Private Financial Holdings, Inc.","11.24","941543687.68","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bpfh",
"EPAY","Bottomline Technologies, Inc.","51.22","2212392531.18","n/a","1999","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/epay",
"BOXL","Boxlight Corporation","2.88","30287093.76","n/a","2017","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/boxl",
"BWMC","Boxwood Merger Corp.","9.73","245682500","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/bwmc",
"BWMCU","Boxwood Merger Corp.","10.07","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/bwmcu",
"BWMCW","Boxwood Merger Corp.","0.36","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/bwmcw",
"BCLI","Brainstorm Cell Therapeutics Inc.","4.29","126514716.9","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/bcli",
"BVNSC","Brandes Investment Trust","100.04","50020200.08","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bvnsc",
"BDGE","Bridge Bancorp, Inc.","30.1","597364028.1","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bdge",
"BLIN          ","Bridgeline Digital, Inc.","0.1666","2705793.7494","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/blin",
"BWB","Bridgewater Bancshares, Inc.","10.48","315423623.52","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/bwb",
"BRID","Bridgford Foods Corporation","23.45","212851710.4","n/a","n/a","Consumer Non-Durables","Specialty Foods","https://www.nasdaq.com/symbol/brid",
"BCOV","Brightcove Inc.","8.35","305988246.65","n/a","2012","Technology","EDP Services","https://www.nasdaq.com/symbol/bcov",
"BHF","Brighthouse Financial, Inc.","37.07","4321074595.97","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/bhf",
"BHFAL","Brighthouse Financial, Inc.","25.2","0","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/bhfal",
"BHFAP","Brighthouse Financial, Inc.","25.9","0","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/bhfap",
"AVGO","Broadcom Inc.","303.05","119961027263","n/a","2009","Technology","Semiconductors","https://www.nasdaq.com/symbol/avgo",
"BVSN","BroadVision, Inc.","1.42","7098798.68","n/a","1996","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/bvsn",
"BYFC","Broadway Financial Corporation","1.33","25447376.78","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/byfc",
"BWEN","Broadwind Energy, Inc.","1.67","26469615.23","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/bwen",
"BPY","Brookfield Property Partners L.P.","20.86","8926810856.74","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/bpy",
"BPYPP","Brookfield Property Partners L.P.","24.8899","159295360","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/bpypp",
"BPR","Brookfield Property REIT Inc.","20.84","15491013726.12","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/bpr",
"BPRAP","Brookfield Property REIT Inc.","25.79","257900000","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/bprap",
"BRKL","Brookline Bancorp, Inc.","14.54","1159805069.94","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/brkl",
"BRKS","Brooks Automation, Inc.","29.53","2095451575.82","n/a","1995","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/brks",
"DOOO","BRP Inc.","27.99","1204690243.77","n/a","n/a","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/dooo",
"BRKR","Bruker Corporation","38.53","6039266678.49","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/brkr",
"BMTC","Bryn Mawr Bank Corporation","36.67","741876270.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bmtc",
"BSQR","BSQUARE Corporation","1.95","24918704.85","n/a","1999","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/bsqr",
"BLDR","Builders FirstSource, Inc.","13.48","1555047623.68","n/a","2005","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/bldr",
"BFST","Business First Bancshares, Inc.","24.35","324365327.3","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bfst",
"CFFI","C&F Financial Corporation","51.76","180479925.36","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cffi",
"CHRW","C.H. Robinson Worldwide, Inc.","88.49","12154864903.23","n/a","1997","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/chrw",
"CCMP","Cabot Microelectronics Corporation","114.42","3313070346.06","n/a","2000","Technology","Semiconductors","https://www.nasdaq.com/symbol/ccmp",
"CDNS","Cadence Design Systems, Inc.","64.61","18167441157.32","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cdns",
"CDZI","Cadiz, Inc.","9.48","241306441.68","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/cdzi",
"CZR","Caesars Entertainment Corporation","8.83","5917303211.12","n/a","2012","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/czr",
"CSTE","Caesarstone Ltd.","15.68","538898252.48","n/a","2012","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/cste",
"CLBS","Caladrius Biosciences, Inc.","3.5","36299032","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/clbs",
"CHY","Calamos Convertible and High Income Fund","10.95","799444016.7","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/chy",
"CHI","Calamos Convertible Opportunities and Income Fund","10.24","717038817.28","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/chi",
"CCD","Calamos Dynamic Convertible & Income Fund","20.4","498118570.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ccd",
"CHW","Calamos Global Dynamic Income Fund","8.07","477333777.69","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/chw",
"CGO","Calamos Global Total Return Fund","12.49","108029082.54","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/cgo",
"CSQ","Calamos Strategic Total Return Fund","12.52","1935908655.84","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/csq",
"CAMP","CalAmp Corp.","12.85","440229512.1","n/a","1983","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/camp",
"CVGW","Calavo Growers, Inc.","82.02","1443552000","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/cvgw",
"CALA","Calithera Biosciences, Inc.","6.69","259824199.62","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cala",
"CALM","Cal-Maine Foods, Inc.","42","2042372766","n/a","1996","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/calm",
"CLMT","Calumet Specialty Products Partners, L.P.","3.69","285862458.69","n/a","2006","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/clmt",
"CRUSC","Calvert Management Series","99.98","99980000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/crusc",
"CLXT","Calyxt, Inc.","16.97","554726034.13","n/a","2017","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/clxt",
"CATC","Cambridge Bancorp","81.4","335663970.4","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/catc",
"CAC","Camden National Corporation","42.64","665792515.44","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cac",
"CAMT","Camtek Ltd.","9.18","334547373.42","n/a","2000","Capital Goods","Electronic Components","https://www.nasdaq.com/symbol/camt",
"CSIQ","Canadian Solar Inc.","18.99","1112467717.35","n/a","2006","Technology","Semiconductors","https://www.nasdaq.com/symbol/csiq",
"CGIX","Cancer Genetics, Inc.","0.24","13506293.28","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/cgix",
"CPHC","Canterbury Park Holding Corporation","14.35","65631992.3","n/a","n/a","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/cphc",
"CBNK","Capital Bancorp, Inc.","12","164069748","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/cbnk",
"CCBG","Capital City Bank Group","21.98","369437268.34","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ccbg",
"CPLP","Capital Product Partners L.P.","10.35","188143324.65","n/a","2007","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/cplp",
"CSWC","Capital Southwest Corporation","21.51","370690111.35","n/a","n/a","Consumer Non-Durables","Textiles","https://www.nasdaq.com/symbol/cswc",
"CSWCL","Capital Southwest Corporation","25.7","0","n/a","n/a","Consumer Non-Durables","Textiles","https://www.nasdaq.com/symbol/cswcl",
"CPTA","Capitala Finance Corp.","8.08","129864878.88","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/cpta",
"CPTAG","Capitala Finance Corp.","25.0464","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cptag",
"CPTAL","Capitala Finance Corp.","25.0874","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cptal",
"CFFN","Capitol Federal Financial, Inc.","13.4","1893141802.6","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/cffn",
"CAPR","Capricor Therapeutics, Inc.","0.64","21543261.44","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/capr",
"CSTR","CapStar Financial Holdings, Inc.","15.84","280093603.68","n/a","2016","Finance","Major Banks","https://www.nasdaq.com/symbol/cstr",
"CPST","Capstone Turbine Corporation","0.876","62715704.52","n/a","2000","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cpst",
"CARA","Cara Therapeutics, Inc.","19.61","775527612.38","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cara",
"CBLK","Carbon Black, Inc.","14.04","993821414.04","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cblk",
"CARB","Carbonite, Inc.","24.32","835766990.08","n/a","2011","Technology","EDP Services","https://www.nasdaq.com/symbol/carb",
"CSII","Cardiovascular Systems, Inc.","37.9","1319793519.2","n/a","1981","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/csii",
"CDLX","Cardlytics, Inc.","17.09","384561111.17","n/a","2018","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/cdlx",
"CATM","Cardtronics plc","35.77","1654758581.21","n/a","2007","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/catm",
"CDNA","CareDx, Inc.","31.61","1319036051.62","n/a","2014","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/cdna",
"CECO","Career Education Corporation","16.48","1149935358.88","n/a","1998","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/ceco",
"CTRE","CareTrust REIT, Inc.","23.31","2073219488.55","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ctre",
"CARG","CarGurus, Inc.","40.8","3683108412","n/a","2017","Technology","EDP Services","https://www.nasdaq.com/symbol/carg",
"CARO","Carolina Financial Corporation","35.05","782048288.1","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/caro",
"CART","Carolina Trust BancShares, Inc.","8.21","76328181.17","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cart",
"CRZO","Carrizo Oil & Gas, Inc.","12.34","1130686286.92","n/a","1997","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/crzo",
"TAST","Carrols Restaurant Group, Inc.","9.98","369298652.54","n/a","2006","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/tast",
"CARE","Carter Bank & Trust","19","499853653","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/care",
"CARV","Carver Bancorp, Inc.","3.6789","13607750.7696","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/carv",
"CASM","CAS Medical Systems, Inc.","2.44","71591520.28","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/casm",
"CASA","Casa Systems, Inc.","8.62","716565239.16","n/a","2017","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/casa",
"CWST","Casella Waste Systems, Inc.","34.22","1591187977.84","n/a","1997","Public Utilities","Environmental Services","https://www.nasdaq.com/symbol/cwst",
"CASY","Caseys General Stores, Inc.","128.76","4716564682.92","n/a","1983","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/casy",
"CASI","CASI Pharmaceuticals, Inc.","2.85","272793598.2","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/casi",
"CASS","Cass Information Systems, Inc","45.96","667588257.24","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/cass",
"SAVA","Cassava Sciences, Inc.","1.24","21351932","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sava",
"CTRM","Castor Maritime Inc.","5.96","0","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/ctrm",
"CATB","Catabasis Pharmaceuticals, Inc.","7.74","88977043.08","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/catb",
"CBIO","Catalyst Biosciences, Inc. ","9.04","108209179.68","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cbio",
"CPRX","Catalyst Pharmaceuticals, Inc.","5.1","523970210.7","n/a","2006","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cprx",
"CATS","Catasys, Inc.","13.74","222658706.04","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/cats",
"CATY","Cathay General Bancorp","34.62","2786156945.76","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/caty",
"CGVIC","Causeway ETMF Trust","100.1","50549098.6","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cgvic",
"CIVEC","Causeway ETMF Trust","100.12","50572714.52","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/civec",
"CVCO","Cavco Industries, Inc.","119.43","1086612357.6","n/a","n/a","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/cvco",
"CBFV","CB Financial Services, Inc.","23.3","126595633.7","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cbfv",
"CBAT","CBAK Energy Technology, Inc.","1.02","27180427.56","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cbat",
"CBMB","CBM Bancorp, Inc.","13.1","55439200","n/a","2018","Finance","Savings Institutions","https://www.nasdaq.com/symbol/cbmb",
"CBOE","Cboe Global Markets, Inc.","96.5","10790509375","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/cboe",
"CBTX","CBTX, Inc.","32.55","846386355.15","n/a","2017","Finance","Major Banks","https://www.nasdaq.com/symbol/cbtx",
"CDK","CDK Global, Inc.","58.82","7335580132.9","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/cdk",
"CDW","CDW Corporation","99.27","14598566287.65","n/a","2013","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/cdw",
"CECE","CECO Environmental Corp.","7.55","264098207.25","n/a","n/a","Capital Goods","Pollution Control Equipment","https://www.nasdaq.com/symbol/cece",
"CELC","Celcuity Inc.","22.36","228275811.4","n/a","2017","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/celc",
"CELG","Celgene Corporation","93.44","65628107264","n/a","1987","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/celg",
"CELGZ","Celgene Corporation","0.9652","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/celgz",
"CLDX","Celldex Therapeutics, Inc.","4.51","56103182.3","n/a","n/a","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/cldx",
"APOP","Cellect Biotechnology Ltd.","0.9688","6267159.4496","6468992","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/apop",
"APOPW","Cellect Biotechnology Ltd.","0.11","0","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/apopw",
"CLRB","Cellectar Biosciences, Inc.","2.42","11513655.78","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/clrb",
"CLRBW","Cellectar Biosciences, Inc.","0.105","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/clrbw",
"CLRBZ","Cellectar Biosciences, Inc.","0.05","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/clrbz",
"CLLS","Cellectis S.A.","18.71","294115643.13","15719703","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/clls",
"CBMG","Cellular Biomedicine Group, Inc.","17.05","308426043.2","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/cbmg",
"CLSN","Celsion Corporation","2.05","40102141","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/clsn",
"CELH","Celsius Holdings, Inc.","4.37","249956855.05","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/celh",
"CYAD","Celyad SA","22.43","21522841.08","959556","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cyad",
"CETX","Cemtrex Inc.","0.5271","7656196.5501","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cetx",
"CETXP","Cemtrex Inc.","1.717","3623630.631","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cetxp",
"CETXW","Cemtrex Inc.","0.03","0","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cetxw",
"CDEV","Centennial Resource Development, Inc.","8.85","2339887625.7","n/a","2016","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cdev",
"CSFL","CenterState Bank Corporation","24.04","2304251813.64","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/csfl",
"CETV","Central European Media Enterprises Ltd.","4.02","1016471287.08","n/a","1994","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/cetv",
"CFBK","Central Federal Corporation","12.85","56441003.6","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/cfbk",
"CENT","Central Garden & Pet Company","25.88","1498751250.44","n/a","1993","Consumer Durables","Consumer Specialties","https://www.nasdaq.com/symbol/cent",
"CENTA","Central Garden & Pet Company","23.53","1362659077.39","n/a","n/a","Consumer Durables","Consumer Specialties","https://www.nasdaq.com/symbol/centa",
"CVCY","Central Valley Community Bancorp","19.87","272466003.97","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cvcy",
"CTRC","Centric Brands Inc.","4.47","260760020.25","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/ctrc",
"CENX","Century Aluminum Company","8.85","779715444","n/a","1996","Basic Industries","Aluminum","https://www.nasdaq.com/symbol/cenx",
"CNBKA","Century Bancorp, Inc.","74.54","268964843.66","n/a","1987","Finance","Major Banks","https://www.nasdaq.com/symbol/cnbka",
"CNTY","Century Casinos, Inc.","8.97","264069435.63","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/cnty",
"CRNT","Ceragon Networks Ltd.","3.72","291537858.24","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/crnt",
"CERC","Cerecor Inc.","5.99","255495417.41","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cerc",
"CERN","Cerner Corporation","56.93","18465866492.44","n/a","1986","Technology","EDP Services","https://www.nasdaq.com/symbol/cern",
"CERS","Cerus Corporation","6.14","840892175.22","n/a","1997","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/cers",
"KOOL","Cesca Therapeutics Inc.","0.2994","6631454.6118","n/a","n/a","Capital Goods","Medical Specialities","https://www.nasdaq.com/symbol/kool",
"CEVA","CEVA, Inc.","27.41","604760260.9","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/ceva",
"CFFA","CF Finance Acquisition Corp.","9.88","285121120.44","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/cffa",
"CFFAU","CF Finance Acquisition Corp.","10.2","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/cffau",
"CFFAW","CF Finance Acquisition Corp.","0.4134","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/cffaw",
"CSBR","Champions Oncology, Inc.","9.37","108835098.64","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/csbr",
"CYOU","Changyou.com Limited","17.54","343188622.24","19566056","2009","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cyou",
"BURG","Chanticleer Holdings, Inc.","1.82","6762035.28","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/burg",
"CTHR","Charles & Colvard Ltd.","1.18","25485721.42","n/a","1997","Consumer Durables","Consumer Specialties","https://www.nasdaq.com/symbol/cthr",
"GTLS","Chart Industries, Inc.","88","2780550168","n/a","2006","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/gtls",
"CHTR","Charter Communications, Inc.","346.63","77982024602.09","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/chtr",
"CTAC","ChaSerg Technology Acquisition Corp.","9.88","223683200","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/ctac",
"CTACU","ChaSerg Technology Acquisition Corp.","10.18","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/ctacu",
"CTACW","ChaSerg Technology Acquisition Corp.","0.65","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/ctacw",
"CHKP","Check Point Software Technologies Ltd.","127.99","20354849717.12","n/a","1996","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/chkp",
"CHEK","Check-Cap Ltd.","2.75","22651915","n/a","2015","Health Care","Medical Electronics","https://www.nasdaq.com/symbol/chek",
"CHEKW","Check-Cap Ltd.","0.1493","0","n/a","2015","Health Care","Medical Electronics","https://www.nasdaq.com/symbol/chekw",
"CHEKZ","Check-Cap Ltd.","0.38","0","n/a","n/a","Health Care","Medical Electronics","https://www.nasdaq.com/symbol/chekz",
"CKPT","Checkpoint Therapeutics, Inc.","3.14","90609918.68","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ckpt",
"CEMI","Chembio Diagnostics, Inc.","6.07","104200406.13","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cemi",
"CHFC","Chemical Financial Corporation","42.4","3033231212.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/chfc",
"CCXI","ChemoCentryx, Inc.","14.08","808108716.8","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ccxi",
"CHMG","Chemung Financial Corp","47.58","230071757.76","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/chmg",
"CHKE","Cherokee Inc.","0.7199","10239164.3363","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/chke",
"CHFS","CHF Solutions, Inc.","4.55","4407234.65","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/chfs",
"CHMA","Chiasma, Inc.","5.49","134315589.51","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/chma",
"CSSE","Chicken Soup for the Soul Entertainment, Inc.","10.52","122197079.84","n/a","2017","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/csse",
"CSSEP","Chicken Soup for the Soul Entertainment, Inc.","25.35","19785598.95","n/a","n/a","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/cssep",
"PLCE","Children&#39;s Place, Inc. (The)","96.34","1515977338","n/a","1997","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/plce",
"CMRX","Chimerix, Inc.","2.12","107914775.52","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cmrx",
"CADC","China Advanced Construction Materials Group, Inc.","2.86","15972030.36","n/a","n/a","Basic Industries","Engineering & Construction","https://www.nasdaq.com/symbol/cadc",
"CAAS","China Automotive Systems, Inc.","3.2","100792713.6","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/caas",
"GLG","China Bat Group, Inc.","2.37","2331662.88","n/a","2013","Finance","Major Banks","https://www.nasdaq.com/symbol/glg",
"CBPO","China Biologic Products Holdings, Inc.","92.83","3653938813.28","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/cbpo",
"CCCL","China Ceramics Co., Ltd.","1.6652","9416392.9424","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/cccl",
"CCRC","China Customer Relations Centers, Inc.","11.53","211340288","n/a","2015","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ccrc",
"JRJC","China Finance Online Co. Limited","1.4","29707441.4","21219601","2004","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/jrjc",
"HGSH","China HGS Real Estate, Inc.","1.06","47753000","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/hgsh",
"CIFS","China Internet Nationwide Financial Services Inc.","3.54","78284225.52","n/a","2017","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/cifs",
"CJJD","China Jo-Jo Drugstores, Inc.","2.82","81601713.96","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/cjjd",
"CLDC","China Lending Corporation","1.24","30413354.76","n/a","2014","Finance","Diversified Financial Services","https://www.nasdaq.com/symbol/cldc",
"CHNR","China Natural Resources, Inc.","1.7375","43282716.55","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/chnr",
"CREG","China Recycling Energy Corporation","1","10295280","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/creg",
"SXTC","China SXT Pharmaceuticals, Inc.","6.37","151287500","n/a","2019","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sxtc",
"CNTF","China TechFaith Wireless Communication Technology Limited","1.06","7694526.22","7258987","2005","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/cntf",
"CXDC","China XD Plastics Company Limited","2.3101","116541867.5941","n/a","n/a","Capital Goods","Containers/Packaging","https://www.nasdaq.com/symbol/cxdc",
"CCIH","ChinaCache International Holdings Ltd.","1.25","30201850","24161480","2010","Technology","EDP Services","https://www.nasdaq.com/symbol/ccih",
"CNET","ChinaNet Online Holdings, Inc.","1.97","31781109.71","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/cnet",
"IMOS","ChipMOS TECHNOLOGIES INC.","17.21","91382105.46","5309826","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/imos",
"CDXC","ChromaDex Corporation","4.12","227777957.44","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/cdxc",
"CHSCL","CHS Inc","27.73","574011000","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/chscl",
"CHSCM","CHS Inc","26.53","522641000","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/chscm",
"CHSCN","CHS Inc","27.21","457128000","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/chscn",
"CHSCO","CHS Inc","27.88","598278760.08","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/chsco",
"CHSCP","CHS Inc","29.29","359446967.87","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/chscp",
"CHDN","Churchill Downs, Incorporated","89.86","3623316498.7","n/a","n/a","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/chdn",
"CHUY","Chuy&#39;s Holdings, Inc.","21.04","355260126.48","n/a","2012","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/chuy",
"CDTX","Cidara Therapeutics, Inc.","2.61","69467796.54","n/a","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/cdtx",
"CMCT","CIM Commercial Trust Corporation","18.5","866204872.5","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cmct",
"CMCTP","CIM Commercial Trust Corporation","25.1","202826574","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cmctp",
"CMPR","Cimpress N.V","80.02","2468180170.82","n/a","n/a","Miscellaneous","Publishing","https://www.nasdaq.com/symbol/cmpr",
"CINF","Cincinnati Financial Corporation","85.52","13950697067.28","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/cinf",
"CIDM","Cinedigm Corp","1.76","62793716.48","n/a","n/a","Consumer Services","Consumer Electronics/Video Chains","https://www.nasdaq.com/symbol/cidm",
"CTAS","Cintas Corporation","206.09","21625441856.61","n/a","1983","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/ctas",
"CRUS","Cirrus Logic, Inc.","40.95","2421881812.35","n/a","1989","Technology","Semiconductors","https://www.nasdaq.com/symbol/crus",
"CSCO","Cisco Systems, Inc.","55.29","243388112417.64","n/a","1990","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/csco",
"CTRN","Citi Trends, Inc.","19.07","232654000","n/a","2005","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/ctrn",
"CTXR","Citius Pharmaceuticals, Inc.","1.32","24446875.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ctxr",
"CTXRW","Citius Pharmaceuticals, Inc.","0.335","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ctxrw",
"CZNC","Citizens & Northern Corp","25.8","319731195.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cznc",
"CZWI","Citizens Community Bancorp, Inc.","12.15","133540540.65","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/czwi",
"CZFC","Citizens First Corporation","24.76","62831099.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/czfc",
"CIZN","Citizens Holding Company","23.18","113687005.4","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cizn",
"CTXS","Citrix Systems, Inc.","100.13","13189707658.29","n/a","1995","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ctxs",
"CHCO","City Holding Company","76.59","1266055447.23","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/chco",
"CIVB","Civista Bancshares, Inc. ","21.25","331574353.75","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/civb",
"CIVBP","Civista Bancshares, Inc. ","66.05","668426","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/civbp",
"CLAR","Clarus Corporation","12.98","386133660.88","n/a","n/a","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/clar",
"CLNE","Clean Energy Fuels Corp.","3.14","642501989.52","n/a","2007","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/clne",
"CACG","ClearBridge All Cap Growth ETF","30.85","64776238.6","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cacg",
"YLDE","ClearBridge Dividend Strategy ESG ETF","29.43","4415147.46","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ylde",
"LRGE","ClearBridge Large Cap Growth ESG ETF","33.6793","5051996.0379","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lrge",
"CLFD","Clearfield, Inc.","14.645","200086668.12","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/clfd",
"CLRO","ClearOne, Inc.","2.08","34555185.6","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/clro",
"CLSD","Clearside Biomedical, Inc.","1.35","48652980.75","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/clsd",
"CLIR","ClearSign Combustion Corporation","0.91","24294507.51","n/a","2012","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/clir",
"CMTA","Clementia Pharmaceuticals Inc.","26.07","992202457.62","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cmta",
"CBLI","Cleveland BioLabs, Inc.","1.67","18868059.13","n/a","2006","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/cbli",
"CLVS","Clovis Oncology, Inc.","24.79","1310611999.04","n/a","2011","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/clvs",
"CLPS","CLPS Incorporation","9.83","135789860.43","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/clps",
"CMFN","CM Finance Inc","7.29","99243924.03","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/cmfn",
"CMFNL","CM Finance Inc","25.3392","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cmfnl",
"CMSS","CM Seven Star Acquisition Corporation","10.325","271785924.9","n/a","2017","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/cmss",
"CMSSR","CM Seven Star Acquisition Corporation","0.34","0","n/a","2017","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/cmssr",
"CMSSU","CM Seven Star Acquisition Corporation","10.99","0","n/a","2017","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/cmssu",
"CMSSW","CM Seven Star Acquisition Corporation","0.16","0","n/a","2017","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/cmssw",
"CME","CME Group Inc.","168.07","60141468956.52","n/a","2002","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/cme",
"CCNE","CNB Financial Corporation","25.38","386779195.26","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ccne",
"CCB","Coastal Financial Corporation","17.04","202822263.6","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/ccb",
"COKE","Coca-Cola Consolidated, Inc.","283.66","2025742856.02","n/a","1972","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/coke",
"COCP","Cocrystal Pharma, Inc.","2.75","82288459","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cocp",
"CODA","Coda Octopus Group, Inc.","10.4","110983849.6","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/coda",
"CDXS","Codexis, Inc.","21.66","1173075644.22","n/a","2010","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/cdxs",
"CODX","Co-Diagnostics, Inc.","1.12","18870990.88","n/a","2017","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/codx",
"CVLY","Codorus Valley Bancorp, Inc","21.15","200032893","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/cvly",
"JVA","Coffee Holding Co., Inc.","5.46","30408645.54","n/a","2005","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/jva",
"CCOI","Cogent Communications Holdings, Inc.","53.92","2502052348.16","n/a","n/a","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/ccoi",
"CGNX","Cognex Corporation","53.26","9126724355.04","n/a","1989","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cgnx",
"CTSH","Cognizant Technology Solutions Corporation","73.57","42310053661.75","n/a","1998","Technology","EDP Services","https://www.nasdaq.com/symbol/ctsh",
"CWBR","CohBar, Inc.","3.3","140838937.8","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cwbr",
"COHR","Coherent, Inc.","150.17","3653123870.13","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/cohr",
"CHRS","Coherus BioSciences, Inc.","13.11","907994719.44","n/a","2014","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/chrs",
"COHU","Cohu, Inc.","15.24","622049388.36","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/cohu",
"CLCT","Collectors Universe, Inc.","17.62","160719966.62","n/a","1999","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/clct",
"COLL","Collegium Pharmaceutical, Inc.","15.73","524941276.86","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/coll",
"CIGI","Colliers International Group Inc. ","67.83","2580133954.86","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/cigi",
"CLGN","CollPlant Holdings, Ltd.","5.3969","20314762.7226","3764154","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/clgn",
"CBAN","Colony Bankcorp, Inc.","17","143563436","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cban",
"COLB","Columbia Banking System, Inc.","33.86","2480821466.5","n/a","1992","Finance","Major Banks","https://www.nasdaq.com/symbol/colb",
"CLBK","Columbia Financial, Inc.","15.67","1815983372.25","n/a","2018","Finance","Savings Institutions","https://www.nasdaq.com/symbol/clbk",
"COLM","Columbia Sportswear Company","104.05","7096677912.85","n/a","1998","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/colm",
"CMCO","Columbus McKinnon Corporation","35.51","829331540.23","n/a","1996","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/cmco",
"CMCSA","Comcast Corporation","40.02","181129020130.44","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/cmcsa",
"CCNI","Command Center, Inc.","3.9","18388203.6","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/ccni",
"CBSH","Commerce Bancshares, Inc.","59.14","6571556665.3","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cbsh",
"CBSHP","Commerce Bancshares, Inc.","26.7","160200","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cbshp",
"CVGI","Commercial Vehicle Group, Inc.","8.05","251750813.65","n/a","2004","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/cvgi",
"COMM","CommScope Holding Company, Inc.","22.83","4392041746.74","n/a","2013","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/comm",
"JCS","Communications Systems, Inc.","2.62","24030412.06","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/jcs",
"ESXB","Community Bankers Trust Corporation.","7.24","160237880.96","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/esxb",
"CFBI","Community First Bancshares, Inc.","10.26","76316445","n/a","2017","Finance","Savings Institutions","https://www.nasdaq.com/symbol/cfbi",
"CTBI","Community Trust Bancorp, Inc.","41.31","733981745.43","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ctbi",
"CWBC","Community West Bancshares","10.15","86044493.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cwbc",
"CVLT","Commvault Systems, Inc.","62.31","2859817270.62","n/a","2006","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cvlt",
"CGEN","Compugen Ltd.","4.07","243801840.04","n/a","2000","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/cgen",
"CPSI","Computer Programs and Systems, Inc.","29.57","423891272.6","n/a","2002","Technology","EDP Services","https://www.nasdaq.com/symbol/cpsi",
"CTG","Computer Task Group, Incorporated","4.415","63942356.7","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/ctg",
"SCOR","comScore, Inc.","14.06","836094069","n/a","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/scor",
"CHCI","Comstock Holding Companies, Inc.","2.4095","9248126.0335","n/a","2004","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/chci",
"CMTL","Comtech Telecommunications Corp.","23.39","564304777.61","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/cmtl",
"CNAT","Conatus Pharmaceuticals Inc.","1.36","45104565.92","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cnat",
"CNCE","Concert Pharmaceuticals, Inc.","12.61","296703880.33","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cnce",
"BBCP","Concrete Pumping Holdings, Inc. ","7.35","212030646.45","n/a","2017","Basic Industries","Engineering & Construction","https://www.nasdaq.com/symbol/bbcp",
"CDOR","Condor Hospitality Trust, Inc.","9.27","110387447.37","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cdor",
"CFMS","ConforMIS, Inc.","2.56","173861575.68","n/a","2015","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/cfms",
"CNFR","Conifer Holdings, Inc.","4.55","38575819.1","n/a","2015","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/cnfr",
"CNFRL","Conifer Holdings, Inc.","23.4634","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/cnfrl",
"CNMD","CONMED Corporation","82.79","2330573934.12","n/a","1987","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/cnmd",
"CTWS","Connecticut Water Service, Inc.","68.31","823854394.44","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/ctws",
"CNOB","ConnectOne Bancorp, Inc.","19.95","706738345.95","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cnob",
"CONN","Conn&#39;s, Inc.","23.09","736200151.51","n/a","2003","Consumer Services","Consumer Electronics/Video Chains","https://www.nasdaq.com/symbol/conn",
"CNSL","Consolidated Communications Holdings, Inc.","11.25","809943896.25","n/a","2005","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/cnsl",
"CWCO","Consolidated Water Co. Ltd.","12.75","191374567.5","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/cwco",
"CNAC","Constellation Alpha Capital Corp.","10.1","187153000","n/a","2017","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/cnac",
"CNACR","Constellation Alpha Capital Corp.","0.18","0","n/a","2017","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/cnacr",
"CNACU","Constellation Alpha Capital Corp.","10.32","191229600","n/a","2017","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/cnacu",
"CNACW","Constellation Alpha Capital Corp.","0.12","0","n/a","2017","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/cnacw",
"CNST","Constellation Pharmaceuticals, Inc.","13.2","340635622.8","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cnst",
"ROAD","Construction Partners, Inc.","12.02","618003720.38","n/a","2018","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/road",
"CPSS","Consumer Portfolio Services, Inc.","3.55","78627480.3","n/a","1992","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/cpss",
"CFRX","ContraFect Corporation","0.4","31763822.4","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cfrx",
"CTRV","ContraVir Pharmaceuticals Inc.","0.2781","5700863.9511","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ctrv",
"CTRL","Control4 Corporation","16.93","450620849.51","n/a","2013","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/ctrl",
"AWSM","Cool Holdings Inc.","3.35","26106275.3","n/a","n/a","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/awsm",
"CPRT","Copart, Inc.","63.16","14413485022.96","n/a","1994","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/cprt",
"CRBP","Corbus Pharmaceuticals Holdings, Inc.","7.23","465577447.83","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/crbp",
"CORT","Corcept Therapeutics Incorporated","11.41","1308992636.21","n/a","2004","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cort",
"CORE","Core-Mark Holding Company, Inc.","37.34","1712793305.34","n/a","n/a","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/core",
"CSOD","Cornerstone OnDemand, Inc.","54.4","3215051424","n/a","2011","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/csod",
"CORV","Correvio Pharma Corp.","3.11","121924262.73","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/corv",
"CLDB","Cortland Bancorp","23.95","104173494.8","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/cldb",
"CRVL","CorVel Corp.","65.47","1220241579.13","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/crvl",
"CRVS","Corvus Pharmaceuticals, Inc.","4.03","118187407","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/crvs",
"CSGP","CoStar Group, Inc.","478.74","17450948615.46","n/a","1998","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/csgp",
"COST","Costco Wholesale Corporation","240.5","105791201808.5","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/cost",
"CPAH","CounterPath Corporation","1.7","10114156.8","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cpah",
"ICBK","County Bancorp, Inc.","17.1","114732108","n/a","2015","Finance","Major Banks","https://www.nasdaq.com/symbol/icbk",
"COUP","Coupa Software Incorporated","91.19","5566560959.74","n/a","2016","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/coup",
"CVTI","Covenant Transportation Group, Inc.","20.33","373431869.29","n/a","1994","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/cvti",
"CVET","Covetrus, Inc.","32.45","3612946688.45","n/a","n/a","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/cvet",
"COWN","Cowen Inc.","15.06","443848756.74","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/cown",
"COWNL","Cowen Inc.","25.6","0","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/cownl",
"COWNZ","Cowen Inc.","25.32","0","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/cownz",
"PMTS","CPI Card Group Inc.","3.4272","38249392.4064","n/a","2015","Finance","Finance Companies","https://www.nasdaq.com/symbol/pmts",
"CPSH","CPS Technologies Corp.","1.6","21129499.2","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/cpsh",
"CRAI","CRA International,Inc.","50.55","406944383.7","n/a","1998","Miscellaneous","Other Consumer Services","https://www.nasdaq.com/symbol/crai",
"CBRL","Cracker Barrel Old Country Store, Inc.","155.28","3733144554.72","n/a","1981","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/cbrl",
"BREW","Craft Brew Alliance, Inc.","13.75","266511313.75","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/brew",
"CRAY","Cray Inc","26.47","1082363302.83","n/a","n/a","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/cray",
"CREX","Creative Realities, Inc.","2.29","22269851.54","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/crex",
"CREXW","Creative Realities, Inc.","0.3788","0","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/crexw",
"CACC","Credit Acceptance Corporation","455.76","8559303603.12","n/a","1992","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/cacc",
"DGLD","Credit Suisse AG","46.389","18741619.89","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/dgld",
"DSLV","Credit Suisse AG","30.25","29007814","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/dslv",
"GLDI","Credit Suisse AG","8.55","35835837.3","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/gldi",
"SLVO","Credit Suisse AG","6.72","22185360.96","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/slvo",
"TVIX","Credit Suisse AG","25.15","821985271.65","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/tvix",
"UGLD","Credit Suisse AG","94.58","112695191.14","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/ugld",
"USLV","Credit Suisse AG","65.45","222609521.75","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/uslv",
"USOI","Credit Suisse AG","23.9372","7899276","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/usoi",
"VIIX","Credit Suisse AG","12.12","44228037.36","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/viix",
"ZIV","Credit Suisse AG","74.7","101816100","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/ziv",
"CREE","Cree, Inc.","60.38","6232680335.76","n/a","1993","Technology","Semiconductors","https://www.nasdaq.com/symbol/cree",
"CRSAU","Crescent Acquisition Corp","10.03","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/crsau",
"CRESY","Cresud S.A.C.I.F. y A.","11.54","460508223.68","39905392","1997","Finance","Real Estate","https://www.nasdaq.com/symbol/cresy",
"CRNX","Crinetics Pharmaceuticals, Inc.","23.08","556123793.8","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/crnx",
"CRSP","CRISPR Therapeutics AG","37.9","1981380429.3","n/a","2016","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/crsp",
"CRTO","Criteo S.A.","20.06","1263771053.24","62999554","2013","Technology","Advertising","https://www.nasdaq.com/symbol/crto",
"CROX","Crocs, Inc.","26.39","1935345801.48","n/a","2006","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/crox",
"CRON","Cronos Group Inc.","18.26","5999344473.76","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/cron",
"CCRN","Cross Country Healthcare, Inc.","7.41","267796481.16","n/a","2001","Technology","Professional Services","https://www.nasdaq.com/symbol/ccrn",
"CRWS","Crown Crafts, Inc.","5.17","52333624.86","n/a","n/a","Basic Industries","Textiles","https://www.nasdaq.com/symbol/crws",
"CYRX","CryoPort, Inc.","12.48","379845298.56","n/a","n/a","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/cyrx",
"CYRXW","CryoPort, Inc.","8.9","0","n/a","n/a","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/cyrxw",
"CSGS","CSG Systems International, Inc.","43.58","1437582437.48","n/a","1996","Technology","EDP Services","https://www.nasdaq.com/symbol/csgs",
"CCLP","CSI Compressco LP","2.9","136226722.8","n/a","2011","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/cclp",
"CSPI","CSP Inc.","11.57","46502768.78","n/a","1982","Technology","EDP Services","https://www.nasdaq.com/symbol/cspi",
"CSWI","CSW Industrials, Inc.","57.22","862401758.48","n/a","n/a","Basic Industries","Home Furnishings","https://www.nasdaq.com/symbol/cswi",
"CSX","CSX Corporation","76.18","61910475624.66","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/csx",
"CTIC","CTI BioPharma Corp.","0.987","57225593.775","n/a","1997","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ctic",
"CTIB","CTI Industries Corporation","3.19","11837930.5","n/a","1997","Basic Industries","Specialty Chemicals","https://www.nasdaq.com/symbol/ctib",
"CTRP","Ctrip.com International, Ltd.","44.62","21726205841.44","486916312","2003","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ctrp",
"CUE","Cue Biopharma, Inc.","8.95","185571376.4","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cue",
"CUI","CUI Global, Inc.","1.2","34298343.6","n/a","n/a","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/cui",
"CPIX","Cumberland Pharmaceuticals Inc.","6","92684478","n/a","2009","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cpix",
"CMLS","Cumulus Media Inc.","18.39","256117658.73","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/cmls",
"CRIS","Curis, Inc.","2.17","71937192.6","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/cris",
"CUTR","Cutera, Inc.","17.16","240489008.76","n/a","2004","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/cutr",
"CVBF","CVB Financial Corporation","21.21","2968827690.57","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cvbf",
"CVV","CVD Equipment Corporation","3.78","24598402.92","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cvv",
"CYAN","Cyanotech Corporation","3.28","19142440.8","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/cyan",
"CYBR","CyberArk Software Ltd.","119.57","4447293036.78","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cybr",
"CYBE","CyberOptics Corporation","17.15","121800586.25","n/a","1987","Capital Goods","Electronic Components","https://www.nasdaq.com/symbol/cybe",
"CYCC","Cyclacel Pharmaceuticals, Inc.","0.88","15135977.12","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cycc",
"CYCCP","Cyclacel Pharmaceuticals, Inc.","4.91","1646190.43","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cyccp",
"CYCN","Cyclerion Therapeutics, Inc.","14.49","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cycn",
"CBAY","CymaBay Therapeutics Inc.","13.31","791550598.08","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cbay",
"CY","Cypress Semiconductor Corporation","15.39","5611087285.74","n/a","1986","Technology","Semiconductors","https://www.nasdaq.com/symbol/cy",
"CYRN","CYREN Ltd.","2.14","114992148.86","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cyrn",
"CONE","CyrusOne Inc","54.37","5889875404.33","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cone",
"CYTK","Cytokinetics, Incorporated","8.09","444046905.21","n/a","2004","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cytk",
"CTMX","CytomX Therapeutics, Inc.","10.68","481788491.76","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ctmx",
"CYTX","Cytori Therapeutics Inc.","0.2688","4388459.9808","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/cytx",
"CYTXZ","Cytori Therapeutics Inc.","0.0028","0","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/cytxz",
"CTSO","Cytosorbents Corporation","7.47","237957589.53","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/ctso",
"CYTR","CytRx Corporation","0.669","22503488.169","n/a","1986","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/cytr",
"DJCO","Daily Journal Corp. (S.C.)","216","298241136","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/djco",
"DAKT","Daktronics, Inc.","7.45","335343303.8","n/a","1994","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/dakt",
"DARE","Dare Bioscience, Inc.","1.66","18960787.26","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/dare",
"DRIO","DarioHealth Corp.","0.7181","26441284.3313","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/drio",
"DRIOW","DarioHealth Corp.","0.0219","0","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/driow",
"DZSI","DASAN Zhone Solutions, Inc.","10.58","175590790.14","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/dzsi",
"DSKE","Daseke, Inc.","5.29","341044564.88","n/a","2015","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/dske",
"DSKEW","Daseke, Inc.","0.37","0","n/a","2015","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/dskew",
"DAIO","Data I/O Corporation","5.17","43145909.29","n/a","1981","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/daio",
"DTSS","Datasea Inc.","2.0626","43198776.7596","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/dtss",
"PLAY","Dave & Buster&#39;s Entertainment, Inc.","50.48","1950740336.48","n/a","2014","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/play",
"DTEA","DAVIDsTEA Inc.","1.35","35110471.95","n/a","2015","Consumer Non-Durables","Food Chains","https://www.nasdaq.com/symbol/dtea",
"DFNL","Davis Select Financial ETF","22.5113","141821190","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dfnl",
"DINT","Davis Select International ETF","18.13","112406000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dint",
"DUSA","Davis Select U.S. Equity ETF","22.9715","184920575","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dusa",
"DWLD","Davis Select Worldwide ETF","23.57","214487000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwld",
"DWSN","Dawson Geophysical Company","2.91","67342460.49","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/dwsn",
"DBVT","DBV Technologies S.A.","7.7","206184101.2","26777156","2014","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/dbvt",
"DDMX","DD3 Acquisition Corp.","10","72232000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/ddmx",
"DDMXU","DD3 Acquisition Corp.","10.12","73098784","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/ddmxu",
"DDMXW","DD3 Acquisition Corp.","0.3","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/ddmxw",
"DCPH","Deciphera Pharmaceuticals, Inc.","23.54","898970284.08","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/dcph",
"DFRG","Del Frisco&#39;s Restaurant Group, Inc.","6.45","215160983.4","n/a","2012","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/dfrg",
"TACO","Del Taco Restaurants, Inc.","10.17","377373735.54","n/a","2014","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/taco",
"TACOW","Del Taco Restaurants, Inc.","1.2999","0","n/a","2014","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/tacow",
"DMPI","DelMar Pharmaceuticals, Inc.","0.434","11104121.322","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/dmpi",
"DNLI","Denali Therapeutics Inc.","25.64","2443211165.08","n/a","2017","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/dnli",
"DENN","Denny&#39;s Corporation","18.08","1112984586.56","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/denn",
"XRAY","DENTSPLY SIRONA Inc.","50.15","11194389620.7","n/a","1987","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/xray",
"DERM","Dermira, Inc.","13.06","700162089.16","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/derm",
"DEST","Destination Maternity Corporation","2.23","32217978.52","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/dest",
"DXLG","Destination XL Group, Inc.","2.5","123805582.5","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/dxlg",
"DSWL","Deswell Industries, Inc.","3.03","48132274.17","n/a","1995","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/dswl",
"DXCM","DexCom, Inc.","116.98","10528406703.66","n/a","2005","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/dxcm",
"DFBH","DFB Healthcare Acquisitions Corp.","10.02","313125000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/dfbh",
"DFBHU","DFB Healthcare Acquisitions Corp.","10.15","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/dfbhu",
"DFBHW","DFB Healthcare Acquisitions Corp.","1.1","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/dfbhw",
"DHXM","DHX Media Ltd.","1.6101","217196208.9999","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dhxm",
"DMAC","DiaMedica Therapeutics Inc.","4.01","47947064.74","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/dmac",
"DHIL","Diamond Hill Investment Group, Inc.","140.96","494264540.32","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/dhil",
"FANG","Diamondback Energy, Inc.","102.49","16847462189.78","n/a","2012","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/fang",
"DPHCU","DiamondPeak Holdings Corp.","10.02","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/dphcu",
"DRNA","Dicerna Pharmaceuticals, Inc.","14.96","1021243637.04","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/drna",
"DFFN","Diffusion Pharmaceuticals Inc.","3.97","13415999.65","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/dffn",
"DGII","Digi International Inc.","12.53","346767787.59","n/a","1989","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/dgii",
"DMRC","Digimarc Corporation","34","397800000","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/dmrc",
"DRAD","Digirad Corporation","0.8497","17257328.8276","n/a","2004","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/drad",
"DGLY","Digital Ally, Inc.","3.91","43260384.67","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/dgly",
"APPS","Digital Turbine, Inc.","3.72","292282334.4","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/apps",
"DCOM","Dime Community Bancshares, Inc.","19.17","688124096.28","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/dcom",
"DIOD","Diodes Incorporated","36.7","1898858734","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/diod",
"DISCA","Discovery, Inc.","27.39","4321269738.06","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/disca",
"DISCB","Discovery, Inc.","31.5","205139907","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/discb",
"DISCK","Discovery, Inc.","25.85","9319837401.6","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/disck",
"DISH","DISH Network Corporation","33.22","7622599543.68","n/a","1995","Consumer Services","Television Services","https://www.nasdaq.com/symbol/dish",
"DVCR","Diversicare Healthcare Services Inc.","3.93","25617972.24","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/dvcr",
"SAUC","Diversified Restaurant Holdings, Inc.","0.8805","29233223.394","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/sauc",
"DLHC","DLH Holdings Corp.","6.4","77031430.4","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/dlhc",
"BOOM","DMC Global Inc.","50.8","761417222.4","n/a","n/a","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/boom",
"DNBF","DNB Financial Corp","38.6","167038219","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/dnbf",
"DOCU","DocuSign, Inc.","53.72","9127028000","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/docu",
"DOGZ","Dogness (International) Corporation","3.56","92252526.36","n/a","2017","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/dogz",
"DLTR","Dollar Tree, Inc.","104.11","24799454982.61","n/a","1995","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/dltr",
"DLPN","Dolphin Entertainment, Inc.","1.7","24009366.9","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/dlpn",
"DLPNW","Dolphin Entertainment, Inc.","0.0308","0","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/dlpnw",
"DOMO","Domo, Inc.","40.76","1073533741.48","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/domo",
"DGICA","Donegal Group, Inc.","13.29","377792995.98","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/dgica",
"DGICB","Donegal Group, Inc.","12.12","344533567.44","n/a","1986","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/dgicb",
"DMLP","Dorchester Minerals, L.P.","18.75","605245762.5","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/dmlp",
"DORM","Dorman Products, Inc.","88.78","2929295300.98","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/dorm",
"DOVA","Dova Pharmaceuticals, Inc.","9.05","255450295.6","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/dova",
"LYL","Dragon Victory International Limited","1.4059","16057337.8246","n/a","2017","Finance","Finance/Investors Services","https://www.nasdaq.com/symbol/lyl",
"DBX","Dropbox, Inc.","22.13","9101490057.07","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/dbx",
"DCAR","DropCar, Inc.","2.675","9202690.15","n/a","n/a","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/dcar",
"DRYS","DryShips Inc.","4.61","400547350.47","n/a","2005","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/drys",
"DSPG","DSP Group, Inc.","14.81","335087416.74","n/a","1994","Technology","Semiconductors","https://www.nasdaq.com/symbol/dspg",
"DLTH","Duluth Holdings Inc.","23.17","754852556.92","n/a","2015","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/dlth",
"DNKN","Dunkin&#39; Brands Group, Inc.","75.29","6221674528.86","n/a","2011","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/dnkn",
"DRRX","DURECT Corporation","0.6214","100703908.7652","n/a","2000","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/drrx",
"DXPE","DXP Enterprises, Inc.","40.26","707837712.12","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/dxpe",
"DYSL","Dynasil Corporation of America","1.13","19736064.72","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/dysl",
"DYNT","Dynatronics Corporation","1.99","16444456.54","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/dynt",
"DVAX","Dynavax Technologies Corporation","7.56","483816647.16","n/a","2004","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/dvax",
"ETFC","E*TRADE Financial Corporation","48.06","11781267543.18","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/etfc",
"SSP","E.W. Scripps Company (The)","21.29","1464828835.61","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/ssp",
"EBMT","Eagle Bancorp Montana, Inc.","16.89","108732617.88","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ebmt",
"EGBN","Eagle Bancorp, Inc.","51.16","1766800419.16","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/egbn",
"EGLE","Eagle Bulk Shipping Inc.","4.71","344702216.64","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/egle",
"EFBI","Eagle Financial Bancorp, Inc.","15.6742","25748917.4436","n/a","2017","Finance","Savings Institutions","https://www.nasdaq.com/symbol/efbi",
"EGRX","Eagle Pharmaceuticals, Inc.","50.72","706240293.12","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/egrx",
"EWBC","East West Bancorp, Inc.","50.6","7344417707","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ewbc",
"EML","Eastern Company (The)","28.74","179090694.66","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/eml",
"EAST","Eastside Distilling, Inc.","6.11","55615034.67","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/east",
"EVGBC","Eaton Vance NextShares Trust","100.02","62512500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/evgbc",
"EVSTC","Eaton Vance NextShares Trust","99.98","44991000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/evstc",
"EVFTC","Eaton Vance NextShares Trust II","100.03","52515750","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/evftc",
"EVLMC","Eaton Vance NextShares Trust II","100.04","70028000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/evlmc",
"OKDCC","Eaton Vance NextShares Trust II","100.06","505303000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/okdcc",
"EBAY","eBay Inc.","37.92","34692266701.92","n/a","1998","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ebay",
"EBAYL","eBay Inc.","26.22","0","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ebayl",
"EBIX","Ebix, Inc.","49.42","1509593797.04","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/ebix",
"ECHO","Echo Global Logistics, Inc.","25.14","699348115.02","n/a","2009","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/echo",
"SATS","EchoStar Corporation","37.67","1795292267.03","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/sats",
"EEI","Ecology and Environment, Inc.","10.555","45525139.925","n/a","1987","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/eei",
"EDAP","EDAP TMS S.A.","4.25","124704749.5","29342294","1997","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/edap",
"EDNT","Edison Nation, Inc.","5.09","25791559.36","n/a","2018","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/ednt",
"EDIT","Editas Medicine, Inc.","26.02","1277380371.02","n/a","2016","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/edit",
"EDTX","EdtechX Holdings Acquisition Corp.","10.05","79457812.5","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/edtx",
"EDTXU","EdtechX Holdings Acquisition Corp.","10.2","80643750","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/edtxu",
"EDTXW","EdtechX Holdings Acquisition Corp.","0.19","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/edtxw",
"EDUC","Educational Development Corporation","7.75","63533151.5","n/a","n/a","Consumer Durables","Consumer Specialties","https://www.nasdaq.com/symbol/educ",
"EGAN","eGain Corporation","10.4","290184180","n/a","1999","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/egan",
"EHTH","eHealth, Inc.","61.83","1394005515.57","n/a","2006","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/ehth",
"EIDX","Eidos Therapeutics, Inc.","23.52","864293720.64","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/eidx",
"EIGR","Eiger BioPharmaceuticals, Inc.","14.83","285632369.69","n/a","2014","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/eigr",
"EKSO","Ekso Bionics Holdings, Inc.","2.51","161283759.78","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/ekso",
"LOCO","El Pollo Loco Holdings, Inc.","12.37","481969415.42","n/a","2014","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/loco",
"ESLT","Elbit Systems Ltd.","134.68","5757998551.76","n/a","n/a","Capital Goods","Military/Government/Technical","https://www.nasdaq.com/symbol/eslt",
"ERI","Eldorado Resorts, Inc.","47.87","3706764718.34","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/eri",
"SOLO","Electrameccanica Vehicles Corp. Ltd.","3.77","138754838.69","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/solo",
"SOLOW","Electrameccanica Vehicles Corp. Ltd.","1.05","0","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/solow",
"ECOR","electroCore, Inc.","6.15","181100255.4","n/a","2018","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/ecor",
"EA","Electronic Arts Inc.","100.84","30211217278.8","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ea",
"EFII","Electronics for Imaging, Inc.","27.88","1188864089.92","n/a","1992","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/efii",
"ELSE","Electro-Sensors, Inc.","3.4579","11741372.0659","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/else",
"ESBK","Elmira Savings Bank NY (The)","17","51653004","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/esbk",
"ELOX","Eloxx Pharmaceuticals, Inc.","11.58","415260120.12","n/a","n/a","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/elox",
"ELTK","Eltek Ltd.","1.59","3225397.68","n/a","1997","Technology","Electrical Products","https://www.nasdaq.com/symbol/eltk",
"EMCI","EMC Insurance Group Inc.","31.89","690119276.13","n/a","1982","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/emci",
"EMCF","Emclaire Financial Corp","31","83660072","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/emcf",
"EMKR","EMCORE Corporation","3.99","110405159.34","n/a","1997","Technology","Semiconductors","https://www.nasdaq.com/symbol/emkr",
"EMMS","Emmis Communications Corporation","3.63","47269420.77","n/a","1994","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/emms",
"NYNY","Empire Resorts, Inc.","10.49","361099892.5","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/nyny",
"ENTA","Enanta Pharmaceuticals, Inc.","95.95","1865419984.8","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/enta",
"ECPG","Encore Capital Group Inc","27.81","858894969.33","n/a","n/a","Finance","Finance Companies","https://www.nasdaq.com/symbol/ecpg",
"WIRE","Encore Wire Corporation","58.23","1216666238.04","n/a","1992","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/wire",
"ENDP","Endo International plc","7.95","1784013763.65","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/endp",
"ELGX","Endologix, Inc.","7.03","7272795.11","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/elgx",
"NDRA","ENDRA Life Sciences Inc.","1.74","12915397.08","n/a","2017","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/ndra",
"NDRAW","ENDRA Life Sciences Inc.","0.6","0","n/a","2017","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/ndraw",
"EIGI","Endurance International Group Holdings, Inc.","7.4","1065500114.8","n/a","2013","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/eigi",
"WATT","Energous Corporation","6.18","164903770.44","n/a","2014","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/watt",
"EFOI","Energy Focus, Inc.","0.51","6159861.6","n/a","n/a","Consumer Durables","Building Products","https://www.nasdaq.com/symbol/efoi",
"ERII","Energy Recovery, Inc.","8.92","482634975.2","n/a","2008","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/erii",
"ENG","ENGlobal Corporation","0.52","14253151.64","n/a","n/a","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/eng",
"ENLV","Enlivex Therapeutics Ltd.","11.18","110333284.62","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/enlv",
"ENOB","Enochian Biosciences, Inc.","6.98","270749383.8","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/enob",
"ENPH","Enphase Energy, Inc.","9.35","1014658241.3","n/a","2012","Technology","Semiconductors","https://www.nasdaq.com/symbol/enph",
"ESGR","Enstar Group Limited","174","3736556214","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/esgr",
"ESGRO","Enstar Group Limited","25.715","113146","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/esgro",
"ESGRP","Enstar Group Limited","25.78","412480","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/esgrp",
"ETTX","Entasis Therapeutics Holdings Inc.","6.45","84669975.6","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ettx",
"ENFC","Entegra Financial Corp.","22.79","157710058.97","n/a","2014","Finance","Banks","https://www.nasdaq.com/symbol/enfc",
"ENTG","Entegris, Inc.","36.71","4974705577.56","n/a","2000","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/entg",
"ENTX","Entera Bio Ltd.","4.27","48933260.6","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/entx",
"ENTXW","Entera Bio Ltd.","0.85","0","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/entxw",
"EBTC","Enterprise Bancorp Inc","29.58","346748976.54","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ebtc",
"EFSC","Enterprise Financial Services Corporation","41.67","1119917752.92","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/efsc",
"EPZM","Epizyme, Inc.","12.93","1024446136.89","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/epzm",
"PLUS","ePlus inc.","90.35","1229774178.75","n/a","1996","Technology","Retail: Computer Software & Peripheral Equipment","https://www.nasdaq.com/symbol/plus",
"EPSN","Epsilon Energy Ltd.","4.2801","117083192.6847","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/epsn",
"EQ","Equillium, Inc.","7.41","128757908.76","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/eq",
"EQIX","Equinix, Inc.","460.44","38608357202.64","n/a","2000","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/eqix",
"EQBK","Equity Bancshares, Inc.","28.28","446925440.36","n/a","2015","Finance","Major Banks","https://www.nasdaq.com/symbol/eqbk",
"ERIC","Ericsson","9.47","2959975038.14","312563362","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/eric",
"ERIE","Erie Indemnity Company","177.4","9276222583.2","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/erie",
"ERYP","Erytech Pharma S.A.","7.93","15102185.41","1904437","2017","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/eryp",
"ESCA","Escalade, Incorporated","11.67","168882358.32","n/a","n/a","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/esca",
"ESPR","Esperion Therapeutics, Inc.","43.42","1164735377.78","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/espr",
"ESQ","Esquire Financial Holdings, Inc.","22.3","167979722.9","n/a","2017","Finance","Commercial Banks","https://www.nasdaq.com/symbol/esq",
"ESSA","ESSA Bancorp, Inc.","15.57","184034503.98","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/essa",
"EPIX","ESSA Pharma Inc.","3.57","22530619.86","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/epix",
"ESTA","Establishment Labs Holdings Inc.","24.15","492396837.45","n/a","2018","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/esta",
"ESTR","Estre Ambiental, Inc.","1.31","67054618.92","n/a","n/a","Public Utilities","Environmental Services","https://www.nasdaq.com/symbol/estr",
"ESTRW","Estre Ambiental, Inc.","0.1171","0","n/a","n/a","Public Utilities","Environmental Services","https://www.nasdaq.com/symbol/estrw",
"VBND","ETF Series Solutions Trust Vident Core U.S. Bond Strategy Fund","48.67","418562000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vbnd",
"VUSE","ETF Series Solutions Trust Vident Core US Equity ETF","31.2503","475004560","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vuse",
"VIDI","ETF Series Solutions Trust Vident International Equity Fund","24.59","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vidi",
"ETON","Eton Pharmaceuticals, Inc.","8.09","142609937.52","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/eton",
"ETSY","Etsy, Inc.","69.73","8337364583.89","n/a","2015","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/etsy",
"CLWT","Euro Tech Holdings Company Limited","5.23","10783784.07","n/a","1997","Consumer Durables","Diversified Electronic Products","https://www.nasdaq.com/symbol/clwt",
"EDRY","EuroDry Ltd.","8.4","18934692","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/edry",
"EEFT","Euronet Worldwide, Inc.","141.33","7330962066.54","n/a","1997","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/eeft",
"ESEA","Euroseas Ltd.","0.71","8004629.46","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/esea",
"EVLO","Evelo Biosciences, Inc.","8.37","266749723.8","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/evlo",
"EVBG","Everbridge, Inc.","75.14","2465183802.64","n/a","2016","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/evbg",
"EVK","Ever-Glory International Group, Inc.","3.78","55944529.2","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/evk",
"EVER","EverQuote, Inc.","8","200212744","n/a","2018","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/ever",
"MRAM","Everspin Technologies, Inc.","7.57","129413328.64","n/a","2016","Technology","Semiconductors","https://www.nasdaq.com/symbol/mram",
"EVLV","EVINE Live Inc.","0.4656","31636898.424","n/a","n/a","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/evlv",
"EVOP","EVO Payments, Inc.","28.42","752877346.2","n/a","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/evop",
"EVFM","Evofem Biosciences, Inc.","3.5","98547984.5","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/evfm",
"EVGN","Evogene Ltd.","1.8","46357734.6","n/a","n/a","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/evgn",
"EVOK","Evoke Pharma, Inc.","0.9","15684779.7","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/evok",
"EOLS","Evolus, Inc.","22.6","616414796.6","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/eols",
"EVOL","Evolving Systems, Inc.","1.18","14298076.52","n/a","1998","Technology","EDP Services","https://www.nasdaq.com/symbol/evol",
"EXAS","Exact Sciences Corporation","91.86","11552396917.02","n/a","2001","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/exas",
"FLAG","Exchange Traded Concepts Trust FLAG-Forensic Accounting Long-S","39.1909","15676360","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/flag",
"ROBO","Exchange Traded Concepts Trust ROBO Global Robotics and Automa","39.78","182988000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/robo",
"XELA","Exela Technologies, Inc.","3.5","525497332.5","n/a","2015","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/xela",
"EXEL","Exelixis, Inc.","24.73","7422205749.9","n/a","2000","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/exel",
"EXFO","EXFO Inc","3.8575","91604295.5225","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/exfo",
"EXLS","ExlService Holdings, Inc.","60.09","2062489440.51","n/a","2006","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/exls",
"EXPI","eXp World Holdings, Inc.","10.67","650641704.68","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/expi",
"EXPE","Expedia Group, Inc.","120.44","17727600213.76","n/a","n/a","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/expe",
"EXPD","Expeditors International of Washington, Inc.","78.09","13420304305.83","n/a","n/a","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/expd",
"EXPO","Exponent, Inc.","56.89","2929742212.41","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/expo",
"STAY","Extended Stay America, Inc.","17.98","3384365349.18","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/stay",
"XOG","Extraction Oil & Gas, Inc.","4.25","729106013","n/a","2016","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/xog",
"EXTR","Extreme Networks, Inc.","7.78","908389835.82","n/a","1999","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/extr",
"EYEG","Eyegate Pharmaceuticals, Inc.","0.3521","15418718.4977","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/eyeg",
"EYEGW","Eyegate Pharmaceuticals, Inc.","0.041","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/eyegw",
"EYEN","Eyenovia, Inc.","5.66","68028377.68","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/eyen",
"EYPT","EyePoint Pharmaceuticals, Inc.","1.88","179303563.68","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/eypt",
"EZPW","EZCORP, Inc.","9.5","526729789.5","n/a","1991","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/ezpw",
"FFIV","F5 Networks, Inc.","165.32","9826841171.56","n/a","1999","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/ffiv",
"FB","Facebook, Inc.","174.2","497165023160","n/a","2012","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/fb",
"FLMN","Falcon Minerals Corporation","9.1","781280500","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/flmn",
"FLMNW","Falcon Minerals Corporation","0.99","0","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/flmnw",
"DAVE","Famous Dave&#39;s of America, Inc.","5.8","53788649","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/dave",
"FANH","Fanhua Inc.","26.11","943005000.42","36116622","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/fanh",
"FARM","Farmer Brothers Company","19.85","337500200.65","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/farm",
"FMAO","Farmers & Merchants Bancorp, Inc.","29.82","331469011.02","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/fmao",
"FMNB","Farmers National Banc Corp.","14.1","391847488.2","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fmnb",
"FAMI","FARMMI, INC.","3.76","44864320","n/a","2018","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/fami",
"FARO","FARO Technologies, Inc.","44.55","768621640.05","n/a","1997","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/faro",
"FAST","Fastenal Company","66.01","18889306874.62","n/a","1987","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/fast",
"FAT","FAT Brands Inc.","5.4","63759684.6","n/a","2017","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/fat",
"FATE","Fate Therapeutics, Inc.","18.41","1197239340.92","n/a","2013","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/fate",
"FBSS","Fauquier Bankshares, Inc.","21.42","81084424.68","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fbss",
"FLF","Federal Life Group, Inc.","12","42363000","n/a","2018","Finance","Life Insurance","https://www.nasdaq.com/symbol/flf",
"FNHC","FedNat Holding Company","16.38","209409192.72","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/fnhc",
"FENC","Fennec Pharmaceuticals Inc.","5.09","101269774.7","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/fenc",
"GSM","Ferroglobe PLC","2.19","376629040.89","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/gsm",
"FFBW","FFBW, Inc.","10.9","72840405.4","n/a","2017","Finance","Savings Institutions","https://www.nasdaq.com/symbol/ffbw",
"FCSC","Fibrocell Science Inc.","1.86","18150497.52","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/fcsc",
"FGEN","FibroGen, Inc","54.5","4663150309.5","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/fgen",
"FDBC","Fidelity D & D Bancorp, Inc.","59.5","226622826.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fdbc",
"ONEQ","Fidelity Nasdaq Composite Index Tracking Stock","307.6","2008628000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/oneq",
"LION","Fidelity Southern Corporation","28.1","775442682.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/lion",
"FDUS","Fidus Investment Corporation","15.43","377465926.17","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/fdus",
"FDUSL","Fidus Investment Corporation","25.5908","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fdusl",
"FDUSZ","Fidus Investment Corporation","25.5453","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fdusz",
"FRGI","Fiesta Restaurant Group, Inc.","12.92","350999151.64","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/frgi",
"FITB","Fifth Third Bancorp","26.22","20218492138.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fitb",
"FITBI","Fifth Third Bancorp","27.06","487080","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fitbi",
"FISI","Financial Institutions, Inc.","27.15","432461435.7","n/a","1999","Finance","Major Banks","https://www.nasdaq.com/symbol/fisi",
"FNSR","Finisar Corporation","23.65","2788414274.8","n/a","1999","Technology","Semiconductors","https://www.nasdaq.com/symbol/fnsr",
"FNJN","Finjan Holdings, Inc.","2.93","80855811.2","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/fnjn",
"FTAC","FinTech Acquisition Corp. III","9.79","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/ftac",
"FTACU","FinTech Acquisition Corp. III","10.22","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/ftacu",
"FTACW","FinTech Acquisition Corp. III","0.9","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/ftacw",
"FEYE","FireEye, Inc.","16.69","3389630681.9","n/a","2013","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/feye",
"FBNC","First Bancorp","35.35","1051381891.7","n/a","1987","Finance","Major Banks","https://www.nasdaq.com/symbol/fbnc",
"FNLC","First Bancorp, Inc (ME)","25.71","279821752.41","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fnlc",
"FRBA","First Bank","11.51","215513792.48","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/frba",
"BUSE","First Busey Corporation","24.73","1374992550.32","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/buse",
"FBIZ","First Business Financial Services, Inc.","20.68","181546804.12","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fbiz",
"FCAP","First Capital, Inc.","52.74","177443413.56","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/fcap",
"FCBP","First Choice Bancorp","21.33","248302956.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fcbp",
"FCNCA","First Citizens BancShares, Inc.","420","4831262100","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fcnca",
"FCBC","First Community Bankshares, Inc.","33.33","526586902.71","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fcbc",
"FCCO","First Community Corporation","19.24","147445624.56","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fcco",
"FDEF","First Defiance Financial Corp.","28.9","573939232.1","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/fdef",
"FFBC","First Financial Bancorp.","24.52","2412510319.32","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ffbc",
"FFIN","First Financial Bankshares, Inc.","58.89","3993726287.46","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ffin",
"THFF","First Financial Corporation Indiana","42.5","522225082.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/thff",
"FFNW","First Financial Northwest, Inc.","16.24","170673062","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ffnw",
"FFWM","First Foundation Inc.","13.82","615012291.66","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ffwm",
"FGBI","First Guaranty Bancshares, Inc.","21.4","188473545","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/fgbi",
"FHB","First Hawaiian, Inc.","26.37","3556635343.74","n/a","2016","Finance","Major Banks","https://www.nasdaq.com/symbol/fhb",
"INBK","First Internet Bancorp","19.68","198871005.12","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/inbk",
"INBKL","First Internet Bancorp","25.8244","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/inbkl",
"FIBK","First Interstate BancSystem, Inc.","40.21","1539319059.16","n/a","2010","Finance","Major Banks","https://www.nasdaq.com/symbol/fibk",
"FRME","First Merchants Corporation","37.45","1861167143.15","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/frme",
"FMBH","First Mid-Illinois Bancshares, Inc.","32.99","549988397.33","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fmbh",
"FMBI","First Midwest Bancorp, Inc.","20.9","2233124767.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fmbi",
"FNWB","First Northwest Bancorp","16.1","177759794.1","n/a","2015","Finance","Banks","https://www.nasdaq.com/symbol/fnwb",
"FSFG","First Savings Financial Group, Inc.","54.5","125584895","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/fsfg",
"FSLR","First Solar, Inc.","53.9","5653817430.8","n/a","2006","Technology","Semiconductors","https://www.nasdaq.com/symbol/fslr",
"FAAR","First Trust Alternative Absolute Return Strategy ETF","26.8132","28153913.6264","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/faar",
"FPA","First Trust Asia Pacific Ex-Japan AlphaDEX Fund","30.96","38700061.92","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fpa",
"BICK","First Trust BICK Index Fund","27.65","154840055.3","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bick",
"FBZ","First Trust Brazil AlphaDEX Fund","14.54","139584029.08","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fbz",
"FTHI","First Trust BuyWrite Income ETF","21.8","62657581.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fthi",
"FCAL","First Trust California Municipal High income ETF","51.223","23050452.446","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fcal",
"FCAN","First Trust Canada AlphaDEX Fund","23.221","9288446.442","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fcan",
"FTCS","First Trust Capital Strength ETF","54.6","2014740109.2","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftcs",
"FCEF","First Trust CEF Income Opportunity ETF","21.6227","36866703.5","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fcef",
"FCA","First Trust China AlphaDEX Fund","27.86","9751055.72","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fca",
"SKYY","First Trust Cloud Computing ETF","58.74","2170443117.48","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/skyy",
"RNDM","First Trust Developed International Equity Select ETF","50.04","25020100.08","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rndm",
"FDT","First Trust Developed Markets Ex-US AlphaDEX Fund","55.2","1048910400","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fdt",
"FDTS","First Trust Developed Markets ex-US Small Cap AlphaDEX Fund","36.9758","9244023.9516","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fdts",
"FVC","First Trust Dorsey Wright Dynamic Focus 5 ETF","27","535950054","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fvc",
"FV","First Trust Dorsey Wright Focus 5 ETF","30.58","2486154061.16","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fv",
"IFV","First Trust Dorsey Wright International Focus 5 ETF","19.46","575043038.92","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ifv",
"DDIV","First Trust Dorsey Wright Momentum & Dividend ETF","24.3529","30441173.7058","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ddiv",
"DVOL","First Trust Dorsey Wright Momentum & Low Volatility ETF","20.45","25562540.9","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dvol",
"DVLU","First Trust Dorsey Wright Momentum & Value ETF","17.95","17950035.9","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dvlu",
"DWPP","First Trust Dorsey Wright People&#39;s Portfolio ETF","30.19","45285060.38","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwpp",
"DALI","First Trust DorseyWright DALI 1 ETF","20.3566","63105500.7132","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dali",
"FDNI","First Trust Dow Jones International Internet ETF","22.515","3377295.03","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fdni",
"FEM","First Trust Emerging Markets AlphaDEX Fund","25.4","679450050.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fem",
"RNEM","First Trust Emerging Markets Equity Select ETF","51.585","12896353.17","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rnem",
"FEMB","First Trust Emerging Markets Local Currency Bond ETF","38.04","87492076.08","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/femb",
"FEMS","First Trust Emerging Markets Small Cap AlphaDEX Fund","36.05","158620072.1","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fems",
"FTSM","First Trust Enhanced Short Maturity ETF","59.98","4285554445.52","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftsm",
"FEP","First Trust Europe AlphaDEX Fund","35.63","639558571.26","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fep",
"FEUZ","First Trust Eurozone AlphaDEX ETF","38.3301","51745711.6602","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/feuz",
"FGM","First Trust Germany AlphaDEX Fund","42.1719","158144709.3438","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fgm",
"FTGC","First Trust Global Tactical Commodity Strategy Fund","18.89","171017479.26","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftgc",
"FTLB","First Trust Hedged BuyWrite Income ETF","21.6957","9763108.3914","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftlb",
"HYLS","First Trust High Yield Long/Short ETF","47.93","1140734095.86","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hyls",
"FHK","First Trust Hong Kong AlphaDEX Fund","38.1247","3812546.2494","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fhk",
"NFTY","First Trust India Nifty 50 Equal Weight ETF","38.5","3850077","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nfty",
"FTAG","First Trust Indxx Global Agriculture ETF","22.907","4350680.696","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftag",
"FTRI","First Trust Indxx Global Natural Resources Income ETF","12.44","8708024.88","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftri",
"LEGR","First Trust Indxx Innovative Transaction & Process ETF","29.6831","41556399.3662","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/legr",
"FPXI","First Trust International Equity Opportunities ETF","35.319","22957420.638","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fpxi",
"FPXE","First Trust IPOX Europe Equity Opportunities ETF","19.32","1932038.64","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fpxe",
"FJP","First Trust Japan AlphaDEX Fund","50.3559","166174570.7118","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fjp",
"FEX","First Trust Large Cap Core AlphaDEX Fund","60.23","1409382120.46","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fex",
"FTC","First Trust Large Cap Growth AlphaDEX Fund","67.72","968396135.44","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftc",
"RNLC","First Trust Large Cap US Equity Select ETF","22.3969","19037409.7938","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rnlc",
"FTA","First Trust Large Cap Value AlphaDEX Fund","52.21","1174725104.42","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fta",
"FLN","First Trust Latin America AlphaDEX Fund","19.96","27944039.92","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fln",
"LMBS","First Trust Low Duration Opportunities ETF","51.28","2576820102.56","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lmbs",
"LDSF","First Trust Low Duration Strategic Focus ETF","20.4","14280040.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ldsf",
"FMB","First Trust Managed Municipal ETF","53.71","636463607.42","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fmb",
"FMK","First Trust Mega Cap AlphaDEX Fund","34.8265","26119944.653","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fmk",
"FNX","First Trust Mid Cap Core AlphaDEX Fund","67.84","895488135.68","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fnx",
"FNY","First Trust Mid Cap Growth AlphaDEX Fund","43.7","235980087.4","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fny",
"RNMC","First Trust Mid Cap US Equity Select ETF","21.6244","14055903.2488","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rnmc",
"FNK","First Trust Mid Cap Value AlphaDEX Fund","34.9993","54248984.9986","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fnk",
"FAD","First Trust Multi Cap Growth AlphaDEX Fund","72.3507","184494429.7014","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fad",
"FAB","First Trust Multi Cap Value AlphaDEX Fund","54.4537","87126028.9074","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fab",
"MDIV","First Trust Multi-Asset Diversified Income Index Fund","18.51","636744037.02","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mdiv",
"MCEF","First Trust Municipal CEF Income Opportunity ETF","18.43","9215036.86","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mcef",
"FMHI","First Trust Municipal High Income ETF","51.41","46269102.82","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fmhi",
"QABA","First Trust NASDAQ ABA Community Bank Index Fund","47.22","205407094.44","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qaba",
"ROBT","First Trust Nasdaq Artificial Intelligence and Robotics ETF","32.3566","37210154.7132","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/robt",
"FTXO","First Trust Nasdaq Bank ETF","25.13","173397050.26","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftxo",
"QCLN","First Trust NASDAQ Clean Edge Green Energy Index Fund","20.52","98496041.04","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qcln",
"GRID","First Trust NASDAQ Clean Edge Smart Grid Infrastructure Index ","44.3389","26603428.6778","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/grid",
"CIBR","First Trust NASDAQ Cybersecurity ETF","28.42","822759056.84","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cibr",
"FTXG","First Trust Nasdaq Food & Beverage ETF","19.95","1995039.9","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftxg",
"CARZ","First Trust NASDAQ Global Auto Index Fund","33.8787","20327287.7574","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/carz",
"FTXN","First Trust Nasdaq Oil & Gas ETF","18.9701","12330602.9402","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftxn",
"FTXH","First Trust Nasdaq Pharmaceuticals ETF","21.525","5381293.05","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftxh",
"FTXD","First Trust Nasdaq Retail ETF","22.4203","8968164.8406","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftxd",
"FTXL","First Trust Nasdaq Semiconductor ETF","32.6153","30984600.2306","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftxl",
"FONE","First Trust NASDAQ Smartphone Index Fund","49.5399","14862069.0798","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fone",
"TDIV","First Trust NASDAQ Technology Dividend Index Fund","38.89","962721950","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tdiv",
"FTXR","First Trust Nasdaq Transportation ETF","23.8765","2387697.753","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftxr",
"QQEW","First Trust NASDAQ-100 Equal Weighted Index Fund","65.37","758292130.74","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qqew",
"QQXT","First Trust NASDAQ-100 Ex-Technology Sector Index Fund","53.3041","90617076.6082","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qqxt",
"QTEC","First Trust NASDAQ-100- Technology Index Fund","84.59","2465798669.18","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qtec",
"AIRR","First Trust RBA American Industrial Renaissance ETF","24.86","79552049.72","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/airr",
"RDVY","First Trust Rising Dividend Achievers ETF","30.38","741272060.76","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rdvy",
"RFAP","First Trust RiverFront Dynamic Asia Pacific ETF","51.6902","38767753.3804","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rfap",
"RFDI","First Trust RiverFront Dynamic Developed International ETF","57.2717","346493899.5434","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rfdi",
"RFEM","First Trust RiverFront Dynamic Emerging Markets ETF","63.49","117456626.98","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rfem",
"RFEU","First Trust RiverFront Dynamic Europe ETF","59.4737","65421188.9474","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rfeu",
"FID","First Trust S&P International Dividend Aristocrats ETF","16.9499","13559953.8998","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fid",
"FTSL","First Trust Senior Loan Fund ETF","47.33","1587921594.66","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftsl",
"FYX","First Trust Small Cap Core AlphaDEX Fund","62.09","608482124.18","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fyx",
"FYC","First Trust Small Cap Growth AlphaDEX Fund","46.38","301470092.76","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fyc",
"RNSC","First Trust Small Cap US Equity Select ETF","21.0548","5263742.1096","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rnsc",
"FYT","First Trust Small Cap Value AlphaDEX Fund","35.4799","60315900.9598","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fyt",
"SDVY","First Trust SMID Cap Rising Dividend Achievers ETF","20.3199","4064020.6398","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sdvy",
"FKO","First Trust South Korea AlphaDEX Fund","23.02","2302046.04","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fko",
"FCVT","First Trust SSI Strategic Convertible Securities ETF","30.6","188190061.2","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fcvt",
"FDIV","First Trust Strategic Income ETF","49.86","79776099.72","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fdiv",
"FSZ","First Trust Switzerland AlphaDEX Fund","49.205","167297098.41","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fsz",
"FIXD","First Trust TCW Opportunistic Fixed Income ETF","50.39","508939100.78","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fixd",
"TUSA","First Trust Total US Market AlphaDEX ETF","33.7306","16865367.4612","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tusa",
"FKU","First Trust United Kingdom AlphaDEX Fund","37.43","11229074.86","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fku",
"RNDV","First Trust US Equity Dividend Select ETF","22.38","5595044.76","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rndv",
"FUNC","First United Corporation","17.32","122781254.84","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/func",
"FUSB","First US Bancshares, Inc.","10.01","63043600.62","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fusb",
"MYFW","First Western Financial, Inc.","13.04","103908196.8","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/myfw",
"FCFS","FirstCash, Inc.","87.59","3815864919.25","n/a","1991","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/fcfs",
"SVVC","Firsthand Technology Value Fund, Inc.","13.1099","94112956.823","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/svvc",
"FSV","FirstService Corporation","88.72","3079427106.16","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/fsv",
"FISV","Fiserv, Inc.","89.78","35191009499.92","n/a","1986","Technology","EDP Services","https://www.nasdaq.com/symbol/fisv",
"FIVE","Five Below, Inc.","117.76","6570888120.32","n/a","2012","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/five",
"FPRX","Five Prime Therapeutics, Inc.","13.47","478011897.03","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/fprx",
"FVE","Five Star Senior Living Inc.","0.599","30456246.048","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/fve",
"FIVN","Five9, Inc.","52.4","3104859715.2","n/a","2014","Technology","EDP Services","https://www.nasdaq.com/symbol/fivn",
"FLEX","Flex Ltd.","10.41","5427956476.89","n/a","1994","Technology","Electrical Products","https://www.nasdaq.com/symbol/flex",
"FLKS","Flex Pharma, Inc.","0.44","7950569.44","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/flks",
"FLXN","Flexion Therapeutics, Inc.","12.35","469207535.55","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/flxn",
"SKOR","FlexShares Credit-Scored US Corporate Bond Index Fund","50.4","103320050.4","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/skor",
"LKOR","FlexShares Credit-Scored US Long Corporate Bond Index Fund","51.5262","28339461.5262","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lkor",
"MBSD","FlexShares Disciplined Duration MBS Index Fund","23.18","69540023.18","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mbsd",
"ASET","FlexShares Real Assets Allocation Index Fund","28.98","10143028.98","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aset",
"ESGG","FlexShares STOXX Global ESG Impact Index Fund","96.36","72270096.36","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/esgg",
"ESG","FlexShares STOXX US ESG Impact Index Fund","67.9095","35652555.4095","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/esg",
"QLC","FlexShares US Quality Large Cap Index Fund","33.95","81480033.95","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qlc",
"FPAY","FlexShopper, Inc.","0.8261","14594042.0373","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/fpay",
"FPAYW","FlexShopper, Inc.","0.28","0","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/fpayw",
"FLXS","Flexsteel Industries, Inc.","23.42","184788530.84","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/flxs",
"FLIR","FLIR Systems, Inc.","48.58","6588091782.16","n/a","1993","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/flir",
"FLNT","Fluent, Inc.","5.6","424067515.2","n/a","n/a","Consumer Services","Advertising","https://www.nasdaq.com/symbol/flnt",
"FLDM","Fluidigm Corporation","13.32","918936663.48","n/a","2011","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/fldm",
"FFIC","Flushing Financial Corporation","22.21","626037356.64","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ffic",
"FNCB","FNCB Bancorp Inc.","7.82","157248947.02","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fncb",
"FOMX","Foamix Pharmaceuticals Ltd.","4.04","219638458.2","n/a","2014","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/fomx",
"FOCS","Focus Financial Partners Inc.","36.79","1717179982.57","n/a","2018","Finance","Investment Managers","https://www.nasdaq.com/symbol/focs",
"FONR","Fonar Corporation","20.94","135798664.08","n/a","1981","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/fonr",
"FSCT","ForeScout Technologies, Inc.","42.9","1910055490.2","n/a","2017","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/fsct",
"FRSX","Foresight Autonomous Holdings Ltd.","1.32","2197818.48","1665014","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/frsx",
"FORM","FormFactor, Inc.","16.98","1264643996.1","n/a","2003","Technology","Semiconductors","https://www.nasdaq.com/symbol/form",
"FORTY","Formula Systems (1985) Ltd.","42","6475854","154187","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/forty",
"FORR","Forrester Research, Inc.","48.6","894774600","n/a","1996","Consumer Services","Diversified Commercial Services","https://www.nasdaq.com/symbol/forr",
"FRTA","Forterra, Inc.","4.37","280578489.48","n/a","2016","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/frta",
"FTNT","Fortinet, Inc.","85.63","14611361247.73","n/a","2009","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/ftnt",
"FBIO","Fortress Biotech, Inc.","1.81","110957074.31","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/fbio",
"FBIOP","Fortress Biotech, Inc.","19.468","19468000","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/fbiop",
"FTSV","Forty Seven, Inc.","16.15","505041394.95","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ftsv",
"FMCI","Forum Merger II Corporation","9.92","204897600","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/fmci",
"FMCIU","Forum Merger II Corporation","10.35","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/fmciu",
"FMCIW","Forum Merger II Corporation","0.44","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/fmciw",
"FWRD","Forward Air Corporation","64.2","1850574180.6","n/a","n/a","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/fwrd",
"FORD","Forward Industries, Inc.","1.52","14491453.52","n/a","n/a","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/ford",
"FWP","Forward Pharma A/S","1.19","13666299.15","11484285","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/fwp",
"FOSL","Fossil Group, Inc.","13.9","689548030.8","n/a","1993","Consumer Non-Durables","Consumer Specialties","https://www.nasdaq.com/symbol/fosl",
"FOX","Fox Corporation","35.7","9502399305","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/fox",
"FOXA","Fox Corporation","36.28","12855029635.6","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/foxa",
"FOXF","Fox Factory Holding Corp.","72.22","2746825518.58","n/a","2013","Consumer Non-Durables","Motor Vehicles","https://www.nasdaq.com/symbol/foxf",
"FRAN","Francesca&#39;s Holdings Corporation","0.6796","24583615.2584","n/a","2011","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/fran",
"FELE","Franklin Electric Co., Inc.","51.44","2384190913.92","n/a","n/a","Consumer Durables","Metal Fabrications","https://www.nasdaq.com/symbol/fele",
"FRED","Fred&#39;s, Inc.","2.37","89317135.35","n/a","1992","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/fred",
"RAIL","Freightcar America, Inc.","6.31","79516455.67","n/a","2005","Capital Goods","Railroads","https://www.nasdaq.com/symbol/rail",
"FEIM","Frequency Electronics, Inc.","11.85","103446731.7","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/feim",
"FRPT","Freshpet, Inc.","41.91","1493838531.24","n/a","2014","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/frpt",
"FTDR","frontdoor, inc.","34.07","2882915635.68","n/a","n/a","Finance","Diversified Commercial Services","https://www.nasdaq.com/symbol/ftdr",
"FTEO","FRONTEO, Inc.","9.5","497705","52390","2013","Technology","EDP Services","https://www.nasdaq.com/symbol/fteo",
"FTR","Frontier Communications Corporation","2.27","239073326.42","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ftr",
"FRPH","FRP Holdings, Inc.","49.65","493424430.75","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/frph",
"FSBW","FS Bancorp, Inc.","49.98","224663998.44","n/a","2012","Finance","Banks","https://www.nasdaq.com/symbol/fsbw",
"FSBC","FSB Bancorp, Inc.","17.15","33282336.15","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/fsbc",
"FTD","FTD Companies, Inc.","0.6592","18670264.512","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/ftd",
"FTEK","Fuel Tech, Inc.","1.86","44986333.86","n/a","n/a","Capital Goods","Pollution Control Equipment","https://www.nasdaq.com/symbol/ftek",
"FCEL","FuelCell Energy, Inc.","0.2594","33591630.748","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/fcel",
"FLGT","Fulgent Genetics, Inc.","5.84","106668084.72","n/a","2016","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/flgt",
"FORK","Fuling Global Inc.","2.4","37872492","n/a","2015","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/fork",
"FLL","Full House Resorts, Inc.","2.12","57152732.32","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/fll",
"FULT","Fulton Financial Corporation","15.89","2699456760","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fult",
"FNKO","Funko, Inc.","21.57","1051552189.17","n/a","2017","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/fnko",
"FSNN","Fusion Connect, Inc.","1.2","98535564","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/fsnn",
"FHL","Futu Holdings Limited","17.62","132150000","7500000","2019","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/fhl",
"FTFT","Future FinTech Group Inc.","0.7801","24196426.4483","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/ftft",
"FFHL","Fuwei Films (Holdings) Co., Ltd.","2.62","8556492.94","n/a","2006","Capital Goods","Specialty Chemicals","https://www.nasdaq.com/symbol/ffhl",
"FVCB","FVCBankcorp, Inc.","17.02","234114337.98","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fvcb",
"WILC","G. Willi-Food International,  Ltd.","7.96","105207439.4","n/a","n/a","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/wilc",
"GTHX","G1 Therapeutics, Inc.","16.91","632573236.94","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gthx",
"GAIA","Gaia, Inc.","9.06","162175259.34","n/a","1999","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/gaia",
"GLPG","Galapagos NV","119.46","1076091140.52","9007962","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/glpg",
"GALT","Galectin Therapeutics Inc.","4.95","225473618.7","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/galt",
"GLMD","Galmed Pharmaceuticals Ltd.","8.63","182205759.58","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/glmd",
"GMDA","Gamida Cell Ltd.","11.14","279944846.86","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/gmda",
"GLPI","Gaming and Leisure Properties, Inc.","38.69","8304364880.46","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/glpi",
"GPIC","Gaming Partners International Corporation","12.99","105111105.06","n/a","n/a","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/gpic",
"GRMN","Garmin Ltd.","88.25","16719970138.5","n/a","2000","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/grmn",
"GARS","Garrison Capital Inc.","7.22","115876321.44","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/gars",
"GLIBA","GCI Liberty, Inc.","56.31","5944610380.05","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/gliba",
"GLIBP","GCI Liberty, Inc.","24.8","179824800","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/glibp",
"GDS","GDS Holdings Limited","37.19","1991893238.85","53559915","2016","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/gds",
"GEMP","Gemphire Therapeutics Inc.","1.3","18545034.3","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gemp",
"GENC","Gencor Industries Inc.","12.57","182782808.58","n/a","n/a","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/genc",
"GFN","General Finance Corporation","9.27","280972040.67","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/gfn",
"GFNCP","General Finance Corporation","102.4665","40996846.65","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/gfncp",
"GFNSL","General Finance Corporation","26.05","0","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/gfnsl",
"GENE","Genetic Technologies Ltd","0.8551","8577517.5061","10031011","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/gene",
"GNFT","GENFIT S.A.","23.81","170181975","7147500","2019","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/gnft",
"GNUS","Genius Brands International, Inc.","1.99","20761108.82","n/a","n/a","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/gnus",
"GNMK","GenMark Diagnostics, Inc.","7.12","402083666","n/a","2010","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/gnmk",
"GNCA","Genocea Biosciences, Inc.","0.575","64626230.875","n/a","2014","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/gnca",
"GHDX","Genomic Health, Inc.","68.7","2535305693.1","n/a","2005","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/ghdx",
"GNPX","Genprex, Inc.","1.68","25321899.12","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gnpx",
"GNTX","Gentex Corporation","20.8","5392002990.4","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/gntx",
"THRM","Gentherm Inc","38.24","1287069644.96","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/thrm",
"GEOS","Geospace Technologies Corporation","13.23","180361824.93","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/geos",
"GABC","German American Bancorp, Inc.","29.99","748774065.42","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/gabc",
"GERN","Geron Corporation","1.74","324323266.68","n/a","1996","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gern",
"GEVO","Gevo, Inc.","2.25","26231370.75","n/a","2011","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/gevo",
"ROCK","Gibraltar Industries, Inc.","40.24","1293920580.16","n/a","1993","Capital Goods","Steel/Iron Ore","https://www.nasdaq.com/symbol/rock",
"GIGM","GigaMedia Limited","2.65","29288422.75","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/gigm",
"GIII","G-III Apparel Group, LTD.","40.05","1950771820.5","n/a","1989","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/giii",
"GILT","Gilat Satellite Networks Ltd.","8.27","456854267.58","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/gilt",
"GILD","Gilead Sciences, Inc.","66.24","84449111040","n/a","1992","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/gild",
"GBCI","Glacier Bancorp, Inc.","41","3467754252","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/gbci",
"GLAD","Gladstone Capital Corporation","9.23","263098796.35","n/a","2001","Consumer Non-Durables","Textiles","https://www.nasdaq.com/symbol/glad",
"GLADD","Gladstone Capital Corporation","25.65","0","n/a","n/a","Consumer Non-Durables","Textiles","https://www.nasdaq.com/symbol/gladd",
"GLADN","Gladstone Capital Corporation","25.29","52350300","n/a","n/a","Consumer Non-Durables","Textiles","https://www.nasdaq.com/symbol/gladn",
"GOOD","Gladstone Commercial Corporation","20.98","636793331.02","n/a","2003","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/good",
"GOODM","Gladstone Commercial Corporation","25.66","90055181.3","n/a","n/a","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/goodm",
"GOODO","Gladstone Commercial Corporation","26.287","56517050","n/a","n/a","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/goodo",
"GOODP","Gladstone Commercial Corporation","26.5","59996000","n/a","n/a","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/goodp",
"GAIN","Gladstone Investment Corporation","11.99","393541283.41","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/gain",
"GAINL","Gladstone Investment Corporation","25.5444","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gainl",
"GAINM","Gladstone Investment Corporation","25.4024","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gainm",
"LAND","Gladstone Land Corporation","12.6","227548679.4","n/a","1993","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/land",
"LANDP","Gladstone Land Corporation","25.6193","29462195","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/landp",
"GLBZ","Glen Burnie Bancorp","10.7618","30324826.0378","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/glbz",
"GBT","Global Blood Therapeutics, Inc.","54.05","3044217990.85","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gbt",
"ENT","Global Eagle Entertainment Inc.","0.69","63331227.72","n/a","2011","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/ent",
"GBLI","Global Indemnity Limited","30.83","437905743.72","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/gbli",
"GBLIL","Global Indemnity Limited","25.681","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/gblil",
"GBLIZ","Global Indemnity Limited","25.6","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/gbliz",
"SELF","Global Self Storage, Inc.","3.93","30232012.32","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/self",
"GWRS","Global Water Resources, Inc.","9.89","212351117.44","n/a","2016","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/gwrs",
"DRIV","Global X Autonomous & Electric Vehicles ETF","13.63","12947532.27","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/driv",
"KRMA","Global X Conscious Companies ETF","21.3139","59685101.031","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/krma",
"DAX","Global X DAX Germany ETF","25.84","15506997.44","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dax",
"EBIZ","Global X E-commerce ETF","17.7667","1776758.8335","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ebiz",
"FINX","Global X FinTech ETF","28.15","332193280.05","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/finx",
"AIQ","Global X Future Analytics Tech ETF","16.01","40017571.36","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aiq",
"BFIT","Global X Health & Wellness Thematic ETF","19.623","18638906.55","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bfit",
"SNSR","Global X Internet of Things ETF","18.675","79384586.4","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/snsr",
"LNGR","Global X Longevity Thematic ETF","21.5929","17277623.7137","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lngr",
"MILN","Global X Millennials Thematic ETF","23.9999","37193221.0276","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/miln",
"CHIC","Global X MSCI China Communication Services ETF","27.25","27250572.25","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/chic",
"EFAS","Global X MSCI SuperDividend EAFE ETF","16.17","6469374.45","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/efas",
"QYLD","Global X NASDAQ-100 Covered Call ETF","22.84","467064729.96","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qyld",
"BOTZ","Global X Robotics & Artificial Intelligence ETF","20.61","1639301304.42","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/botz",
"CATH","Global X S&P 500 Catholic Values ETF","35.15","242504419.5","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cath",
"SOCL","Global X Social Media ETF","32.57","140059500.77","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/socl",
"ALTY","Global X SuperDividend Alternatives ETF","14.97","20205952.11","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/alty",
"SRET","Global X SuperDividend REIT ETF","15.15","182584951.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sret",
"YLCO","Global X YieldCo & Renewable Energy Income ETF","12.945","17472112.455","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ylco",
"GLBS","Globus Maritime Limited","3.39","10885652.73","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/glbs",
"GLUU","Glu Mobile Inc.","11.28","1625678202.24","n/a","2007","Technology","EDP Services","https://www.nasdaq.com/symbol/gluu",
"GLYC","GlycoMimetics, Inc.","11.95","515869179.55","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/glyc",
"GOGO","Gogo Inc.","4.64","406281620.16","n/a","2013","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/gogo",
"GLNG","Golar LNG Limited","21.08","2135454676.32","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/glng",
"GMLP","Golar LNG Partners LP","12.87","912376886.85","n/a","2011","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/gmlp",
"GMLPP","Golar LNG Partners LP","25.15","138828000","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/gmlpp",
"DNJR","GOLDEN BULL LIMITED","7.0799","104658621.75","n/a","2018","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/dnjr",
"GDEN","Golden Entertainment, Inc.","15.58","431528841.7","n/a","n/a","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/gden",
"GOGL","Golden Ocean Group Limited","4.95","711328350.15","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/gogl",
"GBDC","Golub Capital BDC, Inc.","17.95","1084579190.05","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/gbdc",
"GTIM","Good Times Restaurants Inc.","2.41","30179894.98","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/gtim",
"GSHD","Goosehead Insurance, Inc.","25.93","940879825.61","n/a","2018","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/gshd",
"GPRO","GoPro, Inc.","6.63","996152726.4","n/a","2014","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/gpro",
"GPAQ","Gordon Pointe Acquisition Corp.","10.22","127750000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/gpaq",
"GPAQU","Gordon Pointe Acquisition Corp.","10.5","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/gpaqu",
"GPAQW","Gordon Pointe Acquisition Corp.","0.31","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/gpaqw",
"GRSH","Gores Holdings III, Inc.","9.9","396000000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/grsh",
"GRSHU","Gores Holdings III, Inc.","10.3","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/grshu",
"GRSHW","Gores Holdings III, Inc.","1.48","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/grshw",
"GMHI","Gores Metropoulos, Inc.","9.81","392400000","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/gmhi",
"GMHIU","Gores Metropoulos, Inc.","10.2","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/gmhiu",
"GMHIW","Gores Metropoulos, Inc.","1.3","8666665.8","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/gmhiw",
"GOSS","Gossamer Bio, Inc.","20.66","1360988263.86","n/a","2019","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/goss",
"LOPE","Grand Canyon Education, Inc.","117.47","5666566962.46","n/a","2008","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/lope",
"GRVY","GRAVITY Co., Ltd.","63.53","208994831.59","3289703","2005","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/grvy",
"GECC","Great Elm Capital Corp.","8.29","88308404.29","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gecc",
"GECCL","Great Elm Capital Corp.","25.3684","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/geccl",
"GECCM","Great Elm Capital Corp.","25.4365","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/geccm",
"GEC","Great Elm Capital Group, Inc. ","4.3","111812104.5","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/gec",
"GLDD","Great Lakes Dredge & Dock Corporation","9.1","574964016.9","n/a","n/a","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/gldd",
"GSBC","Great Southern Bancorp, Inc.","53.03","751418236.46","n/a","1989","Finance","Major Banks","https://www.nasdaq.com/symbol/gsbc",
"GRBK","Green Brick Partners, Inc.","9.09","460060153.02","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/grbk",
"GPP","Green Plains Partners LP","15.92","368352104.4","n/a","2015","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/gpp",
"GPRE","Green Plains, Inc.","16.94","701703587.2","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/gpre",
"GCBC","Greene County Bancorp, Inc.","30.35","259122654.9","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/gcbc",
"GLAC","Greenland Acquisition Corporation","10","57820000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/glac",
"GLACR","Greenland Acquisition Corporation","0.29","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/glacr",
"GLACU","Greenland Acquisition Corporation","10.42","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/glacu",
"GLACW","Greenland Acquisition Corporation","0.1","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/glacw",
"GLRE","Greenlight Reinsurance, Ltd.","11.03","401325766.87","n/a","2007","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/glre",
"GRNQ","Greenpro Capital Corp.","1.9899","108877949.6013","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/grnq",
"GSKY","GreenSky, Inc.","13.15","802664546.35","n/a","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/gsky",
"GSUM","Gridsum Holding Inc.","3.22","51104687.62","15871021","2016","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/gsum",
"GRIF","Griffin Industrial Realty, Inc.","35.29","178749955.17","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/grif",
"GRFS","Grifols, S.A.","20.27","2786902557.02","137489026","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/grfs",
"GRIN","Grindrod Shipping Holdings Ltd.","5.2","99131931.6","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/grin",
"GRTS","Gritstone Oncology, Inc.","14.74","430316892.06","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/grts",
"GRPN","Groupon, Inc.","3.5","1996100827","n/a","2011","Technology","Advertising","https://www.nasdaq.com/symbol/grpn",
"OMAB","Grupo Aeroportuario del Centro Norte S.A.B. de C.V.","46.12","320079579.64","6940147","2006","Transportation","Aerospace","https://www.nasdaq.com/symbol/omab",
"GGAL","Grupo Financiero Galicia S.A.","24.63","1565093005.62","63544174","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/ggal",
"GVP","GSE Systems, Inc.","2.87","56921005.61","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/gvp",
"GSIT","GSI Technology, Inc.","7.92","174589137.36","n/a","2007","Technology","Semiconductors","https://www.nasdaq.com/symbol/gsit",
"GSVC","GSV Capital Corp","6.99","138140902.53","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/gsvc",
"GTXI","GTx, Inc.","1.28","30786360.32","n/a","2004","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gtxi",
"GTYH","GTY Technology Holdings, Inc.","8.85","429406380.75","n/a","2016","Technology","EDP Services","https://www.nasdaq.com/symbol/gtyh",
"GTYHW","GTY Technology Holdings, Inc.","0.6","0","n/a","2016","Technology","EDP Services","https://www.nasdaq.com/symbol/gtyhw",
"GNTY","Guaranty Bancshares, Inc.","28.83","340407399.66","n/a","2017","Finance","Major Banks","https://www.nasdaq.com/symbol/gnty",
"GFED","Guaranty Federal Bancshares, Inc.","22.4417","100168101.5577","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/gfed",
"GH","Guardant Health, Inc.","67","5757188931","n/a","2018","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/gh",
"GIFI","Gulf Island Fabrication, Inc.","9.09","138498666.93","n/a","1997","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/gifi",
"GURE","Gulf Resources, Inc.","1.19","55835704.4","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/gure",
"GPOR","Gulfport Energy Corporation","7.99","1302258499.55","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/gpor",
"GWPH","GW Pharmaceuticals Plc","165.65","4804921092.9","29006466","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gwph",
"GWGH","GWG Holdings, Inc","11.97","395227387.17","n/a","2014","Finance","Life Insurance","https://www.nasdaq.com/symbol/gwgh",
"GYRO","Gyrodyne , LLC","18.1001","26836656.268","n/a","n/a","Consumer Services","Building operators","https://www.nasdaq.com/symbol/gyro",
"HEES","H&E Equipment Services, Inc.","25.57","914871714.85","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/hees",
"HLG","Hailiang Education Group Inc.","39.18","116193814.38","2965641","2015","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/hlg",
"HNRG","Hallador Energy Company","5.12","154852346.88","n/a","n/a","Energy","Coal Mining","https://www.nasdaq.com/symbol/hnrg",
"HALL","Hallmark Financial Services, Inc.","10.48","189930014.64","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/hall",
"HALO","Halozyme Therapeutics, Inc.","16.74","2432330939.16","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/halo",
"HBK","Hamilton Bancorp, Inc.","14.2","48513078.8","n/a","2012","Finance","Savings Institutions","https://www.nasdaq.com/symbol/hbk",
"HLNE","Hamilton Lane Incorporated","44.89","2313666781.34","n/a","2017","Finance","Investment Managers","https://www.nasdaq.com/symbol/hlne",
"HJLI","Hancock Jaffe Laboratories, Inc.","1.82","25769383.64","n/a","2018","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/hjli",
"HJLIW","Hancock Jaffe Laboratories, Inc.","0.3088","0","n/a","2018","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/hjliw",
"HWC","Hancock Whitney Corporation","41.69","3627647595.66","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hwc",
"HWCPL","Hancock Whitney Corporation","25.96","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hwcpl",
"HAFC","Hanmi Financial Corporation","21.7","671025823.3","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hafc",
"HONE","HarborOne Bancorp, Inc.","17.23","561011143.28","n/a","2016","Finance","Major Banks","https://www.nasdaq.com/symbol/hone",
"HLIT","Harmonic Inc.","5.62","498374294","n/a","1995","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/hlit",
"HARP","Harpoon Therapeutics, Inc.","11.15","271389104.5","n/a","2019","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/harp",
"HROW","Harrow Health, Inc.","4.8","118490851.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/hrow",
"HFGIC","Hartford Funds NextShares Trust","100.1","27527500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hfgic",
"HBIO","Harvard Bioscience, Inc.","4.08","153684554.64","n/a","2000","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/hbio",
"HCAP","Harvest Capital Credit Corporation","10.49","65655284.05","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hcap",
"HCAPZ","Harvest Capital Credit Corporation","25.68","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hcapz",
"HAS","Hasbro, Inc.","85.12","10711711046.4","n/a","n/a","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/has",
"HA","Hawaiian Holdings, Inc.","27.13","1313684926.15","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/ha",
"HWKN","Hawkins, Inc.","37.52","400791003.76","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/hwkn",
"HWBK","Hawthorn Bancshares, Inc.","24","144836232","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hwbk",
"HAYN","Haynes International, Inc.","34.01","425719902.92","n/a","2007","Capital Goods","Steel/Iron Ore","https://www.nasdaq.com/symbol/hayn",
"HDS","HD Supply Holdings, Inc.","44.03","7519888367.18","n/a","2013","Consumer Services","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/hds",
"HIIQ","Health Insurance Innovations, Inc.","25.4","385547006.4","n/a","2013","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/hiiq",
"HCSG","Healthcare Services Group, Inc.","33.56","2484648160","n/a","1983","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/hcsg",
"HQY","HealthEquity, Inc.","74.45","4651036826.4","n/a","2014","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/hqy",
"HSTM","HealthStream, Inc.","28.2","911689333.8","n/a","2000","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/hstm",
"HTLD","Heartland Express, Inc.","19.25","1577236237.5","n/a","1986","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/htld",
"HTLF","Heartland Financial USA, Inc.","43.47","1502681045.04","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/htlf",
"HTBX","Heat Biologics, Inc.","1.23","40702943.52","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/htbx",
"HEBT","Hebron Technology Co., Ltd.","0.96","15618793.92","n/a","2016","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/hebt",
"HSII","Heidrick & Struggles International, Inc.","39.51","750071431.44","n/a","1999","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/hsii",
"HELE","Helen of Troy Limited","112","2866622080","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/hele",
"HSDT","Helius Medical Technologies, Inc.","6.66","172055638.8","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/hsdt",
"HMTV","Hemisphere Media Group, Inc.","14.12","556769052.32","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/hmtv",
"HNNA","Hennessy Advisors, Inc.","9.33","73874622.78","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/hnna",
"HCACU","Hennessy Capital Acquisition Corp. IV","10.12","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/hcacu",
"HSIC","Henry Schein, Inc.","60.67","9185662661.01","n/a","1995","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/hsic",
"HTBK","Heritage Commerce Corp","12.21","528687737.49","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/htbk",
"HFWA","Heritage Financial Corporation","30.68","1131464808.76","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/hfwa",
"HCCI","Heritage-Crystal Clean, Inc.","26.19","629919156.24","n/a","2008","Basic Industries","Miscellaneous","https://www.nasdaq.com/symbol/hcci",
"MLHR","Herman Miller, Inc.","35.16","2070783008.4","n/a","n/a","Consumer Durables","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/mlhr",
"HRTX","Heron Therapeutics, Inc.  ","25.56","1998322999.56","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/hrtx",
"HSKA","Heska Corporation","83.88","649417581.36","n/a","1997","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/hska",
"HX","Hexindai Inc.","3.36","45976596.96","13683511","2017","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/hx",
"HFFG","HF Foods Group Inc.","13.13","291059091.18","n/a","2017","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/hffg",
"HIBB","Hibbett Sports, Inc.","22.78","416547972.64","n/a","1996","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/hibb",
"SNLN","Highland/iBoxx Senior Loan ETF","17.66","416775682.12","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/snln",
"HPJ","Highpower International Inc","3.04","47326577.12","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/hpj",
"HIHO","Highway Holdings Limited","3.2837","12484213.6538","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/hiho",
"HIMX","Himax Technologies, Inc.","3.22","348076616.16","108098328","2006","Technology","Semiconductors","https://www.nasdaq.com/symbol/himx",
"HIFS","Hingham Institution for Savings","173.73","370522657.5","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hifs",
"HSGX","Histogenics Corporation","0.1159","10964093.7559","n/a","2014","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/hsgx",
"HCCH","HL Acquisitions Corp.","9.92","69075291.2","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/hcch",
"HCCHR","HL Acquisitions Corp.","0.29","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/hcchr",
"HCCHU","HL Acquisitions Corp.","10.42","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/hcchu",
"HCCHW","HL Acquisitions Corp.","0.25","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/hcchw",
"HMNF","HMN Financial, Inc.","22.09","106963005.14","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/hmnf",
"HMSY","HMS Holdings Corp","30.12","2568388634.04","n/a","1992","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/hmsy",
"HOLI","Hollysys Automation Technologies, Ltd.","21.75","1312440653.25","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/holi",
"HOLX","Hologic, Inc.","48.17","14032632326.39","n/a","1990","Health Care","Medical Electronics","https://www.nasdaq.com/symbol/holx",
"HBCP","Home Bancorp, Inc.","35.09","332847598.6","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/hbcp",
"HOMB","Home BancShares, Inc.","17.99","3034851330.28","n/a","2006","Finance","Major Banks","https://www.nasdaq.com/symbol/homb",
"HFBL","Home Federal Bancorp, Inc. of Louisiana","31.6","58555906","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/hfbl",
"HMST","HomeStreet, Inc.","26.33","711772307.5","n/a","2012","Finance","Major Banks","https://www.nasdaq.com/symbol/hmst",
"HTBI","HomeTrust Bancshares, Inc.","25.45","468138396.2","n/a","2012","Finance","Savings Institutions","https://www.nasdaq.com/symbol/htbi",
"FIXX","Homology Medicines, Inc.","29.44","1105135059.2","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/fixx",
"HOFT","Hooker Furniture Corporation","29.05","342358520.35","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/hoft",
"HOPE","Hope Bancorp, Inc.","13.46","1704603312.08","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hope",
"HFBC","HopFed Bancorp, Inc.","19.98","132844762.26","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hfbc",
"HBNC","Horizon Bancorp, Inc.","16.16","726009605.92","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hbnc",
"HZNP","Horizon Pharma plc","26.98","4976018851.76","n/a","2011","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/hznp",
"HRZN","Horizon Technology Finance Corporation","11.9","137295298","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/hrzn",
"HPT","Hospitality Properties Trust","26.57","4369216208.13","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hpt",
"TWNK","Hostess Brands, Inc.","13.01","1695223503.76","n/a","2015","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/twnk",
"TWNKW","Hostess Brands, Inc.","1.49","0","n/a","2015","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/twnkw",
"HOTH","Hoth Therapeutics, Inc.","5.45","51363928.3","n/a","2019","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/hoth",
"HMHC","Houghton Mifflin Harcourt Company","7.55","937034629.85","n/a","2013","Consumer Services","Books","https://www.nasdaq.com/symbol/hmhc",
"HWCC","Houston Wire & Cable Company","6.06","100674852.72","n/a","2006","Consumer Non-Durables","Telecommunications Equipment","https://www.nasdaq.com/symbol/hwcc",
"HOVNP","Hovnanian Enterprises Inc","3.9177","21939.12","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/hovnp",
"HBMD","Howard Bancorp, Inc.","13.63","259743311.68","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hbmd",
"HTGM","HTG Molecular Diagnostics, Inc.","2.62","74947751.44","n/a","2015","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/htgm",
"HTHT","Huazhu Group Limited","43.67","6367431604.38","145807914","2010","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/htht",
"HUBG","Hub Group, Inc.","42.25","1469206358.75","n/a","1996","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/hubg",
"HSON","Hudson Global, Inc.","1.58","46434419.34","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/hson",
"HDSN","Hudson Technologies, Inc.","1.96","83500764.76","n/a","n/a","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/hdsn",
"HUNT","Hunter Maritime Acquisition Corp.","95","19383895380","n/a","2017","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/hunt",
"HUNTU","Hunter Maritime Acquisition Corp.","88","0","n/a","2016","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/huntu",
"HUNTW","Hunter Maritime Acquisition Corp.","0.465","0","n/a","2017","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/huntw",
"HBAN","Huntington Bancshares Incorporated","13.18","13851584198.1","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hban",
"HBANN","Huntington Bancshares Incorporated","26.94","2694000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hbann",
"HBANO","Huntington Bancshares Incorporated","25.99","5198000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hbano",
"HURC","Hurco Companies, Inc.","39.5","266945858.5","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/hurc",
"HURN","Huron Consulting Group Inc.","46.77","1070144042.61","n/a","2004","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/hurn",
"HCM","Hutchison China MediTech Limited","31.22","1056929685","33854250","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/hcm",
"HBP","Huttig Building Products, Inc.","2.76","73331066.52","n/a","n/a","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/hbp",
"HVBC","HV Bancorp, Inc.","16","36082000","n/a","2017","Finance","Major Banks","https://www.nasdaq.com/symbol/hvbc",
"HYGS","Hydrogenics Corporation","7.96","151123895.44","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/hygs",
"HYRE","HyreCar Inc.","5.2","62965780.8","n/a","2018","Consumer Services","Rental/Leasing Companies","https://www.nasdaq.com/symbol/hyre",
"IDSY","I.D. Systems, Inc.","5.78","104732085.64","n/a","1999","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/idsy",
"IIIV","i3 Verticals, Inc.","22.51","592150738.69","n/a","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/iiiv",
"IAC","IAC/InterActiveCorp","210.18","17607998484.72","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/iac",
"IBKC","IBERIABANK Corporation","72.55","3957750647.1","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ibkc",
"IBKCO","IBERIABANK Corporation","26.58","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ibkco",
"IBKCP","IBERIABANK Corporation","26.51","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ibkcp",
"ICAD","icad inc.","5.22","89968093.74","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/icad",
"IEP","Icahn Enterprises L.P.","73.8","14123428653.6","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/iep",
"ICCH","ICC Holdings, Inc.","13.52","40461763.68","n/a","2017","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/icch",
"ICFI","ICF International, Inc.","75.38","1418214848.28","n/a","2006","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/icfi",
"ICHR","Ichor Holdings","23.3","521200845.5","n/a","2016","Technology","Semiconductors","https://www.nasdaq.com/symbol/ichr",
"ICLK","iClick Interactive Asia Group Limited","3.83","69282830.96","18089512","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/iclk",
"ICLR","ICON plc","138.6","7480478451.6","n/a","1998","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/iclr",
"ICON","Iconix Brand Group, Inc.","1.79","15819409.61","n/a","n/a","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/icon",
"ICUI","ICU Medical, Inc.","236.41","4846156533.09","n/a","1992","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/icui",
"IPWR","Ideal Power Inc.","0.4101","5740274.6856","n/a","2013","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/ipwr",
"IDEX","Ideanomics, Inc.","1.93","206058391.58","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/idex",
"INVE","Identiv, Inc.","5.06","83110049.66","n/a","n/a","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/inve",
"IDRA","Idera Pharmaceuticals, Inc.","2.73","75402878.46","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/idra",
"IDXX","IDEXX Laboratories, Inc.","224.92","19353227679.88","n/a","1991","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/idxx",
"IESC","IES Holdings, Inc.","17.7","374151202.2","n/a","n/a","Capital Goods","Engineering & Construction","https://www.nasdaq.com/symbol/iesc",
"IROQ","IF Bancorp, Inc.","20.3","73179632.4","n/a","2011","Finance","Savings Institutions","https://www.nasdaq.com/symbol/iroq",
"IFMK","iFresh Inc.","1.2","19629220.8","n/a","n/a","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/ifmk",
"INFO","IHS Markit Ltd.","54.73","21878226429.28","n/a","1996","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/info",
"IIVI","II-VI Incorporated","38.83","2461598960.48","n/a","1987","Capital Goods","Electronic Components","https://www.nasdaq.com/symbol/iivi",
"IKNX","Ikonics Corporation","8.22","16304805.66","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/iknx",
"ILMN","Illumina, Inc.","316.1","46443082588.5","n/a","2000","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/ilmn",
"IMAC","IMAC Holdings, Inc.","5.5","39836632","n/a","2019","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/imac",
"IMACW","IMAC Holdings, Inc.","0.9614","0","n/a","2019","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/imacw",
"ISNS","Image Sensing Systems, Inc.","5.14","27136552.9","n/a","1995","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/isns",
"IMMR","Immersion Corporation","8.7","268434759","n/a","1999","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/immr",
"ICCC","ImmuCell Corporation","6.35","45780928.25","n/a","1987","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/iccc",
"IMDZ","Immune Design Corp.","5.85","282936700.8","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/imdz",
"IMGN","ImmunoGen, Inc.","2.71","404900625.75","n/a","1989","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/imgn",
"IMMU","Immunomedics, Inc.","18.04","3444917461.92","n/a","n/a","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/immu",
"IMRN","Immuron Limited","6.019","2006620.239","333381","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/imrn",
"IMRNW","Immuron Limited","1.38","0","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/imrnw",
"IMMP","Immutep Limited","2.16","24327228.96","11262606","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/immp",
"PI","Impinj, Inc.","17.69","380232698.73","n/a","2016","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/pi",
"IMV","IMV Inc.","3.9","197329493.4","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/imv",
"INCY","Incyte Corporation","86.7","18576734490.9","n/a","n/a","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/incy",
"INDB","Independent Bank Corp.","83.24","2342168080.44","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/indb",
"IBCP","Independent Bank Corporation","21.83","515545553.57","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ibcp",
"IBTX","Independent Bank Group, Inc","53.05","2321982001.45","n/a","2013","Finance","Major Banks","https://www.nasdaq.com/symbol/ibtx",
"ILPT","Industrial Logistics Properties Trust","20.25","1317764517.75","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/ilpt",
"IDSA","Industrial Services of America, Inc.","1.27","10296988.55","n/a","n/a","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/idsa",
"INFN","Infinera Corporation","4.56","809014657.2","n/a","2007","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/infn",
"INFI","Infinity Pharmaceuticals, Inc.","1.77","100758184.56","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/infi",
"IFRX","InflaRx N.V.","37.16","964836323.64","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/ifrx",
"III","Information Services Group, Inc.","3.84","175870483.2","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/iii",
"IEA","Infrastructure and Energy Alternatives, Inc.","5.13","113656540.23","n/a","2016","Finance","Business Services","https://www.nasdaq.com/symbol/iea",
"IEAWW","Infrastructure and Energy Alternatives, Inc.","0.34","0","n/a","2016","Finance","Business Services","https://www.nasdaq.com/symbol/ieaww",
"IMKTA","Ingles Markets, Incorporated","27.12","549445125.12","n/a","1987","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/imkta",
"INMB","INmune Bio Inc.","7.5293","73337347.1473","n/a","2019","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/inmb",
"INWK","InnerWorkings, Inc.","3.63","189747163.98","n/a","2006","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/inwk",
"INOD","Innodata Inc.","1.31","33997714.74","n/a","1993","Technology","EDP Services","https://www.nasdaq.com/symbol/inod",
"IPHS","Innophos Holdings, Inc.","31.31","614057731.52","n/a","2006","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/iphs",
"IOSP","Innospec Inc.","84.01","2083832429.76","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/iosp",
"INNT","Innovate Biopharmaceuticals, Inc.","1.85","55999292.8","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/innt",
"ISSC","Innovative Solutions and Support, Inc.","3.15","53258574.6","n/a","2000","Technology","EDP Services","https://www.nasdaq.com/symbol/issc",
"INVA","Innoviva, Inc.","13.82","1398296239.96","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/inva",
"INGN","Inogen, Inc","90.18","1977578682.84","n/a","2014","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/ingn",
"INOV","Inovalon Holdings, Inc.","12.15","1854754519.95","n/a","2015","Technology","EDP Services","https://www.nasdaq.com/symbol/inov",
"INO","Inovio Pharmaceuticals, Inc.","3.7","362355837","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/ino",
"INPX","Inpixon ","0.7989","5571146.7258","n/a","2014","Technology","EDP Services","https://www.nasdaq.com/symbol/inpx",
"INSG","Inseego Corp.","4.75","352850363.25","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/insg",
"NSIT","Insight Enterprises, Inc.","55.66","1976078667.86","n/a","1995","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/nsit",
"ISIG","Insignia Systems, Inc.","1.38","16487529.3","n/a","1991","Consumer Services","Advertising","https://www.nasdaq.com/symbol/isig",
"INSM","Insmed, Inc.","29.68","2301344520.16","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/insm",
"INSE","Inspired Entertainment, Inc.","6.74","153793798.54","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/inse",
"IIIN","Insteel Industries, Inc.","21.02","404067817.34","n/a","n/a","Capital Goods","Steel/Iron Ore","https://www.nasdaq.com/symbol/iiin",
"PODD","Insulet Corporation","95.8","5678927529.4","n/a","2007","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/podd",
"INSUU","Insurance Acquisition Corp.","10.1","135592500","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/insuu",
"INSY","Insys Therapeutics, Inc.","4.73","352045669.8","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/insy",
"NTEC","Intec Pharma Ltd.","7.68","255229347.84","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ntec",
"IART","Integra LifeSciences Holdings Corporation","54.25","4623677318.75","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/iart",
"IMTE","Integrated Media Technology Limited","11","29357746","n/a","n/a","Consumer Non-Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/imte",
"INTC","Intel Corporation","54.36","244456920000","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/intc",
"NTLA","Intellia Therapeutics, Inc.","17.97","813251577.9","n/a","2016","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/ntla",
"IPAR","Inter Parfums, Inc.","75.67","2379241716.46","n/a","n/a","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/ipar",
"ICPT","Intercept Pharmaceuticals, Inc.","113.97","3384211047.72","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/icpt",
"IDCC","InterDigital, Inc.","66.62","2172969855.6","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/idcc",
"TILE","Interface, Inc.","15.29","909048357.36","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/tile",
"IMI","Intermolecular, Inc.","1.14","56724375.36","n/a","2011","Technology","Semiconductors","https://www.nasdaq.com/symbol/imi",
"INAP","Internap Corporation","4.96","125969744.96","n/a","1999","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/inap",
"IBOC","International Bancshares Corporation","38.68","2538085093.4","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/iboc",
"IMXI","International Money Express, Inc.","11.76","425509528.08","n/a","2017","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/imxi",
"ISCA","International Speedway Corporation","43.66","1895760510.72","n/a","1996","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/isca",
"IGLD","Internet Gold Golden Lines Ltd.","0.5435","15219731.591","n/a","1999","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/igld",
"IIJI","Internet Initiative Japan, Inc.","9.89","16567549.98","1675182","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/iiji",
"IDXG","Interpace Diagnostics Group, Inc.","0.8235","31372087.293","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/idxg",
"XENT","Intersect ENT, Inc.","32.15","990304811.7","n/a","2014","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/xent",
"IPLDP","Interstate Power and Light Company","25.1678","201342400","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/ipldp",
"IVAC","Intevac, Inc.","6.27","143657725.86","n/a","1995","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/ivac",
"INTL","INTL FCStone Inc.","39.98","762793972.22","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/intl",
"ITCI","Intra-Cellular Therapies Inc.","12.83","707147761.37","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/itci",
"XON","Intrexon Corporation","5.45","874228821.1","n/a","n/a","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/xon",
"IIN","IntriCon Corporation","26.59","231544310.73","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/iin",
"INTU","Intuit Inc.","268.26","69498921370.44","n/a","1993","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/intu",
"ISRG","Intuitive Surgical, Inc.","575.98","66445832676.92","n/a","2000","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/isrg",
"PLW","Invesco 1-30 Laddered Treasury ETF","32.61","167941500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/plw",
"ADRA","Invesco BLDRS Asia 50 ADR Index Fund","31.7657","19059420","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/adra",
"ADRD","Invesco BLDRS Developed Markets 100 ADR Index Fund","21.63","36771000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/adrd",
"ADRE","Invesco BLDRS Emerging Markets 50 ADR Index Fund","41.58","139293000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/adre",
"ADRU","Invesco BLDRS Europe Select ADR Index Fund","21.252","11688600","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/adru",
"PKW","Invesco BuyBack Achievers ETF","60.69","1153110000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pkw",
"PFM","Invesco Dividend Achievers ETF","27.7527","296953890","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pfm",
"PYZ","Invesco DWA Basic Materials Momentum ETF","59.944","62941200","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pyz",
"PEZ","Invesco DWA Consumer Cyclicals Momentum ETF","55.0272","30264960","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pez",
"PSL","Invesco DWA Consumer Staples Momentum ETF","70.62","169488000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psl",
"PIZ","Invesco DWA Developed Markets Momentum ETF","26.15","188280000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/piz",
"PIE","Invesco DWA Emerging Markets Momentum ETF","17.11","157412000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pie",
"PXI","Invesco DWA Energy Momentum ETF","32.3999","51839840","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pxi",
"PFI","Invesco DWA Financial Momentum ETF","33.8853","25413975","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pfi",
"PTH","Invesco DWA Healthcare Momentum ETF","79.26","198150000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pth",
"PRN","Invesco DWA Industrials Momentum ETF","62.08","96224000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/prn",
"PDP","Invesco DWA Momentum ETF","57.17","1480703000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pdp",
"DWAQ","Invesco DWA NASDAQ Momentum ETF","110.0196","44007840","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwaq",
"DWAS","Invesco DWA SmallCap Momentum ETF","50.67","248283000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwas",
"DWIN","Invesco DWA Tactical Multi-Asset Income ETF","25.0526","37578925.0526","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwin",
"DWTR","Invesco DWA Tactical Sector Rotation ETF","29.808","64087200","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwtr",
"PTF","Invesco DWA Technology Momentum ETF","68.66","147619000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ptf",
"PUI","Invesco DWA Utilities Momentum ETF","31.89","242364000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pui",
"IDLB","Invesco FTSE International Low Beta Equal Weight ETF","28.24","121421692.4","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/idlb",
"PRFZ","Invesco FTSE RAFI US 1500 Small-Mid ETF","128.61","2122065000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/prfz",
"PIO","Invesco Global Water ETF","27.09","182857500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pio",
"PGJ","Invesco Golden Dragon China ETF","41.3","210630000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pgj",
"PEY","Invesco High Yield Equity Dividend Achievers ETF","17.935","799901000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pey",
"IPKW","Invesco International BuyBack Achievers ETF","32.18","180191781.28","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ipkw",
"PID","Invesco International Dividend Achievers ETF","16.12","752804000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pid",
"KBWB","Invesco KBW Bank ETF","49.73","569408500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kbwb",
"KBWD","Invesco KBW High Dividend Yield Financial ETF","21.9","300030000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kbwd",
"KBWY","Invesco KBW Premium Yield Equity REIT ETF","30.75","349012500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kbwy",
"KBWP","Invesco KBW Property & Casualty Insurance ETF","62.2","62200000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kbwp",
"KBWR","Invesco KBW Regional Banking ETF","50.095","82656750","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kbwr",
"LDRI","Invesco LadderRite 0-5 Year Corporate Bond ETF","24.87","12435000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ldri",
"PNQI","Invesco Nasdaq Internet ETF","137.35","576870000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pnqi",
"PDBC","Invesco Optimum Yield Diversified Commodity Strategy No K-1 ET","16.8","2014320000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pdbc",
"QQQ","Invesco QQQ Trust, Series 1","182.73","70990605000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qqq",
"ISDX","Invesco RAFI Strategic Developed ex-US ETF","24.849","2484924.849","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/isdx",
"ISDS","Invesco RAFI Strategic Developed ex-US Small Company ETF","23.36","2336023.36","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/isds",
"ISEM","Invesco RAFI Strategic Emerging Markets ETF","26.6629","2666316.6629","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/isem",
"IUS","Invesco RAFI Strategic US ETF","24.049","2404924.049","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ius",
"IUSS","Invesco RAFI Strategic US Small Company ETF","22.73","2273022.73","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iuss",
"USLB","Invesco Russell 1000 Low Beta Equal Weight ETF","32.06","163493592.78","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/uslb",
"PSCD","Invesco S&P SmallCap Consumer Discretionary ETF","60.69","78897000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pscd",
"PSCC","Invesco S&P SmallCap Consumer Staples ETF","74.8888","67399920","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pscc",
"PSCE","Invesco S&P SmallCap Energy ETF","10.86","30951000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psce",
"PSCF","Invesco S&P SmallCap Financials ETF","53.0924","140694860","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pscf",
"PSCH","Invesco S&P SmallCap Health Care ETF","115.43","698351500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psch",
"PSCI","Invesco S&P SmallCap Industrials ETF","63.345","63345000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psci",
"PSCT","Invesco S&P SmallCap Information Technology ETF","81.89","323465500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psct",
"PSCM","Invesco S&P SmallCap Materials ETF","47.86","19144000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pscm",
"PSCU","Invesco S&P SmallCap Utilities & Communication Services ETF","53.3594","61363310","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pscu",
"VRIG","Invesco Variable Rate Investment Grade ETF","24.9","417075024.9","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vrig",
"PHO","Invesco Water Resources ETF","34.14","962748000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pho",
"ISTR","Investar Holding Corporation","22.31","226604610.97","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/istr",
"ISBC","Investors Bancorp, Inc.","12.06","3403795586.4","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/isbc",
"ITIC","Investors Title Company","161.4","304502082","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/itic",
"NVIV","InVivo Therapeutics Holdings Corp.","1.54","14331632.7","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nviv",
"IONS","Ionis Pharmaceuticals, Inc.","81.74","11312632411.96","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ions",
"IOVA","Iovance Biotherapeutics, Inc.","9.8","1209516891.8","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/iova",
"IPGP","IPG Photonics Corporation","162.27","8594145200.43","n/a","2006","Technology","Semiconductors","https://www.nasdaq.com/symbol/ipgp",
"IPIC","iPic Entertainment Inc.","4.3","49177934.7","n/a","2018","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/ipic",
"CLRG","IQ Chaikin U.S. Large Cap ETF","23.92","303784000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/clrg",
"CSML","IQ Chaikin U.S. Small Cap ETF","25.08","341088000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/csml",
"IQ","iQIYI, Inc.","24.4","7121932048.4","291882461","2018","Consumer Services","Consumer Electronics/Video Chains","https://www.nasdaq.com/symbol/iq",
"IRMD","iRadimed Corporation","27.93","307147662.36","n/a","2014","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/irmd",
"IRTC","iRhythm Technologies, Inc.","69.34","1696303319.74","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/irtc",
"IRIX","IRIDEX Corporation","4.6","62710866.2","n/a","1996","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/irix",
"IRDM","Iridium Communications Inc","26.7","3023516437.2","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/irdm",
"IRDMB","Iridium Communications Inc","912.65","453587050","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/irdmb",
"IRBT","iRobot Corporation","121.48","3376732668.72","n/a","2005","Consumer Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/irbt",
"IRWD","Ironwood Pharmaceuticals, Inc.","12.31","1903683150.6","n/a","2010","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/irwd",
"IRCP","IRSA Propiedades Comerciales S.A.","20.4","77619735.6","3804889","n/a","Consumer Services","Building operators","https://www.nasdaq.com/symbol/ircp",
"SLQD","iShares 0-5 Year Investment Grade Corporate Bond ETF","50.25","1613025000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/slqd",
"ISHG","iShares 1-3 Year International Treasury Bond ETF","78.63","74698500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ishg",
"SHY","iShares 1-3 Year Treasury Bond ETF","83.91","20490822000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/shy",
"TLT","iShares 20+ Year Treasury Bond ETF","124.6","9905700000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tlt",
"IEI","iShares 3-7 Year Treasury Bond ETF","122.66","7261472000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iei",
"IEF","iShares 7-10 Year Treasury Bond ETF","105.9","12655050000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ief",
"AIA","iShares Asia 50 ETF","62.4","1113840000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aia",
"USIG","iShares Broad USD Investment Grade Corporate Bond ETF","54.95","2788712500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/usig",
"COMT","iShares Commodities Select Strategy ETF","33.49","388484000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/comt",
"ISTB","iShares Core 1-5 Year USD Bond ETF","49.7","2465120000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/istb",
"IXUS","iShares Core MSCI Total International Stock ETF","58.8","14053200000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ixus",
"IUSG","iShares Core S&P U.S. Growth ETF","60.95","6049287500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iusg",
"IUSV","iShares Core S&P U.S. Value ETF","55.51","5273450000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iusv",
"IUSB","iShares Core Total USD Bond Market ETF","50.29","3324169000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iusb",
"HEWG","iShares Currency Hedged MSCI Germany ETF","26.52","210834000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hewg",
"SUSB","iShares ESG 1-5 Year USD Corporate Bond ETF","24.8971","77181010","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/susb",
"ESGD","iShares ESG MSCI EAFE ETF","64.04","710844000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/esgd",
"ESGE","iShares ESG MSCI EM ETF","34.46","544468000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/esge",
"ESGU","iShares ESG MSCI USA ETF","63.03","182787000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/esgu",
"SUSC","iShares ESG USD Corporate Bond ETF","24.84","31050000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/susc",
"XT","iShares Exponential Technologies ETF","38.675","2421055000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/xt",
"FALN","iShares Fallen Angels USD Bond ETF","26.22","69483000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/faln",
"IFEU","iShares FTSE EPRA/NAREIT Europe Index Fund","38.3475","30678000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ifeu",
"IFGL","iShares FTSE EPRA/NAREIT Global Real Estate ex-U.S. Index Fund","30.4","504640000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ifgl",
"BGRN","iShares Global Green Bond ETF","52.53","26265000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bgrn",
"IGF","iShares Global Infrastructure ETF","44.98","2838238000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/igf",
"GNMA","iShares GNMA Bond ETF","49.24","115714000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gnma",
"HYXE","iShares iBoxx $ High Yield ex Oil & Gas Corporate Bond ETF","50.8","10160000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hyxe",
"IGIB","iShares Intermediate-Term Corporate Bond ETF","54.74","5610850000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/igib",
"IGOV","iShares International Treasury Bond ETF","48.85","884185000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/igov",
"EMB","iShares J.P. Morgan USD Emerging Markets Bond ETF","109.87","17216629000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/emb",
"MBB","iShares MBS ETF","105.78","15824688000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mbb",
"JKI","iShares Morningstar Mid-Cap ETF","157.3394","464151230","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jki",
"ACWX","iShares MSCI ACWI ex US Index Fund","46.88","3712896000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/acwx",
"ACWI","iShares MSCI ACWI Index Fund","73","10278400000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/acwi",
"AAXJ","iShares MSCI All Country Asia ex Japan Index Fund","71.59","4481534000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aaxj",
"EWZS","iShares MSCI Brazil Small-Cap ETF","15.55","89412500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ewzs",
"MCHI","iShares MSCI China ETF","63.12","4544640000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mchi",
"SCZ","iShares MSCI EAFE Small-Cap ETF","58.27","9626204000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/scz",
"EEMA","iShares MSCI Emerging Markets Asia ETF","68.32","519232000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/eema",
"EMXC","iShares MSCI Emerging Markets ex China ETF","49.28","14784000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/emxc",
"EUFN","iShares MSCI Europe Financials Sector Index Fund","18.71","694141000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/eufn",
"IEUS","iShares MSCI Europe Small-Cap ETF","51.4891","280615595","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ieus",
"RING","iShares MSCI Global Gold Miners ETF","17.31","213778500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ring",
"SDG","iShares MSCI Global Impact ETF","59.72","47776000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sdg",
"EWJE","iShares MSCI Japan Equal Weighted ETF","33.95","10185000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ewje",
"EWJV","iShares MSCI Japan Value ETF","25.14","10056000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ewjv",
"ENZL","iShares MSCI New Zealand ETF","52.18","169585000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/enzl",
"QAT","iShares MSCI Qatar ETF","18.49","55470000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qat",
"TUR","iShares MSCI Turkey ETF","24.3","391230000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tur",
"UAE","iShares MSCI UAE ETF","14.7901","51765350","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/uae",
"IBB","iShares Nasdaq Biotechnology Index Fund","112.82","8100476000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ibb",
"SOXX","iShares PHLX SOX Semiconductor Sector Index Fund","194.56","1089536000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/soxx",
"PFF","iShares Preferred and Income Securities ETF","36.64","14437992000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pff",
"AMCA","iShares Russell 1000 Pure U.S. Revenue ETF","27.69","11076000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/amca",
"EMIF","iShares S&P Emerging Markets Infrastructure Index Fund","28.699","25829100","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/emif",
"ICLN","iShares S&P Global Clean Energy Index Fund","9.89","211646000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/icln",
"WOOD","iShares S&P Global Timber & Forestry Index Fund","65.27","285882600","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wood",
"INDY","iShares S&P India Nifty 50 Index Fund","38.41","839258500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/indy",
"IJT","iShares S&P Small-Cap 600 Growth ETF","179.4","5606250000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ijt",
"DVY","iShares Select Dividend ETF","99.05","17239652500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dvy",
"SHV","iShares Short Treasury Bond ETF","110.38","19537260000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/shv",
"IGSB","iShares Short-Term Corporate Bond ETF","52.61","10624589500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/igsb",
"ISRL","Isramco, Inc.","118","320682464","n/a","1983","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/isrl",
"ITMR","Itamar Medical Ltd.","11.61","5665250.43","487963","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/itmr",
"ITI","Iteris, Inc.","4.19","139747984.79","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/iti",
"ITRM","Iterum Therapeutics plc","8.5838","123327240.0558","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/itrm",
"ITRI","Itron, Inc.","46.78","1864406561.62","n/a","1993","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/itri",
"ITRN","Ituran Location and Control Ltd.","34.72","728032777.92","n/a","2005","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/itrn",
"IVENC","Ivy NextShares","100.02","44996097.42","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ivenc",
"IVFGC","Ivy NextShares","100.02","43012800.84","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ivfgc",
"IVFVC","Ivy NextShares","100.02","45012500.7","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ivfvc",
"IZEA","IZEA Worldwide, Inc.","1.2","15389522.4","n/a","n/a","Consumer Services","Advertising","https://www.nasdaq.com/symbol/izea",
"JJSF","J & J Snack Foods Corp.","152.5","2864352600","n/a","1986","Consumer Non-Durables","Specialty Foods","https://www.nasdaq.com/symbol/jjsf",
"MAYS","J. W. Mays, Inc.","37.21","75007173.8","n/a","n/a","Consumer Services","Building operators","https://www.nasdaq.com/symbol/mays",
"JBHT","J.B. Hunt Transport Services, Inc.","103.22","11224017697.36","n/a","n/a","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/jbht",
"JCOM","j2 Global, Inc.","87.49","4265308892.91","n/a","1999","Technology","Telecommunications Equipment","https://www.nasdaq.com/symbol/jcom",
"JKHY","Jack Henry & Associates, Inc.","141.78","10942099907.58","n/a","1985","Technology","EDP Services","https://www.nasdaq.com/symbol/jkhy",
"JACK","Jack In The Box Inc.","80.92","2088286579.68","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/jack",
"JAGX","Jaguar Health, Inc.","0.2925","13274680.185","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/jagx",
"JAKK","JAKKS Pacific, Inc.","1.03","30299037.23","n/a","1996","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/jakk",
"JRVR","James River Group Holdings, Ltd.","39.75","1195184913.75","n/a","2014","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/jrvr",
"JSML","Janus Henderson Small Cap Growth Alpha ETF","41.8182","29356334.5818","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jsml",
"JSMD","Janus Henderson Small/Mid Cap Growth Alpha ETF","43.7299","63495771.0701","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jsmd",
"JASN","Jason Industries, Inc.","1.57","43402135.04","n/a","2013","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/jasn",
"JASNW","Jason Industries, Inc.","0.003","0","n/a","2013","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/jasnw",
"JAZZ","Jazz Pharmaceuticals plc","140.7","8027741351.7","n/a","2007","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/jazz",
"JD","JD.com, Inc.","30.29","28005660264.4","924584360","2014","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/jd",
"JSYN","Jensyn Acquistion Corp.","9.86","17940092.52","n/a","2016","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/jsyn",
"JSYNR","Jensyn Acquistion Corp.","0.31","0","n/a","2016","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/jsynr",
"JSYNU","Jensyn Acquistion Corp.","12.25","0","n/a","2016","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/jsynu",
"JSYNW","Jensyn Acquistion Corp.","0.0902","0","n/a","2016","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/jsynw",
"JRSH","Jerash Holdings (US), Inc.","7.5599","85615867.5","n/a","2018","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/jrsh",
"JBLU","JetBlue Airways Corporation","16.81","5050281537.27","n/a","2002","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/jblu",
"JCTCF","Jewett-Cameron Trading Company","9.05","38181841.4","n/a","n/a","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/jctcf",
"JMU","JMU Limited","1.76","4511995.84","2563634","2015","Technology","EDP Services","https://www.nasdaq.com/symbol/jmu",
"JBSS","John B. Sanfilippo & Son, Inc.","70.6","803905256","n/a","1991","Consumer Non-Durables","Specialty Foods","https://www.nasdaq.com/symbol/jbss",
"JOUT","Johnson Outdoors Inc.","69.81","700821612.66","n/a","n/a","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/jout",
"JNCE","Jounce Therapeutics, Inc.","6.73","221903881.85","n/a","2017","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/jnce",
"KALU","Kaiser Aluminum Corporation","106.84","1719482212.12","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/kalu",
"KALA","Kala Pharmaceuticals, Inc.","8.42","285293782.24","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kala",
"KLDO","Kaleido Biosciences, Inc.","13.95","410057822.7","n/a","2019","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/kldo",
"KALV","KalVista Pharmaceuticals, Inc.","28.75","495861255","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kalv",
"KMDA","Kamada Ltd.","5.65","227667190.7","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kmda",
"KNDI","Kandi Technologies Group, Inc.","5.7","293532580.8","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/kndi",
"KPTI","Karyopharm Therapeutics Inc.","5.58","339595703.1","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kpti",
"KZIA","Kazia Therapeutics Limited","3.3898","5680125.1496","1675652","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kzia",
"KBLM","KBL Merger Corp. IV","10.39","154577225","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/kblm",
"KBLMR","KBL Merger Corp. IV","0.23","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/kblmr",
"KBLMU","KBL Merger Corp. IV","10.51","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/kblmu",
"KBLMW","KBL Merger Corp. IV","0.112","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/kblmw",
"KBSF","KBS Fashion Group Limited","3.95","8802563.15","n/a","2013","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/kbsf",
"KRNY","Kearny Financial","12.99","1209391407.75","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/krny",
"KELYA","Kelly Services, Inc.","22.21","863348719.12","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/kelya",
"KELYB","Kelly Services, Inc.","23.4","909606484.8","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/kelyb",
"KMPH","KemPharm, Inc.","1.84","49083015.68","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kmph",
"KFFB","Kentucky First Federal Bancorp","7.75","64900941.25","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/kffb",
"KEQU","Kewaunee Scientific Corporation","21.1","57953217.8","n/a","n/a","Capital Goods","Medical Specialities","https://www.nasdaq.com/symbol/kequ",
"KTCC","Key Tronic Corporation","6.18","66494822.4","n/a","1983","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/ktcc",
"KZR","Kezar Life Sciences, Inc.","19.62","375103420.02","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kzr",
"KFRC","Kforce, Inc.","35.92","929475869.84","n/a","1995","Technology","Professional Services","https://www.nasdaq.com/symbol/kfrc",
"KE","Kimball Electronics, Inc.","16.08","410773617.84","n/a","n/a","Technology","Electrical Products","https://www.nasdaq.com/symbol/ke",
"KBAL","Kimball International, Inc.","13.98","513229733.76","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/kbal",
"KIN","Kindred Biosciences, Inc.","9.2","357467416.8","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kin",
"KGJI","Kingold Jewelry Inc.","0.86","56857611.72","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/kgji",
"KINS","Kingstone Companies, Inc","14.13","152039393.46","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/kins",
"KNSA","Kiniksa Pharmaceuticals, Ltd.","17.49","950269478.4","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/knsa",
"KNSL","Kinsale Capital Group, Inc.","66.19","1406553584.17","n/a","2016","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/knsl",
"KIRK","Kirkland&#39;s, Inc.","6.89","98986611.23","n/a","2002","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/kirk",
"KTOV","Kitov Pharma Ltd.","1.14","11957951.34","10489431","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ktov",
"KTOVW","Kitov Pharma Ltd.","0.16","0","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ktovw",
"KLAC","KLA-Tencor Corporation","121.95","19958823336.6","n/a","1980","Capital Goods","Electronic Components","https://www.nasdaq.com/symbol/klac",
"KLXE","KLX Energy Services Holdings, Inc. ","25.66","593502713.4","n/a","n/a","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/klxe",
"KOD","Kodiak Sciences Inc","6.2","228841113.4","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/kod",
"KONA","Kona Grill, Inc.","0.8","10608256.8","n/a","2005","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/kona",
"KOPN","Kopin Corporation","1.29","107785677.81","n/a","1992","Technology","Semiconductors","https://www.nasdaq.com/symbol/kopn",
"KRNT","Kornit Digital Ltd.","25.4","893524095.6","n/a","2015","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/krnt",
"KOSS","Koss Corporation","2.0592","15248027.9952","n/a","n/a","Consumer Non-Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/koss",
"KWEB","KraneShares Trust KraneShares CSI China Internet ETF","47.83","162622000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kweb",
"KTOS","Kratos Defense & Security Solutions, Inc.","15.78","1670664767.76","n/a","n/a","Capital Goods","Military/Government/Technical","https://www.nasdaq.com/symbol/ktos",
"KRYS","Krystal Biotech, Inc.","31.69","457323650.54","n/a","2017","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/krys",
"KLIC","Kulicke and Soffa Industries, Inc.","22.41","1482212302.65","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/klic",
"KURA","Kura Oncology, Inc.","16.53","630934247.73","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kura",
"KVHI","KVH Industries, Inc.","10.06","178504348.26","n/a","1996","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/kvhi",
"FSTR","L.B. Foster Company","19.66","208027984.46","n/a","n/a","Basic Industries","Metal Fabrications","https://www.nasdaq.com/symbol/fstr",
"LJPC","La Jolla Pharmaceutical Company","7.01","189803958.71","n/a","1994","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/ljpc",
"LSBK","Lake Shore Bancorp, Inc.","15.6079","93687200.145","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/lsbk",
"LBAI","Lakeland Bancorp, Inc.","15.27","768642890.19","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/lbai",
"LKFN","Lakeland Financial Corporation","46.28","1185418048.88","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/lkfn",
"LAKE","Lakeland Industries, Inc.","11.67","94754424.96","n/a","1986","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/lake",
"LRCX","Lam Research Corporation","184.26","28116869834.04","n/a","1984","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/lrcx",
"LAMR","Lamar Advertising Company","80.76","8042349488.52","n/a","1996","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/lamr",
"LANC","Lancaster Colony Corporation","153.04","4209823554.8","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/lanc",
"LNDC","Landec Corporation","12.54","365794909.92","n/a","1996","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/lndc",
"LARK","Landmark Bancorp Inc.","23","100558668","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/lark",
"LMRK","Landmark Infrastructure Partners LP","16.19","410229214.08","n/a","2014","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/lmrk",
"LMRKN","Landmark Infrastructure Partners LP","24.751","49502000","n/a","n/a","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/lmrkn",
"LMRKO","Landmark Infrastructure Partners LP","25","61575375","n/a","n/a","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/lmrko",
"LMRKP","Landmark Infrastructure Partners LP","25.3","40306669.7","n/a","n/a","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/lmrkp",
"LE","Lands&#39; End, Inc.","16.35","526798308","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/le",
"LSTR","Landstar System, Inc.","109.97","4411651534.08","n/a","1993","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/lstr",
"LNTH","Lantheus Holdings, Inc.","24.48","945625704.48","n/a","2015","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/lnth",
"LTRX","Lantronix, Inc.","3.09","68638846.71","n/a","2000","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/ltrx",
"LSCC","Lattice Semiconductor Corporation","12","1582196136","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/lscc",
"LAUR","Laureate Education, Inc.","15.19","3407354070.33","n/a","2017","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/laur",
"LAWS","Lawson Products, Inc.","30.72","275326464","n/a","n/a","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/laws",
"LAZY","Lazydays Holdings, Inc.","4.65","39392977.2","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/lazy",
"LCNB","LCNB Corporation","16.85","224249185.45","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/lcnb",
"LPTX","LEAP THERAPEUTICS, INC.","2.07","46078823.07","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/lptx",
"LEGH","Legacy Housing Corporation","12.49","299760000","n/a","2018","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/legh",
"LGCY","Legacy Reserves Inc.","0.4253","48828978.3763","n/a","2007","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/lgcy",
"LTXB","LegacyTexas Financial Group, Inc.","38.81","1884795230.8","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/ltxb",
"INFR","Legg Mason Global Infrastructure ETF","29.7875","35747948.9625","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/infr",
"LVHD","Legg Mason Low Volatility High Dividend ETF","31.8692","638977460","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lvhd",
"SQLV","Legg Mason Small-Cap Quality Value ETF","27.0099","8102970","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sqlv",
"LACQ","Leisure Acquisition Corp.","10.06","251500000","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/lacq",
"LACQU","Leisure Acquisition Corp.","10.24","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/lacqu",
"LACQW","Leisure Acquisition Corp.","0.6","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/lacqw",
"LMAT","LeMaitre Vascular, Inc.","30.79","604929374.97","n/a","2006","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/lmat",
"TREE","LendingTree, Inc.","352.36","4520958503.6","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/tree",
"LEVL","Level One Bancorp, Inc.","23.91","185296068.21","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/levl",
"LXRX","Lexicon Pharmaceuticals, Inc.","5.73","608938141.71","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/lxrx",
"LX","LexinFintech Holdings Ltd.","11.94","815419661.76","68293104","2017","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/lx",
"LFAC","LF Capital Acquistion Corp.","10.05","195032812.5","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/lfac",
"LFACU","LF Capital Acquistion Corp.","10.45","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/lfacu",
"LFACW","LF Capital Acquistion Corp.","0.35","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/lfacw",
"LGIH","LGI Homes, Inc.","61.74","1401953949.9","n/a","2013","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/lgih",
"LHCG","LHC Group","108.41","3404742998.11","n/a","2005","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/lhcg",
"LLIT","Lianluo Smart Limited","1.3877","24432659.3922","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/llit",
"LBRDA","Liberty Broadband Corporation","92.55","16784877625.2","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/lbrda",
"LBRDK","Liberty Broadband Corporation","92.68","16808454438.72","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/lbrdk",
"LEXEA","Liberty Expedia Holdings, Inc.","43.42","2489112939.3","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/lexea",
"LEXEB","Liberty Expedia Holdings, Inc.","43.584","2498514471.36","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/lexeb",
"LBTYA","Liberty Global plc","25.31","18782664287.56","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/lbtya",
"LBTYB","Liberty Global plc","26.6","19739979061.6","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/lbtyb",
"LBTYK","Liberty Global plc","24.62","18270612199.12","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/lbtyk",
"LILA","Liberty Latin America Ltd.","20.07","3632332924.35","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/lila",
"LILAK","Liberty Latin America Ltd.","20.15","3646811580.75","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/lilak",
"BATRA","Liberty Media Corporation","27.42","280906685.22","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/batra",
"BATRK","Liberty Media Corporation","27.27","1389860981.82","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/batrk",
"FWONA","Liberty Media Corporation","34.16","877069819.36","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/fwona",
"FWONK","Liberty Media Corporation","35.21","8134098112.63","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/fwonk",
"LSXMA","Liberty Media Corporation","39.19","4029113553.84","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/lsxma",
"LSXMB","Liberty Media Corporation","39.63","389227273.53","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/lsxmb",
"LSXMK","Liberty Media Corporation","39.31","12715001112.2","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/lsxmk",
"LTRPA","Liberty TripAdvisor Holdings, Inc.","14.64","1099122595.2","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/ltrpa",
"LTRPB","Liberty TripAdvisor Holdings, Inc.","14.35","1077350358","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/ltrpb",
"LCUT","Lifetime Brands, Inc.","9.45","196147904.4","n/a","1991","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/lcut",
"LFVN","Lifevantage Corporation","14.48","206828917.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/lfvn",
"LWAY","Lifeway Foods, Inc.","2.22","35159682.9","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/lway",
"LGND","Ligand Pharmaceuticals Incorporated","123.46","2524189948.22","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/lgnd",
"LTBR","Lightbridge Corporation","0.74","25867637.58","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/ltbr",
"LPTH","LightPath Technologies, Inc.","1.52","39233683.68","n/a","1996","Technology","Semiconductors","https://www.nasdaq.com/symbol/lpth",
"LLEX","Lilis Energy, Inc.","1.1","78646676.9","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/llex",
"LMB","Limbach Holdings, Inc.","7.73","58676713.94","n/a","n/a","Basic Industries","Engineering & Construction","https://www.nasdaq.com/symbol/lmb",
"LLNW","Limelight Networks, Inc.","3.23","369027541.99","n/a","2007","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/llnw",
"LMST","Limestone Bancorp, Inc.","15","112229175","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/lmst",
"LMNR","Limoneira Co","23.99","426368344.47","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/lmnr",
"LINC","Lincoln Educational Services Corporation","3.23","81116827.87","n/a","2005","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/linc",
"LECO","Lincoln Electric Holdings, Inc.","86.78","5475564342.06","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/leco",
"LIND","Lindblad Expeditions Holdings Inc. ","15.56","711748025.16","n/a","2013","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/lind",
"LINDW","Lindblad Expeditions Holdings Inc. ","4.83","0","n/a","2013","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/lindw",
"LPCN","Lipocine Inc.","2.32","55399159.36","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/lpcn",
"YVR","Liquid Media Group Ltd.","3.39","13934710.26","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/yvr",
"LQDA","Liquidia Technologies, Inc.","10.53","196199235.18","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/lqda",
"LQDT","Liquidity Services, Inc.","7.34","244475604.02","n/a","2006","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/lqdt",
"LFUS","Littelfuse, Inc.","185.44","4582263753.12","n/a","n/a","Consumer Durables","Electrical Products","https://www.nasdaq.com/symbol/lfus",
"LIVN","LivaNova PLC","96.32","4650617885.76","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/livn",
"LOB","Live Oak Bancshares, Inc.","15.2","610437593.6","n/a","2015","Finance","Major Banks","https://www.nasdaq.com/symbol/lob",
"LIVE","Live Ventures Incorporated","7.5771","14717971.1988","n/a","n/a","Finance","Finance/Investors Services","https://www.nasdaq.com/symbol/live",
"LPSN","LivePerson, Inc.","29.87","1909786988.75","n/a","2000","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/lpsn",
"LIVX","LiveXLive Media, Inc.","5.45","283913613.45","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/livx",
"LKQ","LKQ Corporation","29.17","9174927726.68","n/a","n/a","Consumer Services","Motor Vehicles","https://www.nasdaq.com/symbol/lkq",
"LMFA","LM Funding America, Inc.","1.38","4325281.56","n/a","2015","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/lmfa",
"LMFAW","LM Funding America, Inc.","0.0201","0","n/a","2015","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/lmfaw",
"LOGC","LogicBio Therapeutics, Inc.","10.1","223978902.9","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/logc",
"LOGI","Logitech International S.A.","39.8","6596913759.6","n/a","1997","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/logi",
"LOGM","LogMein, Inc.","82.63","4200867637.11","n/a","2009","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/logm",
"CNCR","Loncar Cancer Immunotherapy ETF","21.48","40812000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cncr",
"CHNA","Loncar China BioPharma ETF","24.09","3613500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/chna",
"LONE","Lonestar Resources US Inc.","4.41","109251765.63","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/lone",
"LOAC","Longevity Acquisition Corporation","9.99","52647300","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/loac",
"LOACR","Longevity Acquisition Corporation","0.19","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/loacr",
"LOACU","Longevity Acquisition Corporation","10.244","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/loacu",
"LOACW","Longevity Acquisition Corporation","0.12","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/loacw",
"LOOP","Loop Industries, Inc.","7.76","262332278.56","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/loop",
"LORL","Loral Space and Communications, Inc.","36.6","784231054.8","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/lorl",
"LPLA","LPL Financial Holdings Inc.","70.51","5946403877.92","n/a","2010","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/lpla",
"LRAD","LRAD Corporation","2.98","97193096.34","n/a","n/a","Consumer Non-Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/lrad",
"LYTS","LSI Industries Inc.","2.59","67052445.25","n/a","1985","Consumer Durables","Building Products","https://www.nasdaq.com/symbol/lyts",
"LULU","lululemon athletica inc.","165.47","20399164765.8","n/a","2007","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/lulu",
"LITE","Lumentum Holdings Inc.","57.9","4406190000","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/lite",
"LMNX","Luminex Corporation","23.47","1048522907.16","n/a","2000","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/lmnx",
"LUNA","Luna Innovations Incorporated","4.26","119815047.48","n/a","2006","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/luna",
"LKCO","Luokung Technology Corp","7.41","10411050","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/lkco",
"LBC","Luther Burbank Corporation","10.45","590442117.1","n/a","2003","Finance","Major Banks","https://www.nasdaq.com/symbol/lbc",
"LYFT","Lyft, Inc.","68.97","18716222751.27","n/a","2019","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/lyft",
"MBTF","M B T Financial Corp","10.25","236126769.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mbtf",
"MCBC","Macatawa Bank Corporation","10.11","344085246.39","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mcbc",
"MFNC","Mackinac Financial Corporation","15.74","168920184.7","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mfnc",
"MTSI","MACOM Technology Solutions Holdings, Inc.","17.29","1130512494.02","n/a","2012","Technology","Semiconductors","https://www.nasdaq.com/symbol/mtsi",
"MGNX","MacroGenics, Inc.","18.79","916582231.59","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mgnx",
"MDGL","Madrigal Pharmaceuticals, Inc.","131.83","2032431547.12","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mdgl",
"MAGS","Magal Security Systems Ltd.","5.24","120780108.36","n/a","1993","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/mags",
"MGLN","Magellan Health, Inc.","64.89","1552515442.38","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/mgln",
"MGTA","Magenta Therapeutics, Inc.","15.47","517727157.22","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mgta",
"MGIC","Magic Software Enterprises Ltd.","8.48","414596002.24","n/a","1991","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mgic",
"MGYR","Magyar Bancorp, Inc.","11.6199","67636486.4454","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/mgyr",
"MHLD","Maiden Holdings, Ltd.","0.7501","62226717.0395","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/mhld",
"MJCO","Majesco","7.215","308787461.775","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mjco",
"MMYT","MakeMyTrip Limited","27.9","1655669700","n/a","2010","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/mmyt",
"MBUU","Malibu Boats, Inc.","40.18","837215110.34","n/a","2014","Capital Goods","Marine Transportation","https://www.nasdaq.com/symbol/mbuu",
"MLVF","Malvern Bancorp, Inc.","20.33","158057496.02","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/mlvf",
"MAMS","MAM Software Group, Inc.","8.61","108526208.7","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mams",
"TUSK","Mammoth Energy Services, Inc.","17.01","763351799.49","n/a","2016","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/tusk",
"RPIBC","Managed Portfolio Series","99.95","12493750","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rpibc",
"MANH","Manhattan Associates, Inc.","56.11","3624364233.99","n/a","1998","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/manh",
"LOAN","Manhattan Bridge Capital, Inc","6.46","62371151.42","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/loan",
"MNTX","Manitex International, Inc.","7.65","150531291.45","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/mntx",
"MTEX","Mannatech, Incorporated","17.8146","42678740.0682","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/mtex",
"MNKD","MannKind Corporation","1.73","324849071.9","n/a","2004","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mnkd",
"MANT","ManTech International Corporation","53.39","2123369899.31","n/a","2002","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/mant",
"MARA","Marathon Patent Group, Inc.","0.678","17302519.32","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/mara",
"MCHX","Marchex, Inc.","4.72","174835115.36","n/a","2004","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/mchx",
"MRIN","Marin Software Incorporated","4.77","28398676.77","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/mrin",
"MARPS","Marine Petroleum Trust","2.45","4900000","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/marps",
"MRNS","Marinus Pharmaceuticals, Inc.","4.21","221105044.73","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mrns",
"MRKR","Marker Therapeutics, Inc.","6.45","293266561.8","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mrkr",
"MKTX","MarketAxess Holdings, Inc.","248.69","9367956083.59","n/a","2004","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/mktx",
"MRLN","Marlin Business Services Corp.","21.16","260877915.84","n/a","2003","Finance","Major Banks","https://www.nasdaq.com/symbol/mrln",
"MAR","Marriott International","128.5","43647445811.5","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/mar",
"MBII","Marrone Bio Innovations, Inc.","1.45","160494700","n/a","2013","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/mbii",
"MRTN","Marten Transport, Ltd.","17.69","965273229.91","n/a","1986","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/mrtn",
"MMLP","Martin Midstream Partners L.P.","12.62","492800664.22","n/a","2002","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/mmlp",
"MRVL","Marvell Technology Group Ltd.","20.18","13300638000","n/a","2000","Technology","Semiconductors","https://www.nasdaq.com/symbol/mrvl",
"MASI","Masimo Corporation","136.4","7252664619.2","n/a","2007","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/masi",
"MCFT","MasterCraft Boat Holdings, Inc.","22.62","423625143.24","n/a","2015","Capital Goods","Marine Transportation","https://www.nasdaq.com/symbol/mcft",
"MTCH","Match Group, Inc.","56.68","15782484445.52","n/a","2015","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/mtch",
"MTLS","Materialise NV","16.11","272904527.7","16940070","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mtls",
"MTRX","Matrix Service Company","19.26","515866138.02","n/a","1990","Basic Industries","Engineering & Construction","https://www.nasdaq.com/symbol/mtrx",
"MAT","Mattel, Inc.","13.49","4659395169.68","n/a","n/a","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/mat",
"MATW","Matthews International Corporation","36.43","1161069382.49","n/a","1994","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/matw",
"MXIM","Maxim Integrated Products, Inc.","54.96","15025972766.4","n/a","1988","Technology","Semiconductors","https://www.nasdaq.com/symbol/mxim",
"MXWL","Maxwell Technologies, Inc.","4.49","206578385.01","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/mxwl",
"MGRC","McGrath RentCorp","57.36","1387097932.56","n/a","1984","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/mgrc",
"MDCA","MDC Partners Inc.","2.15","154571108.85","n/a","n/a","Technology","Advertising","https://www.nasdaq.com/symbol/mdca",
"MDJH","MDJM LTD","3.7","44326000","n/a","2019","Finance","Real Estate","https://www.nasdaq.com/symbol/mdjh",
"MDRR","Medalist Diversified REIT, Inc.","7.65","17760102.3","n/a","2018","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/mdrr",
"MFIN","Medallion Financial Corp.","6.97","170299250.66","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/mfin",
"MFINL","Medallion Financial Corp.","26","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/mfinl",
"MNOV","MediciNova, Inc.","9.55","402740785.5","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mnov",
"MDSO","Medidata Solutions, Inc.","75.83","4722462255.95","n/a","2009","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mdso",
"MDGS","Medigus Ltd.","3.02","4972279","1646450","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/mdgs",
"MDGSW","Medigus Ltd.","0.55","0","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/mdgsw",
"MDWD","MediWound Ltd.","4.96","134807041.44","n/a","2014","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/mdwd",
"MEDP","Medpace Holdings, Inc.","60.67","2165238525.28","n/a","2016","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/medp",
"MEIP","MEI Pharma, Inc.","3.1","220562340.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/meip",
"MGTX","MeiraGTx Holdings plc","18.18","603280284.12","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/mgtx",
"MLCO","Melco Resorts & Entertainment Limited","25.01","6045831215.54","241736554","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/mlco",
"MLNT","Melinta Therapeutics, Inc.","3.98","44694990.06","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mlnt",
"MLNX","Mellanox Technologies, Ltd.","118.06","6436149042.96","n/a","2007","Technology","Semiconductors","https://www.nasdaq.com/symbol/mlnx",
"MELR","Melrose Bancorp, Inc.","18.16","44312815.28","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/melr",
"MNLO","Menlo Therapeutics Inc.","7.83","182111580.72","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mnlo",
"MTSL","MER Telemanagement Solutions Ltd.","1.83","6028611.09","n/a","1997","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/mtsl",
"MELI","MercadoLibre, Inc.","509.99","23053006061.41","n/a","2007","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/meli",
"AMTB","Mercantil Bank Holding Corporation","15.45","652568370.75","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/amtb",
"AMTBB","Mercantil Bank Holding Corporation","12.4365","525285860.3775","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/amtbb",
"MBWM","Mercantile Bank Corporation","32.83","538926281.95","n/a","1998","Finance","Major Banks","https://www.nasdaq.com/symbol/mbwm",
"MERC","Mercer International Inc.","13.85","903043004.85","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/merc",
"MBIN","Merchants Bancorp","21.9","628621169.7","n/a","2017","Finance","Major Banks","https://www.nasdaq.com/symbol/mbin",
"MBINP","Merchants Bancorp","26.12","52240000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mbinp",
"MRCY","Mercury Systems Inc","63.94","3098471401.24","n/a","1998","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/mrcy",
"EBSB","Meridian Bancorp, Inc.","16.03","857858177.82","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ebsb",
"VIVO","Meridian Bioscience Inc.","14.2","603346668.4","n/a","1986","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/vivo",
"MRBK","Meridian Corporation","17.51","111928945.37","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/mrbk",
"MMSI","Merit Medical Systems, Inc.","61.77","3391348117.95","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/mmsi",
"MACK","Merrimack Pharmaceuticals, Inc.","7.105","94800480.32","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mack",
"MRSN","Mersana Therapeutics, Inc.","5.18","247003969.52","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mrsn",
"MRUS","Merus N.V.","13.06","297126323.02","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mrus",
"MESA","Mesa Air Group, Inc.","8.59","205325936.77","n/a","2018","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/mesa",
"MLAB","Mesa Laboratories, Inc.","228.73","884839946.43","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/mlab",
"MESO","Mesoblast Limited","5.61","44275550.55","7892255","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/meso",
"CASH","Meta Financial Group, Inc.","20.33","801408417.03","n/a","1993","Finance","Savings Institutions","https://www.nasdaq.com/symbol/cash",
"MEOH","Methanex Corporation","59.05","4562555705.65","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/meoh",
"MGEE","MGE Energy Inc.","67.28","2332487933.6","n/a","n/a","Energy","Electric Utilities: Central","https://www.nasdaq.com/symbol/mgee",
"MGPI","MGP Ingredients, Inc.","77.69","1317451715.07","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/mgpi",
"MBOT","Microbot Medical Inc. ","7.74","33341334.84","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/mbot",
"MCHP","Microchip Technology Incorporated","87.72","20786916557.16","n/a","1993","Technology","Semiconductors","https://www.nasdaq.com/symbol/mchp",
"MU","Micron Technology, Inc.","42.44","46967796746.84","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/mu",
"MSFT","Microsoft Corporation","119.19","914451120628.74","n/a","1986","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/msft",
"MSTR","MicroStrategy Incorporated","146.2","1502490528.6","n/a","1998","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mstr",
"MVIS","Microvision, Inc.","0.998","101900790","n/a","1996","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/mvis",
"MICT","MICT, Inc.","1.37","12798697.55","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/mict",
"MPB","Mid Penn Bancorp","24.24","205068412.32","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mpb",
"MTP","Midatech Pharma PLC","0.3001","1511619.3052","5037052","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mtp",
"MCEP","Mid-Con Energy Partners, LP","0.835","25600229.93","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mcep",
"MBCN","Middlefield Banc Corp.","40.46","131359984.98","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mbcn",
"MSEX","Middlesex Water Company","54.37","893261475.96","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/msex",
"MSBI","Midland States Bancorp, Inc.","24.05","583973466.05","n/a","2016","Finance","Major Banks","https://www.nasdaq.com/symbol/msbi",
"MSVB","Mid-Southern Bancorp, Inc.","12.5","44564950","n/a","2018","Finance","Savings Institutions","https://www.nasdaq.com/symbol/msvb",
"MOFG","MidWestOne Financial Group, Inc.","27.89","339450082.48","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mofg",
"MLND","Millendo Therapeutics, Inc. ","16.18","208953568.16","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mlnd",
"TIGO","Millicom International Cellular S.A.","61.86","6293587963.62","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tigo",
"MIME","Mimecast Limited","49.62","2998130807.64","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mime",
"MNDO","MIND C.T.I. Ltd.","2.13","41424704.34","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/mndo",
"NERV","Minerva Neurosciences, Inc","8.17","318838098.07","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nerv",
"MGEN","Miragen Therapeutics, Inc.","2.93","90599171.67","n/a","2014","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/mgen",
"MRTX","Mirati Therapeutics, Inc.","70.52","2487071222.52","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mrtx",
"MSON","MISONIX, Inc.","19.75","186856784.25","n/a","1992","Capital Goods","Medical Specialities","https://www.nasdaq.com/symbol/mson",
"MIND","Mitcham Industries, Inc.","3.76","45568940.24","n/a","1994","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/mind",
"MINDP","Mitcham Industries, Inc.","24.8","19790400","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/mindp",
"MITK","Mitek Systems, Inc.","12","464816292","n/a","n/a","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/mitk",
"MKSI","MKS Instruments, Inc.","94.8","5140526587.2","n/a","1999","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/mksi",
"MMAC","MMA Capital Holdings, Inc.","31","182332080","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/mmac",
"MTC","MMTec, Inc.","4.5716","90517680","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/mtc",
"MINI","Mobile Mini, Inc.","34.33","1540334575.1","n/a","1994","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/mini",
"MOBL","MobileIron, Inc.","5.67","605517262.56","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mobl",
"MMDM","Modern Media Acquisition Corp.","10.375","268453125","n/a","2017","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/mmdm",
"MMDMR","Modern Media Acquisition Corp.","0.28","0","n/a","2017","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/mmdmr",
"MMDMU","Modern Media Acquisition Corp.","11.1119","0","n/a","2017","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/mmdmu",
"MMDMW","Modern Media Acquisition Corp.","0.28","0","n/a","2017","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/mmdmw",
"MRNA","Moderna, Inc.","19.7","6481309239.3","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/mrna",
"MOGO","Mogo Finance Technology Inc.","2.45","56905772.7","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/mogo",
"MTEM","Molecular Templates, Inc.","6.2","226275919.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mtem",
"MBRX","Moleculin Biotech, Inc.","0.9375","27313153.125","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mbrx",
"MNTA","Momenta Pharmaceuticals, Inc.","14.58","1436262605.1","n/a","2004","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/mnta",
"MOMO","Momo Inc.","39.88","6254918022.28","156843481","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/momo",
"MKGI","Monaker Group, Inc.","1.98","18990092.88","n/a","n/a","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/mkgi",
"MCRI","Monarch Casino & Resort, Inc.","45.2","811334847.2","n/a","1993","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/mcri",
"MDLZ","Mondelez International, Inc.","49.64","71688571448.36","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/mdlz",
"MGI","Moneygram International, Inc.","2.17","122203048.73","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/mgi",
"MDB","MongoDB, Inc.","144.7","7860365907","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mdb",
"MNCL","Monocle Acquisition Corporation","9.79","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/mncl",
"MNCLU","Monocle Acquisition Corporation","10.12","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/mnclu",
"MNCLW","Monocle Acquisition Corporation","0.32","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/mnclw",
"MPWR","Monolithic Power Systems, Inc.","138.44","5941291040","n/a","2004","Technology","Semiconductors","https://www.nasdaq.com/symbol/mpwr",
"TYPE","Monotype Imaging Holdings Inc.","20.3","833834050.7","n/a","2007","Technology","EDP Services","https://www.nasdaq.com/symbol/type",
"MNRO","Monro, Inc. ","85.23","2821408577.64","n/a","1991","Consumer Services","Automotive Aftermarket","https://www.nasdaq.com/symbol/mnro",
"MRCC","Monroe Capital Corporation","12.38","253103702.32","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/mrcc",
"MRCCL","Monroe Capital Corporation","25.06","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mrccl",
"MNST","Monster Beverage Corporation","53.33","28966091852.77","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/mnst",
"MORN","Morningstar, Inc.","128.92","5490381015.68","n/a","2005","Finance","Investment Managers","https://www.nasdaq.com/symbol/morn",
"MOR","MorphoSys AG","24.47","223198994.04","9121332","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mor",
"MOSY","MoSys, Inc.","0.1771","7636858.383","n/a","2001","Technology","Semiconductors","https://www.nasdaq.com/symbol/mosy",
"MTFB","Motif Bio plc","1.85","2475818","1338280","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mtfb",
"MTFBW","Motif Bio plc","0.28","0","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mtfbw",
"MPAA","Motorcar Parts of America, Inc.","19.45","365837033.9","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/mpaa",
"MOTS","Motus GI Holdings, Inc.","3.77","80869806.29","n/a","2018","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/mots",
"MPVD","Mountain Province Diamonds Inc.","0.89","186997136.38","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/mpvd",
"MOXC","Moxian, Inc.","0.7801","52545353.2802","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/moxc",
"COOP","Mr. Cooper Group Inc.","9.28","842928402.56","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/coop",
"MSBF","MSB Financial Corp.","17.95","96462474.3","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/msbf",
"MTBC","MTBC, Inc.","4.93","59208028.06","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mtbc",
"MTBCP","MTBC, Inc.","26.835","58029318.915","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mtbcp",
"MTEC","MTech Acquisition Corp.","10.0782","74893623.75","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/mtec",
"MTECU","MTech Acquisition Corp.","10.82","0","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/mtecu",
"MTECW","MTech Acquisition Corp.","0.649","0","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/mtecw",
"MTSC","MTS Systems Corporation","54.32","972460595.12","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/mtsc",
"MUDS","Mudrick Capital Acquisition Corporation","10.07","209456000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/muds",
"MUDSU","Mudrick Capital Acquisition Corporation","10.58","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/mudsu",
"MUDSW","Mudrick Capital Acquisition Corporation","0.55","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/mudsw",
"LABL","Multi-Color Corporation","49.87","1023203934.88","n/a","1987","Miscellaneous","Publishing","https://www.nasdaq.com/symbol/labl",
"MBIO","Mustang Bio, Inc.","3.28","89607950.16","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mbio",
"MFSF","MutualFirst Financial Inc.","29.93","258130147.66","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mfsf",
"MVBF","MVB Financial Corp.","15.53","180261260.29","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mvbf",
"MYSZ","My Size, Inc.","0.7836","23392332.0204","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mysz",
"MYL","Mylan N.V.","27.61","14245378009.06","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/myl",
"MYND","MYnd Analytics, Inc.","1.34","11287749.96","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/mynd",
"MYNDW","MYnd Analytics, Inc.","0.2","0","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/myndw",
"MYOK","MyoKardia, Inc.","51.37","2071230951.35","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/myok",
"MYOS","MYOS RENS Technology Inc.","1.58","14481613.24","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/myos",
"MYRG","MYR Group, Inc.","35.5","589290912","n/a","n/a","Basic Industries","Water Supply","https://www.nasdaq.com/symbol/myrg",
"MYGN","Myriad Genetics, Inc.","32.8","2403331210.4","n/a","1995","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/mygn",
"NBRV","Nabriva Therapeutics plc","2.65","184704263.3","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nbrv",
"NAKD","Naked Brand Group Limited","0.3502","10380265.943","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/nakd",
"NNDM","Nano Dimension Ltd.","0.785","6733596.55","8577830","n/a","Technology","Electrical Products","https://www.nasdaq.com/symbol/nndm",
"NANO","Nanometrics Incorporated","30.92","756417016.52","n/a","1984","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/nano",
"NSTG","NanoString Technologies, Inc.","24.56","763453396.16","n/a","2013","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/nstg",
"NAOV","NanoVibronix, Inc.","4.04","17285281.4","n/a","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/naov",
"NH","NantHealth, Inc.","0.92","100731974.84","n/a","2016","Technology","EDP Services","https://www.nasdaq.com/symbol/nh",
"NK","NantKwest, Inc.","1.38","109141072.92","n/a","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/nk",
"NSSC","NAPCO Security Technologies, Inc.","20.15","372171144.8","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/nssc",
"NDAQ","Nasdaq, Inc.","89.01","14723749902.06","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/ndaq",
"NTRA","Natera, Inc.","20.99","1317969824.32","n/a","2015","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/ntra",
"NATH","Nathan&#39;s Famous, Inc.","68.88","287724089.52","n/a","1993","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/nath",
"NKSH","National Bankshares, Inc.","40.39","262760133.86","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/nksh",
"FIZZ","National Beverage Corp.","57.6","2686610304","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/fizz",
"NCMI","National CineMedia, Inc.","7.19","567726951.27","n/a","2007","Consumer Services","Advertising","https://www.nasdaq.com/symbol/ncmi",
"NESR","National Energy Services Reunited Corp.","10.23","888954049.17","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/nesr",
"NESRW","National Energy Services Reunited Corp.","1.14","0","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/nesrw",
"NGHC","National General Holdings Corp","23.55","2664270445.65","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/nghc",
"NGHCN","National General Holdings Corp","22.34","4468000","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/nghcn",
"NGHCO","National General Holdings Corp","22.65","3737250","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/nghco",
"NGHCP","National General Holdings Corp","24.05","52910000","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/nghcp",
"NGHCZ","National General Holdings Corp","25.1901","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/nghcz",
"NHLD","National Holdings Corporation","2.955","37264160.475","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/nhld",
"NHLDW","National Holdings Corporation","0.35","0","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/nhldw",
"NATI","National Instruments Corporation","44.93","5941609786.26","n/a","1995","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/nati",
"NRC","National Research Corporation","38.8","964044200","n/a","n/a","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/nrc",
"NSEC","National Security Group, Inc.","12.0973","30571522.3328","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/nsec",
"EYE","National Vision Holdings, Inc.","30.45","2381450012.55","n/a","2017","Health Care","Ophthalmic Goods","https://www.nasdaq.com/symbol/eye",
"NWLI","National Western Life Group, Inc.","265.61","965763272.2","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/nwli",
"NAII","Natural Alternatives International, Inc.","11.8","88773453.2","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/naii",
"NHTC","Natural Health Trends Corp.","12.78","145386455.76","n/a","n/a","Consumer Durables","Consumer Specialties","https://www.nasdaq.com/symbol/nhtc",
"NATR","Nature&#39;s Sunshine Products, Inc.","9.85","189841758.75","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/natr",
"BABY","Natus Medical Incorporated","25.01","844772473.88","n/a","2001","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/baby",
"JSM","Navient Corporation","21.56","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/jsm",
"NAVI","Navient Corporation","11.83","2892521607.43","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/navi",
"NMCI","Navios Maritime Containers L.P.","2.24","77510944","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/nmci",
"NBTB","NBT Bancorp Inc.","36.18","1582204801.68","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/nbtb",
"NCSM","NCS Multistage Holdings, Inc.","5.49","256213935.45","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/ncsm",
"NEBU","Nebula Acquisition Corporation","10","343750000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/nebu",
"NEBUU","Nebula Acquisition Corporation","10.25","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/nebuu",
"NEBUW","Nebula Acquisition Corporation","0.75","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/nebuw",
"NKTR","Nektar Therapeutics","33.7","5867320268.3","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nktr",
"NMRD","Nemaura Medical Inc.","1.04","215954352.64","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nmrd",
"NEOG","Neogen Corporation","57.2","2981264000","n/a","1989","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/neog",
"NEO","NeoGenomics, Inc.","20.64","1951839020.16","n/a","n/a","Health Care","Precision Instruments","https://www.nasdaq.com/symbol/neo",
"NTGN","Neon Therapeutics, Inc.","6.82","193219766.08","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/ntgn",
"NEON","Neonode Inc.","3.55","31241111.15","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/neon",
"NEOS","Neos Therapeutics, Inc.","2.51","124773799.27","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/neos",
"NVCN","Neovasc Inc.","0.4414","27360230.2024","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nvcn",
"NEPT","Neptune Wellness Solutions Inc.","3.17","253486682.01","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nept",
"UEPS","Net 1 UEPS Technologies, Inc.","3.56","202328773","n/a","2005","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/ueps",
"NETE","Net Element, Inc.","5.99","23139483.81","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/nete",
"NTAP","NetApp, Inc.","70.76","17475934512.92","n/a","1995","Technology","Electronic Components","https://www.nasdaq.com/symbol/ntap",
"NTES","NetEase, Inc.","258.29","18910060757.64","73212516","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ntes",
"NFLX","Netflix, Inc.","367.72","160546036088.84","n/a","2002","Consumer Services","Consumer Electronics/Video Chains","https://www.nasdaq.com/symbol/nflx",
"NTGR","NETGEAR, Inc.","34.27","1079700407.54","n/a","2003","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ntgr",
"NTCT","NetScout Systems, Inc.","28.49","2217427583.14","n/a","1999","Technology","EDP Services","https://www.nasdaq.com/symbol/ntct",
"NTWK","NetSol Technologies Inc.","6.51","77210618.1","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ntwk",
"CUR","Neuralstem, Inc.","0.49","8920479.4","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/cur",
"NBIX","Neurocrine Biosciences, Inc.","89.99","8173005817.33","n/a","1996","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/nbix",
"NURO","NeuroMetrix, Inc.","1.05","8274486.15","n/a","2004","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nuro",
"NUROW","NeuroMetrix, Inc.","0.0243","0","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nurow",
"STIM","Neuronetics, Inc.","15.76","284540937.28","n/a","2018","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/stim",
"NTRP","Neurotrope, Inc.","6.05","78180338.5","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ntrp",
"NBEV","New Age Beverages Corporation","5.24","393348942.08","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/nbev",
"NFE","New Fortress Energy LLC","11.41","237753273.52","n/a","2019","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/nfe",
"NYMT","New York Mortgage Trust, Inc.","6.1","1040602568.5","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nymt",
"NYMTN","New York Mortgage Trust, Inc.","23.98","129492000","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nymtn",
"NYMTO","New York Mortgage Trust, Inc.","24.92","89712000","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nymto",
"NYMTP","New York Mortgage Trust, Inc.","24.7","74100000","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/nymtp",
"NEWA","Newater Technology, Inc.","7.65","82688850","n/a","2017","Basic Industries","Miscellaneous","https://www.nasdaq.com/symbol/newa",
"NWL","Newell Brands Inc.","15.34","6485752000","n/a","n/a","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/nwl",
"NLNK","NewLink Genetics Corporation","1.76","65605939.52","n/a","2011","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nlnk",
"NMRK","Newmark Group, Inc.","8.36","1311452754.04","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/nmrk",
"NWS","News Corporation","12.48","7300247497.92","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/nws",
"NWSA","News Corporation","12.44","7276849268.76","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/nwsa",
"NEWT","Newtek Business Services Corp.","20.47","390130790.67","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/newt",
"NEWTI","Newtek Business Services Corp.","25.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/newti",
"NEWTZ","Newtek Business Services Corp.","26.1091","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/newtz",
"NXST","Nexstar Media Group, Inc.","108.67","4971184349.64","n/a","2003","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/nxst",
"NEXT","NextDecade Corporation","5.39","592095671.86","n/a","2015","Public Utilities","Oil & Gas Production","https://www.nasdaq.com/symbol/next",
"NXGN","NextGen Healthcare, Inc.","16.81","1087555107.53","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/nxgn",
"BIMI","NF Energy Saving Corporation","6.14","46499994.46","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/bimi",
"NODK","NI Holdings, Inc.","16.42","364681615.58","n/a","2017","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/nodk",
"EGOV","NIC Inc.","17.02","1149317522.38","n/a","1999","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/egov",
"NICE","NICE Ltd","124.45","5222184713.95","41962111","n/a","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/nice",
"NICK","Nicholas Financial, Inc.","9","71188632","n/a","n/a","Finance","Finance Companies","https://www.nasdaq.com/symbol/nick",
"NCBS","Nicolet Bankshares Inc.","60","567728280","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ncbs",
"NITE","Nightstar Therapeutics plc","25.3","366765852.2","14496674","2017","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/nite",
"NIHD","NII Holdings, Inc.","1.89","191604359.52","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/nihd",
"NIU","Niu Technologies","9.06","63420000","7000000","2018","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/niu",
"LASR","nLIGHT, Inc.","23.1","848898666","n/a","2018","Technology","Semiconductors","https://www.nasdaq.com/symbol/lasr",
"NMIH","NMI Holdings Inc","27.05","1825165911.3","n/a","2013","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/nmih",
"NNBR","NN, Inc.","7.93","333886361.51","n/a","1994","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/nnbr",
"NDLS","Noodles & Company","6.28","275883150.64","n/a","2013","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/ndls",
"NDSN","Nordson Corporation","136.45","7822018218.45","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/ndsn",
"NSYS","Nortech Systems Incorporated","4.28","11442301.8","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/nsys",
"NBN","Northeast Bancorp","20.33","183780984.03","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/nbn",
"NTIC","Northern Technologies International Corporation","27.07","122956731.39","n/a","n/a","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/ntic",
"NTRS","Northern Trust Corporation","93.28","20381504913.44","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ntrs",
"NTRSP","Northern Trust Corporation","25.58","5589181986.34","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ntrsp",
"NFBK","Northfield Bancorp, Inc.","14.07","700317309.72","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/nfbk",
"NRIM","Northrim BanCorp Inc","34.81","239489388.62","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/nrim",
"NWBI","Northwest Bancshares, Inc.","17.04","1808824303.44","n/a","2009","Finance","Major Banks","https://www.nasdaq.com/symbol/nwbi",
"NWPX","Northwest Pipe Company","24.66","240066456.3","n/a","1995","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/nwpx",
"NCLH","Norwegian Cruise Line Holdings Ltd.","56.5","12301623807.5","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/nclh",
"NWFL","Norwood Financial Corp.","32.8","206533465.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/nwfl",
"NVFY","Nova Lifestyle, Inc","0.95","26270194.2","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/nvfy",
"NVMI","Nova Measuring Instruments Ltd.","25.97","725216119.53","n/a","2000","Capital Goods","Electronic Components","https://www.nasdaq.com/symbol/nvmi",
"NOVN","Novan, Inc.","0.88","22941365.92","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/novn",
"NOVT","Novanta Inc.","85.74","2992377358.26","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/novt",
"NVAX","Novavax, Inc.","0.6122","270190908.2204","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/nvax",
"NVLN","Novelion Therapeutics Inc. ","1.32","25102849.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nvln",
"NVCR","NovoCure Limited","48.08","4567339791.04","n/a","2015","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nvcr",
"NVMM","Novume Solutions, Inc.","0.64","0","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/nvmm",
"NVUS","Novus Therapeutics, Inc.","4.36","41133299.48","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nvus",
"NUAN","Nuance Communications, Inc.","17.2","4909190700.8","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/nuan",
"NCNA","NuCana plc","17.25","200885910","11645560","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ncna",
"NTNX","Nutanix, Inc.","37.66","6857867094.68","n/a","2016","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ntnx",
"NUVA","NuVasive, Inc.","55.57","2881664538.03","n/a","2004","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nuva",
"NVTR","Nuvectra Corporation","11.11","196641656.09","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nvtr",
"QQQX","Nuveen NASDAQ 100 Dynamic Overwrite Fund","22.52","871075671.84","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qqqx",
"NVEE","NV5 Global, Inc.","59.95","754507799.1","n/a","2013","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/nvee",
"NVEC","NVE Corporation","97.11","470596031.1","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/nvec",
"NVDA","NVIDIA Corporation","183","110898000000","n/a","1999","Technology","Semiconductors","https://www.nasdaq.com/symbol/nvda",
"NXPI","NXP Semiconductors N.V.","92.79","27167956077.42","n/a","2010","Technology","Semiconductors","https://www.nasdaq.com/symbol/nxpi",
"NXTD","NXT-ID Inc.","1.07","27062398.27","n/a","n/a","Consumer Services","Diversified Commercial Services","https://www.nasdaq.com/symbol/nxtd",
"NXTDW","NXT-ID Inc.","0.0422","0","n/a","n/a","Consumer Services","Diversified Commercial Services","https://www.nasdaq.com/symbol/nxtdw",
"NYMX","Nymox Pharmaceutical Corporation","2.08","140766612.48","n/a","n/a","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/nymx",
"OIIM","O2Micro International Limited","1.51","50393972.92","33373492","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/oiim",
"OVLY","Oak Valley Bancorp (CA)","19.2","157352812.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ovly",
"OCSL","Oaktree Specialty Lending Corporation","5.22","735814598.22","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ocsl",
"OCSLL","Oaktree Specialty Lending Corporation","25.129","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ocsll",
"OCSI","Oaktree Strategic Income Corporation","8.15","240154159.2","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ocsi",
"OASM","Oasmia Pharmaceutical AB","2.2337","1317311.1728","589744","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/oasm",
"OBLN","Obalon Therapeutics, Inc.","1.47","34549151.28","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/obln",
"OBSV","ObsEva SA","12.97","563467525.67","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/obsv",
"OBCI","Ocean Bio-Chem, Inc.","3.29","30814531.51","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/obci",
"OPTT","Ocean Power Technologies, Inc.","5","240065","n/a","2007","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/optt",
"OCFC","OceanFirst Financial Corp.","24.18","1242810942.36","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/ocfc",
"OFED","Oconee Federal Financial Corp.","26.63","153400384.05","n/a","2011","Finance","Savings Institutions","https://www.nasdaq.com/symbol/ofed",
"OCUL","Ocular Therapeutix, Inc.","4.15","177771773.8","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ocul",
"ODT","Odonate Therapeutics, Inc.","24.35","651427490.15","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/odt",
"OMEX","Odyssey Marine Exploration, Inc.","7.02","64351701.18","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/omex",
"ODP","Office Depot, Inc.","3.61","1961062505.71","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/odp",
"OPI","Office Properties Income Trust","28.03","1348016041.09","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/opi",
"OPINI","Office Properties Income Trust","24.92","0","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/opini",
"OFS","OFS Capital Corporation","11.98","160020897.26","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ofs",
"OFSSL","OFS Capital Corporation","25.38","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ofssl",
"OFSSZ","OFS Capital Corporation","25.18","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ofssz",
"OCCI","OFS Credit Company, Inc.","18.25","45716761","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/occi",
"OCCIP","OFS Credit Company, Inc.","25.15","20120000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/occip",
"OHAI","OHA Investment Corporation","1.21","24408594.32","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ohai",
"OVBC","Ohio Valley Banc Corp.","36.59","174119332.81","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ovbc",
"OHRP","Ohr Pharmaceutical, Inc.","2.3","6507270.4","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ohrp",
"OKTA","Okta, Inc.","85.79","9627809773.85","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/okta",
"ODFL","Old Dominion Freight Line, Inc.","148.59","12057631095.51","n/a","1991","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/odfl",
"OLBK","Old Line Bancshares, Inc.","25.47","434091119.04","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/olbk",
"ONB","Old National Bancorp","16.78","2944564266.64","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/onb",
"OPOF","Old Point Financial Corporation","20.88","108265952.88","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/opof",
"OSBC","Old Second Bancorp, Inc.","12.85","384086307.25","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/osbc",
"OSBCP","Old Second Bancorp, Inc.","10.7569","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/osbcp",
"OLLI","Ollie&#39;s Bargain Outlet Holdings, Inc.","84.78","5357450739.42","n/a","2015","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/olli",
"ZEUS","Olympic Steel, Inc.","17.35","190995722.65","n/a","1994","Basic Industries","Metal Fabrications","https://www.nasdaq.com/symbol/zeus",
"OFLX","Omega Flex, Inc.","76.75","774547338.5","n/a","n/a","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/oflx",
"OMER","Omeros Corporation","17.88","876329821.8","n/a","2009","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/omer",
"OMCL","Omnicell, Inc.","79.88","3259037699.6","n/a","2001","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/omcl",
"ON","ON Semiconductor Corporation","21.46","8841459869.08","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/on",
"OTIV","On Track Innovations Ltd","0.646","26676167.542","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/otiv",
"ONCY","Oncolytics Biotech Inc.","1.85","34854018.5","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/oncy",
"OMED","OncoMed Pharmaceuticals, Inc.","1.16","44880503.24","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/omed",
"ONTX","Onconova Therapeutics, Inc.","3.57","20256965.4","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ontx",
"ONTXW","Onconova Therapeutics, Inc.","0.189","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ontxw",
"ONCS","OncoSec Medical Incorporated","0.67","43421875.23","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/oncs",
"OSS","One Stop Systems, Inc.","2.14","30538373.52","n/a","2018","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/oss",
"OSPN","OneSpan Inc.","18.9","759993456.6","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/ospn",
"OSW","OneSpaWorld Holdings Limited","13.53","0","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/osw",
"OPBK","OP Bancorp","8.93","140063326.19","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/opbk",
"OTEX","Open Text Corporation","38.46","10336865739.6","n/a","1996","Technology","EDP Services","https://www.nasdaq.com/symbol/otex",
"OPRA","Opera Limited","6.6","65568835.2","9934672","2018","n/a","n/a","https://www.nasdaq.com/symbol/opra",
"OPES","Opes Acquisition Corp.","10.18","150867600","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/opes",
"OPESU","Opes Acquisition Corp.","10.3601","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/opesu",
"OPESW","Opes Acquisition Corp.","0.24","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/opesw",
"OPGN","OpGen, Inc.","0.5999","5186567.428","n/a","2015","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/opgn",
"OPGNW","OpGen, Inc.","0.091","0","n/a","2015","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/opgnw",
"OPHT","Ophthotech Corporation","1.43","59232813.64","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/opht",
"OPNT","Opiant Pharmaceuticals, Inc.","12.34","48438954.74","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/opnt",
"OPK","Opko Health, Inc.","2.52","1551313953","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/opk",
"OBAS","Optibase Ltd.","9.85","51380121.6","n/a","1999","Finance","Real Estate","https://www.nasdaq.com/symbol/obas",
"OCC","Optical Cable Corporation","4.69","34879093.83","n/a","n/a","Basic Industries","Telecommunications Equipment","https://www.nasdaq.com/symbol/occ",
"OPRX","OptimizeRx Corporation","13","157236443","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/oprx",
"OPHC","OptimumBank Holdings, Inc.","4.2714","7936346.628","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ophc",
"OPTN","OptiNose, Inc.","10.92","450607488.24","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/optn",
"OPB","Opus Bank","20.79","749657982.15","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/opb",
"ORMP","Oramed Pharmaceuticals Inc.","3.52","61171823.68","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ormp",
"OSUR","OraSure Technologies, Inc.","10.81","666577505.64","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/osur",
"ORBC","ORBCOMM Inc.","6.58","522568748.94","n/a","2006","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/orbc",
"ORTX","Orchard Therapeutics plc","18.6","299526439.2","16103572","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/ortx",
"ORLY","O&#39;Reilly Automotive, Inc.","394.33","30911068122.56","n/a","1993","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/orly",
"ORGO","Organogenesis Holdings Inc. ","7.8","717675948.6","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/orgo",
"ONVO","Organovo Holdings, Inc.","0.9773","116780842.1593","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/onvo",
"ORGS","Orgenesis Inc.","5.2","83179049.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/orgs",
"SEED","Origin Agritech Limited","7.6266","1780284.8646","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/seed",
"OBNK","Origin Bancorp, Inc.","34.4","816915204","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/obnk",
"OESX","Orion Energy Systems, Inc.","0.96","28393866.24","n/a","2015","Consumer Durables","Building Products","https://www.nasdaq.com/symbol/oesx",
"ORIT","Oritani Financial Corp.","16.95","762504886.05","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/orit",
"ORRF","Orrstown Financial Services Inc","18.81","178355836.89","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/orrf",
"OFIX","Orthofix Medical Inc. ","55.36","1055227589.12","n/a","1992","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/ofix",
"KIDS","OrthoPediatrics Corp.","40.96","601178112","n/a","2017","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/kids",
"OSIS","OSI Systems, Inc.","88.92","1606909599.36","n/a","1997","Technology","Semiconductors","https://www.nasdaq.com/symbol/osis",
"OSIR","Osiris Therapeutics, Inc.","19.01","656382773.89","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/osir",
"OSMT","Osmotica Pharmaceuticals plc","3.85","202197857.4","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/osmt",
"OSN","Ossen Innovation Co., Ltd.","1.82","4089605.52","2247036","2010","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/osn",
"OTEL","Otelco Inc.","17","57606608","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/otel",
"OTIC","Otonomy, Inc.","2.77","84998591.24","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/otic",
"OTTW","Ottawa Bancorp, Inc.","13.35","44541727.65","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/ottw",
"OTTR","Otter Tail Corporation","48.88","1941988127.04","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ottr",
"OTLK","Outlook Therapeutics, Inc.","7.3","85477211.1","n/a","2016","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/otlk",
"OTLKW","Outlook Therapeutics, Inc.","0.31","0","n/a","2016","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/otlkw",
"OSTK","Overstock.com, Inc.","16.17","521515308.93","n/a","2002","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/ostk",
"OVID","Ovid Therapeutics Inc.","1.94","74976910.48","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ovid",
"OXBR","Oxbridge Re Holdings Limited","1.38","7912350.06","n/a","2014","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/oxbr",
"OXBRW","Oxbridge Re Holdings Limited","0.0301","0","n/a","2014","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/oxbrw",
"OXFD","Oxford Immunotec Global PLC","16.57","441048843.27","n/a","2013","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/oxfd",
"OXLC","Oxford Lane Capital Corp.","9.8","373723264.6","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/oxlc",
"OXLCM","Oxford Lane Capital Corp.","25.4165","69372176.3475","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/oxlcm",
"OXLCO","Oxford Lane Capital Corp.","25.5","92208025.5","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/oxlco",
"OXSQ","Oxford Square Capital Corp.","6.53","311160762.27","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/oxsq",
"OXSQL","Oxford Square Capital Corp.","25.25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/oxsql",
"PFIN","P & F Industries, Inc.","8.31","26405523.6","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/pfin",
"PTSI","P.A.M. Transportation Services, Inc.","51","301762410","n/a","1986","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/ptsi",
"PCAR","PACCAR Inc.","68.42","23727515618.84","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/pcar",
"VETS","Pacer Military Times Best Employers ETF","27.62","2762000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vets",
"PACB","Pacific Biosciences of California, Inc.","7.28","1098988450.56","n/a","2010","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/pacb",
"PCB","Pacific City Financial Corporation","17.75","284153555.25","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/pcb",
"PEIX","Pacific Ethanol, Inc.","1.01","49379332.28","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/peix",
"PMBC","Pacific Mercantile Bancorp","7.76","170868976.48","n/a","2000","Finance","Major Banks","https://www.nasdaq.com/symbol/pmbc",
"PPBI","Pacific Premier Bancorp Inc","27.81","1738036758.87","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ppbi",
"PCRX","Pacira Pharmaceuticals, Inc.","37.97","1565494215.02","n/a","2011","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pcrx",
"PACW","PacWest Bancorp","39.1","4686122097","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pacw",
"PAAS","Pan American Silver Corp.","12.94","2710138951.92","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/paas",
"PANL","Pangaea Logistics Solutions Ltd.","3.41","151758946.9","n/a","2013","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/panl",
"PZZA","Papa John&#39;s International, Inc.","51.77","1645168648.09","n/a","1993","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/pzza",
"FRSH","Papa Murphy&#39;s Holdings, Inc.","5.24","89224246.72","n/a","2014","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/frsh",
"PRTK","Paratek Pharmaceuticals, Inc. ","5.72","185419388.44","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/prtk",
"TEUM","Pareteum Corporation","4.64","513028573.92","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/teum",
"PNRL","Paringa Resources Limited","5.1","46741617.3","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pnrl",
"PCYG","Park City Group, Inc.","7.84","155650616.8","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/pcyg",
"PKBK","Parke Bancorp, Inc.","21.39","229947612.21","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pkbk",
"PKOH","Park-Ohio Holdings Corp.","33.32","421861921.04","n/a","n/a","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/pkoh",
"PTNR","Partner Communications Company Ltd.","4.335","23566139.415","5436249","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ptnr",
"PBHC","Pathfinder Bancorp, Inc.","13.28","58262600.32","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pbhc",
"PATK","Patrick Industries, Inc.","44.69","1066839814.07","n/a","n/a","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/patk",
"PNBK","Patriot National Bancorp Inc.","15.52","60693660.48","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/pnbk",
"PATI","Patriot Transportation Holding, Inc.","19.1557","63759096.1562","n/a","n/a","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/pati",
"PEGI","Pattern Energy Group Inc.","22.16","2178348254.24","n/a","2013","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/pegi",
"PDCO","Patterson Companies, Inc.","21.93","2087056170","n/a","1992","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/pdco",
"PTEN","Patterson-UTI Energy, Inc.","14.27","3048825056.44","n/a","1993","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pten",
"PAVM","PAVmed Inc.","1.18","32028715.22","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/pavm",
"PAVMW","PAVmed Inc.","0.406","0","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/pavmw",
"PAVMZ","PAVmed Inc.","0.418","0","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/pavmz",
"PAYX","Paychex, Inc.","81.02","29118588000","n/a","1983","Consumer Services","Diversified Commercial Services","https://www.nasdaq.com/symbol/payx",
"PCTY","Paylocity Holding Corporation","89.45","4733330833","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/pcty",
"PYDS","Payment Data Systems, Inc.","2.59","43675744.98","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/pyds",
"PYPL","PayPal Holdings, Inc.","105.23","123456821689.41","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/pypl",
"PBBI","PB Bancorp, Inc.","11.35","84540372.85","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/pbbi",
"CNXN","PC Connection, Inc.","36.34","959219120.22","n/a","n/a","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/cnxn",
"PCMI","PCM, Inc.","36.04","441345083.16","n/a","n/a","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/pcmi",
"PCSB","PCSB Financial Corporation","19.51","347356800.89","n/a","2017","Finance","Banks","https://www.nasdaq.com/symbol/pcsb",
"PCTI","PC-Tel, Inc.","5.07","93436616.91","n/a","1999","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/pcti",
"PDCE","PDC Energy, Inc.","41.09","2718026579.52","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pdce",
"PDFS","PDF Solutions, Inc.","12.79","416899297.17","n/a","2001","Technology","EDP Services","https://www.nasdaq.com/symbol/pdfs",
"PDLI","PDL BioPharma, Inc.","3.76","481687832.16","n/a","1992","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/pdli",
"PDLB","PDL Community Bancorp","14.1","260328694.8","n/a","2017","Finance","Savings Institutions","https://www.nasdaq.com/symbol/pdlb",
"PDSB","PDS Biotechnology Corporation","7.5","40111305","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pdsb",
"PDVW","pdvWireless, Inc.","35.42","520519568.8","n/a","2015","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/pdvw",
"SKIS","Peak Resorts, Inc.","4.75","72037702","n/a","2014","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/skis",
"PGC","Peapack-Gladstone Financial Corporation","26.59","514496025.7","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/pgc",
"PEGA","Pegasystems Inc.","67.12","5265070533.76","n/a","1996","Technology","EDP Services","https://www.nasdaq.com/symbol/pega",
"PENN","Penn National Gaming, Inc.","20.8","2430272000","n/a","1994","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/penn",
"PVAC","Penn Virginia Corporation","42.71","645145270.21","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pvac",
"PFLT","PennantPark Floating Rate Capital Ltd.","12.86","498608871.64","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pflt",
"PNNT","PennantPark Investment Corporation","7.08","481634961.96","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/pnnt",
"PWOD","Penns Woods Bancorp, Inc.","41.55","194950397.85","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pwod",
"WRLS","Pensare Acquisition Corp.","10.26","369526314.6","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/wrls",
"WRLSR","Pensare Acquisition Corp.","0.29","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/wrlsr",
"WRLSU","Pensare Acquisition Corp.","10.5","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/wrlsu",
"WRLSW","Pensare Acquisition Corp.","0.1913","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/wrlsw",
"PEBO","Peoples Bancorp Inc.","31.08","611705961.72","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pebo",
"PEBK","Peoples Bancorp of North Carolina, Inc.","27.1","162522385.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pebk",
"PFIS","Peoples Financial Services Corp. ","45.33","335399117.82","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pfis",
"PBCT","People&#39;s United Financial, Inc.","16.7","6306198188.6","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/pbct",
"PBCTP","People&#39;s United Financial, Inc.","25.44","254400000","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/pbctp",
"PUB","People&#39;s Utah Bancorp","27.77","521938371.88","n/a","2015","Finance","Major Banks","https://www.nasdaq.com/symbol/pub",
"KPFS","Pepper Food Service Co., Ltd.","4.34","104160","24000","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/kpfs",
"PEP","Pepsico, Inc.","121.68","170873021957.04","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/pep",
"PRCP","Perceptron, Inc.","7.75","74543134.75","n/a","1992","Capital Goods","Electronic Components","https://www.nasdaq.com/symbol/prcp",
"PRFT","Perficient, Inc.","27.44","910317938.88","n/a","1999","Technology","EDP Services","https://www.nasdaq.com/symbol/prft",
"DCIX","Performance Shipping Inc.","1.16","31034467.16","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/dcix",
"PFMT","Performant Financial Corporation","2.17","115007830","n/a","2012","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/pfmt",
"PERI","Perion Network Ltd","2.85","74128417.35","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/peri",
"PESI","Perma-Fix Environmental Services, Inc.","3.62","43210394.26","n/a","n/a","Basic Industries","Environmental Services","https://www.nasdaq.com/symbol/pesi",
"PPIH","Perma-Pipe International Holdings, Inc.","8.9","70179828.6","n/a","n/a","Capital Goods","Pollution Control Equipment","https://www.nasdaq.com/symbol/ppih",
"PGLC","Pershing Gold Corporation","1.08","36371074.68","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/pglc",
"PETQ","PetIQ, Inc.","31.13","877352884.21","n/a","2017","Health Care","Other Pharmaceuticals","https://www.nasdaq.com/symbol/petq",
"PETS","PetMed Express, Inc.","22.88","473019312.48","n/a","n/a","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/pets",
"PFSW","PFSweb, Inc.","5.17","99578485.93","n/a","1999","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/pfsw",
"PGTI","PGT Innovations, Inc.","13.74","798054140.82","n/a","2006","Capital Goods","Building Products","https://www.nasdaq.com/symbol/pgti",
"PHAS","PhaseBio Pharmaceuticals, Inc.","12","293981100","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/phas",
"PAHC","Phibro Animal Health Corporation","32.79","1326349302.69","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pahc",
"PHIO","Phio Pharmaceuticals Corp.","0.4599","10255370.8068","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/phio",
"PHIOW","Phio Pharmaceuticals Corp.","0.03","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/phiow",
"PLAB","Photronics, Inc.","9.56","641012387.8","n/a","1987","Technology","Semiconductors","https://www.nasdaq.com/symbol/plab",
"PHUN","Phunware, Inc.","14.01","493169638.59","n/a","2016","Technology","EDP Services","https://www.nasdaq.com/symbol/phun",
"PHUNW","Phunware, Inc.","1.9","0","n/a","2016","Technology","EDP Services","https://www.nasdaq.com/symbol/phunw",
"PICO","PICO Holdings Inc.","10.13","207487512.27","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/pico",
"PLL","Piedmont Lithium Limited","8.2","2114115.8","257819","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pll",
"PIRS","Pieris Pharmaceuticals, Inc.","3.34","164165071.46","n/a","n/a","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/pirs",
"PPC","Pilgrim&#39;s Pride Corporation","21.49","5350259590.69","n/a","n/a","Consumer Non-Durables","Meat/Poultry/Fish","https://www.nasdaq.com/symbol/ppc",
"PDD","Pinduoduo Inc.","24.46","2243858328.42","91735827","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/pdd",
"PME","Pingtan Marine Enterprise Ltd.","2.28","180245520.84","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pme",
"PNFP","Pinnacle Financial Partners, Inc.","56.35","4368914112.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pnfp",
"PT","Pintec Technology Holdings Limited","11.22","47214545.4","4208070","2018","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/pt",
"PPSI","Pioneer Power Solutions, Inc.","5.15","44939131.75","n/a","n/a","Consumer Durables","Electrical Products","https://www.nasdaq.com/symbol/ppsi",
"PXLW","Pixelworks, Inc.","4.32","162151714.08","n/a","2000","Technology","Semiconductors","https://www.nasdaq.com/symbol/pxlw",
"PLYA","Playa Hotels & Resorts N.V.","7.55","983517563.85","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/plya",
"PLXS","Plexus Corp.","62.82","1942019301.78","n/a","n/a","Technology","Electrical Products","https://www.nasdaq.com/symbol/plxs",
"PLUG","Plug Power, Inc.","2.45","597397729.6","n/a","1999","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/plug",
"PLBC","Plumas Bancorp","23.4","120530498.4","n/a","n/a","Finance","Finance Companies","https://www.nasdaq.com/symbol/plbc",
"PS","Pluralsight, Inc.","31.94","4417173281.8","n/a","2018","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/ps",
"PSTI","Pluristem Therapeutics, Inc.","0.9436","110265862.2828","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/psti",
"PLXP","PLx Pharma Inc.","5.6","49012196.8","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/plxp",
"PNTR","Pointer Telocation Ltd.","15.5","126426571.5","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/pntr",
"PCOM","Points International, Ltd.","12.61","176150817.57","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/pcom",
"POLA","Polar Power, Inc.","4.77","48382863.66","n/a","2016","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/pola",
"PTE","PolarityTE, Inc.","10.02","217322357.16","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/pte",
"POOL","Pool Corporation","167.71","6641150134.81","n/a","1995","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/pool",
"POPE","Pope Resources","68","296881404","n/a","n/a","Consumer Non-Durables","Environmental Services","https://www.nasdaq.com/symbol/pope",
"BPOP","Popular, Inc.","53.55","5173935829.65","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bpop",
"BPOPM","Popular, Inc.","25.3426","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bpopm",
"BPOPN","Popular, Inc.","26.65","319800000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bpopn",
"KCAPL","Portman Ridge Finance Corporation","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kcapl",
"PTMN","Portman Ridge Finance Corporation","3.17","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ptmn",
"PTLA","Portola Pharmaceuticals, Inc.","37.26","2489756682.42","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ptla",
"PPHI","Positive Physicians Holdings, Inc.","14","0","n/a","2019","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/pphi",
"PBPB","Potbelly Corporation","9.21","222371637.06","n/a","2013","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/pbpb",
"PCH","PotlatchDeltic Corporation","37.54","2547723576.16","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/pch",
"POWL","Powell Industries, Inc.","27.5","339280315","n/a","n/a","Consumer Durables","Electrical Products","https://www.nasdaq.com/symbol/powl",
"POWI","Power Integrations, Inc.","70.74","2054928523.68","n/a","1997","Technology","Semiconductors","https://www.nasdaq.com/symbol/powi",
"PBTS","Powerbridge Technologies Co., Ltd.","5.14","0","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/pbts",
"PRAA","PRA Group, Inc.","27.03","1225154698.14","n/a","2002","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/praa",
"PRAH","PRA Health Sciences, Inc.","110.77","7258941867.43","n/a","2014","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/prah",
"PRAN","Prana Biotechnology Ltd","2.04","13166361.96","6454099","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pran",
"PRPO","Precipio, Inc.","0.1264","6113790.1552","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/prpo",
"DTIL","Precision BioSciences, Inc.","16.76","821747140.84","n/a","2019","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/dtil",
"AIPT","Precision Therapeutics Inc.","0.7275","11489106.315","n/a","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/aipt",
"PFBC","Preferred Bank","45.57","698402356.68","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pfbc",
"PLPC","Preformed Line Products Company","53.54","271036826.96","n/a","n/a","Basic Industries","Water Supply","https://www.nasdaq.com/symbol/plpc",
"PFBI","Premier Financial Bancorp, Inc.","15.9","232599541.8","n/a","1996","Finance","Major Banks","https://www.nasdaq.com/symbol/pfbi",
"PINC","Premier, Inc.","34.12","2176686730.68","n/a","2013","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/pinc",
"LENS","Presbia PLC","0.682","11728459.028","n/a","2015","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/lens",
"PSDO","Presidio, Inc.","14.76","1219004001.72","n/a","2017","Technology","Retail: Computer Software & Peripheral Equipment","https://www.nasdaq.com/symbol/psdo",
"PRGX","PRGX Global, Inc.","7.65","176566314.6","n/a","1996","Consumer Services","Diversified Commercial Services","https://www.nasdaq.com/symbol/prgx",
"PSMT","PriceSmart, Inc.","58.77","1792051512.48","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/psmt",
"PNRG","PrimeEnergy Resources Corporation","144.57","296293034.46","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pnrg",
"PRMW","Primo Water Corporation","14.97","583757081.13","n/a","2010","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/prmw",
"PRIM","Primoris Services Corporation","21.34","1082269154.12","n/a","n/a","Basic Industries","Water Supply","https://www.nasdaq.com/symbol/prim",
"PVAL","Principal Contrarian Value Index ETF","25.93","3889525.93","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pval",
"PFG","Principal Financial Group Inc","51.72","14394383839.92","n/a","2001","Finance","Accident &Health Insurance","https://www.nasdaq.com/symbol/pfg",
"BTEC","Principal Healthcare Innovators Index ETF","35.1523","58001330.1523","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/btec",
"PXUS","Principal International Multi-Factor Index ETF","90.695","13604340.695","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pxus",
"GENY","Principal Millennials Index ETF","37.39","18695037.39","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/geny",
"PSET","Principal Price Setters Index ETF","35.31","14124035.31","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pset",
"PY","Principal Shareholder Yield Index ETF","31.429","14143081.429","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/py",
"PMOM","Principal Sustainable Momentum Index ETF","28.117","5623428.117","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pmom",
"USMC","Principal U.S. Mega-Cap Multi-Factor Index ETF","28.23","1611933028.23","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/usmc",
"PSC","Principal U.S. Small-Cap Multi-Factor Index ETF","31.2225","351253156.2225","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psc",
"PRNB","Principia Biopharma Inc.","32.99","787321228.49","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/prnb",
"PRTH","Priority Technology Holdings, Inc.","5.8174","392432472.8904","n/a","2016","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/prth",
"PDEX","Pro-Dex, Inc.","14.9773","62053679.7686","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/pdex",
"IPDN","Professional Diversity Network, Inc.","3.26","15833650.48","n/a","2013","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/ipdn",
"PFIE","Profire Energy, Inc.","1.8","85125846.6","n/a","n/a","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/pfie",
"PGNX","Progenics Pharmaceuticals Inc.","4.91","415103743.74","n/a","1997","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pgnx",
"PRGS","Progress Software Corporation","44.66","1987064168.32","n/a","1991","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/prgs",
"PFPT","Proofpoint, Inc.","122","6752650224","n/a","2012","Technology","EDP Services","https://www.nasdaq.com/symbol/pfpt",
"PRPH","ProPhase Labs, Inc.","3.07","35479022.95","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/prph",
"PRQR","ProQR Therapeutics N.V.","15","583094040","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/prqr",
"EQRR","ProShares Equities for Rising Rates ETF","42.0717","5048646.0717","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/eqrr",
"BIB","ProShares Ultra Nasdaq Biotechnology","56.42","251069000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bib",
"UBIO","Proshares UltraPro Nasdaq Biotechnology","30.08","31581443.2","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ubio",
"TQQQ","ProShares UltraPro QQQ","59.54","4277949000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tqqq",
"ZBIO","ProShares UltraPro Short NASDAQ Biotechnology","12.8332","4491196.5044","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/zbio",
"SQQQ","ProShares UltraPro Short QQQ","9.66","1041688930.38","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sqqq",
"BIS","ProShares UltraShort Nasdaq Biotechnology","16.37","23490917.26","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bis",
"PSEC","Prospect Capital Corporation","6.57","2409836731.11","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/psec",
"PTGX","Protagonist Therapeutics, Inc.","12.22","285301146.52","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ptgx",
"PTVCA","Protective Insurance Corporation","18.4116","273402483.4404","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/ptvca",
"PTVCB","Protective Insurance Corporation","17.92","266102484.48","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/ptvcb",
"PRTO","Proteon Therapeutics, Inc.","0.58","11161317.58","n/a","2014","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/prto",
"PTI","Proteostasis Therapeutics, Inc.","1.25","63800768.75","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pti",
"PRTA","Prothena Corporation plc","12.03","479560443.33","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/prta",
"PRVB","Provention Bio, Inc.","2.38","88920517.56","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/prvb",
"PVBC","Provident Bancorp, Inc.","22.81","219562650.39","n/a","2015","Finance","Savings Institutions","https://www.nasdaq.com/symbol/pvbc",
"PROV","Provident Financial Holdings, Inc.","20.27","152224760.85","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/prov",
"PBIP","Prudential Bancorp, Inc.","17.47","155439464.76","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/pbip",
"PMD","Psychemedics Corporation","14.09","77597321.58","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/pmd",
"PTC","PTC Inc.","95.01","11270819677.2","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ptc",
"PTCT","PTC Therapeutics, Inc.","38.29","2236201016.42","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ptct",
"PHCF","PUHUI WEALTH INVESTMENT MANAGEMENT CO., LTD.","3.03","36360000","n/a","2018","Finance","Investment Managers","https://www.nasdaq.com/symbol/phcf",
"PULM","Pulmatrix, Inc.","2.02","16216347.9","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pulm",
"PLSE","Pulse Biosciences, Inc","16.61","343641499.52","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/plse",
"PBYI","Puma Biotechnology Inc","35.76","1376687800.56","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pbyi",
"PACQ","Pure Acquisition Corp.","10.07","521122500","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/pacq",
"PACQU","Pure Acquisition Corp.","10.65","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/pacqu",
"PACQW","Pure Acquisition Corp.","1.11","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/pacqw",
"PCYO","Pure Cycle Corporation","9.85","234396490.3","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/pcyo",
"PRPL","Purple Innovation, Inc.","4.75","46220521","n/a","2015","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/prpl",
"PUYI","Puyi Inc.","6.45","27685180.2","4292276","2019","Finance","Investment Managers","https://www.nasdaq.com/symbol/puyi",
"PXS","Pyxis Tankers Inc.","1.17","24640422.3","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/pxs",
"QADA","QAD Inc.","43.15","846892795.4","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/qada",
"QADB","QAD Inc.","31.75","623148233","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/qadb",
"QCRH","QCR Holdings, Inc.","34.01","535275261.61","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/qcrh",
"QGEN","Qiagen N.V.","41.14","9277577503.04","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/qgen",
"QIWI","QIWI plc","14.58","656445648.06","45023707","2013","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/qiwi",
"QRVO","Qorvo, Inc.","74.07","9094949009.55","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/qrvo",
"QCOM","QUALCOMM Incorporated","58.09","70306657706.37","n/a","1991","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/qcom",
"QBAK","Qualstar Corporation","5.59","11157148.08","n/a","2000","Technology","Electronic Components","https://www.nasdaq.com/symbol/qbak",
"QLYS","Qualys, Inc.","82.97","3239004681.11","n/a","2012","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/qlys",
"QTNA","Quantenna Communications, Inc.","24.21","929882398.41","n/a","2016","Technology","Semiconductors","https://www.nasdaq.com/symbol/qtna",
"QTRX","Quanterix Corporation","24.35","546930268.7","n/a","2017","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/qtrx",
"QTRH","Quarterhill Inc.","1.1","130699212.6","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/qtrh",
"QRHC","Quest Resource Holding Corporation","1.68","25752501.6","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/qrhc",
"QUIK","QuickLogic Corporation","0.5886","57084556.3776","n/a","1999","Technology","Semiconductors","https://www.nasdaq.com/symbol/quik",
"QDEL","Quidel Corporation","64.73","2553382754.91","n/a","n/a","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/qdel",
"QNST","QuinStreet, Inc.","13.39","666919224.79","n/a","2010","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/qnst",
"QUMU","Qumu Corporation","2.6468","25780869.5456","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/qumu",
"QTNT","Quotient Limited","9.28","603492245.76","n/a","2014","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/qtnt",
"QRTEA","Qurate Retail, Inc.","16.33","7100416779.23","n/a","n/a","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/qrtea",
"QRTEB","Qurate Retail, Inc.","16.44","7148245673.64","n/a","n/a","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/qrteb",
"QTT","Qutoutiao Inc.","10.88","150144000","13800000","2018","n/a","n/a","https://www.nasdaq.com/symbol/qtt",
"RRD","R.R. Donnelley & Sons Company","4.74","333906228.48","n/a","n/a","Miscellaneous","Publishing","https://www.nasdaq.com/symbol/rrd",
"RCM","R1 RCM Inc.","9.77","1076853786.73","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/rcm",
"RARX","Ra Pharmaceuticals, Inc.","20.88","880896234.96","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rarx",
"RADA","RADA Electronic Industries Ltd.","3","112556676","n/a","n/a","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/rada",
"RDCM","Radcom Ltd.","8.14","111040385.5","n/a","1997","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/rdcm",
"RDUS","Radius Health, Inc.","21.6","988203628.8","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rdus",
"RDNT","RadNet, Inc.","12.73","637409927.67","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/rdnt",
"RDWR","Radware Ltd.","26.35","1173785387.25","n/a","1999","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rdwr",
"METC","Ramaco Resources, Inc.","5.9","240955864.3","n/a","2017","Energy","Coal Mining","https://www.nasdaq.com/symbol/metc",
"RMBS","Rambus, Inc.","10.87","1196031698.05","n/a","1997","Technology","Semiconductors","https://www.nasdaq.com/symbol/rmbs",
"RAND","Rand Capital Corporation","3.0701","19409135.3588","n/a","n/a","Consumer Non-Durables","Textiles","https://www.nasdaq.com/symbol/rand",
"RNDB","Randolph Bancorp, Inc.","15.2","89661653.6","n/a","2016","Finance","Major Banks","https://www.nasdaq.com/symbol/rndb",
"RPD","Rapid7, Inc.","52.25","2507601280.25","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/rpd",
"RAVE","Rave Restaurant Group, Inc.","1.6","24114097.6","n/a","n/a","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/rave",
"RAVN","Raven Industries, Inc.","38.55","1424830667.4","n/a","n/a","Capital Goods","Specialty Chemicals","https://www.nasdaq.com/symbol/ravn",
"RBB","RBB Bancorp","18.99","381205089.09","n/a","2017","Finance","Major Banks","https://www.nasdaq.com/symbol/rbb",
"ROLL","RBC Bearings Incorporated","129.56","3215138934.8","n/a","2005","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/roll",
"RICK","RCI Hospitality Holdings, Inc.","23.29","225691745","n/a","1995","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/rick",
"RCMT","RCM Technologies, Inc.","4.03","51873039.66","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/rcmt",
"RDI","Reading International Inc","16.13","342601909.72","n/a","n/a","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/rdi",
"RDIB","Reading International Inc","26.6325","44758313.175","n/a","n/a","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/rdib",
"BCNA","Reality Shares Nasdaq NexGen Economy China ETF","25.13","2513025.13","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bcna",
"BLCN","Reality Shares Nasdaq NextGen Economy ETF","23.15","77552523.15","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/blcn",
"RLM","Realm Therapeutics plc","3.9999","7583194.4154","1895846","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rlm",
"RNWK","RealNetworks, Inc.","3.23","122271004","n/a","1997","Technology","EDP Services","https://www.nasdaq.com/symbol/rnwk",
"RP","RealPage, Inc.","62.92","5888692238","n/a","2010","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/rp",
"RETA","Reata Pharmaceuticals, Inc.","92.43","2225305212.39","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/reta",
"RCON","Recon Technology, Ltd.","0.987","20668404.771","n/a","2009","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/rcon",
"REPH","Recro Pharma, Inc.","6.31","138761537.85","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/reph",
"RRGB","Red Robin Gourmet Burgers, Inc.","28.52","369851495.4","n/a","2002","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/rrgb",
"RRR","Red Rock Resorts, Inc.","26.33","3070735565.42","n/a","2016","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/rrr",
"RDVT","Red Violet, Inc.","7.25","74432944.25","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/rdvt",
"RDFN","Redfin Corporation","22.26","2014268266.92","n/a","2017","Finance","Real Estate","https://www.nasdaq.com/symbol/rdfn",
"RDHL","Redhill Biopharma Ltd.","8.73","201396848.49","23069513","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rdhl",
"RBZ","Reebonz Holding Limited","11.7","31434624","n/a","2017","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/rbz",
"REG","Regency Centers Corporation","67.66","11334216661.38","n/a","1993","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/reg",
"REGN","Regeneron Pharmaceuticals, Inc.","414.82","45330363540.98","n/a","1991","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/regn",
"RGNX","REGENXBIO Inc.","59.03","2149796805.48","n/a","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/rgnx",
"RGLS","Regulus Therapeutics Inc.","1.08","11603435.76","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rgls",
"RBNC","Reliant Bancorp, Inc.","21.94","252386614.48","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/rbnc",
"RELV","Reliv&#39; International, Inc.","3.9201","6846450.7299","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/relv",
"MARK","Remark Holdings, Inc.","1.47","57408368.64","n/a","n/a","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/mark",
"RNST","Renasant Corporation","34.33","2012864573.28","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/rnst",
"REGI","Renewable Energy Group, Inc.","21.81","814716759.33","n/a","2012","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/regi",
"BIQI","Renmin Tianli Group, Inc.","2","16067490","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/biqi",
"RCII","Rent-A-Center Inc.","20.81","1123294998.96","n/a","1995","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/rcii",
"RGEN","Repligen Corporation","59.32","2605422668.16","n/a","1986","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/rgen",
"REPL","Replimune Group, Inc.","16.36","517741648","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/repl",
"RBCAA","Republic Bancorp, Inc.","44.72","835401306.48","n/a","1998","Finance","Major Banks","https://www.nasdaq.com/symbol/rbcaa",
"FRBK","Republic First Bancorp, Inc.","5.33","313538731.74","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/frbk",
"REFR","Research Frontiers Incorporated","2.11","60487013.41","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/refr",
"RESN","Resonant Inc.","3.22","89285406.14","n/a","2014","Technology","Semiconductors","https://www.nasdaq.com/symbol/resn",
"RECN","Resources Connection, Inc.","16.66","528533951.82","n/a","2000","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/recn",
"HAIR","Restoration Robotics, Inc.","0.6392","26058274.0704","n/a","2017","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/hair",
"TORC","resTORbio, Inc.","6.95","245024640.8","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/torc",
"ROIC","Retail Opportunity Investments Corp.","17.36","1981176582","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/roic",
"RETO","ReTo Eco-Solutions, Inc.","1.82","41423200","n/a","2017","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/reto",
"RTRX","Retrophin, Inc.","22.08","914395396.8","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rtrx",
"RVNC","Revance Therapeutics, Inc.","15.18","668372333.64","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rvnc",
"RVEN","Reven Housing REIT, Inc.","3.5","38594318","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rven",
"RVLT","Revolution Lighting Technologies, Inc.","0.2728","6415710.4","n/a","n/a","Consumer Durables","Building Products","https://www.nasdaq.com/symbol/rvlt",
"RWLK","ReWalk Robotics Ltd.","5.2","19176258.4","n/a","2014","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/rwlk",
"RFIL","RF Industries, Ltd.","6.55","61287924.25","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/rfil",
"RGCO","RGC Resources Inc.","26.04","208918112.76","n/a","n/a","Public Utilities","Oil & Gas Production","https://www.nasdaq.com/symbol/rgco",
"RBKB","Rhinebeck Bancorp, Inc.","11.95","49746451.85","n/a","2019","Finance","Banks","https://www.nasdaq.com/symbol/rbkb",
"RYTM","Rhythm Pharmaceuticals, Inc.","28.16","969431372.8","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rytm",
"RBBN","Ribbon Communications Inc. ","5.16","553517606.64","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/rbbn",
"RIBT","RiceBran Technologies","3.54","114506893.2","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/ribt",
"RELL","Richardson Electronics, Ltd.","6.68","87170793.6","n/a","1983","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/rell",
"RIGL","Rigel Pharmaceuticals, Inc.","2.41","402883327.05","n/a","2000","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rigl",
"RNET","RigNet, Inc.","9.89","192507336.83","n/a","2010","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/rnet",
"RMNI","Rimini Street, Inc.","5","326000000","n/a","2015","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rmni",
"RIOT","Riot Blockchain, Inc","4.34","63792831.06","n/a","n/a","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/riot",
"REDU","RISE Education Cayman Ltd","9.91","235460609","23759900","2017","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/redu",
"RTTR","Ritter Pharmaceuticals, Inc.","0.96","5505253.44","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rttr",
"RVSB","Riverview Bancorp Inc","7.42","167749223.04","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/rvsb",
"RIVE","Riverview Financial Corporation","11.2","102477972.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/rive",
"RCKT","Rocket Pharmaceuticals, Inc.","18.48","833714795.76","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rckt",
"RMTI","Rockwell Medical, Inc.","5.74","327744396.98","n/a","1998","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/rmti",
"RCKY","Rocky Brands, Inc.","25.38","187349068.8","n/a","1993","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/rcky",
"RMCF","Rocky Mountain Chocolate Factory, Inc.","9.2","54727672","n/a","n/a","Consumer Non-Durables","Specialty Foods","https://www.nasdaq.com/symbol/rmcf",
"ROKU","Roku, Inc.","70.64","7770973455.52","n/a","2017","Consumer Services","Television Services","https://www.nasdaq.com/symbol/roku",
"ROSE","Rosehill Resources Inc.","3.43","47197266.48","n/a","2016","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/rose",
"ROSEU","Rosehill Resources Inc.","3.92","0","n/a","2016","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/roseu",
"ROSEW","Rosehill Resources Inc.","0.45","0","n/a","2016","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/rosew",
"ROST","Ross Stores, Inc.","93.76","34746407763.2","n/a","1985","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/rost",
"RGLD","Royal Gold, Inc.","91.46","5992179332.4","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/rgld",
"RTIX","RTI Surgical Holdings, Inc.","5.96","438473850.48","n/a","2000","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/rtix",
"RBCN","Rubicon Technology, Inc.","7.9101","21636077.2947","n/a","2007","Technology","Semiconductors","https://www.nasdaq.com/symbol/rbcn",
"RUBY","Rubius Therapeutics, Inc.","19.63","1561173212.95","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/ruby",
"RMBL","RumbleOn, Inc.","4.82","95290392.62","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/rmbl",
"RUSHA","Rush Enterprises, Inc.","42.45","1549610548.95","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/rusha",
"RUSHB","Rush Enterprises, Inc.","42.11","1537199062.81","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/rushb",
"RUTH","Ruth&#39;s Hospitality Group, Inc.","25.14","762765700.8","n/a","2005","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/ruth",
"RYAAY","Ryanair Holdings plc","72.55","7314910121.35","100825777","1997","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/ryaay",
"STBA","S&T Bancorp, Inc.","39.98","1383961153.26","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/stba",
"SANW","S&W Seed Company","2.71","90166247.38","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/sanw",
"SBRA","Sabra Health Care REIT, Inc.","19.31","3443418501.01","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/sbra",
"SABR","Sabre Corporation","21.64","5962433623.84","n/a","2014","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/sabr",
"SAEX","SAExploration Holdings, Inc.","3.82","15479239.74","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/saex",
"SFET","Safe-T Group Ltd.","2.75","1831843.75","666125","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/sfet",
"SAFT","Safety Insurance Group, Inc.","88.46","1352249893.74","n/a","2002","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/saft",
"SGA","Saga Communications, Inc.","33","165833448","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/sga",
"SAGE","Sage Therapeutics, Inc.","160.33","8164964137.03","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sage",
"SAIA","Saia, Inc.","61.79","1596968790.79","n/a","n/a","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/saia",
"SALM","Salem Media Group, Inc.","2.49","65203418.88","n/a","1999","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/salm",
"SAL","Salisbury Bancorp, Inc.","40.26","113001003.06","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/sal",
"SAFM","Sanderson Farms, Inc.","128.38","2844448132.12","n/a","1987","Consumer Non-Durables","Meat/Poultry/Fish","https://www.nasdaq.com/symbol/safm",
"SASR","Sandy Spring Bancorp, Inc.","31.94","1141686037.4","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sasr",
"SGMO","Sangamo Therapeutics, Inc.","12.29","1256939508.37","n/a","2000","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/sgmo",
"SANM","Sanmina Corporation","30.09","2059046754.27","n/a","1993","Technology","Electrical Products","https://www.nasdaq.com/symbol/sanm",
"GCVRZ","Sanofi","0.4422","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gcvrz",
"SNY","Sanofi","44.15","9597578743.3","217385702","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sny",
"SPNS","Sapiens International Corporation N.V.","15.49","774221241.96","n/a","1992","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/spns",
"SRPT","Sarepta Therapeutics, Inc.","122.7","8747544228.3","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/srpt",
"SVRA","Savara, Inc.","8.41","297179443.58","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/svra",
"SBFG","SB Financial Group, Inc.","18.3","118528038.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sbfg",
"SBFGP","SB Financial Group, Inc.","19","284905","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sbfgp",
"SBBX","SB One Bancorp","21.965","208705741.065","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sbbx",
"SBAC","SBA Communications Corporation","199.64","22477303296.28","n/a","1999","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/sbac",
"SCSC","ScanSource, Inc.","36.22","930938827.24","n/a","n/a","Technology","Retail: Computer Software & Peripheral Equipment","https://www.nasdaq.com/symbol/scsc",
"SMIT","Schmitt Industries, Inc.","2.29","9147508.05","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/smit",
"SCHN","Schnitzer Steel Industries, Inc.","24.57","664034151.69","n/a","1993","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/schn",
"SRRK","Scholar Rock Holding Corporation","18","471947184","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/srrk",
"SCHL","Scholastic Corporation","40.39","1355359838.63","n/a","1992","Consumer Services","Books","https://www.nasdaq.com/symbol/schl",
"SAMA","Schultze Special Purpose Acquisition Corp.","9.75","158437500","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/sama",
"SAMAU","Schultze Special Purpose Acquisition Corp.","10.0999","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/samau",
"SAMAW","Schultze Special Purpose Acquisition Corp.","0.35","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/samaw",
"SGMS","Scientific Games Corp","20.71","1910473393.56","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/sgms",
"SCPH","scPharmaceuticals Inc.","3.03","56298702.9","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/scph",
"WORX","SCWorx Corp.","6.895","45136159.32","n/a","2016","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/worx",
"SCYX","SCYNEXIS, Inc.","1.55","77730109.9","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/scyx",
"SEAC","SeaChange International, Inc.","1.32","47903947.08","n/a","1996","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/seac",
"SBCF","Seacoast Banking Corporation of Florida","26.97","1384084595.58","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sbcf",
"STX","Seagate Technology PLC","48.76","13616129993.24","n/a","2002","Technology","Electronic Components","https://www.nasdaq.com/symbol/stx",
"SHIP","Seanergy Maritime Holdings Corp","4.44","12477390.12","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/ship",
"SHIPW","Seanergy Maritime Holdings Corp","0.035","0","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/shipw",
"SHOS","Sears Hometown and Outlet Stores, Inc.","1.82","41317880.24","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/shos",
"SPNE","SeaSpine Holdings Corporation","14.55","274705047.6","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/spne",
"SGEN","Seattle Genetics, Inc.","74.56","11971445607.04","n/a","2001","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/sgen",
"EYES","Second Sight Medical Products, Inc.","0.826","102587515.786","n/a","2014","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/eyes",
"EYESW","Second Sight Medical Products, Inc.","0.2","0","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/eyesw",
"SECO","Secoo Holding Limited","9.06","133578085.08","14743718","2017","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/seco",
"SCWX","SecureWorks Corp.","19.55","220463590.5","n/a","2016","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/scwx",
"SNFCA","Security National Financial Corporation","4.79","73347770.73","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/snfca",
"SEEL","Seelos Therapeutics, Inc.","3.18","58531140.42","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/seel",
"SEIC","SEI Investments Company","54.15","8322319185.75","n/a","1981","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/seic",
"SLCT","Select Bancorp, Inc.","11.56","223414166.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/slct",
"SIC","Select Interior Concepts, Inc.","12.58","325063048.6","n/a","n/a","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/sic",
"SELB","Selecta Biosciences, Inc.","2.53","113175595.61","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/selb",
"SIGI","Selective Insurance Group, Inc.","63.96","3787893294.12","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/sigi",
"SLS","SELLAS Life Sciences Group, Inc. ","1","23176475","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sls",
"LEDS","SemiLEDS Corporation","4.1","14595651.5","n/a","2010","Technology","Semiconductors","https://www.nasdaq.com/symbol/leds",
"SMTC","Semtech Corporation","52.29","3482439329.88","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/smtc",
"SENEA","Seneca Foods Corp.","24.05","230278822.15","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/senea",
"SENEB","Seneca Foods Corp.","27.2439","260860424.2317","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/seneb",
"SNES","SenesTech, Inc.","1.12","26388167.68","n/a","2016","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/snes",
"SNH","Senior Housing Properties Trust","10.12","2405826588","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/snh",
"SNHNI","Senior Housing Properties Trust","22.21","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/snhni",
"SNHNL","Senior Housing Properties Trust","24.24","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/snhnl",
"AIHS","Senmiao Technology Limited","4.87","126032678","n/a","2018","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/aihs",
"SRTS","Sensus Healthcare, Inc.","6.83","112044920.6","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/srts",
"SRTSW","Sensus Healthcare, Inc.","0.4","0","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/srtsw",
"STNL","Sentinel Energy Services Inc.","10.0466","346607700","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/stnl",
"STNLU","Sentinel Energy Services Inc.","10.23","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/stnlu",
"STNLW","Sentinel Energy Services Inc.","0.67","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/stnlw",
"SQBG","Sequential Brands Group, Inc.","1.23","79289200.95","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/sqbg",
"MCRB","Seres Therapeutics, Inc.","6.6","270919176","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mcrb",
"SREV","ServiceSource International, Inc.","0.8845","82200897.822","n/a","2011","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/srev",
"SFBS","ServisFirst Bancshares, Inc.","33.92","1813879055.36","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/sfbs",
"SESN","Sesen Bio, Inc.","1.01","78230741.8","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sesn",
"SVBI","Severn Bancorp Inc","9.51","120978621.51","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/svbi",
"SGBX","SG Blocks, Inc.","1.75","7455071.75","n/a","2017","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/sgbx",
"SGOC","SGOCO Group, Ltd","1.13","85323249","n/a","2010","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/sgoc",
"SMED","Sharps Compliance Corp.","3.68","59376847.84","n/a","n/a","Basic Industries","Environmental Services","https://www.nasdaq.com/symbol/smed",
"SHSP","SharpSpring, Inc.","17.07","147300973.17","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/shsp",
"SHEN","Shenandoah Telecommunications Co","43.59","2172127666.89","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/shen",
"PIXY","ShiftPixy, Inc.","1.04","33402019.04","n/a","2017","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/pixy",
"SHLO","Shiloh Industries, Inc.","5.56","131821506.24","n/a","1993","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/shlo",
"TYHT","Shineco, Inc.","1.2","27446126.4","n/a","2016","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/tyht",
"SWAV","ShockWave Medical, Inc.","32.15","865052398.3","n/a","2019","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/swav",
"SCVL","Shoe Carnival, Inc.","32.41","500224982.39","n/a","1993","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/scvl",
"SHBI","Shore Bancshares Inc","15.23","194636491.07","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/shbi",
"SSTI","ShotSpotter, Inc.","40.85","445748990.8","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ssti",
"SFLY","Shutterfly, Inc.","39.91","1359586711.47","n/a","2006","Miscellaneous","Other Consumer Services","https://www.nasdaq.com/symbol/sfly",
"SIFI","SI Financial Group, Inc.","13.21","159243709.85","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/sifi",
"SIBN","SI-BONE, Inc.","18.86","461295570.68","n/a","2018","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/sibn",
"SIEB","Siebert Financial Corp.","11.73","318553815.24","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/sieb",
"SNNA","Sienna Biopharmaceuticals, Inc.","2.2","66826804","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/snna",
"SIEN","Sientra, Inc.","8.21","239829666.16","n/a","2014","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/sien",
"BSRR","Sierra Bancorp","24.66","377831395.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bsrr",
"SRRA","Sierra Oncology, Inc.","1.63","121382425.98","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/srra",
"SWIR","Sierra Wireless, Inc.","12.49","449958232.71","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/swir",
"SIFY","Sify Technologies Limited","1.5999","40792546.3065","25496935","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/sify",
"SIGA","SIGA Technologies Inc.","5.98","484030313.52","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/siga",
"SGLB","Sigma Labs, Inc.","1.41","14858001.9","n/a","n/a","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/sglb",
"SGLBW","Sigma Labs, Inc.","0.55","0","n/a","n/a","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/sglbw",
"SGMA","SigmaTron International, Inc.","2.82","11928622.56","n/a","1994","Technology","Electrical Products","https://www.nasdaq.com/symbol/sgma",
"SBNY","Signature Bank","130","7162456860","n/a","2004","Finance","Major Banks","https://www.nasdaq.com/symbol/sbny",
"SLGN","Silgan Holdings Inc.","29.62","3270924633.52","n/a","1997","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/slgn",
"SILC","Silicom Ltd","38.595","291747516.975","n/a","n/a","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/silc",
"SLAB","Silicon Laboratories, Inc.","82.44","3572642098.8","n/a","2000","Technology","Semiconductors","https://www.nasdaq.com/symbol/slab",
"SIMO","Silicon Motion Technology Corporation","39.67","1431807128.15","36092945","2005","Technology","Semiconductors","https://www.nasdaq.com/symbol/simo",
"SAMG","Silvercrest Asset Management Group Inc.","13.7","184295126.3","n/a","2013","Finance","Investment Managers","https://www.nasdaq.com/symbol/samg",
"SSNT","SilverSun Technologies, Inc.","2.75","12377076.25","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ssnt",
"SFNC","Simmons First National Corporation","25.1","2322429381.7","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sfnc",
"SLP","Simulations Plus, Inc.","20.22","353036549.4","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/slp",
"SINA","Sina Corporation","61.7","4409727875.6","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/sina",
"SBGI","Sinclair Broadcast Group, Inc.","39.47","3607267934.97","n/a","1995","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/sbgi",
"SINO","Sino-Global Shipping America, Ltd.","0.8878","13535135.1234","n/a","n/a","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/sino",
"SVA","Sinovac Biotech, Ltd.","6.47","460155205.67","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sva",
"SINT","SiNtx Technologies, Inc.","0.201","4380521.841","n/a","2014","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/sint",
"SG","Sirius International Insurance Group, Ltd.","13.25","1526823894","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/sg",
"SIRI","Sirius XM Holdings Inc.","5.87","27803752740.78","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/siri",
"SITO","SITO Mobile, Ltd.","1.99","50620696.64","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/sito",
"SKYS","Sky Solar Holdings, Ltd.","0.7368","10565176.3464","14339273","2014","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/skys",
"SKYW","SkyWest, Inc.","55.72","2877814190.16","n/a","1986","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/skyw",
"SWKS","Skyworks Solutions, Inc.","84.16","14559815245.12","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/swks",
"SNBR","Sleep Number Corporation","46.19","1409811180","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/snbr",
"SLM","SLM Corporation","10.02","4376761601.1","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/slm",
"SLMBP","SLM Corporation","66.65","266600000","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/slmbp",
"SGH","SMART Global Holdings, Inc.","20.2","463130470.2","n/a","2017","Technology","Semiconductors","https://www.nasdaq.com/symbol/sgh",
"SND","Smart Sand, Inc.","4.43","181690562.53","n/a","2016","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/snd",
"SMBK","SmartFinancial, Inc.","19.26","268605410.58","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/smbk",
"SMSI","Smith Micro Software, Inc.","2.9","93280518.4","n/a","1995","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/smsi",
"SMTX","SMTC Corporation","3.97","92713625.26","n/a","2000","Technology","Electrical Products","https://www.nasdaq.com/symbol/smtx",
"SRAX","Social Reality, Inc.","3.67","37189321.1","n/a","n/a","Technology","Advertising","https://www.nasdaq.com/symbol/srax",
"SCKT","Socket Mobile, Inc.","2.01","12058309.59","n/a","n/a","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/sckt",
"SOHU","Sohu.com Limited ","16.96","670480324.48","39533038","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/sohu",
"SLRC","Solar Capital Ltd.","21.36","902691243.36","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/slrc",
"SUNS","Solar Senior Capital Ltd.","17.13","274773508.05","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/suns",
"SEDG","SolarEdge Technologies, Inc.","38.2","1805149633.2","n/a","2015","Technology","Semiconductors","https://www.nasdaq.com/symbol/sedg",
"SLNO","Soleno Therapeutics, Inc.","1.98","62875234.62","n/a","2014","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/slno",
"SLNOW","Soleno Therapeutics, Inc.","0.15","0","n/a","2014","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/slnow",
"SLGL","Sol-Gel Technologies Ltd.","7.12","134923772.16","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/slgl",
"SLDB","Solid Biosciences Inc.","9.61","340414213.15","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/sldb",
"SNGX","Soligenix, Inc.","0.8896","16181119.4368","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sngx",
"SNGXW","Soligenix, Inc.","0.2009","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sngxw",
"SOLY","Soliton, Inc.","9.35","136631550","n/a","2019","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/soly",
"SNOA","Sonoma Pharmaceuticals, Inc.","0.9399","11252791.0872","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/snoa",
"SNOAW","Sonoma Pharmaceuticals, Inc.","0.015","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/snoaw",
"SONO","Sonos, Inc.","11.12","1121375372.08","n/a","2018","Consumer Non-Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/sono",
"SPHS","Sophiris Bio, Inc.","1.06","32030168.4","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sphs",
"SORL","SORL Auto Parts, Inc.","3.3","63706239.3","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/sorl",
"SRNE","Sorrento Therapeutics, Inc.","3.8","464664349.6","n/a","n/a","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/srne",
"SOHO","Sotherly Hotels Inc.","6.84","97281065.52","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/soho",
"SOHOB","Sotherly Hotels Inc.","24.95","40169500","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/sohob",
"SOHOO","Sotherly Hotels Inc.","24.9874","33786488.0234","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/sohoo",
"SOHOK","Sotherly Hotels LP","25.86","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/sohok",
"SFBC","Sound Financial Bancorp, Inc.","34.27","87293777.72","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/sfbc",
"SSB","South State Corporation","69.96","2474488977.84","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ssb",
"SFST","Southern First Bancshares, Inc.","34.48","258015253.68","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sfst",
"SMBC","Southern Missouri Bancorp, Inc.","31.19","290759698.71","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/smbc",
"SONA","Southern National Bancorp of Virginia, Inc.","14.72","355017004.16","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sona",
"SBSI","Southside Bancshares, Inc.","33.75","1137964410","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sbsi",
"SP","SP Plus Corporation","33.53","763946715.28","n/a","n/a","Consumer Services","Rental/Leasing Companies","https://www.nasdaq.com/symbol/sp",
"SGRP","SPAR Group, Inc.","0.6637","13710660.8403","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/sgrp",
"SPKE","Spark Energy, Inc.","9.16","320067547.52","n/a","2014","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/spke",
"SPKEP","Spark Energy, Inc.","23.4775","87037102.74","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/spkep",
"ONCE","Spark Therapeutics, Inc.","114.01","4329108141.02","n/a","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/once",
"SPAR","Spartan Motors, Inc.","8.54","300854302.14","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/spar",
"SPTN","SpartanNash Company","15.9","571637022.6","n/a","n/a","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/sptn",
"DWFI","SPDR Dorsey Wright Fixed Income Allocation ETF","23.0241","105335257.5","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dwfi",
"SPPI","Spectrum Pharmaceuticals, Inc.","10.59","1176019383.51","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sppi",
"SPRO","Spero Therapeutics, Inc.","13.25","228111682","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/spro",
"ANY","Sphere 3D Corp.","2.4","4713645.6","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/any",
"SPEX","Spherix Incorporated","0.883","7543053.99","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/spex",
"SPI","SPI Energy Co., Ltd.","4.47","32455203.84","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/spi",
"SAVE","Spirit Airlines, Inc.","53.82","3677465542.14","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/save",
"STXB","Spirit of Texas Bancshares, Inc.","21.2","258175783.6","n/a","2018","Finance","Major Banks","https://www.nasdaq.com/symbol/stxb",
"SPLK","Splunk Inc.","127.73","19169016268.19","n/a","2012","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/splk",
"SPOK","Spok Holdings, Inc.","13.74","265768079.7","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/spok",
"SPWH","Sportsman&#39;s Warehouse Holdings, Inc.","4.91","211025809.8","n/a","2014","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/spwh",
"SBPH","Spring Bank Pharmaceuticals, Inc.","10.79","177354097.05","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sbph",
"FUND","Sprott Focus Trust, Inc.","6.87","186549326.52","n/a","n/a","Consumer Services","Miscellaneous","https://www.nasdaq.com/symbol/fund",
"SFM","Sprouts Farmers Market, Inc.","21.09","2608279113.33","n/a","2013","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/sfm",
"SPSC","SPS Commerce, Inc.","105.06","1865865915.18","n/a","2010","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/spsc",
"SSNC","SS&C Technologies Holdings, Inc.","64.74","16320681768.3","n/a","2010","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ssnc",
"SSLJ","SSLJ.com Limited","0.511","22484000","n/a","2018","Finance","Diversified Commercial Services","https://www.nasdaq.com/symbol/sslj",
"SSRM","SSR Mining Inc.","12.06","1460765739.24","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/ssrm",
"STAA","STAAR Surgical Company","34.06","1505729827.42","n/a","n/a","Health Care","Ophthalmic Goods","https://www.nasdaq.com/symbol/staa",
"STAF","Staffing 360 Solutions, Inc.","1.59","13092613.32","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/staf",
"STMP","Stamps.com Inc.","82.23","1441277033.01","n/a","1999","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/stmp",
"STND","Standard AVB Financial Corp.","27.63","133174361.97","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/stnd",
"SBLK","Star Bulk Carriers Corp.","6.85","637664561.45","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/sblk",
"SBLKZ","Star Bulk Carriers Corp.","25.3","0","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/sblkz",
"SBUX","Starbucks Corporation","74.27","92362172000","n/a","1992","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/sbux",
"STFC","State Auto Financial Corporation","33.34","1445236322.8","n/a","1991","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/stfc",
"MITO","Stealth BioTherapeutics Corp.","15","93000000","6200000","2019","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mito",
"GASS","StealthGas, Inc.","3.5","139511970.5","n/a","2005","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/gass",
"STCN","Steel Connect, Inc.","1.985","122668646.895","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/stcn",
"STLD","Steel Dynamics, Inc.","35.39","7889538176.15","n/a","1996","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/stld",
"SMRT","Stein Mart, Inc.","0.968","46306123.072","n/a","1992","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/smrt",
"SBOT","Stellar Biotechnologies, Inc.","1.12","5970400.8","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sbot",
"STML","Stemline Therapeutics, Inc.","13.28","578597395.68","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/stml",
"SRCL","Stericycle, Inc.","56.48","5122914589.76","n/a","1996","Basic Industries","Environmental Services","https://www.nasdaq.com/symbol/srcl",
"SBT","Sterling Bancorp, Inc.","9.99","519273906.3","n/a","2017","Finance","Savings Institutions","https://www.nasdaq.com/symbol/sbt",
"STRL","Sterling Construction Company Inc","12.9","340867368.3","n/a","n/a","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/strl",
"SHOO","Steven Madden, Ltd.","33.86","2908839496.26","n/a","1993","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/shoo",
"SSFN","Stewardship Financial Corp","9.4","81633886.4","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ssfn",
"SFIX","Stitch Fix, Inc.","28.75","2874133561.25","n/a","2017","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/sfix",
"SYBT","Stock Yards Bancorp, Inc.","34.4","784020892","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sybt",
"BANX","StoneCastle Financial Corp","21.2722","139335249.942","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/banx",
"STNE","StoneCo Ltd.","42.15","11678632387.35","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/stne",
"SSKN","Strata Skin Sciences, Inc.","2.85","88350000","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/sskn",
"SSYS","Stratasys, Ltd.","24.59","1327280266.16","n/a","1994","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/ssys",
"STRA","Strategic Education, Inc.","133.4","2926338037.8","n/a","1996","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/stra",
"HNDL","Strategy Shares Nasdaq 7HANDL Index ETF","23.56","12366903.16","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hndl",
"STRT","Strattec Security Corporation","30.2","113001937.2","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/strt",
"STRS","Stratus Properties Inc.","25.48","208028147.6","n/a","n/a","Consumer Services","Homebuilding","https://www.nasdaq.com/symbol/strs",
"STRM","Streamline Health Solutions, Inc.","1.07","21536642.21","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/strm",
"SBBP","Strongbridge Biopharma plc","4.96","268628382.08","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sbbp",
"SUMR","Summer Infant, Inc.","0.7126","13275550.5862","n/a","n/a","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/sumr",
"SMMF","Summit Financial Group, Inc.","25.87","331237358.66","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/smmf",
"SSBI","Summit State Bank","11.48","69643133","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/ssbi",
"SMMT","Summit Therapeutics plc","1.8","12536764.2","6964869","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/smmt",
"WISA","Summit Wireless Technologies, Inc.","1.86","28811725.5","n/a","2018","Technology","Semiconductors","https://www.nasdaq.com/symbol/wisa",
"SNHY","Sun Hydraulics Corporation","48.36","1546469814.24","n/a","1997","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/snhy",
"SNDE","Sundance Energy Australia Limited","3.216","5231701.968","1626773","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/snde",
"SNSS","Sunesis Pharmaceuticals, Inc.","1.33","89878855.71","n/a","2005","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/snss",
"STKL","SunOpta, Inc.","3.69","322757063.91","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/stkl",
"SPWR","SunPower Corporation","6.9","975546391.5","n/a","2005","Technology","Semiconductors","https://www.nasdaq.com/symbol/spwr",
"RUN","Sunrun Inc.","14.22","1619655596.82","n/a","2015","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/run",
"SUNW","Sunworks, Inc.","0.5648","14770895.288","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/sunw",
"SLGG","Super League Gaming, Inc.","7.66","63869233.2","n/a","2019","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/slgg",
"SPCB","SuperCom, Ltd.","1.44","21540008.16","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/spcb",
"SCON","Superconductor Technologies Inc.","1.63","6198252.67","n/a","1993","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/scon",
"SGC","Superior Group of Companies, Inc.","17.04","261457261.44","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/sgc",
"SUPN","Supernus Pharmaceuticals, Inc.","36.48","1908650855.04","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/supn",
"SPRT","support.com, Inc.","2.33","44165765.12","n/a","2000","Technology","EDP Services","https://www.nasdaq.com/symbol/sprt",
"SURF","Surface Oncology, Inc.","4.77","132747048.9","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/surf",
"SGRY","Surgery Partners, Inc.","11.89","580248646","n/a","2015","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/sgry",
"SRDX","Surmodics, Inc.","45.58","614522094.5","n/a","1998","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/srdx",
"STRO","Sutro Biopharma, Inc.","12","274178208","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/stro",
"SIVB","SVB Financial Group","232.36","12232369831.48","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sivb",
"SVMK","SVMK Inc.","18.02","2282133835.94","n/a","2018","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/svmk",
"SYKE","Sykes Enterprises, Incorporated","28.23","1207610123.58","n/a","1996","Technology","EDP Services","https://www.nasdaq.com/symbol/syke",
"SYMC","Symantec Corporation","23.15","14797876397.45","n/a","1989","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/symc",
"SYNC","Synacor, Inc.","1.55","60531657.1","n/a","2012","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/sync",
"SYNL","Synalloy Corporation","15.47","138686600.78","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/synl",
"SYNA","Synaptics Incorporated","39.56","1360987189.84","n/a","2002","Technology","Semiconductors","https://www.nasdaq.com/symbol/syna",
"SNCR","Synchronoss Technologies, Inc.","5.95","253973209.35","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/sncr",
"SNDX","Syndax Pharmaceuticals, Inc.","5.15","128753811","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/sndx",
"SYNH","Syneos Health, Inc.","51.47","5337427316.31","n/a","2014","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/synh",
"SYBX","Synlogic, Inc.","7.5","190503712.5","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/sybx",
"SNPS","Synopsys, Inc.","117.51","17496748278.24","n/a","1992","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/snps",
"SES","Synthesis Energy Systems, Inc.","0.628","6928171.36","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/ses",
"THOR","Synthorx, Inc.","21.41","688164801.74","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/thor",
"SYPR","Sypris Solutions, Inc.","1.07","22848997.21","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/sypr",
"SYRS","Syros Pharmaceuticals, Inc.","9.3","304729603.2","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/syrs",
"TROW","T. Rowe Price Group, Inc.","103.27","24444622630.34","n/a","1986","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/trow",
"TTOO","T2 Biosystems, Inc.","2.71","120107330.08","n/a","2014","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/ttoo",
"TRHC","Tabula Rasa HealthCare, Inc.","55.28","1201945134.96","n/a","2016","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/trhc",
"TCMD","Tactile Systems Technology, Inc.","53.25","1001663278.5","n/a","2016","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/tcmd",
"TAIT","Taitron Components Incorporated","2.97","16720645.59","n/a","1995","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/tait",
"TLC","Taiwan Liposome Company, Ltd.","5.8","22710190","3915550","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tlc",
"TTWO","Take-Two Interactive Software, Inc.","97.66","11051394865.08","n/a","1997","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ttwo",
"TLND","Talend S.A.","50.43","1510515215.73","29952711","2016","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/tlnd",
"TNDM","Tandem Diabetes Care, Inc.","62.85","3627552291.3","n/a","2013","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/tndm",
"TLF","Tandy Leather Factory, Inc.","5.91","53236304.85","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/tlf",
"TANH","Tantech Holdings Ltd.","1.53","43915960.26","n/a","2015","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/tanh",
"TAOP","Taoping Inc.","1.0099","42173588.6137","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/taop",
"TEDU","Tarena International, Inc.","5.3","190470620.9","35937853","2014","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/tedu",
"TH","Target Hospitality Corp.","9.69","393656250","n/a","2018","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/th",
"THWWW","Target Hospitality Corp.","1.54","0","n/a","2018","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/thwww",
"TRNX","Taronis Technologies, Inc.","0.6298","5982235.2846","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/trnx",
"TATT","TAT Technologies Ltd.","6.45","57241789.2","n/a","n/a","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/tatt",
"TAYD","Taylor Devices, Inc.","12.52","43485415.52","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tayd",
"CGBD","TCG BDC, Inc.","14.78","911538438.84","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/cgbd",
"TCRR","TCR2 Therapeutics Inc.","16.56","396444760.56","n/a","2019","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/tcrr",
"AMTD","TD Ameritrade Holding Corporation","52.08","29183730819.6","n/a","1997","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/amtd",
"PETZ","TDH Holdings, Inc.","0.9196","8666080.5","n/a","2017","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/petz",
"TECD","Tech Data Corporation","104.28","3848004787.44","n/a","1986","Technology","Retail: Computer Software & Peripheral Equipment","https://www.nasdaq.com/symbol/tecd",
"TCCO","Technical Communications Corporation","4.15","7673453.75","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/tcco",
"TTGT","TechTarget, Inc.","16.62","461310304.32","n/a","2007","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ttgt",
"TGLS","Tecnoglass Inc.","7.2","278145763.2","n/a","2012","Consumer Durables","Electronic Components","https://www.nasdaq.com/symbol/tgls",
"TGEN","Tecogen Inc.","4","99318984","n/a","2014","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tgen",
"TNAV","Telenav, Inc.","5.86","266868425.82","n/a","2010","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tnav",
"TLGT","Teligent, Inc.","1.15","61840354.15","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tlgt",
"TELL","Tellurian Inc.","11.19","2690754192.33","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/tell",
"TENB","Tenable Holdings, Inc.","32.27","3064203723.14","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/tenb",
"TENX","Tenax Therapeutics, Inc.","1.98","5974153.02","n/a","n/a","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/tenx",
"TZAC","Tenzing Acquisition Corp.","10.1","83477136.3","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tzac",
"TZACU","Tenzing Acquisition Corp.","10.24","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tzacu",
"TZACW","Tenzing Acquisition Corp.","0.16","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tzacw",
"TER","Teradyne, Inc.","42.02","7276905775.92","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/ter",
"TERP","TerraForm Power, Inc.","13.79","2884064318.8","n/a","2014","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/terp",
"TBNK","Territorial Bancorp Inc.","27.74","268360976.48","n/a","2009","Finance","Savings Institutions","https://www.nasdaq.com/symbol/tbnk",
"TSLA","Tesla, Inc. ","285.88","49377618703.56","n/a","2010","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/tsla",
"TESS","TESSCO Technologies Incorporated","15.3","129483303.3","n/a","1994","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/tess",
"TTEK","Tetra Tech, Inc.","59.51","3285707777","n/a","1991","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/ttek",
"TTPH","Tetraphase Pharmaceuticals, Inc.","1.27","68256781.19","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ttph",
"TCBI","Texas Capital Bancshares, Inc.","56.7","2849074130.7","n/a","2003","Finance","Major Banks","https://www.nasdaq.com/symbol/tcbi",
"TCBIL","Texas Capital Bancshares, Inc.","25.96","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/tcbil",
"TCBIP","Texas Capital Bancshares, Inc.","26.02","156120000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/tcbip",
"TXN","Texas Instruments Incorporated","110.28","103510755985.92","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/txn",
"TXRH","Texas Roadhouse, Inc.","62.3","4466169439.9","n/a","2004","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/txrh",
"TFSL","TFS Financial Corporation","16.31","4568159356.95","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/tfsl",
"TGTX","TG Therapeutics, Inc.","8.27","693609415.42","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tgtx",
"WTER","The Alkaline Water Company Inc.","2.26","88750604.54","n/a","n/a","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/wter",
"ANDE","The Andersons, Inc.","32.09","1070418364.22","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/ande",
"TBBK","The Bancorp, Inc.","8.19","462472952.76","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/tbbk",
"BPRN","The Bank of Princeton","32.39","216664775.11","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bprn",
"CG","The Carlyle Group L.P.","18.24","6200342844.48","n/a","2012","Finance","Investment Managers","https://www.nasdaq.com/symbol/cg",
"TCGP","The Carlyle Group L.P.","23.24","371840000","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/tcgp",
"CAKE","The Cheesecake Factory Incorporated","48.2","2174995742.6","n/a","1992","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/cake",
"CHEF","The Chefs&#39; Warehouse, Inc.","31.48","942973357.88","n/a","2011","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/chef",
"TCFC","The Community Financial Corporation","28.18","157287261.78","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/tcfc",
"DSGX","The Descartes Systems Group Inc.","37.61","2902038223.06","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/dsgx",
"DXYN","The Dixie Group, Inc.","0.908","14856597.936","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/dxyn",
"ENSG","The Ensign Group, Inc.","50.76","2674853832.96","n/a","2007","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/ensg",
"XONE","The ExOne Company","9.06","147960690.12","n/a","2013","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/xone",
"FBMS","The First Bancshares, Inc.","30.99","535281933.69","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fbms",
"FLIC","The First of Long Island Corporation","22.05","554644288.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/flic",
"GT","The Goodyear Tire & Rubber Company","18.62","4324755922.06","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/gt",
"HABT","The Habit Restaurants, Inc.","10.54","274634456","n/a","2014","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/habt",
"HCKT","The Hackett Group, Inc.","15.75","470248443","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/hckt",
"HAIN","The Hain Celestial Group, Inc.","22.05","2295810543.6","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/hain",
"CUBA","The Herzfeld Caribbean Basin Fund, Inc.","5.86","35943241.74","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cuba",
"INTG","The Intergroup Corporation","30.43","70893166.59","n/a","n/a","Consumer Services","Building operators","https://www.nasdaq.com/symbol/intg",
"JYNT","The Joint Corp.","15.68","215482870.4","n/a","2014","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/jynt",
"KEYW","The KEYW Holding Corporation","8.44","421760945.44","n/a","2010","Technology","EDP Services","https://www.nasdaq.com/symbol/keyw",
"KHC","The Kraft Heinz Company","32.08","39119468768.96","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/khc",
"OLD","The Long-Term Care ETF","27.52","16512000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/old",
"LOVE","The Lovesac Company","30.11","407546919.48","n/a","2018","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/love",
"MSG","The Madison Square Garden Company","297.4","7065780874","n/a","2015","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/msg",
"MDCO","The Medicines Company","29.31","2164761947.43","n/a","2000","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mdco",
"MEET","The Meet Group, Inc.","5.13","384402545.1","n/a","n/a","Consumer Services","Advertising","https://www.nasdaq.com/symbol/meet",
"MIK","The Michaels Companies, Inc.","11.34","1789146840.6","n/a","2014","Consumer Services","Recreational Products/Toys","https://www.nasdaq.com/symbol/mik",
"MIDD","The Middleby Corporation","134.38","7485431761.08","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/midd",
"NAVG","The Navigators Group, Inc.","69.87","2083416359.16","n/a","1986","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/navg",
"SLIM","The Obesity ETF","34.05","13620000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/slim",
"STKS","The ONE Group Hospitality, Inc.","3.035","86882580.8","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/stks",
"ORG","The Organics ETF","26.93","10772026.93","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/org",
"PRSC","The Providence Service Corporation","65.04","834713343.84","n/a","2003","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/prsc",
"RMR","The RMR Group Inc.","60.53","1890332954.11","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/rmr",
"SMPL","The Simply Good Foods Company","21.68","1775342116.32","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/smpl",
"TSG","The Stars Group Inc.","18.04","4928359650.72","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/tsg",
"TTD","The Trade Desk, Inc.","206.84","7916892630.12","n/a","2016","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/ttd",
"ULTI","The Ultimate Software Group, Inc.","330.19","10460506039.97","n/a","1998","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ulti",
"YORW","The York Water Company","33.69","436143665.1","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/yorw",
"NCTY","The9 Limited","2.11","19402173.73","9195343","2004","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ncty",
"TXMD","TherapeuticsMD, Inc.","4.9","1181693040.5","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/txmd",
"TRPX","Therapix Biosciences Ltd.","3.43","11849583.27","3454689","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/trpx",
"TBPH","Theravance Biopharma, Inc.","23.65","1326909335.95","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tbph",
"TST","TheStreet, Inc.","2.37","122205281.7","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/tst",
"TCRD","THL Credit, Inc.","6.59","212972918.1","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/tcrd",
"TBRG","Thunder Bridge Acquisition, Ltd.","10.19","262902000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tbrg",
"TBRGU","Thunder Bridge Acquisition, Ltd.","10.9","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tbrgu",
"TBRGW","Thunder Bridge Acquisition, Ltd.","0.73","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tbrgw",
"TIBR","Tiberius Acquisition Corporation","10.08","217350000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tibr",
"TIBRU","Tiberius Acquisition Corporation","10.45","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tibru",
"TIBRW","Tiberius Acquisition Corporation","0.42","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tibrw",
"TTTN","TigerShares China-U.S. Internet Titans ETF","28.504","8665216","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tttn",
"TTS","Tile Shop Hldgs, Inc.","5.67","300065165.82","n/a","n/a","Consumer Services","Home Furnishings","https://www.nasdaq.com/symbol/tts",
"TLRY","Tilray, Inc.","63.73","5106400536.74","n/a","2018","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/tlry",
"TSBK","Timberland Bancorp, Inc.","27.94","232276479.82","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/tsbk",
"TIPT","Tiptree Inc.","6.35","219111715.7","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/tipt",
"TITN","Titan Machinery Inc.","15.69","348603369.72","n/a","2007","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/titn",
"TMDI","Titan Medical Inc.","2.55","77955593.55","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/tmdi",
"TTNP","Titan Pharmaceuticals, Inc.","1.75","631739.5","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/ttnp",
"TVTY","Tivity Health, Inc.","18.16","860263933.92","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/tvty",
"TIVO","TiVo Corporation","9.28","1159122724.48","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/tivo",
"TLSA","Tiziana Life Sciences plc","5.73","4658736.39","813043","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tlsa",
"TKKS","TKK Symphony Acquisition Corporation","9.91","311669500","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tkks",
"TKKSR","TKK Symphony Acquisition Corporation","0.32","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tkksr",
"TKKSU","TKK Symphony Acquisition Corporation","10.3","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tkksu",
"TKKSW","TKK Symphony Acquisition Corporation","0.1744","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tkksw",
"TMUS","T-Mobile US, Inc.","69.73","59285942684.72","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tmus",
"TMSR","TMSR Holding Company Limited","1.89","55626833.43","n/a","2015","Finance","Business Services","https://www.nasdaq.com/symbol/tmsr",
"TOCA","Tocagen Inc.","10.93","251598730.21","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/toca",
"TNXP","Tonix Pharmaceuticals Holding Corp.","2.4","14615347.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tnxp",
"TISA","Top Image Systems, Ltd.","0.8426","15574378.259","n/a","1996","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/tisa",
"TOPS","TOP Ships Inc.","0.805","20096395.935","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/tops",
"TRCH","Torchlight Energy Resources, Inc.","1.47","105007780.08","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/trch",
"TRMD","TORM plc","7.7199","570546751.8423","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/trmd",
"TOTA","Tottenham Acquisition I Limited","10.0904","60189236","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tota",
"TOTAR","Tottenham Acquisition I Limited","0.36","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/totar",
"TOTAU","Tottenham Acquisition I Limited","10.42","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/totau",
"TOTAW","Tottenham Acquisition I Limited","0.121","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/totaw",
"TBLT","ToughBuilt Industries, Inc.","1.62","23387904.36","n/a","2018","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tblt",
"TBLTU","ToughBuilt Industries, Inc.","5.2","0","n/a","2018","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tbltu",
"TBLTW","ToughBuilt Industries, Inc.","0.22","0","n/a","2018","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tbltw",
"TSEM","Tower Semiconductor Ltd.","17.32","1833884432.36","n/a","1994","Technology","Semiconductors","https://www.nasdaq.com/symbol/tsem",
"CLUB","Town Sports International Holdings, Inc.","4.57","127610710.33","n/a","2006","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/club",
"TOWN","Towne Bank","25.08","1817406299.28","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/town",
"TPIC","TPI Composites, Inc.","28.48","994361684.8","n/a","2016","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tpic",
"TCON","TRACON Pharmaceuticals, Inc.","1.7","50827786.6","n/a","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/tcon",
"TSCO","Tractor Supply Company","97.16","11767069169.52","n/a","1994","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/tsco",
"TWMC","Trans World Entertainment Corp.","0.4479","16240333.9881","n/a","n/a","Consumer Services","Consumer Electronics/Video Chains","https://www.nasdaq.com/symbol/twmc",
"TACT","TransAct Technologies Incorporated","9.19","68474395.92","n/a","1996","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/tact",
"TRNS","Transcat, Inc.","22.89","165015268.95","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/trns",
"TGA","TransGlobe Energy Corporation","1.86","134835252.06","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/tga",
"TBIO","Translate Bio, Inc.","11.68","528797072.96","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/tbio",
"TA","TravelCenters of America LLC","4.29","173305493.79","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/ta",
"TANNI","TravelCenters of America LLC","25.95","0","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/tanni",
"TANNL","TravelCenters of America LLC","25.16","0","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/tannl",
"TANNZ","TravelCenters of America LLC","25.27","0","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/tannz",
"TZOO","Travelzoo","13.22","156860614.44","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/tzoo",
"TRMT","Tremont Mortgage Trust","9.0564","28788638.2788","n/a","2017","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/trmt",
"TRVN","Trevena, Inc.","1.6","147765820.8","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/trvn",
"TPCO","Tribune Publishing Company","11.97","428105481.93","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/tpco",
"TCDA","Tricida, Inc.","36.25","1536499460","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tcda",
"TCBK","TriCo Bancshares","39.43","1199623012.17","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/tcbk",
"TDAC","Trident Acquisitions Corp.","10.2","268323750","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tdac",
"TDACU","Trident Acquisitions Corp.","10.34","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tdacu",
"TDACW","Trident Acquisitions Corp.","0.17","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tdacw",
"TRIL","Trillium Therapeutics Inc.","0.68","14442405.08","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tril",
"TRS","TriMas Corporation","31.65","1441043964.75","n/a","2007","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/trs",
"TRMB","Trimble Inc.","40.69","10267869181.31","n/a","1990","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/trmb",
"TRIB","Trinity Biotech plc","2.97","71151770.25","23956825","1992","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/trib",
"TMCX","Trinity Merger Corp.","10.245","353452500","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tmcx",
"TMCXU","Trinity Merger Corp.","10.55","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tmcxu",
"TMCXW","Trinity Merger Corp.","0.349","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/tmcxw",
"TRIP","TripAdvisor, Inc.","52.56","7260439302.72","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/trip",
"TSC","TriState Capital Holdings, Inc.","21.01","615420675.98","n/a","2013","Finance","Major Banks","https://www.nasdaq.com/symbol/tsc",
"TSCAP","TriState Capital Holdings, Inc.","26.39","773010549.22","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/tscap",
"TBK","Triumph Bancorp, Inc.","29.77","794902464.2","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/tbk",
"TRVG","trivago N.V.","4.36","155041094.24","35559884","2016","Technology","EDP Services","https://www.nasdaq.com/symbol/trvg",
"TROV","TrovaGene, Inc.","4.12","16542648.72","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/trov",
"TRUE","TrueCar, Inc.","6.6","692226493.2","n/a","2014","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/true",
"TRUP","Trupanion, Inc.","34.74","1192714767.18","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/trup",
"TRST","TrustCo Bank Corp NY","7.82","756552609.56","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/trst",
"TRMK","Trustmark Corporation","34.36","2229964000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/trmk",
"TSRI","TSR, Inc.","5.1","10006516.2","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/tsri",
"TTEC","TTEC Holdings, Inc.","35.81","1654748658.82","n/a","1996","Technology","Professional Services","https://www.nasdaq.com/symbol/ttec",
"TTMI","TTM Technologies, Inc.","12.22","1284861121.96","n/a","2000","Technology","Electrical Products","https://www.nasdaq.com/symbol/ttmi",
"TC","TuanChe Limited","6.55","17030000","2600000","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/tc",
"TCX","Tucows Inc.","80.81","859743973.99","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/tcx",
"TUES","Tuesday Morning Corp.","2.14","100154859.04","n/a","1999","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/tues",
"TOUR","Tuniu Corporation","4.7","167372024.3","35611069","2014","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/tour",
"HEAR","Turtle Beach Corporation","12.53","178884231.75","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/hear",
"THCB","Tuscan Holdings Corp.","9.7652","346537652.4","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/thcb",
"THCBU","Tuscan Holdings Corp.","10.45","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/thcbu",
"THCBW","Tuscan Holdings Corp.","0.68","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/thcbw",
"TWLV","Twelve Seas Investment Company","10.02","268325580","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/twlv",
"TWLVR","Twelve Seas Investment Company","0.27","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/twlvr",
"TWLVU","Twelve Seas Investment Company","10.5","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/twlvu",
"TWLVW","Twelve Seas Investment Company","0.26","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/twlvw",
"TWIN","Twin Disc, Incorporated","16.69","218630855.28","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/twin",
"TWST","Twist Bioscience Corporation","25.63","718099392.12","n/a","2018","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/twst",
"TRCB","Two River Bancorp","16","138647600","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/trcb",
"TYME","Tyme Technologies, Inc.","1.85","192022772.05","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tyme",
"USCR","U S Concrete, Inc.","42.84","711970726.32","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/uscr",
"PRTS","U.S. Auto Parts Network, Inc.","1.03","36474931.65","n/a","2007","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/prts",
"USEG","U.S. Energy Corp.","0.77","10361473.43","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/useg",
"GROW","U.S. Global Investors, Inc.","1.19","18012308.86","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/grow",
"USAU","U.S. Gold Corp.","0.939","18132098.451","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/usau",
"USWS","U.S. Well Services, Inc.","7.76","393176944.32","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/usws",
"USWSW","U.S. Well Services, Inc.","0.9953","0","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/uswsw",
"UBNT","Ubiquiti Networks, Inc.","158.14","11152362680.04","n/a","2011","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/ubnt",
"UFPT","UFP Technologies, Inc.","36.15","267837049.05","n/a","1993","Capital Goods","Containers/Packaging","https://www.nasdaq.com/symbol/ufpt",
"ULTA","Ulta Beauty, Inc.","347.3","20599107958.5","n/a","2007","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/ulta",
"UCTT","Ultra Clean Holdings, Inc.","10.72","419266157.28","n/a","2004","Technology","Semiconductors","https://www.nasdaq.com/symbol/uctt",
"UPL","Ultra Petroleum Corp.","0.605","119416893.475","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/upl",
"RARE","Ultragenyx Pharmaceutical Inc.","72.63","3724390719.54","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rare",
"ULBI","Ultralife Corporation","10.47","163953059.46","n/a","1992","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/ulbi",
"UMBF","UMB Financial Corporation","64.98","3187407147.48","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/umbf",
"UMPQ","Umpqua Holdings Corporation","16.97","3739482353.46","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/umpq",
"UNAM","Unico American Corporation","5.7904","30730249.2112","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/unam",
"UBSH","Union Bankshares Corporation","33.16","2719663591.88","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ubsh",
"UNB","Union Bankshares, Inc.","45.7","204169959.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/unb",
"QURE","uniQure N.V.","59.59","2242151217","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/qure",
"UBCP","United Bancorp, Inc.","10.765","63740716.855","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ubcp",
"UBOH","United Bancshares, Inc.","22.82","74635867.88","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/uboh",
"UBSI","United Bankshares, Inc.","36.71","3752943364.51","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ubsi",
"UCBI","United Community Banks, Inc.","25.71","2034581443.71","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ucbi",
"UCFC","United Community Financial Corp.","9.34","458863692.5","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/ucfc",
"UAL","United Continental Holdings, Inc.","82.77","22077041548.29","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/ual",
"UBNK","United Financial Bancorp, Inc. ","14.66","749088265.16","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/ubnk",
"UFCS","United Fire Group, Inc","43.55","1093641056.95","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/ufcs",
"UIHC","United Insurance Holdings Corp.","16.2","696340038.6","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/uihc",
"UNFI","United Natural Foods, Inc.","13.24","672855396.56","n/a","1996","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/unfi",
"UBFO","United Security Bancshares","10.61","179803659.42","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ubfo",
"USLM","United States Lime & Minerals, Inc.","77.4","434212529.4","n/a","n/a","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/uslm",
"UTHR","United Therapeutics Corporation","116.82","5107654973.52","n/a","1999","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/uthr",
"UG","United-Guardian, Inc.","19.3","88670356.7","n/a","n/a","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/ug",
"UNIT","Uniti Group Inc.","11.3","2069074601.1","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/unit",
"UNTY","Unity Bancorp, Inc.","19.47","210251039.46","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/unty",
"UBX","Unity Biotechnology, Inc.","8.19","350998772.67","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ubx",
"OLED","Universal Display Corporation","159.8","7528237925","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/oled",
"UEIC","Universal Electronics Inc.","36.92","511067389.04","n/a","1993","Consumer Non-Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/ueic",
"UFPI","Universal Forest Products, Inc.","29.77","1825797106.77","n/a","1993","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/ufpi",
"ULH","Universal Logistics Holdings, Inc.","20.57","583855321.39","n/a","n/a","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/ulh",
"USAP","Universal Stainless & Alloy Products, Inc.","16.96","148683859.52","n/a","1994","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/usap",
"UVSP","Univest Financial Corporation","24.93","730192968.9","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/uvsp",
"UMRX","Unum Therapeutics Inc.","4.28","128788889.36","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/umrx",
"TIGR","UP Fintech Holding Limited","14.92","193960000","13000000","2019","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/tigr",
"UPLD","Upland Software, Inc.","41.47","891386784.86","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/upld",
"UPWK","Upwork Inc.","19.12","2039951613.6","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/upwk",
"UONE","Urban One, Inc. ","2.38","3871760.2","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/uone",
"UONEK","Urban One, Inc. ","2.01","76342509.48","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/uonek",
"URBN","Urban Outfitters, Inc.","30.66","3238992396.78","n/a","1993","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/urbn",
"MYT","Urban Tea, Inc.","2.1","48584159.4","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/myt",
"URGN","UroGen Pharma Ltd.","38.95","797557454.85","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/urgn",
"UROV","Urovant Sciences Ltd.","9.85","298680673.35","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/urov",
"ECOL","US Ecology, Inc.","55.49","1224677784.07","n/a","n/a","Public Utilities","Environmental Services","https://www.nasdaq.com/symbol/ecol",
"USAT","USA Technologies, Inc.","4.28","256803920.48","n/a","n/a","Miscellaneous","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/usat",
"USATP","USA Technologies, Inc.","20.05","8923513.15","n/a","n/a","Miscellaneous","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/usatp",
"USAK","USA Truck, Inc.","15.12","126424897.2","n/a","1992","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/usak",
"UTMD","Utah Medical Products, Inc.","87.78","326770705.8","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/utmd",
"UTSI","UTStarcom Holdings Corp","3.6","129216315.6","n/a","2000","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/utsi",
"UXIN","Uxin Limited","3.91","457406833.95","116983845","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/uxin",
"VCNX","Vaccinex, Inc.","7.155","82108984.095","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vcnx",
"VLRX","Valeritas Holdings, Inc.","0.3286","32843056.3982","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/vlrx",
"VALX","Validea Market Legends ETF","26.87","24183026.87","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/valx",
"VLY","Valley National Bancorp","9.81","3256761490.02","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/vly",
"VLYPO","Valley National Bancorp","24.82","99280000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/vlypo",
"VLYPP","Valley National Bancorp","27.18","125028000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/vlypp",
"VALU","Value Line, Inc.","25.12","242935545.12","n/a","1983","Finance","Investment Managers","https://www.nasdaq.com/symbol/valu",
"VNDA","Vanda Pharmaceuticals Inc.","18.17","956518840.18","n/a","2006","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vnda",
"BBH","VanEck Vectors Biotech ETF","130.39","416792026.17","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbh",
"GNRX","VanEck Vectors Generic Drugs ETF","22.4293","3364395","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gnrx",
"PPH","VanEck Vectors Pharmaceutical ETF","59.96","188162754.48","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pph",
"VWOB","Vanguard Emerging Markets Government Bond ETF","77.91","1224394605","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vwob",
"VNQI","Vanguard Global ex-U.S. Real Estate ETF","59.81","5894616058.14","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vnqi",
"VCIT","Vanguard Intermediate-Term Corporate Bond ETF","86.33","22777463457.3","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vcit",
"VGIT","Vanguard Intermediate-Term Treasury ETF","64.16","3655297278.56","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vgit",
"VIGI","Vanguard International Dividend Appreciation ETF","65.3841","1087309402.4529","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vigi",
"VYMI","Vanguard International High Dividend Yield ETF","61.88","1040328849.56","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vymi",
"VCLT","Vanguard Long-Term Corporate Bond ETF","90.55","3233023368.95","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vclt",
"VGLT","Vanguard Long-Treasury ETF","76.66","888845025.74","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vglt",
"VMBS","Vanguard Mortgage-Backed Securities ETF","52.08","8468746767.6","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vmbs",
"VONE","Vanguard Russell 1000 ETF","131.34","1093405500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vone",
"VONG","Vanguard Russell 1000 Growth ETF","157.66","2392760256.26","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vong",
"VONV","Vanguard Russell 1000 Value ETF","109.07","1807835250","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vonv",
"VTWO","Vanguard Russell 2000 ETF","124.12","1551500000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vtwo",
"VTWG","Vanguard Russell 2000 Growth ETF","143.7149","294615545","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vtwg",
"VTWV","Vanguard Russell 2000 Value ETF","105.35","247572500","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vtwv",
"VTHR","Vanguard Russell 3000 ETF","130.96","438716000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vthr",
"VCSH","Vanguard Short-Term Corporate Bond ETF","79.41","24066070198.32","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vcsh",
"VTIP","Vanguard Short-Term Inflation-Protected Securities Index Fund","48.7","6133376130.5","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vtip",
"VGSH","Vanguard Short-Term Treasury ETF","60.28","4900753451","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vgsh",
"BND","Vanguard Total Bond Market ETF","80.7","38068047552.6","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bnd",
"VTC","Vanguard Total Corporate Bond ETF","83.255","116557000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vtc",
"BNDX","Vanguard Total International Bond ETF","55.63","16312780429.3","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bndx",
"VXUS","Vanguard Total International Stock ETF","52.62","12002599689.12","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vxus",
"BNDW","Vanguard Total World Bond ETF","76.52","110954000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bndw",
"VEAC","Vantage Energy Acquisition Corp.","10.22","564144000","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/veac",
"VEACU","Vantage Energy Acquisition Corp.","10.2","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/veacu",
"VEACW","Vantage Energy Acquisition Corp.","0.0053","0","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/veacw",
"VREX","Varex Imaging Corporation","33.82","1289196214.08","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/vrex",
"VRNS","Varonis Systems, Inc.","61.09","1831540572.89","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/vrns",
"VBLT","Vascular Biogenics Ltd.","1.5","53821690.5","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vblt",
"VXRT","Vaxart, Inc.","1.99","16598966.11","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/vxrt",
"VBIV","VBI Vaccines, Inc.","1.89","184580966.43","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/vbiv",
"VTIQ","VectoIQ Acquisition Corp.","10.01","296696400","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/vtiq",
"VTIQU","VectoIQ Acquisition Corp.","10.5","0","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/vtiqu",
"VTIQW","VectoIQ Acquisition Corp.","0.46","13634400","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/vtiqw",
"VECO","Veeco Instruments Inc.","11.27","541343281.43","n/a","1994","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/veco",
"VEON","VEON Ltd.","2.11","3134249845.37","1485426467","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/veon",
"VRA","Vera Bradley, Inc.","13.25","459336743","n/a","2010","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/vra",
"VCYT","Veracyte, Inc.","24.35","1000997843.35","n/a","2013","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/vcyt",
"VSTM","Verastem, Inc.","3.03","223811059.08","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vstm",
"VCEL","Vericel Corporation","17.18","752603538.44","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/vcel",
"VRNT","Verint Systems Inc.","61.49","4017298253.54","n/a","2002","Technology","EDP Services","https://www.nasdaq.com/symbol/vrnt",
"VRSN","VeriSign, Inc.","186.88","22372329669.12","n/a","1998","Technology","EDP Services","https://www.nasdaq.com/symbol/vrsn",
"VRSK","Verisk Analytics, Inc.","134.91","22059070692.3","n/a","2009","Technology","EDP Services","https://www.nasdaq.com/symbol/vrsk",
"VBTX","Veritex Holdings, Inc.","24.77","1350921146.77","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/vbtx",
"VERI","Veritone, Inc.","5.58","109943962.02","n/a","2017","Technology","EDP Services","https://www.nasdaq.com/symbol/veri",
"VRML","Vermillion, Inc.","1.11","83841350.28","n/a","n/a","Health Care","Biotechnology: In Vitro & In Vivo Diagnostic Substances","https://www.nasdaq.com/symbol/vrml",
"VRNA","Verona Pharma plc","6.91","63756690.48","9226728","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vrna",
"VRRM","Verra Mobility Corporation","12.26","1913254430.92","n/a","2017","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/vrrm",
"VRCA","Verrica Pharmaceuticals Inc.","10.23","262985228.88","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vrca",
"VTNR","Vertex Energy, Inc","1.64","65886706.44","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/vtnr",
"VRTX","Vertex Pharmaceuticals Incorporated","187.11","47835960500.79","n/a","1991","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vrtx",
"VERU","Veru Inc.","1.49","93474375.2","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/veru",
"VIA","Viacom Inc.","33.6","13543165977.6","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/via",
"VIAB","Viacom Inc.","28.82","10191890822.3","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/viab",
"VSAT","ViaSat, Inc.","79.02","4779229402.26","n/a","1996","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/vsat",
"VIAV","Viavi Solutions Inc.","12.41","2829435547.38","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/viav",
"VICL","Vical Incorporated","1.2","26184234","n/a","1993","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/vicl",
"VICR","Vicor Corporation","30.33","1219628352.51","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/vicr",
"VCTR","Victory Capital Holdings, Inc.","15.8","230142405","n/a","2018","Finance","Investment Managers","https://www.nasdaq.com/symbol/vctr",
"CIZ","VictoryShares Developed Enhanced Volatility Wtd ETF","32","137581344","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ciz",
"VSDA","VictoryShares Dividend Accelerator ETF","31.7","12678478.4","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vsda",
"CEY","VictoryShares Emerging Market High Div Volatility Wtd ETF","24.3","35237843.1","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cey",
"CEZ","VictoryShares Emerging Market Volatility Wtd ETF","26","18197894","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cez",
"CID","VictoryShares International High Div Volatility Wtd ETF","33.075","43001270.55","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cid",
"CIL","VictoryShares International Volatility Wtd ETF","38.09","43799995.72","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cil",
"CFO","VictoryShares US 500 Enhanced Volatility Wtd ETF","47.27","895810035.67","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cfo",
"CFA","VictoryShares US 500 Volatility Wtd ETF","50.77","698049067.11","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cfa",
"CSF","VictoryShares US Discovery Enhanced Volatility Wtd ETF","39.96","109898031.96","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/csf",
"CDC","VictoryShares US EQ Income Enhanced Volatility Wtd ETF","44.98","715239079.62","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cdc",
"CDL","VictoryShares US Large Cap High Div Volatility Wtd ETF","46.4356","306475145.7424","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cdl",
"VSMV","VictoryShares US Multi-Factor Minimum Volatility ETF","29.49","38333490.69","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vsmv",
"CSB","VictoryShares US Small Cap High Div Volatility Wtd ETF","43.97","65950778.88","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/csb",
"CSA","VictoryShares US Small Cap Volatility Wtd ETF","45.2207","36177645.2968","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/csa",
"VRAY","ViewRay, Inc.","7.43","718255492.07","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/vray",
"VKTX","Viking Therapeutics, Inc.","10.48","754413510.56","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vktx",
"VKTXW","Viking Therapeutics, Inc.","9.41","0","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vktxw",
"VBFC","Village Bank and Trust Financial Corp.","33","47364339","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/vbfc",
"VFF","Village Farms International, Inc.","15.02","715858261.74","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/vff",
"VLGEA","Village Super Market, Inc.","26.87","385894203.62","n/a","n/a","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/vlgea",
"VIOT","Viomi Technology Co., Ltd","11.46","130644000","11400000","2018","Consumer Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/viot",
"VNOM","Viper Energy Partners LP","33.99","4588563529.44","n/a","2014","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/vnom",
"VIRC","Virco Manufacturing Corporation","4.35","67607508.6","n/a","n/a","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/virc",
"VTSI","VirTra, Inc.","3.8592","30167150.2848","n/a","n/a","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/vtsi",
"VIRT","Virtu Financial, Inc.","25.49","4841352405.6","n/a","2015","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/virt",
"VRTS","Virtus Investment Partners, Inc.","104.55","733019078.1","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/vrts",
"VRTSP","Virtus Investment Partners, Inc.","92.22","106053000","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/vrtsp",
"BBC","Virtus LifeSci Biotech Clinical Trials ETF","28.9149","28915015.6596","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbc",
"BBP","Virtus LifeSci Biotech Products ETF","45.404","45404181.616","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbp",
"VRTU","Virtusa Corporation","53.43","1598661932.4","n/a","2007","Technology","EDP Services","https://www.nasdaq.com/symbol/vrtu",
"VISL","Vislink Technologies, Inc.","0.37","7050182.39","n/a","2013","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/visl",
"VTGN","VistaGen Therapeutics, Inc.","1.3","53456604.5","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vtgn",
"VC","Visteon Corporation","71.74","2026230729.64","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/vc",
"VTL","Vital Therapies, Inc.","0.1968","8338355.7792","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vtl",
"VIVE","Viveve Medical, Inc.","0.8798","40791548.686","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/vive",
"VVPR","VivoPower International PLC","1.24","16811146.24","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/vvpr",
"VVUS","VIVUS, Inc.","3.91","41591311.24","n/a","1994","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vvus",
"VOD","Vodafone Group Plc","18.56","8283765514.88","446323573","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/vod",
"VOXX","VOXX International Corporation","4.75","114945506.5","n/a","n/a","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/voxx",
"VYGR","Voyager Therapeutics, Inc.","21.25","781930448.75","n/a","2015","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/vygr",
"VSEC","VSE Corporation","30.66","334345337.76","n/a","n/a","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/vsec",
"VTVT","vTv Therapeutics Inc.","1.7099","40387152.3301","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/vtvt",
"VUZI","Vuzix Corporation","2.69","74238396.73","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/vuzi",
"WTRH","Waitr Holdings Inc.","12.25","856043009.5","n/a","2016","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/wtrh",
"WBA","Walgreens Boots Alliance, Inc.","55.36","52229100584.96","n/a","n/a","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/wba",
"WAFD","Washington Federal, Inc.","29.13","2362806221.97","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wafd",
"WASH","Washington Trust Bancorp, Inc.","48.51","839479084.29","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wash",
"WSBF","Waterstone Financial, Inc.","16.39","460374432.21","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/wsbf",
"WTRE","Watford Holdings Ltd.","25.805","585331589.375","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wtre",
"WVE","WAVE Life Sciences Ltd.","39.93","1365290792.58","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/wve",
"WSTG","Wayside Technology Group, Inc.","11.19","50522782.86","n/a","n/a","Technology","Retail: Computer Software & Peripheral Equipment","https://www.nasdaq.com/symbol/wstg",
"WCFB","WCF Bancorp, Inc.","8.22","21055875.24","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wcfb",
"WDFC","WD-40 Company","170.57","2358017503.23","n/a","1973","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/wdfc",
"HHHH","Wealthbridge Acquisition Limited","9.8","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/hhhh",
"HHHHR","Wealthbridge Acquisition Limited","0.21","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/hhhhr",
"HHHHU","Wealthbridge Acquisition Limited","10.08","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/hhhhu",
"HHHHW","Wealthbridge Acquisition Limited","0.0989","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/hhhhw",
"WB","Weibo Corporation","65.9","4915304981.1","74587329","2014","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/wb",
"WTW","Weight Watchers International Inc","20.16","1349916059.52","n/a","2001","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/wtw",
"WEBK","Wellesley Bancorp, Inc.","30.9","78356590.8","n/a","2012","Finance","Banks","https://www.nasdaq.com/symbol/webk",
"WEN","Wendy&#39;s Company (The)","17.95","4132634782.5","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/wen",
"WERN","Werner Enterprises, Inc.","34.5","2431839519","n/a","1986","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/wern",
"WSBC","WesBanco, Inc.","40.15","2192134874.05","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wsbc",
"WTBA","West Bancorporation","20.83","339435140.02","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wtba",
"WABC","Westamerica Bancorporation","62.25","1673933313.75","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wabc",
"WSTL","Westell Technologies, Inc.","2.2","33851615.6","n/a","1995","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/wstl",
"WINC","Western Asset Short Duration Income ETF","25.37","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/winc",
"WBND","Western Asset Total Return ETF","26.12","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wbnd",
"WDC","Western Digital Corporation","50.38","14653070256.44","n/a","n/a","Technology","Electronic Components","https://www.nasdaq.com/symbol/wdc",
"WNEB","Western New England Bancorp, Inc.","9.55","260362633.65","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/wneb",
"WPRT","Westport Fuel Systems Inc","1.59","212075629.41","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/wprt",
"WWR","Westwater Resources, Inc.","0.138","10267161.636","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/wwr",
"WEYS","Weyco Group, Inc.","32","319848160","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/weys",
"WHLR","Wheeler Real Estate Investment Trust, Inc.","1.6","15507331.2","n/a","2012","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/whlr",
"WHLRD","Wheeler Real Estate Investment Trust, Inc.","14.02","50480916.72","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/whlrd",
"WHLRP","Wheeler Real Estate Investment Trust, Inc.","13.12","24609813.76","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/whlrp",
"WHLRW","Wheeler Real Estate Investment Trust, Inc.","0.015","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/whlrw",
"WHF","WhiteHorse Finance, Inc.","14.05","288671749.6","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/whf",
"WHFBZ","WhiteHorse Finance, Inc.","25.8","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/whfbz",
"WHLM","Wilhelmina International, Inc.","5.67","29769127.29","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/whlm",
"WVVI","Willamette Valley Vineyards, Inc.","7.1","35248155.9","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/wvvi",
"WVVIP","Willamette Valley Vineyards, Inc.","4.62","21541988.16","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/wvvip",
"WLDN","Willdan Group, Inc.","37.96","418168954.32","n/a","2006","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/wldn",
"WLFC","Willis Lease Finance Corporation","41.77","241984261.35","n/a","1996","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/wlfc",
"WLTW","Willis Towers Watson Public Limited Company","177.2","22876851895.6","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/wltw",
"WSC","WillScot Corporation","11.54","1252193825.38","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/wsc",
"WING","Wingstop Inc.","72.56","2128465462.08","n/a","2015","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/wing",
"WINA","Winmark Corporation","193.74","757365695.64","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/wina",
"WINS","Wins Finance Holdings Inc.","24.98","495544297.16","n/a","2014","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/wins",
"WTFC","Wintrust Financial Corporation","70.32","3973603321.44","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wtfc",
"WTFCM","Wintrust Financial Corporation","27.77","138850000","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wtfcm",
"AGND","WisdomTree Barclays Negative Duration U.S. Aggregate Bond Fund","42.5086","25505160","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/agnd",
"CXSE","WisdomTree China ex-State-Owned Enterprises Fund","79.48","147038000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cxse",
"EMCG","WisdomTree Emerging Markets Consumer Growth Fund","22.567","34978850","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/emcg",
"EMCB","WisdomTree Emerging Markets Corporate Bond Fund","71.02","35510000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/emcb",
"DGRE","WisdomTree Emerging Markets Quality Dividend Growth Fund","25.06","70168000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dgre",
"DXGE","WisdomTree Germany Hedged Equity Fund","29.3187","52773660","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dxge",
"HYZD","WisdomTree Interest Rate Hedged High Yield Bond Fund","23.48","248888000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hyzd",
"AGZD","WisdomTree Interest Rate Hedged U.S. Aggregate Bond Fund","47.73","81141000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/agzd",
"WETF","WisdomTree Investments, Inc.","7.14","1107756034.56","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/wetf",
"DXJS","WisdomTree Japan Hedged SmallCap Equity Fund","40.438","84919800","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dxjs",
"GULF","WisdomTree Middle East Dividend Fund","20.6357","20635700","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gulf",
"HYND","WisdomTree Negative Duration High Yield Bond Fund","20.03","52078000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hynd",
"DGRW","WisdomTree U.S. Quality Dividend Growth Fund","43.46","2807516000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dgrw",
"DGRS","WisdomTree U.S. SmallCap Quality Dividend Growth Fund","35.0076","120776220","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dgrs",
"WIX","Wix.com Ltd.","119.3","5593784927","n/a","2013","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/wix",
"WWD","Woodward, Inc.","95.92","5954960689.92","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/wwd",
"WDAY","Workday, Inc.","193.78","30423460000","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/wday",
"WKHS","Workhorse Group, Inc.","0.6602","40600312.798","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/wkhs",
"WRLD","World Acceptance Corporation","119.33","1148294571.17","n/a","1991","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/wrld",
"WRTC","Wrap Technologies, Inc.","6.96","190457664.72","n/a","n/a","Capital Goods","Ordnance And Accessories","https://www.nasdaq.com/symbol/wrtc",
"WMGI","Wright Medical Group N.V.","30.88","3886482935.04","n/a","2011","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/wmgi",
"WSFS","WSFS Financial Corporation","39.26","2235521641.08","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wsfs",
"WVFC","WVS Financial Corp.","17.55","34113619.8","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/wvfc",
"WYNN","Wynn Resorts, Limited","135.03","14534538594.87","n/a","2002","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/wynn",
"XFOR","X4 Pharmaceuticals, Inc.","17.72","118724000","n/a","2017","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/xfor",
"XBIT","XBiotech Inc.","10.89","392558429.34","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/xbit",
"XELB","Xcel Brands, Inc","1.68","32024687.52","n/a","n/a","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/xelb",
"XEL","Xcel Energy Inc.","55.58","28579867833.44","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/xel",
"XNCR","Xencor, Inc.","32.43","1825555040.67","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/xncr",
"XBIO","Xenetic Biosciences, Inc.","1.88","19634511.32","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/xbio",
"XENE","Xenon Pharmaceuticals Inc.","10.15","261375349.9","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/xene",
"XERS","Xeris Pharmaceuticals, Inc.","9.86","265594244.96","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/xers",
"XLNX","Xilinx, Inc.","129.09","32680927205.55","n/a","1990","Technology","Semiconductors","https://www.nasdaq.com/symbol/xlnx",
"XOMA","XOMA Corporation","12.43","108275206.71","n/a","1986","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/xoma",
"XPER","Xperi Corporation","23.97","1177241774.04","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/xper",
"XSPA","XpresSpa Group, Inc. ","2.63","4542867.38","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/xspa",
"XTLB","XTL Biopharmaceuticals Ltd.","2.2833","6267343.4046","2744862","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/xtlb",
"XNET","Xunlei Limited","3.98","154852331.58","38907621","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/xnet",
"YNDX","Yandex N.V.","34.93","11331217389.52","n/a","2011","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/yndx",
"YRIV","Yangtze River Port and Logistics Limited ","0.729","125776239.885","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/yriv",
"YTRA","Yatra Online, Inc.","5","225668765","n/a","n/a","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/ytra",
"YTEN","Yield10 Bioscience, Inc.","1.23","15335909.37","n/a","n/a","Basic Industries","Containers/Packaging","https://www.nasdaq.com/symbol/yten",
"YIN","Yintech Investment Holdings Limited","6.29","101076997.75","16069475","2016","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/yin",
"YMAB","Y-mAbs Therapeutics, Inc.","28.31","968022684.46","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ymab",
"YOGA","YogaWorks, Inc.","0.84","14036988.84","n/a","2017","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/yoga",
"YGYI","Youngevity International, Inc.","5.81","162665626.06","n/a","n/a","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/ygyi",
"YRCW","YRC Worldwide, Inc.","7.26","245705886.36","n/a","n/a","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/yrcw",
"YY","YY Inc.","86.49","4282332059.97","49512453","2012","Technology","EDP Services","https://www.nasdaq.com/symbol/yy",
"ZFGN","Zafgen, Inc.","2.89","107840691.02","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/zfgn",
"ZAGG","ZAGG Inc","9.17","265314903.91","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/zagg",
"ZLAB","Zai Lab Limited","30.46","633091361.92","20784352","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/zlab",
"ZEAL","Zealand Pharma A/S","18.6827","58515823.1122","3132086","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/zeal",
"ZBRA","Zebra Technologies Corporation","213.62","11507815569.14","n/a","1991","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/zbra",
"Z","Zillow Group, Inc.","36.18","7402341276.54","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/z",
"ZG","Zillow Group, Inc.","35.58","7279582714.74","n/a","2011","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/zg",
"ZN","Zion Oil & Gas Inc","0.8","56070628.8","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/zn",
"ZNWAA","Zion Oil & Gas Inc","n/a","0","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/znwaa",
"ZION","Zions Bancorporation N.A.","46.93","8736472562.22","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/zion",
"ZIONW","Zions Bancorporation N.A.","14.64","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/zionw",
"ZIOP","ZIOPHARM Oncology Inc","4","649177976","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ziop",
"ZIXI","Zix Corporation","6.8","367807056.4","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/zixi",
"ZKIN","ZK International Group Co., Ltd","1.555","25747747.535","n/a","2017","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/zkin",
"ZGNX","Zogenix, Inc.","53.89","2285311020.51","n/a","2010","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/zgnx",
"ZSAN","Zosano Pharma Corporation","4.81","57590317.59","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/zsan",
"ZS","Zscaler, Inc.","70.91","8803270648.27","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/zs",
"ZUMZ","Zumiez Inc.","24.89","635215773.47","n/a","2005","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/zumz",
"ZYNE","Zynerba Pharmaceuticals, Inc.","6.48","136533574.08","n/a","2015","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/zyne",
"ZYXI","Zynex, Inc.","4.73","152485853.52","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/zyxi",
"ZNGA","Zynga Inc.","5.41","5020101797.72","n/a","2011","Technology","EDP Services","https://www.nasdaq.com/symbol/znga",
