"Symbol","Name","LastSale","MarketCap","ADR TSO","IPOyear","Sector","Industry","Summary Quote",
"DDD","3D Systems Corporation","10.92","1274116301.64","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ddd",
"MMM","3M Company","212.13","122164953394.68","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/mmm",
"WBAI","500.com Limited","14.26","605842987.58","n/a","2013","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/wbai",
"WUBA","58.com Inc.","66.8","9901248905.2","n/a","2013","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/wuba",
"EGHT","8x8 Inc","20.66","1976226060.68","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/eght",
"AHC","A.H. Belo Corporation","3.76","71739111.76","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/ahc",
"AOS","A.O Smith Corporation","54.05","9072980502.45","n/a","n/a","Consumer Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/aos",
"ATEN","A10 Networks, Inc.","7.12","534362037.76","n/a","2014","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/aten",
"AAC","AAC Holdings, Inc.","2.01","49450733.55","n/a","2014","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/aac",
"AIR","AAR Corp.","33.02","1157898108.38","n/a","n/a","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/air",
"AAN","Aaron&#39;s,  Inc.","52.39","3550892877.74","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/aan",
"ABB","ABB Ltd","19.26","41061595939.56","n/a","n/a","Consumer Durables","Electrical Products","https://www.nasdaq.com/symbol/abb",
"ABT","Abbott Laboratories","79.62","139850162817.78","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/abt",
"ABBV","AbbVie Inc.","83.07","122791143207.33","n/a","2012","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/abbv",
"ANF","Abercrombie & Fitch Company","26.71","1768923170","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/anf",
"AGD","Aberdeen Global Dynamic Dividend Fund","9.56","119974003.92","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/agd",
"AWP","Aberdeen Global Premier Properties Fund","6.01","513301785.51","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/awp",
"ACP","Aberdeen Income Credit Strategies Fund","12.22","159765159.84","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/acp",
"JEQ","Aberdeen Japan Equity Fund, Inc. ","6.99","93589613.28","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/jeq",
"AOD","Aberdeen Total Dynamic Dividend Fund","8.37","900556247.43","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/aod",
"ABM","ABM Industries Incorporated","37.38","2476012175.28","n/a","n/a","Finance","Diversified Commercial Services","https://www.nasdaq.com/symbol/abm",
"AKR","Acadia Realty Trust","27.21","2248187339.7","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/akr",
"ACN","Accenture plc","175.37","111856699203.86","n/a","2001","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/acn",
"ACCO","Acco Brands Corporation","8.7","889200360.6","n/a","n/a","Consumer Durables","Publishing","https://www.nasdaq.com/symbol/acco",
"ATV","Acorn International, Inc.","26.03","69764044.2","n/a","2007","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/atv",
"ATU","Actuant Corporation","25.12","1535455830.08","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/atu",
"AYI","Acuity Brands, Inc. ","123.89","4942267825.43","n/a","n/a","Consumer Durables","Building Products","https://www.nasdaq.com/symbol/ayi",
"GOLF","Acushnet Holdings Corp.","22.54","1691156161.94","n/a","2016","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/golf",
"ADX","Adams Diversified Equity Fund, Inc.","14.63","1475705394.24","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/adx",
"PEO","Adams Natural Resources Fund, Inc.","16.84","488286695.48","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/peo",
"AGRO","Adecoagro S.A.","6.7","780924422.8","n/a","2011","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/agro",
"ADNT","Adient plc","14.49","1355283737.01","n/a","2016","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/adnt",
"ADT","ADT Inc.","6.6","4993602075","n/a","2018","Consumer Services","Diversified Commercial Services","https://www.nasdaq.com/symbol/adt",
"ATGE","Adtalem Global Education Inc.","46.48","2685614400","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/atge",
"AAP","Advance Auto Parts Inc","173.34","12423301027.56","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/aap",
"ADSW","Advanced Disposal Services, Inc.","27.59","2447021881.32","n/a","2016","Public Utilities","Environmental Services","https://www.nasdaq.com/symbol/adsw",
"WMS","Advanced Drainage Systems, Inc.","25.95","1486291907.1","n/a","2014","Capital Goods","Containers/Packaging","https://www.nasdaq.com/symbol/wms",
"ASIX","AdvanSix Inc.","29.02","842348014.3","n/a","2016","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/asix",
"AVK","Advent Claymore Convertible Securities and Income Fund","14.78","510282781.16","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/avk",
"ACM","AECOM","30.51","4762453415.85","n/a","2007","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/acm",
"AEB","Aegon NV","21.87","0","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/aeb",
"AED","Aegon NV","25.83","0","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/aed",
"AEG","Aegon NV","4.96","10154931967.36","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/aeg",
"AEH","Aegon NV","25.87","0","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/aeh",
"AER","Aercap Holdings N.V.","47.6","6791314006.4","n/a","2006","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/aer",
"HIVE","Aerohive Networks, Inc.","4.54","253644846.86","n/a","2014","Technology","EDP Services","https://www.nasdaq.com/symbol/hive",
"AJRD","Aerojet Rocketdyne Holdings, Inc. ","34.36","2703019285.76","n/a","n/a","Capital Goods","Military/Government/Technical","https://www.nasdaq.com/symbol/ajrd",
"AMG","Affiliated Managers Group, Inc.","111.37","5796664275.85","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/amg",
"MGR","Affiliated Managers Group, Inc.","24.88","0","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/mgr",
"AFL","Aflac Incorporated","49.25","36880854275.25","n/a","n/a","Finance","Accident &Health Insurance","https://www.nasdaq.com/symbol/afl",
"MITT","AG Mortgage Investment Trust, Inc.","16.79","540633668.18","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/mitt",
"MITT^A","AG Mortgage Investment Trust, Inc.","25.33","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mitt^a",
"MITT^B","AG Mortgage Investment Trust, Inc.","25.78","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mitt^b",
"AGCO","AGCO Corporation","70.55","5412125502.05","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/agco",
"A","Agilent Technologies, Inc.","81.14","25763237610.66","n/a","1999","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/a",
"AEM","Agnico Eagle Mines Limited","43.21","10162875721.89","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/aem",
"ADC","Agree Realty Corporation","67.89","2551083792.36","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/adc",
"AL","Air Lease Corporation","35.54","3949139726.26","n/a","2011","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/al",
"AL^A","Air Lease Corporation","25.67","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/al^a",
"APD","Air Products and Chemicals, Inc.","190.48","41835345452.08","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/apd",
"AYR","Aircastle Limited","20.41","1533326558.4","n/a","2006","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/ayr",
"AKS","AK Steel Holding Corporation","2.83","895153142.73","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/aks",
"ALP^Q","Alabama Power Company","25.84","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/alp^q",
"ALG","Alamo Group, Inc.","99.77","1171307182.98","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/alg",
"AGI","Alamos Gold Inc.","4.93","1918136821.58","n/a","2015","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/agi",
"ALK","Alaska Air Group, Inc.","58.14","7186838017.5","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/alk",
"AIN","Albany International Corporation","71.82","2087073543.24","n/a","n/a","Basic Industries","Textiles","https://www.nasdaq.com/symbol/ain",
"ALB","Albemarle Corporation","82.9","8777941856.1","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/alb",
"AA","Alcoa Corporation","28.54","5294644448.96","n/a","2016","Basic Industries","Aluminum","https://www.nasdaq.com/symbol/aa",
"ALEX","Alexander & Baldwin, Inc.","25","1802300325","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/alex",
"ALX","Alexander&#39;s, Inc.","375.79","1919268509.1","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/alx",
"ARE","Alexandria Real Estate Equities, Inc.","143.23","16146091883.06","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/are",
"ARE^D","Alexandria Real Estate Equities, Inc.","37.35","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/are^d",
"AQN","Algonquin Power & Utilities Corp.","11.29","5537843742.34","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/aqn",
"AQNA","Algonquin Power & Utilities Corp.","26.73","0","n/a","2018","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/aqna",
"BABA","Alibaba Group Holding Limited","181.74","471103567048.92","n/a","2014","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/baba",
"Y","Alleghany Corporation","613.06","8864286037.04","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/y",
"ATI","Allegheny Technologies Incorporated","26.22","3306592322.34","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/ati",
"ALLE","Allegion plc","92.42","8729839320.7","n/a","2013","Consumer Services","Diversified Commercial Services","https://www.nasdaq.com/symbol/alle",
"AGN","Allergan plc.","146.26","48297734554.66","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/agn",
"ALE","Allete, Inc.","81.61","4212797644.56","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/ale",
"AKP","Alliance California Municipal Income Fund Inc","14.78","126437993.04","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/akp",
"ADS","Alliance Data Systems Corporation","175.53","9302683648.05","n/a","2001","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ads",
"AFB","Alliance National Municipal Income Fund Inc","12.91","371097123.76","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/afb",
"AWF","Alliance World Dollar Government Fund II","11.68","1007162627.36","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/awf",
"AB","AllianceBernstein Holding L.P.","28.79","2779912823.62","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/ab",
"CBH","AllianzGI Convertible & Income 2024 Target Term Fund","9.12","166503949.44","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/cbh",
"NCV","AllianzGI Convertible & Income Fund","5.96","534537321.2","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/ncv",
"NCV^A","AllianzGI Convertible & Income Fund","24.55","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ncv^a",
"NCZ","AllianzGI Convertible & Income Fund II","5.29","400178993.87","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/ncz",
"NCZ^A","AllianzGI Convertible & Income Fund II","24.04","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ncz^a",
"ACV","AllianzGI Diversified Income & Convertible Fund","22.66","233655984.1","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/acv",
"NIE","AllianzGI Equity & Convertible Income Fund","21.67","600453271.55","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/nie",
"NFJ","AllianzGI NFJ Dividend, Interest & Premium Strategy Fund","12.14","1150891193.34","n/a","2005","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/nfj",
"ALSN","Allison Transmission Holdings, Inc.","45.64","5716678910.88","n/a","2012","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/alsn",
"ALL","Allstate Corporation (The)","94.81","31473421890.24","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/all",
"ALL^A","Allstate Corporation (The)","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/all^a",
"ALL^B","Allstate Corporation (The)","25.63","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/all^b",
"ALL^D","Allstate Corporation (The)","25.4432","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/all^d",
"ALL^E","Allstate Corporation (The)","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/all^e",
"ALL^F","Allstate Corporation (The)","25.97","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/all^f",
"ALL^G","Allstate Corporation (The)","25.51","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/all^g",
"ALLY","Ally Financial Inc.","28.52","11438366812.6","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/ally",
"ALLY^A","Ally Financial Inc.","26.27","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ally^a",
"AYX","Alteryx, Inc.","84.76","5236830402.44","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ayx",
"ATUS","Altice USA, Inc.","22.55","11132653869.15","n/a","2017","Consumer Services","Television Services","https://www.nasdaq.com/symbol/atus",
"MO","Altria Group","56.69","106261484716.43","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/mo",
"ACH","Aluminum Corporation of China Limited","10.16","6918014286.88","n/a","2001","Basic Industries","Aluminum","https://www.nasdaq.com/symbol/ach",
"AMBR","Amber Road, Inc.","8.81","247411326.91","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ambr",
"ABEV","Ambev S.A.","4.35","68409703562.25","n/a","2013","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/abev",
"AMC","AMC Entertainment Holdings, Inc.","14.78","1534421127.66","n/a","2013","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/amc",
"AEE","Ameren Corporation","72.56","17807596907.76","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/aee",
"AMRC","Ameresco, Inc.","16.3","754698247.8","n/a","2010","Basic Industries","Engineering & Construction","https://www.nasdaq.com/symbol/amrc",
"AMOV","America Movil, S.A.B. de C.V.","14.26","47074793916.44","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/amov",
"AMX","America Movil, S.A.B. de C.V.","14.34","47338888131.96","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/amx",
"AAT","American Assets Trust, Inc.","46.4","2195903524.8","n/a","2011","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/aat",
"AXL","American Axle & Manufacturing Holdings, Inc.","15.15","1692894027","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/axl",
"ACC","American Campus Communities Inc","48.2","6613671034.4","n/a","2004","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/acc",
"AEO","American Eagle Outfitters, Inc.","21.72","3748536404.28","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/aeo",
"AEP","American Electric Power Company, Inc.","83.08","42319918318.64","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/aep",
"AEP^B","American Electric Power Company, Inc.","51.1","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aep^b",
"AEL","American Equity Investment Life Holding Company","27.24","2465287854.84","n/a","2003","Finance","Life Insurance","https://www.nasdaq.com/symbol/ael",
"AXP","American Express Company","111","93100995810","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/axp",
"AFG","American Financial Group, Inc.","95.99","8573097084.02","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/afg",
"AFGB","American Financial Group, Inc.","25.22","0","n/a","2019","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/afgb",
"AFGE","American Financial Group, Inc.","25.8","0","n/a","2014","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/afge",
"AFGH","American Financial Group, Inc.","26.03","0","n/a","2015","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/afgh",
"AMH","American Homes 4 Rent","23.02","6828989375.42","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/amh",
"AMH^D","American Homes 4 Rent","26.32","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/amh^d",
"AMH^E","American Homes 4 Rent","26.08","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/amh^e",
"AMH^F","American Homes 4 Rent","24.78","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/amh^f",
"AMH^G","American Homes 4 Rent","24.8246","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/amh^g",
"AMH^H","American Homes 4 Rent","25.2","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/amh^h",
"AIG","American International Group, Inc.","43.55","37866129845.7","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/aig",
"AIG.WS","American International Group, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aig.ws",
"AIG^A","American International Group, Inc.","25.48","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aig^a",
"AMID","American Midstream Partners, LP","5.18","279983216.52","n/a","2011","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/amid",
"ARL","American Realty Investors, Inc.","11.66","186525906.16","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/arl",
"ARA","American Renal Associates Holdings, Inc","5.96","193801707.4","n/a","2016","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/ara",
"AWR","American States Water Company","70.31","2585594353.55","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/awr",
"AMT","American Tower Corporation (REIT)","195.12","86074242858.72","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/amt",
"AVD","American Vanguard Corporation","17.26","512456597.42","n/a","n/a","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/avd",
"AWK","American Water Works","103.71","18720802862.28","n/a","2008","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/awk",
"COLD","Americold Realty Trust","30.72","4570954444.8","n/a","2018","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cold",
"APU","AmeriGas Partners, L.P.","34.4","3198763739.2","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/apu",
"AMP","AMERIPRISE FINANCIAL SERVICES, INC.","136.12","18431018382.52","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/amp",
"ABC","AmerisourceBergen Corporation (Holding Co)","74.49","15724086129.57","n/a","n/a","Health Care","Other Pharmaceuticals","https://www.nasdaq.com/symbol/abc",
"ANFI","Amira Nature Foods Ltd","1.44","54595402.56","n/a","2012","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/anfi",
"AMN","AMN Healthcare Services Inc","48.23","2260305268.13","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/amn",
"AMRX","Amneal Pharmaceuticals, Inc.","13.95","1611613298.25","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/amrx",
"AP","Ampco-Pittsburgh Corporation","3.4","42482476.4","n/a","n/a","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/ap",
"APH","Amphenol Corporation","99.76","29737180069.6","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/aph",
"AXR","AMREP Corporation","5.91","48035912.64","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/axr",
"AME","AMTEK, Inc.","83.72","19047868577.92","n/a","n/a","Consumer Durables","Metal Fabrications","https://www.nasdaq.com/symbol/ame",
"APC","Anadarko Petroleum Corporation","45.24","22600817878.08","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/apc",
"PLAN","Anaplan, Inc.","38.45","4860080000","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/plan",
"ANDX","Andeavor Logistics LP","35.46","8707250232.72","n/a","2011","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/andx",
"AU","AngloGold Ashanti Limited","12.84","5300145738.24","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/au",
"BUD","Anheuser-Busch Inbev SA","84.18","164698170000","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/bud",
"AXE","Anixter International Inc.","58.11","1945630071.06","n/a","n/a","Consumer Non-Durables","Telecommunications Equipment","https://www.nasdaq.com/symbol/axe",
"NLY","Annaly Capital Management Inc","10","14000603370","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nly",
"NLY^C","Annaly Capital Management Inc","25.65","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nly^c",
"NLY^D","Annaly Capital Management Inc","25.4768","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nly^d",
"NLY^F","Annaly Capital Management Inc","25.76","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nly^f",
"NLY^G","Annaly Capital Management Inc","24.21","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nly^g",
"NLY^H","Annaly Capital Management Inc","25.6071","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nly^h",
"AM","Antero Midstream Corporation","14.08","5096760697.6","n/a","2017","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/am",
"AR","Antero Resources Corporation","8.65","2669831323","n/a","2013","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/ar",
"ANTM","Anthem, Inc.","288.2","74140404230.2","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/antm",
"ANH","Anworth Mortgage Asset  Corporation","4.08","402135816","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/anh",
"ANH^A","Anworth Mortgage Asset  Corporation","26.3458","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/anh^a",
"ANH^B","Anworth Mortgage Asset  Corporation","23.2754","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/anh^b",
"ANH^C","Anworth Mortgage Asset  Corporation","24.9244","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/anh^c",
"AON","Aon plc","173.14","41553503387.88","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/aon",
"APA","Apache Corporation","34.28","12868903522.36","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/apa",
"AIV","Apartment Investment and Management Company","50.83","7561765156.53","n/a","1994","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/aiv",
"AIV^A","Apartment Investment and Management Company","25.36","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aiv^a",
"APY","Apergy Corporation","41.03","3174191334.82","n/a","2018","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/apy",
"APHA","Aphria Inc.","9.8","2455697739.6","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/apha",
"ARI","Apollo Commercial Real Estate Finance","18.28","2454773635.44","n/a","2009","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ari",
"ARI^C","Apollo Commercial Real Estate Finance","25.59","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ari^c",
"APO","Apollo Global Management, LLC","28.32","11462339658.24","n/a","2011","Finance","Investment Managers","https://www.nasdaq.com/symbol/apo",
"APO^A","Apollo Global Management, LLC","24.94","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/apo^a",
"APO^B","Apollo Global Management, LLC","24.75","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/apo^b",
"AIY","Apollo Investment Corporation","25.95","0","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/aiy",
"AFT","Apollo Senior Floating Rate Fund Inc.","15.04","234218837.44","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/aft",
"AIF","Apollo Tactical Income Fund Inc.","14.85","214790786.1","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/aif",
"APLE","Apple Hospitality REIT, Inc.","16.51","3693692634.19","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/aple",
"AIT","Applied Industrial Technologies, Inc.","58.66","2273645409.84","n/a","n/a","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/ait",
"ATR","AptarGroup, Inc.","107.22","6756306933.9","n/a","n/a","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/atr",
"APTV","Aptiv PLC","82.93","21387590773.46","n/a","2011","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/aptv",
"WTR","Aqua America, Inc.","36.31","6476351561.43","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/wtr",
"AQ","Aquantia Corp.","9.18","322900487.1","n/a","2017","Technology","Semiconductors","https://www.nasdaq.com/symbol/aq",
"WAAS","AquaVenture Holdings Limited","19.66","529467883.5","n/a","2016","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/waas",
"ARMK","Aramark","29.86","7354428390.14","n/a","2013","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/armk",
"ABR","Arbor Realty Trust","13.24","1130143653.68","n/a","2004","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/abr",
"ABR^A","Arbor Realty Trust","25.8001","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/abr^a",
"ABR^B","Arbor Realty Trust","25.55","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/abr^b",
"ABR^C","Arbor Realty Trust","26","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/abr^c",
"ARC","ARC Document Solutions, Inc.","2.26","104506614.9","n/a","2004","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/arc",
"MT","ArcelorMittal","21.64","21841330401.72","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/mt",
"ARCH","Arch Coal, Inc.","91.27","1589840891.92","n/a","2016","Energy","Coal Mining","https://www.nasdaq.com/symbol/arch",
"ADM","Archer-Daniels-Midland Company","42.26","23669428037.58","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/adm",
"AROC","Archrock, Inc.","9.97","1300231946.86","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/aroc",
"ARNC","Arconic Inc.","19.75","8948392666.75","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/arnc",
"ARCO","Arcos Dorados Holdings Inc.","6.99","919835580.27","n/a","2011","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/arco",
"ACA","Arcosa, Inc.","30.9","1502524458.3","n/a","2018","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/aca",
"RCUS","Arcus Biosciences, Inc.","11.8","525508209.2","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rcus",
"ARD","Ardagh Group S.A.","13.62","3219078528.36","n/a","2017","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/ard",
"ASC","Ardmore Shipping Corporation","6.23","206199487.13","n/a","2013","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/asc",
"AFC","Ares Capital Corporation","25.75","206000000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/afc",
"ACRE","Ares Commercial Real Estate Corporation","15.18","436510994.7","n/a","2012","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/acre",
"ARDC","Ares Dynamic Credit Allocation Fund, Inc.","15.02","344895863.82","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/ardc",
"ARES","Ares Management Corporation","23.7","2441161169.7","n/a","2014","Finance","Investment Managers","https://www.nasdaq.com/symbol/ares",
"ARES^A","Ares Management Corporation","26.315","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ares^a",
"AGX","Argan, Inc.","50.41","784919944.79","n/a","n/a","Basic Industries","Engineering & Construction","https://www.nasdaq.com/symbol/agx",
"ARGD","Argo Group International Holdings, Ltd.","25.52","0","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/argd",
"ARGO","Argo Group International Holdings, Ltd.","70.43","2392498859.69","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/argo",
"ANET","Arista Networks, Inc.","318.43","24114981889.39","n/a","2014","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/anet",
"AI","Arlington Asset Investment Corp","7.86","287460769.62","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ai",
"AI^B","Arlington Asset Investment Corp","22.0761","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ai^b",
"AI^C","Arlington Asset Investment Corp","23.25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ai^c",
"AIC","Arlington Asset Investment Corp","23.7475","0","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/aic",
"AIW","Arlington Asset Investment Corp","24.28","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/aiw",
"ARLO","Arlo Technologies, Inc.","4.13","306673930.57","n/a","2018","Consumer Non-Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/arlo",
"AHH","Armada Hoffler Properties, Inc.","15.69","789759946.98","n/a","2013","Finance","Real Estate","https://www.nasdaq.com/symbol/ahh",
"ARR","ARMOUR Residential REIT, Inc.","19.58","1170640679.34","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/arr",
"ARR^A","ARMOUR Residential REIT, Inc.","25.5","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/arr^a",
"ARR^B","ARMOUR Residential REIT, Inc.","25.0262","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/arr^b",
"AFI","Armstrong Flooring, Inc.","14.34","370486089","n/a","2016","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/afi",
"AWI","Armstrong World Industries Inc","81.13","3934998981.83","n/a","n/a","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/awi",
"ARW","Arrow Electronics, Inc.","78.52","6688764674.8","n/a","n/a","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/arw",
"AJG","Arthur J. Gallagher & Co.","78.57","14553107271.81","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/ajg",
"APAM","Artisan Partners Asset Management Inc.","25.76","1981848923.04","n/a","2013","Finance","Investment Managers","https://www.nasdaq.com/symbol/apam",
"ASA","ASA Gold and Precious Metals Limited","10.07","194250300","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/asa",
"ABG","Asbury Automotive Group Inc","70.22","1369229891.68","n/a","2002","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/abg",
"ASX","ASE Technology Holding Co., Ltd.","4.53","9462253513.05","n/a","2018","Technology","Semiconductors","https://www.nasdaq.com/symbol/asx",
"ASGN","ASGN Incorporated","64.09","3374674844.32","n/a","1992","Technology","Professional Services","https://www.nasdaq.com/symbol/asgn",
"AHT","Ashford Hospitality Trust Inc","5.04","509071056.48","n/a","2003","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/aht",
"AHT^D","Ashford Hospitality Trust Inc","25.3999","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aht^d",
"AHT^F","Ashford Hospitality Trust Inc","23.3","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aht^f",
"AHT^G","Ashford Hospitality Trust Inc","22.93","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aht^g",
"AHT^H","Ashford Hospitality Trust Inc","23.27","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aht^h",
"AHT^I","Ashford Hospitality Trust Inc","23.25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/aht^i",
"ASH","Ashland Global Holdings Inc.","78.2","4896766230.8","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/ash",
"ASPN","Aspen Aerogels, Inc.","2.51","60859485.57","n/a","2014","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/aspn",
"AHL^C","Aspen Insurance Holdings Limited","26.06","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ahl^c",
"AHL^D","Aspen Insurance Holdings Limited","24.52","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ahl^d",
"ASB","Associated Banc-Corp","22.08","3637656882.24","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/asb",
"ASB^C","Associated Banc-Corp","25.87","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/asb^c",
"ASB^D","Associated Banc-Corp","24.6623","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/asb^d",
"ASB^E","Associated Banc-Corp","25.435","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/asb^e",
"AC","Associated Capital Group, Inc.","39.91","901373575.96","n/a","2015","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/ac",
"AIZ","Assurant, Inc.","95.45","5887645499.85","n/a","2004","Finance","Accident &Health Insurance","https://www.nasdaq.com/symbol/aiz",
"AIZP","Assurant, Inc.","103.89","298683750","n/a","n/a","Finance","Accident &Health Insurance","https://www.nasdaq.com/symbol/aizp",
"AGO","Assured Guaranty Ltd.","44.72","4592740288.24","n/a","2004","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/ago",
"AGO^B","Assured Guaranty Ltd.","26.805","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ago^b",
"AGO^E","Assured Guaranty Ltd.","25.86","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ago^e",
"AGO^F","Assured Guaranty Ltd.","25.55","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ago^f",
"AZN","Astrazeneca PLC","41.59","105412987392.44","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/azn",
"HOME","At Home Group Inc.","18.66","1187672202.48","n/a","2016","Consumer Services","Home Furnishings","https://www.nasdaq.com/symbol/home",
"T","AT&T Inc.","31.63","230590193368.41","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/t",
"TBB","AT&T Inc.","25.32","0","n/a","2017","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tbb",
"TBC","AT&T Inc.","25.56","0","n/a","2018","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tbc",
"ATTO","Atento S.A.","3.87","291822601.59","n/a","2014","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/atto",
"ATH","Athene Holding Ltd.","41.84","8205561471.84","n/a","2016","Finance","Life Insurance","https://www.nasdaq.com/symbol/ath",
"ATKR","Atkore International Group Inc.","22.06","1014329190.26","n/a","2016","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/atkr",
"AT","Atlantic Power Corporation","2.53","277507163.78","n/a","n/a","Energy","Electric Utilities: Central","https://www.nasdaq.com/symbol/at",
"ATO","Atmos Energy Corporation","100.17","11708735669.82","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/ato",
"AUO","AU Optronics Corp","3.63","3493600974.93","n/a","2002","Technology","Semiconductors","https://www.nasdaq.com/symbol/auo",
"ACB","Aurora Cannabis Inc.","9.07","9189128908.23","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/acb",
"ATHM","Autohome Inc.","102.62","12020994642.72","n/a","2013","Technology","EDP Services","https://www.nasdaq.com/symbol/athm",
"ALV","Autoliv, Inc.","76.91","6708176031.56","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/alv",
"AN","AutoNation, Inc.","35.87","3230410447.32","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/an",
"AZO","AutoZone, Inc.","1041.98","25932348104.64","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/azo",
"AVLR","Avalara, Inc.","56.85","3949402188.75","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/avlr",
"AVB","AvalonBay Communities, Inc.","202.21","28043862478.83","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/avb",
"AGR","Avangrid, Inc.","50.26","15530604970.72","n/a","2015","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/agr",
"AVNS","Avanos Medical, Inc.","43.19","2049505737.93","n/a","2014","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/avns",
"AVYA","Avaya Holdings Corp.","17.11","1894000398.53","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/avya",
"AVY","Avery Dennison Corporation","113.09","9496491529.03","n/a","n/a","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/avy",
"AVH","Avianca Holdings S.A.","4.25","531944832.5","n/a","2013","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/avh",
"AVA","Avista Corporation","40.61","2669905871.35","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/ava",
"AVP","Avon Products, Inc.","2.94","1300733968.8","n/a","n/a","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/avp",
"AVX","AVX Corporation","18.11","3056963943.36","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/avx",
"EQH","AXA Equitable Holdings, Inc.","20.65","10140207362.6","n/a","2018","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/eqh",
"AXTA","Axalta Coating Systems Ltd.","25.81","6061145344.52","n/a","2014","Basic Industries","Paints/Coatings","https://www.nasdaq.com/symbol/axta",
"AXS","Axis Capital Holdings Limited","54.99","4615501075.38","n/a","2003","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/axs",
"AXS^D","Axis Capital Holdings Limited","24.78","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/axs^d",
"AXS^E","Axis Capital Holdings Limited","24.45","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/axs^e",
"AX","Axos Financial, Inc.","29.56","1809559651.32","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/ax",
"AXO","Axos Financial, Inc.","25.7","0","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/axo",
"AZUL","Azul S.A.","29.98","3384586193.94","n/a","2017","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/azul",
"AZRE","Azure Power Global Limited","11.69","478591078.28","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/azre",
"AZZ","AZZ Inc.","41.34","1078444475.94","n/a","n/a","Consumer Durables","Building Products","https://www.nasdaq.com/symbol/azz",
"BGS","B&G Foods, Inc.","23.47","1532534836.29","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/bgs",
"BW","Babcock","0.47","79302877.69","n/a","2015","Capital Goods","Building Products","https://www.nasdaq.com/symbol/bw",
"BGH","Babson Global Short Duration High Yield Fund","18.41","369265000.09","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/bgh",
"BMI","Badger Meter, Inc.","55.21","1607724364.86","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/bmi",
"BCSF","Bain Capital Specialty Finance, Inc.","19.89","1023979704.93","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/bcsf",
"BHGE","Baker Hughes, a GE company","26.99","13897204521.17","n/a","2017","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/bhge",
"BBN","BalckRock Taxable Municipal Bond Trust","22.6","1290778253.2","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/bbn",
"BLL","Ball Corporation","57.98","19375149407.38","n/a","n/a","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/bll",
"BANC","Banc of California, Inc.","14.12","715281951.44","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/banc",
"BANC^D","Banc of California, Inc.","25.9665","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/banc^d",
"BANC^E","Banc of California, Inc.","25.66","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/banc^e",
"BBVA","Banco Bilbao Viscaya Argentaria S.A.","6.01","40073998345.8","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bbva",
"BBD","Banco Bradesco Sa","9.17","73945348059.8","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bbd",
"BBDO","Banco Bradesco Sa","8.35","56110815093.25","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bbdo",
"BCH","Banco De Chile","29.11","44109152520.3","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bch",
"BLX","Banco Latinoamericano de Comercio Exterior, S.A.","19.93","616856120.55","n/a","1992","Finance","Commercial Banks","https://www.nasdaq.com/symbol/blx",
"BSBR","Banco Santander Brasil SA","11.45","85553220650","n/a","2009","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bsbr",
"BSAC","Banco Santander Chile","30.16","14208837930.56","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bsac",
"BSMX","Banco Santander Mexico, S.A., Institucion de Ban","6.86","9311756255.06","n/a","2012","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bsmx",
"SAN","Banco Santander, S.A.","4.78","77610823442.76","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/san",
"SAN^B","Banco Santander, S.A.","22.9","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/san^b",
"CIB","BanColombia S.A.","51.75","12443636812.5","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/cib",
"BXS","BancorpSouth Bank","28.94","2876943284.92","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bxs",
"BAC","Bank of America Corporation","28.87","278276389670.02","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bac",
"BAC^A","Bank of America Corporation","26.1313","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bac^a",
"BAC^B","Bank of America Corporation","26.59","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bac^b",
"BAC^C","Bank of America Corporation","26.16","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bac^c",
"BAC^E","Bank of America Corporation","22.1501","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bac^e",
"BAC^K","Bank of America Corporation","26.07","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bac^k",
"BAC^L","Bank of America Corporation","1310","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bac^l",
"BAC^W","Bank of America Corporation","25.71","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bac^w",
"BAC^Y","Bank of America Corporation","25.82","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bac^y",
"BML^G","Bank of America Corporation","19.3205","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bml^g",
"BML^H","Bank of America Corporation","18.98","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bml^h",
"BML^J","Bank of America Corporation","21.075","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bml^j",
"BML^L","Bank of America Corporation","20.94","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bml^l",
"BOH","Bank of Hawaii Corporation","79.82","3301746557.46","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/boh",
"BMO","Bank Of Montreal","76.52","48854112888.8","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bmo",
"NTB","Bank of N.T. Butterfield & Son Limited (The)","35.79","1979187000","n/a","2016","Finance","Commercial Banks","https://www.nasdaq.com/symbol/ntb",
"BK","Bank Of New York Mellon Corporation (The)","51.35","49031122219.3","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bk",
"BK^C","Bank Of New York Mellon Corporation (The)","25.18","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bk^c",
"BNS","Bank of Nova Scotia (The)","53.04","65026217190.48","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bns",
"BKU","BankUnited, Inc.","34.37","3388595388.57","n/a","2011","Finance","Savings Institutions","https://www.nasdaq.com/symbol/bku",
"BCS","Barclays PLC","8.39","35942862349.61","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bcs",
"BBDC","Barings BDC, Inc.","9.92","507920506.88","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbdc",
"MCI","Barings Corporate Investors","15.35","308272039.15","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mci",
"MPV","Barings Participation Investors","15.39","162008975.61","n/a","1988","Consumer Services","Miscellaneous","https://www.nasdaq.com/symbol/mpv",
"BNED","Barnes & Noble Education, Inc","4.38","199556702.58","n/a","2015","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/bned",
"BKS","Barnes & Noble, Inc.","5.61","410626362.3","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/bks",
"B","Barnes Group, Inc.","52.6","2702355455.4","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/b",
"GOLD","Barrick Gold Corporation","13.46","23581675014.54","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/gold",
"BAS","Basic Energy Services, Inc.","3.68","99016619.2","n/a","2005","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/bas",
"BHC","Bausch Health Companies Inc.","24.92","8747151033.32","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bhc",
"BAX","Baxter International Inc.","81.54","41676503989.68","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/bax",
"BTE","Baytex Energy Corp","1.69","939423962.23","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/bte",
"BBT","BB&T Corporation","48.49","37038071798.26","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/bbt",
"BBT^D","BB&T Corporation","25.47","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbt^d",
"BBT^E","BB&T Corporation","25.41","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbt^e",
"BBT^F","BB&T Corporation","24.92","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbt^f",
"BBT^G","BB&T Corporation","24.89","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbt^g",
"BBT^H","BB&T Corporation","25.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbt^h",
"BFR","BBVA Banco Frances S.A.","9.26","1891076079.54","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bfr",
"BBX","BBX Capital Corporation","6.09","595384952.4","n/a","2017","Finance","Real Estate","https://www.nasdaq.com/symbol/bbx",
"BCE","BCE, Inc.","44.72","40177051093.92","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/bce",
"BZH","Beazer Homes USA, Inc.","11.6","372789049.2","n/a","1994","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/bzh",
"BDX","Becton, Dickinson and Company","250.74","67464951650.46","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/bdx",
"BDXA","Becton, Dickinson and Company","62.38","0","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/bdxa",
"BDC","Belden Inc","55.1","2170907601.2","n/a","n/a","Basic Industries","Telecommunications Equipment","https://www.nasdaq.com/symbol/bdc",
"BDC^B","Belden Inc","74.27","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bdc^b",
"BEL","Belmond Ltd.","24.92","2568794767.84","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/bel",
"BMS","Bemis Company, Inc.","55.25","5039462392.25","n/a","n/a","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/bms",
"BHE","Benchmark Electronics, Inc.","26.9","1093618558.5","n/a","n/a","Technology","Electrical Products","https://www.nasdaq.com/symbol/bhe",
"BRK.A","Berkshire Hathaway Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/brk.a",
"BRK.B","Berkshire Hathaway Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/brk.b",
"BHLB","Berkshire Hills Bancorp, Inc.","27.77","1264443828.79","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/bhlb",
"BERY","Berry Global Group, Inc.","53.98","7033594000","n/a","2012","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/bery",
"BBY","Best Buy Co., Inc.","71.45","19134623522.6","n/a","n/a","Consumer Services","Consumer Electronics/Video Chains","https://www.nasdaq.com/symbol/bby",
"BEST","BEST Inc.","5.03","1947616000","n/a","2017","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/best",
"BHP","BHP Group Limited","56.11","141874135000","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/bhp",
"BBL","BHP Group Plc","49.85","126045725000","n/a","n/a","Energy","Coal Mining","https://www.nasdaq.com/symbol/bbl",
"BIG","Big Lots, Inc.","38.08","1525049964.48","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/big",
"BH","Biglari Holdings Inc.","141","291549366","n/a","2018","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/bh",
"BH.A","Biglari Holdings Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bh.a",
"BHVN","Biohaven Pharmaceutical Holding Company Ltd.","50.19","2221542805.02","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bhvn",
"BIO","Bio-Rad Laboratories, Inc.","309.14","9262515744.56","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/bio",
"BIO.B","Bio-Rad Laboratories, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bio.b",
"BITA","Bitauto Holdings Limited","15.53","496245620","n/a","2010","Technology","EDP Services","https://www.nasdaq.com/symbol/bita",
"BJ","BJ&#39;s Wholesale Club Holdings, Inc.","27.53","3794483080.26","n/a","2018","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/bj",
"BKH","Black Hills Corporation","72.78","4379431842.36","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/bkh",
"BKI","Black Knight, Inc.","54.06","8109644341.14","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/bki",
"BSM","Black Stone Minerals, L.P.","17.9","3672725383.1","n/a","2015","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/bsm",
"BB","BlackBerry Limited","9.6","5254636531.2","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/bb",
"BGIO","BlackRock 2022 Global Income Opportunity Trust","9.17","202921820.43","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/bgio",
"BFZ","BlackRock California Municipal Income Trust","12.92","412185274.2","n/a","2001","n/a","n/a","https://www.nasdaq.com/symbol/bfz",
"CII","Blackrock Capital and Income Strategies Fund Inc","15.94","703295116","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/cii",
"BHK","Blackrock Core Bond Trust","13.45","725427444.7","n/a","2001","n/a","n/a","https://www.nasdaq.com/symbol/bhk",
"HYT","Blackrock Corporate High Yield Fund, Inc.","10.33","1286597213.05","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/hyt",
"BTZ","BlackRock Credit Allocation Income Trust","12.47","1327534664.31","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/btz",
"DSU","Blackrock Debt Strategies Fund, Inc.","10.74","567702362.82","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/dsu",
"BGR","BlackRock Energy and Resources Trust","12.17","362974217.42","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/bgr",
"BDJ","Blackrock Enhanced Equity Dividend Trust","8.64","1620366379.2","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/bdj",
"EGF","Blackrock Enhanced Government Fund, Inc","13.1076","68960341.9296","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/egf",
"FRA","Blackrock Floating Rate Income Strategies Fund Inc","12.62","469873998.56","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/fra",
"BFO","Blackrock Florida Municipal 2020 Term Trust","14.254","79282572.512","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/bfo",
"BGT","Blackrock Global","12.31","291341040.82","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/bgt",
"BOE","Blackrock Global","10.67","735288852.65","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/boe",
"BME","Blackrock Health Sciences Trust","39.9","374279915.1","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/bme",
"BAF","BlackRock Income Investment Quality Trust","13.97","122229369.46","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/baf",
"BKT","BlackRock Income Trust Inc. (The)","5.93","378316874.16","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bkt",
"BGY","BLACKROCK INTERNATIONAL, LTD.","5.58","608493514.86","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/bgy",
"BKN","BlackRock Investment Quality Municipal Trust Inc. (The)","14.22","244382914.98","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/bkn",
"BTA","BlackRock Long-Term Municipal Advantage Trust","12.18","163482968.46","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/bta",
"BZM","BlackRock Maryland Municipal Bond Trust","14.44","30052282.52","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/bzm",
"MHE","BlackRock Massachusetts Tax-Exempt Trust","12.51","29661497.73","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/mhe",
"BIT","BlackRock Multi-Sector Income Trust","16.93","642431096.02","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/bit",
"MUI","Blackrock Muni Intermediate Duration Fund Inc","13.73","525807732.18","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/mui",
"MNE","Blackrock Muni New York Intermediate Duration Fund Inc","13.8","58095847.2","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/mne",
"MUA","Blackrock MuniAssets Fund, Inc.","14.82","533634277.02","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/mua",
"BKK","Blackrock Municipal 2020 Term Trust","15.02","303954152.56","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/bkk",
"BBK","Blackrock Municipal Bond Trust","14.49","152477646.93","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/bbk",
"BBF","BlackRock Municipal Income Investment Trust","13.54","138364948.58","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bbf",
"BYM","Blackrock Municipal Income Quality Trust","13.38","353315932.74","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/bym",
"BFK","BlackRock Municipal Income Trust","13.63","610847900.01","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bfk",
"BLE","BlackRock Municipal Income Trust II","14.18","333653428.98","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/ble",
"BTT","BlackRock Municipal Target Term Trust Inc. (The)","22.21","1565928731.91","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/btt",
"MEN","Blackrock MuniEnhanced Fund, Inc.","10.67","316301917.47","n/a","1989","n/a","n/a","https://www.nasdaq.com/symbol/men",
"MUC","Blackrock MuniHoldings California Quality Fund,  Inc.","13.34","546973123.22","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/muc",
"MUH","Blackrock MuniHoldings Fund II, Inc.","14.99","169653057.51","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/muh",
"MHD","Blackrock MuniHoldings Fund, Inc.","15.95","225966186.05","n/a","1997","n/a","n/a","https://www.nasdaq.com/symbol/mhd",
"MFL","Blackrock MuniHoldings Investment Quality Fund","12.94","490376931.52","n/a","1997","n/a","n/a","https://www.nasdaq.com/symbol/mfl",
"MUJ","Blackrock MuniHoldings New Jersey Insured Fund, Inc.","13.79","415821798.35","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/muj",
"MHN","Blackrock MuniHoldings New York Quality Fund, Inc.","12.97","403782338.31","n/a","1997","n/a","n/a","https://www.nasdaq.com/symbol/mhn",
"MUE","Blackrock MuniHoldings Quality Fund II, Inc.","12.25","275811494","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mue",
"MUS","Blackrock MuniHoldings Quality Fund, Inc.","12.08","157225730","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/mus",
"MVT","Blackrock MuniVest Fund II, Inc.","14.6","311058591.8","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/mvt",
"MYC","Blackrock MuniYield California Fund, Inc.","13.35","285950244.9","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/myc",
"MCA","Blackrock MuniYield California Insured Fund, Inc.","13.52","465165293.84","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/mca",
"MYD","Blackrock MuniYield Fund, Inc.","14.11","659858834.52","n/a","1991","n/a","n/a","https://www.nasdaq.com/symbol/myd",
"MYF","Blackrock MuniYield Investment Fund","14.32","195932512.16","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/myf",
"MFT","Blackrock MuniYield Investment QualityFund","13.14","111363983.46","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/mft",
"MIY","Blackrock MuniYield Michigan Quality Fund, Inc.","13.43","397236152.67","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/miy",
"MYJ","Blackrock MuniYield New Jersey Fund, Inc.","14.67","354399400.35","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/myj",
"MYN","Blackrock MuniYield New York Quality Fund, Inc.","12.35","488894312.4","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/myn",
"MPA","Blackrock MuniYield Pennsylvania Quality Fund","13.62","181859211.3","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/mpa",
"MQT","Blackrock MuniYield Quality Fund II, Inc.","12.28","277012350.52","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/mqt",
"MYI","Blackrock MuniYield Quality Fund III, Inc.","12.93","880336955.34","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/myi",
"MQY","Blackrock MuniYield Quality Fund, Inc.","14.12","433487233.48","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/mqy",
"BNY","BlackRock New York Investment Quality Municipal Trust Inc. (Th","13.24","171637719.76","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bny",
"BQH","Blackrock New York Municipal Bond Trust","14.28","39985499.4","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/bqh",
"BSE","Blackrock New York Municipal Income Quality Trust","12.8","83451648","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/bse",
"BFY","BlackRock New York Municipal Income Trust II","13.56","67866742.32","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/bfy",
"BCX","BlackRock Resources","8.2","803913584.4","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/bcx",
"BST","BlackRock Science and Technology Trust","33.1","740487547.5","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/bst",
"BSD","BlackRock Strategic Municipal Trust Inc. (The)","13.44","98198110.08","n/a","1999","n/a","n/a","https://www.nasdaq.com/symbol/bsd",
"BUI","BlackRock Utility, Infrastructure & Power Opportun","21.37","361597752.44","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/bui",
"BHV","BlackRock Virginia Municipal Bond Trust","16.1594","25915863.9816","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/bhv",
"BLK","BlackRock, Inc.","436.45","69394930241","n/a","1999","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/blk",
"BGB","Blackstone / GSO Strategic Credit Fund","14.59","651653333.38","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/bgb",
"BGX","Blackstone GSO Long Short Credit Income Fund","15.5","196883480","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/bgx",
"BSL","Blackstone GSO Senior Floating Rate Term Fund","16.69","254544163.62","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/bsl",
"BE","Bloom Energy Corporation","12.98","760805047.2","n/a","2018","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/be",
"APRN","Blue Apron Holdings, Inc.","0.9689","188468883.5734","n/a","2017","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/aprn",
"BCRH","Blue Capital Reinsurance Holdings Ltd.","6.75","59178363.75","n/a","2013","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/bcrh",
"BXG","Bluegreen Vacations Corporation","15.35","1142744918.05","n/a","2017","Finance","Real Estate","https://www.nasdaq.com/symbol/bxg",
"BXC","BlueLinx Holdings Inc.","25.2","234108000","n/a","2004","Capital Goods","Wholesale Distributors","https://www.nasdaq.com/symbol/bxc",
"BA","Boeing Company (The)","390.75","220571326651.5","n/a","n/a","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/ba",
"BCC","Boise Cascade, L.L.C.","26.76","1042953204.6","n/a","2013","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/bcc",
"BCEI","Bonanza Creek Energy, Inc.","22.26","457634235.66","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/bcei",
"BOOT","Boot Barn Holdings, Inc.","29.5","835705588.5","n/a","2014","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/boot",
"BAH","Booz Allen Hamilton Holding Corporation","57.95","8117734804.75","n/a","2010","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/bah",
"BWA","BorgWarner Inc.","40.71","8451782012.22","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/bwa",
"SAM","Boston Beer Company, Inc. (The)","285.61","3320204254.38","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/sam",
"BXP","Boston Properties, Inc.","137.61","21262013213.76","n/a","1997","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/bxp",
"BXP^B","Boston Properties, Inc.","25.15","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bxp^b",
"BSX","Boston Scientific Corporation","38.52","53562053913.84","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/bsx",
"BOX","Box, Inc.","19.59","2827468699.14","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/box",
"BYD","Boyd Gaming Corporation","28.58","3171750182.54","n/a","1993","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/byd",
"BPMP","BP Midstream Partners LP","14.43","1511680133.34","n/a","2017","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/bpmp",
"BP","BP p.l.c.","44.23","149357216818.78","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/bp",
"BPT","BP Prudhoe Bay Royalty Trust","27.59","590426000","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/bpt",
"BRC","Brady Corporation","46.51","2449394268.2","n/a","n/a","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/brc",
"BHR","Braemar Hotels & Resorts Inc.","12.84","421948670.64","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/bhr",
"BHR^B","Braemar Hotels & Resorts Inc.","19.66","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bhr^b",
"BHR^D","Braemar Hotels & Resorts Inc.","25.18","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bhr^d",
"BDN","Brandywine Realty Trust","16.13","2835865254.61","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/bdn",
"BWG","BrandywineGLOBAL Global Income Opportunities Fund ","11.12","233406520.4","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/bwg",
"LND","Brasilagro Cia Brasileira De Propriedades Agricolas","4.0475","217764274.98","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/lnd",
"BAK","Braskem S.A.","25.86","10288836482.4","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/bak",
"BRFS","BRF S.A.","5.96","4836040724.84","n/a","n/a","Consumer Non-Durables","Meat/Poultry/Fish","https://www.nasdaq.com/symbol/brfs",
"BPI","Bridgepoint Education, Inc.","6","163048002","n/a","2009","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/bpi",
"BGG","Briggs & Stratton Corporation","12","505260852","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/bgg",
"BFAM","Bright Horizons Family Solutions Inc.","126.48","7329344493.12","n/a","2013","Miscellaneous","Other Consumer Services","https://www.nasdaq.com/symbol/bfam",
"BEDU","Bright Scholar Education Holdings Limited","10.56","1308634018.56","n/a","2017","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/bedu",
"BSA","BrightSphere Investment Group plc","23.35","0","n/a","2016","Finance","Investment Managers","https://www.nasdaq.com/symbol/bsa",
"BSIG","BrightSphere Investment Group plc","13.72","1262568223.56","n/a","2014","Finance","Investment Managers","https://www.nasdaq.com/symbol/bsig",
"BV","BrightView Holdings, Inc.","14.52","1524044174.4","n/a","2018","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/bv",
"EAT","Brinker International, Inc.","44.28","1660500000","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/eat",
"BCO","Brink&#39;s Company (The)","78.52","3902838405.96","n/a","n/a","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/bco",
"BMY","Bristol-Myers Squibb Company","46.7","76245963455.9","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/bmy",
"BRS","Bristow Group Inc","1.23","44031767.55","n/a","n/a","Transportation","Transportation Services","https://www.nasdaq.com/symbol/brs",
"BTI","British American Tobacco p.l.c.","41.43","95030930458.5","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/bti",
"BRX","Brixmor Property Group Inc.","18.44","5506866888.52","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/brx",
"BR","Broadridge Financial Solutions, Inc.","105.18","12167304230.04","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/br",
"BKD","Brookdale Senior Living Inc.","6.62","1235289457.92","n/a","2005","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/bkd",
"BAM","Brookfield Asset Management Inc","47.29","47001789581.72","n/a","n/a","Consumer Services","Building operators","https://www.nasdaq.com/symbol/bam",
"BBU","Brookfield Business Partners L.P.","38.24","2530944915.52","n/a","2016","Basic Industries","Engineering & Construction","https://www.nasdaq.com/symbol/bbu",
"DTLA^","Brookfield DTLA Inc.","21.829","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dtla^",
"INF","Brookfield Global Listed Infrastructure Income Fund","12.5","168540287.5","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/inf",
"BIP","Brookfield Infrastructure Partners LP","41.55","11616292013.25","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/bip",
"RA","Brookfield Real Assets Income Fund Inc.","21.85","797261423.45","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/ra",
"BEP","Brookfield Renewable Partners L.P.","31.95","5712698467.8","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/bep",
"BRO","Brown & Brown, Inc.","29.66","8359054042.34","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/bro",
"BF.A","Brown Forman Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bf.a",
"BF.B","Brown Forman Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bf.b",
"BRT","BRT Apartments Corp.","13.93","221492502.35","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/brt",
"BC","Brunswick Corporation","50.54","4398919927.36","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/bc",
"BC^A","Brunswick Corporation","25.97","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bc^a",
"BC^B","Brunswick Corporation","25.75","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bc^b",
"BC^C","Brunswick Corporation","25.53","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bc^c",
"BT","BT Group plc","14.92","29609673066.96","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/bt",
"BPL","Buckeye Partners L.P.","34.83","5356751564.97","n/a","1986","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/bpl",
"BKE","Buckle, Inc. (The)","18.62","912703894.9","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/bke",
"BVN","Buenaventura Mining Company Inc.","16.72","4246660416.24","n/a","1996","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/bvn",
"BBW","Build-A-Bear Workshop, Inc.","6.04","90335592.96","n/a","2004","Consumer Services","Recreational Products/Toys","https://www.nasdaq.com/symbol/bbw",
"BG","Bunge Limited","52.16","7360724738.24","n/a","2001","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/bg",
"BURL","Burlington Stores, Inc.","152.58","10234596148.44","n/a","2013","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/burl",
"BWXT","BWX Technologies, Inc.","50.2","4775818013.4","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/bwxt",
"BY","Byline Bancorp, Inc.","19.06","693211856.92","n/a","2017","Finance","Major Banks","https://www.nasdaq.com/symbol/by",
"CJ","C&J Energy Services, Inc","15.71","1037840775.3","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/cj",
"GYB","CABCO Series 2004-101 Trust","20.86","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/gyb",
"PFH","CABCO Series 2004-101 Trust","7.45","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/pfh",
"CABO","Cable One, Inc.","999.06","5697960877.32","n/a","2015","Consumer Services","Television Services","https://www.nasdaq.com/symbol/cabo",
"CBT","Cabot Corporation","42.98","2558174241.84","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/cbt",
"COG","Cabot Oil & Gas Corporation","25.9","10965211775","n/a","1990","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cog",
"CACI","CACI International, Inc.","181.7","4517538780.8","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/caci",
"WHD","Cactus, Inc.","35.99","1363051825.29","n/a","2018","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/whd",
"CADE","Cadence Bancorporation","19.14","2463963879.3","n/a","2017","Finance","Major Banks","https://www.nasdaq.com/symbol/cade",
"CAE","CAE Inc","22.64","6007332193.92","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cae",
"CAI","CAI International, Inc.","23.78","444977352.56","n/a","n/a","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/cai",
"CAI^A","CAI International, Inc.","25.14","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cai^a",
"CAI^B","CAI International, Inc.","25.0923","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cai^b",
"CAL","Caleres, Inc.","24.92","1068508421.4","n/a","n/a","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/cal",
"CRC","California Resources Corporation","27.23","1328803877.03","n/a","2014","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/crc",
"CWT","California Water  Service Group Holding","52.41","2519191470","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/cwt",
"CALX","Calix, Inc","7.78","420436311.46","n/a","2010","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/calx",
"ELY","Callaway Golf Company","15.8","1498137640.4","n/a","1992","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/ely",
"CPE","Callon Petroleum Company","7.51","1711409523.41","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cpe",
"CPE^A","Callon Petroleum Company","52.8027","0","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cpe^a",
"CBM","Cambrex Corporation","38.17","1284602380.05","n/a","1987","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/cbm",
"CPT","Camden Property Trust","102.14","10132976015.04","n/a","1993","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cpt",
"CCJ","Cameco Corporation","11.7","4630774964.4","n/a","1996","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/ccj",
"CPB","Campbell Soup Company","37.62","11328059235.24","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/cpb",
"CWH","Camping World Holdings, Inc.","13.57","504711656.15","n/a","2016","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/cwh",
"GOOS","Canada Goose Holdings Inc.","47.94","2834100045.12","n/a","2017","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/goos",
"CM","Canadian Imperial Bank of Commerce","81.01","35964929512.66","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/cm",
"CNI","Canadian National Railway Company","90.34","65504059831.88","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/cni",
"CNQ","Canadian Natural Resources Limited","27.81","33383648941.56","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cnq",
"CP","Canadian Pacific Railway Limited","206.94","28961360608.8","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/cp",
"CANG","Cango Inc.","7.02","1060756720.92","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cang",
"CNNE","Cannae Holdings, Inc.","24.55","1773091638.6","n/a","2017","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/cnne",
"CTST","CannTrust Holdings Inc.","7.72","815531528.28","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/ctst",
"CAJ","Canon, Inc.","29.29","31625872315.67","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/caj",
"CGC","Canopy Growth Corporation","43.15","14831065529.1","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/cgc",
"CMD","Cantel Medical Corp.","66.57","2777386941","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/cmd",
"COF","Capital One Financial Corporation","84.68","39744077949.08","n/a","1994","Finance","Major Banks","https://www.nasdaq.com/symbol/cof",
"COF^C","Capital One Financial Corporation","25.63","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cof^c",
"COF^D","Capital One Financial Corporation","25.94","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cof^d",
"COF^F","Capital One Financial Corporation","26.23","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cof^f",
"COF^G","Capital One Financial Corporation","24.99","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cof^g",
"COF^H","Capital One Financial Corporation","26.15","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cof^h",
"COF^P","Capital One Financial Corporation","25.36","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cof^p",
"CSU","Capital Senior Living Corporation","4.12","129022352.6","n/a","1997","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/csu",
"BXMT","Capital Trust, Inc.","34.56","4277252321.28","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/bxmt",
"CIC","Capitol Investment Corp. IV","10.2","513187500","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/cic",
"CIC.U","Capitol Investment Corp. IV","n/a","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/cic.u",
"CIC.WS","Capitol Investment Corp. IV","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cic.ws",
"CPRI","Capri Holdings Limited","46.63","7027537961.19","n/a","2011","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/cpri",
"CMO","Capstead Mortgage Corporation","8.61","736550982.51","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cmo",
"CMO^E","Capstead Mortgage Corporation","24.9736","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cmo^e",
"CRR","Carbo Ceramics, Inc.","3.46","97199067.36","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/crr",
"CAH","Cardinal Health, Inc.","47.16","14054465355.48","n/a","n/a","Health Care","Other Pharmaceuticals","https://www.nasdaq.com/symbol/cah",
"CRCM","Care.com, Inc.","16.64","535698042.88","n/a","2014","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/crcm",
"CSL","Carlisle Companies Incorporated","124.29","7109255258.28","n/a","n/a","Basic Industries","Specialty Chemicals","https://www.nasdaq.com/symbol/csl",
"KMX","CarMax Inc","69.79","11870381081.86","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/kmx",
"CCL","Carnival Corporation","52.37","27596739503.99","n/a","1987","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/ccl",
"CUK","Carnival Corporation","51.41","36862230418.97","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/cuk",
"CRS","Carpenter Technology Corporation","47.77","2263352106.23","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/crs",
"CSV","Carriage Services, Inc.","19.15","348208241.7","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/csv",
"CARS","Cars.com Inc.","23.16","1560867852.6","n/a","2017","Technology","EDP Services","https://www.nasdaq.com/symbol/cars",
"CRI","Carter&#39;s, Inc.","99.24","4498092993.72","n/a","2003","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/cri",
"CVNA","Carvana Co.","62.82","2588267173.68","n/a","2017","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/cvna",
"CSLT","Castlight Health, inc.","3.76","539650992","n/a","2014","Technology","EDP Services","https://www.nasdaq.com/symbol/cslt",
"CTLT","Catalent, Inc.","40.34","5874823158.34","n/a","2014","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ctlt",
"CTT           ","CatchMark Timber Trust, Inc.","10.02","491816419.5","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ctt",
"CAT","Caterpillar, Inc.","140.19","80685336440.22","n/a","n/a","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/cat",
"CATO","Cato Corporation (The)","15.12","345312812.88","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/cato",
"CBZ","CBIZ, Inc.","20.43","1120549236.75","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/cbz",
"CBL","CBL & Associates Properties, Inc.","1.51","261930590.17","n/a","1993","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cbl",
"CBL^D","CBL & Associates Properties, Inc.","9.67","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cbl^d",
"CBL^E","CBL & Associates Properties, Inc.","8.94","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cbl^e",
"CBO","CBO (Listing Market - NYSE - Networks A/E)","5.32","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cbo",
"IGR","CBRE Clarion Global Real Estate Income Fund","7.47","870930990.18","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/igr",
"CBRE","CBRE Group, Inc.","50.45","16942862178.95","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/cbre",
"CBS","CBS Corporation","47.94","17880180985.02","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/cbs",
"CBS.A","CBS Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cbs.a",
"CBX","CBX (Listing Market NYSE Networks AE","1.01","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cbx",
"FUN","Cedar Fair, L.P.","51.82","2931285409.42","n/a","1987","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/fun",
"CDR","Cedar Realty Trust, Inc.","3.34","297427875.08","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cdr",
"CDR^B","Cedar Realty Trust, Inc.","24.4362","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cdr^b",
"CDR^C","Cedar Realty Trust, Inc.","21.2","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cdr^c",
"CE","Celanese Corporation","101.81","13015719246.3","n/a","2005","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/ce",
"CLS","Celestica, Inc.","8.53","977799998.95","n/a","1998","Technology","Electrical Products","https://www.nasdaq.com/symbol/cls",
"CEL","Cellcom Israel, Ltd.","3.86","448519373.94","n/a","2007","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/cel",
"CPAC","Cementos Pacasmayo S.A.A.","9.8307","119108761.2","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/cpac",
"CX","Cemex S.A.B. de C.V.","4.76","7140625535.4","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/cx",
"CVE","Cenovus Energy Inc","9.1","11181987589.5","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cve",
"CNC","Centene Corporation","53.69","22184204441.49","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/cnc",
"CEN","Center Coast Brookfield MLP & Energy Infrastructur","8.57","288550905.88","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/cen",
"CNP","CenterPoint Energy, Inc.","30.78","15434331726.06","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/cnp",
"CNP^B","CenterPoint Energy, Inc.","53.17","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cnp^b",
"EBR","Centrais Electricas Brasileiras S.A.- Eletrobras","9.28","12552441877.44","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ebr",
"EBR.B","Centrais Electricas Brasileiras S.A.- Eletrobras","n/a","0","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/ebr.b",
"CEPU","Central Puerto S.A.","9","1362620025","n/a","2018","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/cepu",
"CCS","Century Communities, Inc.","23.4","708959113.2","n/a","2014","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/ccs",
"CTL","CenturyLink, Inc.","12.13","13097770531.38","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ctl",
"CDAY","Ceridian HCM Holding Inc.","51.48","7233706485.72","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cday",
"CF","CF Industries Holdings, Inc.","41.68","9269510586.16","n/a","2005","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/cf",
"GIB","CGI Inc.","69.56","17050427904.6","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/gib",
"ECOM          ","ChannelAdvisor Corporation","12.22","339685596.64","n/a","2013","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/ecom",
"CHAP","Chaparral Energy, Inc.","5.4","250836480","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/chap",
"CHRA","Charah Solutions, Inc.","6.18","182647353.84","n/a","2018","Basic Industries","Environmental Services","https://www.nasdaq.com/symbol/chra",
"CRL","Charles River Laboratories International, Inc.","147.58","7117240748.34","n/a","2000","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/crl",
"CLDT","Chatham Lodging Trust (REIT)","19.6","912548756","n/a","2010","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cldt",
"CMCM","Cheetah Mobile Inc.","6.51","933106416.69","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cmcm",
"CHGG","Chegg, Inc.","38.28","4435564158.96","n/a","2013","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/chgg",
"CHE","Chemed Corp.","322.7","5152702246.3","n/a","n/a","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/che",
"CC","Chemours Company (The)","37.32","6205661705.76","n/a","2015","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/cc",
"CHMI","Cherry Hill Mortgage Investment Corporation","17.27","287582975.9","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/chmi",
"CHMI^A","Cherry Hill Mortgage Investment Corporation","25.17","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/chmi^a",
"CHMI^B","Cherry Hill Mortgage Investment Corporation","25.34","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/chmi^b",
"CHK","Chesapeake Energy Corporation","3.2","5221519248","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/chk",
"CHK^D","Chesapeake Energy Corporation","55.55","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/chk^d",
"CHKR","Chesapeake Granite Wash Trust","1.4299","66847825","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/chkr",
"CHSP","Chesapeake Lodging Trust","28.5","1731790758","n/a","2010","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/chsp",
"CPK","Chesapeake Utilities Corporation","89.28","1462301138.88","n/a","n/a","Public Utilities","Oil & Gas Production","https://www.nasdaq.com/symbol/cpk",
"CVX","Chevron Corporation","124.93","237374840606.8","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/cvx",
"CHS","Chico&#39;s FAS, Inc.","4.29","499772846.43","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/chs",
"CIM","Chimera Investment Corporation","18.93","3540920786.28","n/a","2007","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cim",
"CIM^A","Chimera Investment Corporation","25.72","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cim^a",
"CIM^B","Chimera Investment Corporation","25.79","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cim^b",
"CIM^C","Chimera Investment Corporation","25.0299","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cim^c",
"CIM^D","Chimera Investment Corporation","25.605","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cim^d",
"DL","China Distance Education Holdings Limited","6.7","224079356","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/dl",
"CEA","China Eastern Airlines Corporation Ltd.","36.24","10486106079.12","n/a","1997","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/cea",
"CHN","China Fund, Inc. (The)","20.7","227821550.4","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/chn",
"CGA","China Green Agriculture, Inc.","0.5082","20097757.449","n/a","n/a","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/cga",
"LFC","China Life Insurance Company Limited","13.64","77106128880","n/a","2003","Finance","Life Insurance","https://www.nasdaq.com/symbol/lfc",
"CHL","China Mobile (Hong Kong) Ltd.","50.08","205082436676.32","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/chl",
"BORN","China New Borun Corporation","0.8643","22234117.5","n/a","2010","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/born",
"COE","China Online Education Group","5.94","119874843","n/a","2016","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/coe",
"SNP","China Petroleum & Chemical Corporation","80.6","97583395260","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/snp",
"XRF","China Rapid Finance Limited","1.05","69047170.5","n/a","2017","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/xrf",
"ZNH","China Southern Airlines Company Limited","45.62","11192567960.9","n/a","1997","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/znh",
"CHA","China Telecom Corp Ltd","56.64","45840093405.12","n/a","2002","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/cha",
"CHU","China Unicom (Hong Kong) Ltd","12.95","39624410000","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/chu",
"CYD","China Yuchai International Limited","15.94","651281158.54","n/a","1994","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cyd",
"CMG","Chipotle Mexican Grill, Inc.","704.8","19540909846.4","n/a","2006","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/cmg",
"CHH","Choice Hotels International, Inc.","79.07","4400526751.99","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/chh",
"CBK","Christopher & Banks Corporation","0.3595","13781243.0435","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/cbk",
"CB","Chubb Limited","139.91","64132076895.67","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/cb",
"CHT","Chunghwa Telecom Co., Ltd.","35.51","27546694297","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/cht",
"CHD","Church & Dwight Company, Inc.","72.01","17709628489.05","n/a","n/a","Basic Industries","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/chd",
"CCC","Churchill Capital Corp","13.53","1166962500","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/ccc",
"CCC.U","Churchill Capital Corp","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/ccc.u",
"CCC.WS","Churchill Capital Corp","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ccc.ws",
"CIEN","Ciena Corporation","37.92","5913745495.68","n/a","1997","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/cien",
"CI","Cigna Corporation","158.62","60284953345.54","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/ci",
"XEC","Cimarex Energy Co","68.57","6954393948.06","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/xec",
"CBB","Cincinnati Bell Inc","9.86","496330491.08","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/cbb",
"CBB^B","Cincinnati Bell Inc","39.2117","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cbb^b",
"CNK","Cinemark Holdings Inc","39.13","4580179686.81","n/a","2007","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/cnk",
"CINR","Ciner Resources LP","24.82","490053550.82","n/a","2013","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/cinr",
"CIR","CIRCOR International, Inc.","33.13","658402959.08","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/cir",
"CISN","Cision Ltd.","13.65","2024405592.3","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cisn",
"CIT","CIT Group Inc (DEL)","49","4939640608","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cit",
"BLW","Citigroup Inc.","14.8","542221916.8","n/a","2003","Finance","Major Banks","https://www.nasdaq.com/symbol/blw",
"C","Citigroup Inc.","64.42","150774449417.16","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/c",
"C^J","Citigroup Inc.","27.41","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/c^j",
"C^K","Citigroup Inc.","27.28","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/c^k",
"C^N","Citigroup Inc.","27.4","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/c^n",
"C^S","Citigroup Inc.","26.48","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/c^s",
"CFG","Citizens Financial Group, Inc.","34.01","15657864104.06","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/cfg",
"CFG^D","Citizens Financial Group, Inc.","26.29","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cfg^d",
"CIA","Citizens, Inc.","6.62","325888002.9","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/cia",
"CIO","City Office REIT, Inc.","11.44","458378446.24","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cio",
"CIO^A","City Office REIT, Inc.","24.87","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cio^a",
"CVEO","Civeo Corporation","2.01","333892225.35","n/a","2014","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/cveo",
"CLH","Clean Harbors, Inc.","71.79","4009840644.18","n/a","n/a","Basic Industries","Environmental Services","https://www.nasdaq.com/symbol/clh",
"CCO","Clear Channel Outdoor Holdings, Inc.","5.47","276681450.46","n/a","2005","Consumer Services","Advertising","https://www.nasdaq.com/symbol/cco",
"EMO","ClearBridge Energy Midstream Opportunity Fund Inc.","9.81","703514212.47","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/emo",
"CEM","ClearBridge MLP and Midstream Fund Inc.","12.85","904832261.7","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/cem",
"CTR","ClearBridge MLP and Midstream Total Return Fund In","9.845","378049397.99","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/ctr",
"CLW","Clearwater Paper Corporation","20.82","343845547.92","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/clw",
"CWEN","Clearway Energy, Inc.","15.13","1109418461.33","n/a","2015","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/cwen",
"CWEN.A","Clearway Energy, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cwen.a",
"CLF","Cleveland-Cliffs Inc.","10.27","2984139881.45","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/clf",
"CLPR","Clipper Realty Inc.","13.37","238156534.35","n/a","2017","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/clpr",
"CLX","Clorox Company (The)","157.64","20203818517.96","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/clx",
"CLDR","Cloudera, Inc.","11.31","3041684945.91","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/cldr",
"CMS","CMS Energy Corporation","54.9","15578368221.6","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/cms",
"CMS^B","CMS Energy Corporation","103.75","0","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/cms^b",
"CMSA","CMS Energy Corporation","25.6399","0","n/a","2018","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/cmsa",
"CMSC","CMS Energy Corporation","26.13","0","n/a","2018","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/cmsc",
"CMSD","CMS Energy Corporation","25.77","0","n/a","2019","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/cmsd",
"CNA","CNA Financial Corporation","43.42","11781425011.72","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/cna",
"CNF","CNFinance Holdings Limited","5.8624","398770425.8048","n/a","2018","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/cnf",
"CNHI","CNH Industrial N.V.","10.58","14323542115.64","n/a","2013","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/cnhi",
"CNO","CNO Financial Group, Inc.","16.39","2642685886.61","n/a","n/a","Finance","Accident &Health Insurance","https://www.nasdaq.com/symbol/cno",
"CEO","CNOOC Limited","186.31","1930108254.6","n/a","2001","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/ceo",
"CNXM","CNX Midstream Partners LP","14.97","952868883.12","n/a","2014","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/cnxm",
"CEIX","CNX Resources Corporation","33.28","918778165.76","n/a","2017","Energy","Coal Mining","https://www.nasdaq.com/symbol/ceix",
"CNX","CNX Resources Corporation","10.54","2090453556.08","n/a","1999","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cnx",
"KOF","Coca Cola Femsa S.A.B. de C.V.","66.32","13932505600","n/a","1993","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/kof",
"KO","Coca-Cola Company (The)","46.57","199094259598.78","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/ko",
"CCEP","Coca-Cola European Partners plc","50.85","24023054923.2","n/a","2016","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/ccep",
"CDE","Coeur Mining, Inc.","3.92","804412020.16","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/cde",
"FOF","Cohen & Steers Closed-End Opportunity Fund, Inc.","12.39","337121343.72","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/fof",
"INB","Cohen & Steers Global Income Builder, Inc.","8.49","196476157.32","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/inb",
"CNS","Cohen & Steers Inc","42.47","2005503050.8","n/a","2004","Finance","Investment Managers","https://www.nasdaq.com/symbol/cns",
"UTF","Cohen & Steers Infrastructure Fund, Inc","24.75","2111664901.5","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/utf",
"LDP","Cohen & Steers Limited Duration Preferred and Income Fund, Inc","24.09","694874339.61","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/ldp",
"MIE","Cohen & Steers MLP Income and Energy Opportunity Fund, Inc.","9.65","258555731","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/mie",
"RQI","Cohen & Steers Quality Income Realty Fund Inc","12.89","1407090471.78","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/rqi",
"RNP","Cohen & Steers REIT and Preferred and Income Fund,","20.66","982728765.76","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/rnp",
"PSF","Cohen & Steers Select Preferred and Income Fund, Inc.","27.1784","326202658.0384","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/psf",
"RFI","Cohen & Steers Total Return Realty Fund, Inc.","13.27","346904884.07","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/rfi",
"CFX","Colfax Corporation","30.09","3530849124.78","n/a","2008","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/cfx",
"CFXA","Colfax Corporation","135.14","0","n/a","n/a","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/cfxa",
"CL","Colgate-Palmolive Company","68.37","2638629048.75","n/a","n/a","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/cl",
"CCH","Collier Creek Holdings","9.92","436480000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/cch",
"CCH.U","Collier Creek Holdings","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/cch.u",
"CCH.WS","Collier Creek Holdings","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cch.ws",
"CXE","Colonial High Income Municipal Trust","5.18","163232709.08","n/a","1989","n/a","n/a","https://www.nasdaq.com/symbol/cxe",
"CIF","Colonial Intermediate High Income Fund","2.555","50372292.565","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cif",
"CXH","Colonial Investment Grade Municipal Trust","9.48","86365122.6","n/a","1989","n/a","n/a","https://www.nasdaq.com/symbol/cxh",
"CMU","Colonial Municipal Income Trust","4.65","131690724.9","n/a","1987","n/a","n/a","https://www.nasdaq.com/symbol/cmu",
"CLNY","Colony Capital, Inc.","5.59","2710136862.81","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/clny",
"CLNY^B","Colony Capital, Inc.","25.05","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/clny^b",
"CLNY^E","Colony Capital, Inc.","25.08","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/clny^e",
"CLNY^G","Colony Capital, Inc.","22.99","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/clny^g",
"CLNY^H","Colony Capital, Inc.","22.22","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/clny^h",
"CLNY^I","Colony Capital, Inc.","22.55","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/clny^i",
"CLNY^J","Colony Capital, Inc.","22.52","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/clny^j",
"CLNC","Colony Credit Real Estate, Inc.","15.87","2039505753.6","n/a","2018","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/clnc",
"CXP","Columbia Property Trust, Inc.","22.79","2663687565.35","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cxp",
"STK","Columbia Seligman Premium Technology Growth Fund, Inc","20.57","321478265.57","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/stk",
"CCZ","Comcast Corporation","50.61","0","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/ccz",
"CMA","Comerica Incorporated","76.93","12148433952.97","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cma",
"FIX","Comfort Systems USA, Inc.","52.77","1945614702.24","n/a","1997","Capital Goods","Engineering & Construction","https://www.nasdaq.com/symbol/fix",
"CMC","Commercial Metals Company","17.37","2048288985.9","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/cmc",
"CBU","Community Bank System, Inc.","61.1","3135530105.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cbu",
"CYH","Community Health Systems, Inc.","3.7","430040732.5","n/a","2000","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/cyh",
"CHCT","Community Healthcare Trust Incorporated","35.57","665841659.44","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/chct",
"CIG","Comp En De Mn Cemig ADS","3.49","5089089671.67","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/cig",
"CIG.C","Comp En De Mn Cemig ADS","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cig.c",
"CBD","Companhia Brasileira de Distribuicao","23.95","6391071438.9","n/a","1997","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/cbd",
"SBS","Companhia de saneamento Basico Do Estado De Sao Paulo - Sabesp","10.48","7163183427.12","n/a","2002","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/sbs",
"ELP","Companhia Paranaense de Energia (COPEL)","9.22","2523102557.5","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/elp",
"CCU","Compania Cervecerias Unidas, S.A.","28.64","5291281127.04","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/ccu",
"CODI","Compass Diversified Holdings","16.01","958999000","n/a","2006","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/codi",
"CODI^A","Compass Diversified Holdings","21.87","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/codi^a",
"CODI^B","Compass Diversified Holdings","22.91","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/codi^b",
"CMP","Compass Minerals International, Inc.","54.83","1857302427.88","n/a","2003","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/cmp",
"CRK","Comstock Resources, Inc.","7.11","752743265.04","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/crk",
"CAG","ConAgra Brands, Inc.","27.39","13301733996.54","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/cag",
"CXO","Concho Resources Inc.","111.59","22384310348.88","n/a","2007","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cxo",
"CCM","Concord Medical Services Holdings Limited","2.9126","126301963.0992","n/a","2009","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/ccm",
"CNDT","Conduent Incorporated","13.72","2903173389.48","n/a","2016","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/cndt",
"COP","ConocoPhillips","66.35","75267711636.9","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/cop",
"CCR","CONSOL Coal Resources LP","17.56","483291201.68","n/a","2015","Energy","Coal Mining","https://www.nasdaq.com/symbol/ccr",
"ED","Consolidated Edison Inc","84.76","27214499403.52","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/ed",
"STZ","Constellation Brands Inc","176.71","33553111833.71","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/stz",
"STZ.B","Constellation Brands Inc","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/stz.b",
"CSTM","Constellium N.V.","8.44","1147834885.36","n/a","2013","Basic Industries","Metal Fabrications","https://www.nasdaq.com/symbol/cstm",
"TCS","Container Store (The)","8.86","433361888.22","n/a","2013","Consumer Services","Home Furnishings","https://www.nasdaq.com/symbol/tcs",
"CBPX","Continental Building Products, Inc.","25.09","884534953.38","n/a","2014","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/cbpx",
"CLR","Continental Resources, Inc.","46.09","17330527893.25","n/a","2007","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/clr",
"VLRS","Controladora Vuela Compania de Aviacion, S.A.B. de C.V.","8.78","875818249.02","n/a","2013","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/vlrs",
"CTRA","Contura Energy, Inc.","59.97","1150627538.43","n/a","n/a","Energy","Coal Mining","https://www.nasdaq.com/symbol/ctra",
"CTB","Cooper Tire & Rubber Company","30.44","1525496490.6","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/ctb",
"CPS","Cooper-Standard Holdings Inc.","49.22","858205777.18","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/cps",
"CTK","CooTek (Cayman) Inc.","10.75","683792708","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/ctk",
"CPA","Copa Holdings, S.A.","83.05","3504322903.95","n/a","2005","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/cpa",
"CLB","Core Laboratories N.V.","68.38","3031543466.12","n/a","1995","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/clb",
"CXW","CoreCivic, Inc.","19.66","2333073373.82","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cxw",
"CLGX","CoreLogic, Inc.","37.9","3036779493.2","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/clgx",
"CORR","CorEnergy Infrastructure Trust, Inc.","37.59","481049191.35","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/corr",
"CORR^A","CorEnergy Infrastructure Trust, Inc.","25.06","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/corr^a",
"CPLG","CorePoint Lodging Inc.","11.84","705137321.28","n/a","2018","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cplg",
"COR","CoreSite Realty Corporation","108.63","3984671586.42","n/a","2010","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cor",
"GLW","Corning Incorporated","34.02","26713141364.7","n/a","n/a","Basic Industries","Telecommunications Equipment","https://www.nasdaq.com/symbol/glw",
"CAAP","Corporacion America Airports SA","8.15","1304181435.3","n/a","2018","Transportation","Aerospace","https://www.nasdaq.com/symbol/caap",
"GYC","Corporate Asset Backed Corp CABCO","21.03","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/gyc",
"OFC","Corporate Office Properties Trust","27.31","3012942786.83","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ofc",
"CZZ","Cosan Limited","11.59","2835791502.08","n/a","n/a","Consumer Non-Durables","Specialty Foods","https://www.nasdaq.com/symbol/czz",
"CMRE","Costamare Inc.","5.26","596620160.36","n/a","2010","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/cmre",
"CMRE^B","Costamare Inc.","23.2","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cmre^b",
"CMRE^C","Costamare Inc.","24.595","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cmre^c",
"CMRE^D","Costamare Inc.","24.9424","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cmre^d",
"CMRE^E","Costamare Inc.","25.15","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cmre^e",
"COT","Cott Corporation","14.88","2023132773.12","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/cot",
"COTY","Coty Inc.","11.25","8453116237.5","n/a","2013","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/coty",
"CUZ","Cousins Properties Incorporated","9.64","4054456597.76","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cuz",
"CVA","Covanta Holding Corporation","17.56","2303052474.8","n/a","n/a","Basic Industries","Electric Utilities: Central","https://www.nasdaq.com/symbol/cva",
"CVIA","Covia Holdings Corporation","5.95","781946923.45","n/a","2018","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/cvia",
"CPF","CPB Inc.","29.07","838278246.87","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cpf",
"CPL","CPFL Energia S.A.","15.1","7685256332.3","n/a","2004","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/cpl",
"CR","Crane Co.","85.64","5128294736.92","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/cr",
"CRD.A","Crawford & Company","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/crd.a",
"CRD.B","Crawford & Company","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/crd.b",
"BAP","Credicorp Ltd.","243.1","19389899100","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bap",
"CS","Credit Suisse Group","12.06","30760043389.74","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/cs",
"CPG","Crescent Point Energy Corporation","3.14","1724888086.24","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/cpg",
"CEQP","Crestwood Equity Partners LP","35.52","2553939930.24","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/ceqp",
"CRH","CRH PLC","31.76","25707128352.24","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/crh",
"CRT","Cross Timbers Royalty Trust","11.23","67380000","n/a","1992","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/crt",
"CAPL","CrossAmerica Partners LP","18.45","635493884.85","n/a","2012","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/capl",
"CCI","Crown Castle International Corporation","128.37","53346513197.34","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cci",
"CCI^A","Crown Castle International Corporation","1188.95","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cci^a",
"CCK","Crown Holdings, Inc.","55.13","7460653534.27","n/a","n/a","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/cck",
"CRY","CryoLife, Inc.","29.42","1091557991.86","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/cry",
"CSS","CSS Industries, Inc.","6.02","53192118","n/a","n/a","Consumer Services","Consumer: Greeting Cards","https://www.nasdaq.com/symbol/css",
"CTS","CTS Corporation","29.74","973515910.98","n/a","n/a","Technology","Electrical Products","https://www.nasdaq.com/symbol/cts",
"CUBE","CubeSmart","32.25","6035916030.75","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cube",
"CUB","Cubic Corporation","55.63","1732887406.16","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cub",
"CFR","Cullen/Frost Bankers, Inc.","99.75","6290536444.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cfr",
"CFR^A","Cullen/Frost Bankers, Inc.","26.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cfr^a",
"CULP","Culp, Inc.","18.9","233763005.7","n/a","n/a","Basic Industries","Textiles","https://www.nasdaq.com/symbol/culp",
"CMI","Cummins Inc.","161.83","25462149979.42","n/a","n/a","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cmi",
"CURO","CURO Group Holdings Corp.","10.04","466015505.48","n/a","2017","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/curo",
"CW","Curtiss-Wright Corporation","112","4796404480","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/cw",
"SRF","Cushing Energy Income Fund (The)","7.65","18933665.85","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/srf",
"SRV","Cushing MLP & Infrastructure Total Return Fund","10.57","71181572.14","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/srv",
"SZC","Cushing Renaissance Fund (The)","17.17","134014305.31","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/szc",
"CWK","Cushman & Wakefield plc","17.99","3896584419.56","n/a","2018","Finance","Real Estate","https://www.nasdaq.com/symbol/cwk",
"CUBI","Customers Bancorp, Inc","18.78","583693160.94","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/cubi",
"CUBI^C","Customers Bancorp, Inc","25.71","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cubi^c",
"CUBI^D","Customers Bancorp, Inc","25.56","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cubi^d",
"CUBI^E","Customers Bancorp, Inc","25.531","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cubi^e",
"CUBI^F","Customers Bancorp, Inc","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cubi^f",
"CVI","CVR Energy Inc.","41.9","4212232098.1","n/a","2007","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/cvi",
"UAN","CVR Partners, LP","3.89","440670764.97","n/a","2011","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/uan",
"CVS","CVS Health Corporation","52.13","67616893261.45","n/a","n/a","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/cvs",
"CELP","Cypress Energy Partners, L.P.","7.28","87528677.6","n/a","2014","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/celp",
"DHI","D.R. Horton, Inc.","41.7","15571744104","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/dhi",
"DAN","Dana Incorporated","18.26","2619598060.86","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/dan",
"DHR","Danaher Corporation","131.62","94199589526.08","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/dhr",
"DHR^A","Danaher Corporation","1051.06","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dhr^a",
"DAC","Danaos Corporation","0.865","184525653.575","n/a","2006","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/dac",
"DQ","DAQO New Energy Corp.","34.88","448689727.68","n/a","2010","Technology","Semiconductors","https://www.nasdaq.com/symbol/dq",
"DRI","Darden Restaurants, Inc.","119.18","14719811796.86","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/dri",
"DAR","Darling Ingredients Inc.","21.1","3475094630.8","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/dar",
"DVA","DaVita Inc.","54.6","9085440000","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/dva",
"DCP","DCP Midstream LP","33.64","4821194913.92","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/dcp",
"DCP^B","DCP Midstream LP","24.45","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dcp^b",
"DCP^C","DCP Midstream LP","24.74","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dcp^c",
"DF","Dean Foods Company","2.71","248515978.23","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/df",
"DECK","Deckers Outdoor Corporation","143.23","4172431411.24","n/a","1993","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/deck",
"DE","Deere & Company","162.12","51634162491.24","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/de",
"DEX","Delaware Enhanced Global Dividend","9.76","123593193.12","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/dex",
"DDF","Delaware Investments Dividend & Income Fund, Inc.","12.97","99715422.23","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/ddf",
"DKL","Delek Logistics Partners, L.P.","32.17","785186218.85","n/a","2012","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/dkl",
"DK","Delek US Holdings, Inc.","36.58","2834047973.78","n/a","2017","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/dk",
"DELL","Dell Technologies Inc.","61.27","25031903594.72","n/a","2018","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/dell",
"DLPH","Delphi Technologies PLC","20.87","1847655869.42","n/a","2017","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/dlph",
"DAL","Delta Air Lines, Inc.","55.33","37566308922.34","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/dal",
"DLX","Deluxe Corporation","44.23","1930104936.22","n/a","n/a","Consumer Durables","Publishing","https://www.nasdaq.com/symbol/dlx",
"DNR","Denbury Resources Inc.","2.18","1003764242.34","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/dnr",
"DESP","Despegar.com, Corp.","14.93","1032581433.88","n/a","2017","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/desp",
"DKT","Deutsch Bk Contingent Cap Tr V","25.87","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/dkt",
"DB","Deutsche Bank AG","8.5","17556146389.5","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/db",
"DXB","Deutsche Bank AG","25.39","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/dxb",
"DVN","Devon Energy Corporation","31.21","13679343000","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/dvn",
"DHX","DHI Group, Inc.","2.5","137186535","n/a","2007","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/dhx",
"DHT","DHT Holdings, Inc.","4.66","662817127.1","n/a","2005","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/dht",
"DEO","Diageo plc","163.9","98391420347","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/deo",
"DO","Diamond Offshore Drilling, Inc.","11.1","1525565718.3","n/a","1995","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/do",
"DSSI","Diamond S Shipping Inc.","9.65","0","n/a","2019","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/dssi",
"DRH","Diamondrock Hospitality Company","10.94","2208381088.72","n/a","2005","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/drh",
"DSX","Diana Shipping inc.","2.92","308831904.92","n/a","2005","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/dsx",
"DSX^B","Diana Shipping inc.","23.75","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dsx^b",
"DKS","Dick&#39;s Sporting Goods Inc","38.36","2752790665.24","n/a","2002","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/dks",
"DBD","Diebold Nixdorf Incorporated","12.02","920290962.16","n/a","n/a","Miscellaneous","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/dbd",
"DLR","Digital Realty Trust, Inc.","121.71","25294239809.82","n/a","2004","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/dlr",
"DLR^C","Digital Realty Trust, Inc.","26.38","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dlr^c",
"DLR^G","Digital Realty Trust, Inc.","25.23","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dlr^g",
"DLR^I","Digital Realty Trust, Inc.","26.21","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dlr^i",
"DLR^J","Digital Realty Trust, Inc.","24.2","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dlr^j",
"DLR^K","Digital Realty Trust, Inc.","25.28","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dlr^k",
"DDS","Dillard&#39;s, Inc.","71.97","1607675144.13","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/dds",
"DDT","Dillard&#39;s, Inc.","26.92","0","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/ddt",
"DIN","Dine Brands Global, Inc.","91.85","1610497073.35","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/din",
"DPLO","Diplomat Pharmacy, Inc.","5.76","429061092.48","n/a","2014","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/dplo",
"DFS","Discover Financial Services","73.78","24069804594.5","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/dfs",
"DNI","Dividend and Income Fund","11.47","141667896.96","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dni",
"DLB","Dolby Laboratories","63.28","6493585851.76","n/a","2005","Miscellaneous","Multi-Sector Companies","https://www.nasdaq.com/symbol/dlb",
"DG","Dollar General Corporation","117.89","30594671449.89","n/a","2009","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/dg",
"D","Dominion Energy, Inc.","76.97","61529686304.33","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/d",
"DCUD","Dominion Energy, Inc.","50.15","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/dcud",
"DRUA","Dominion Energy, Inc.","25.15","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/drua",
"DPZ","Domino&#39;s Pizza Inc","245.22","10069525505.82","n/a","2004","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/dpz",
"UFS","Domtar Corporation","49.83","3135490113.69","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/ufs",
"DCI","Donaldson Company, Inc.","51.44","6566542336","n/a","n/a","Capital Goods","Pollution Control Equipment","https://www.nasdaq.com/symbol/dci",
"DFIN","Donnelley Financial Solutions, Inc.","15.02","512434275.92","n/a","2016","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/dfin",
"LPG","Dorian LPG Ltd.","6.75","372446039.25","n/a","2014","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/lpg",
"DSL","DoubleLine Income Solutions Fund","20.07","2034091308.87","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/dsl",
"DBL","DoubleLine Opportunistic Credit Fund","19.96","296618114.92","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/dbl",
"PLOW","Douglas Dynamics, Inc.","37.84","862578390.08","n/a","2010","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/plow",
"DEI","Douglas Emmett, Inc.","40.93","6967220104.46","n/a","2006","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/dei",
"DOV","Dover Corporation","95.87","13921597153.6","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/dov",
"DVD","Dover Motorsports, Inc.","2.07","37448160.93","n/a","1996","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/dvd",
"DWDP","DowDuPont Inc.","36.49","82276267496.42","n/a","2017","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/dwdp",
"RDY","Dr. Reddy&#39;s Laboratories Ltd","41.11","6818663901.25","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/rdy",
"DRD","DRDGOLD Limited","1.95","133978394.55","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/drd",
"DCF","Dreyfus Alcentra","8.83","132108932.42","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/dcf",
"DHF","Dreyfus High Yield Strategies Fund","3.13","227575063.44","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/dhf",
"DMB","Dreyfus Municipal Bond Infrastructure Fund, Inc.","13.05","239884852.05","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/dmb",
"DSM","Dreyfus Strategic Municipal Bond Fund, Inc.","7.75","382613307.25","n/a","1989","n/a","n/a","https://www.nasdaq.com/symbol/dsm",
"LEO","Dreyfus Strategic Municipals, Inc.","7.98","494680447.38","n/a","1987","n/a","n/a","https://www.nasdaq.com/symbol/leo",
"DRQ","Dril-Quip, Inc.","45.65","1632391046","n/a","1997","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/drq",
"DS","Drive Shack Inc.","4.52","302962510.08","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ds",
"DS^B","Drive Shack Inc.","25.8485","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ds^b",
"DS^C","Drive Shack Inc.","24.6502","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ds^c",
"DS^D","Drive Shack Inc.","24.11","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ds^d",
"DTE","DTE Energy Company","123.9","22700273080.8","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/dte",
"DTJ","DTE Energy Company","24.99","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/dtj",
"DTQ","DTE Energy Company","25.08","0","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/dtq",
"DTV","DTE Energy Company","55.05","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/dtv",
"DTW","DTE Energy Company","25.09","0","n/a","2017","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/dtw",
"DTY","DTE Energy Company","27.14","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/dty",
"DCO","Ducommun Incorporated","44.36","506855319.44","n/a","n/a","Capital Goods","Military/Government/Technical","https://www.nasdaq.com/symbol/dco",
"DPG","Duff & Phelps Global Utility Income Fund Inc.","15.12","573498666.72","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/dpg",
"DSE","Duff & Phelps Select MLP and Midstream Energy Fund","5.13","134450153.91","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/dse",
"DNP","Duff & Phelps Utilities Income, Inc.","11.48","3278742036.36","n/a","1987","n/a","n/a","https://www.nasdaq.com/symbol/dnp",
"DTF","Duff & Phelps Utilities Tax-Free Income, Inc.","13.3","113325110.5","n/a","1991","n/a","n/a","https://www.nasdaq.com/symbol/dtf",
"DUC","Duff & Phelps Utility & Corporate Bond Trust, Inc.","8.605","236591747.215","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/duc",
"DUK","Duke Energy Corporation","89.13","64855047604.11","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/duk",
"DUKB","Duke Energy Corporation","25.48","0","n/a","2018","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/dukb",
"DUKH","Duke Energy Corporation","24.92","0","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/dukh",
"DRE","Duke Realty Corporation","30.94","11114996798.36","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/dre",
"DXC","DXC Technology Company","64.19","17220327493.53","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/dxc",
"DY","Dycom Industries, Inc.","47.21","1484330743.04","n/a","n/a","Basic Industries","Water Supply","https://www.nasdaq.com/symbol/dy",
"DLNG","Dynagas LNG Partners LP","2.28","80917200","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/dlng",
"DLNG^A","Dynagas LNG Partners LP","19.593","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dlng^a",
"DLNG^B","Dynagas LNG Partners LP","18.795","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dlng^b",
"DX","Dynex Capital, Inc.","6.04","429224687.6","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/dx",
"DX^A","Dynex Capital, Inc.","25.58","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dx^a",
"DX^B","Dynex Capital, Inc.","23.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/dx^b",
"DD^A","E.I. du Pont de Nemours and Company","82.05","0","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/dd^a",
"DD^B","E.I. du Pont de Nemours and Company","104.8135","0","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/dd^b",
"ELF","e.l.f. Beauty, Inc.","10.45","510170316.7","n/a","2016","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/elf",
"EGIF","Eagle Growth and Income Opportunities Fund","15.45","110944518.75","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/egif",
"EXP","Eagle Materials Inc","83.49","3832073362.59","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/exp",
"ECC           ","Eagle Point Credit Company Inc.","17.12","396384821.28","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/ecc",
"ECCA","Eagle Point Credit Company Inc.","25.6","0","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/ecca",
"ECCB","Eagle Point Credit Company Inc.","26.2","0","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/eccb",
"ECCX","Eagle Point Credit Company Inc.","25.2","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/eccx",
"ECCY","Eagle Point Credit Company Inc.","25.4098","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/eccy",
"ESTE","Earthstone Energy, Inc.","7.03","451113532.31","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/este",
"DEA","Easterly Government Properties, Inc.","18.05","1099303608.35","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/dea",
"EGP","EastGroup Properties, Inc.","112.47","4102829570.28","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/egp",
"EMN","Eastman Chemical Company","78.87","10946042671.08","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/emn",
"KODK","Eastman Kodak Company","2.99","127752689.48","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/kodk",
"ETN","Eaton Corporation, PLC","82.64","35057806404.96","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/etn",
"ETV","Eaton Vance Corporation","15.12","1208543338.8","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/etv",
"ETW","Eaton Vance Corporation","9.8","1043592837","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/etw",
"EV","Eaton Vance Corporation","41.53","4800344555.88","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/ev",
"EOI","Eaton Vance Enhance Equity Income Fund","14.54","570407776.84","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/eoi",
"EOS","Eaton Vance Enhanced Equity Income Fund II","16.7","798095521.7","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/eos",
"EFT","Eaton Vance Floating Rate Income Trust","13.52","538957088.8","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/eft",
"EFL","Eaton Vance Floating-Rate 2022 Target Term Trust","9.29","219353064.6","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/efl",
"EFF","Eaton vance Floating-Rate Income Plus Fund","14.94","113639944.68","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/eff",
"EHT","Eaton Vance High Income 2021 Target Term Trust","9.67","207527492.87","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/eht",
"ETX           ","Eaton Vance Municipal Income 2028 Term Trust","20.26","219515094.26","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/etx",
"EOT","Eaton Vance Municipal Income Trust","21.13","321854758.99","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/eot",
"EVN","Eaton Vance Municipal Income Trust","12.14","481572567.14","n/a","1999","n/a","n/a","https://www.nasdaq.com/symbol/evn",
"ETJ","Eaton Vance Risk-Managed Diversified Equity Income Fund","9.2","585763337.6","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/etj",
"EFR","Eaton Vance Senior Floating-Rate Fund","13.23","487503180.99","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/efr",
"EVF","Eaton Vance Senior Income Trust","6.17","233636965.19","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/evf",
"EVG","Eaton Vance Short Diversified Income Fund","12.93","231196106.28","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/evg",
"EVT","Eaton Vance Tax Advantaged Dividend Income Fund","22.53","1643003877.33","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/evt",
"ETO","Eaton Vance Tax-Advantage Global Dividend Opp","24.17","363999740.77","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/eto",
"ETG","Eaton Vance Tax-Advantaged Global Dividend Income Fund","15.83","1207832387.62","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/etg",
"ETB","Eaton Vance Tax-Managed Buy-Write Income Fund","15.69","416447949.57","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/etb",
"EXD","Eaton Vance Tax-Managed Buy-Write Strategy Fund","9.3771","91254055.0806","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/exd",
"ETY","Eaton Vance Tax-Managed Diversified Equity Income Fund","11.43","1711621057.32","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/ety",
"EXG","Eaton Vance Tax-Managed Global Diversified Equity Income Fund","8.18","2467795774.5","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/exg",
"ECT","ECA Marcellus Trust I","1.78","31336900","n/a","2010","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/ect",
"ECL","Ecolab Inc.","178.14","51369623095.62","n/a","n/a","Basic Industries","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/ecl",
"EC","Ecopetrol S.A.","21.84","44899430590.56","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/ec",
"EIX","Edison International","62.51","20366458487.06","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/eix",
"EW","Edwards Lifesciences Corporation","190","39540779350","n/a","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/ew",
"EHIC","eHi Car Services Limited","11.78","824114510.86","n/a","2014","Consumer Services","Rental/Leasing Companies","https://www.nasdaq.com/symbol/ehic",
"EP^C","El Paso Corporation","51.78","0","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/ep^c",
"EE","El Paso Electric Company","58.67","2390220493.6","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ee",
"ELAN","Elanco Animal Health Incorporated","32.44","11861488472.84","n/a","2018","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/elan",
"ESTC","Elastic N.V.","82.3","6032315694.1","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/estc",
"EGO","Eldorado Gold Corporation","4.45","706667662.9","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/ego",
"ESI","Element Solutions Inc.","10.23","2582007069.84","n/a","2014","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/esi",
"ELVT","Elevate Credit, Inc.","4.37","189473568.52","n/a","2017","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/elvt",
"LLY","Eli Lilly and Company","129.32","125494428214.84","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/lly",
"ELLI","Ellie Mae, Inc.","98.84","3439874355.68","n/a","2011","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/elli",
"EFC","Ellington Financial Inc.","17.83","530367186.08","n/a","2010","Finance","Real Estate","https://www.nasdaq.com/symbol/efc",
"EARN","Ellington Residential Mortgage REIT","11.81","147236486.43","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/earn",
"AKO.A","Embotelladora Andina S.A.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ako.a",
"AKO.B","Embotelladora Andina S.A.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ako.b",
"ERJ","Embraer S.A.","19.4","3557607172.2","n/a","2000","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/erj",
"EME","EMCOR Group, Inc.","74.25","4157823804.75","n/a","n/a","Capital Goods","Engineering & Construction","https://www.nasdaq.com/symbol/eme",
"EEX","Emerald Expositions Events, Inc.","12.8","919542092.8","n/a","2017","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/eex",
"EMES","Emerge Energy Services LP","2.01","62382565.02","n/a","2013","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/emes",
"EBS","Emergent Biosolutions, Inc.","50.99","2610688000","n/a","2006","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/ebs",
"EMR","Emerson Electric Company","69.93","42980366739.87","n/a","n/a","Energy","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/emr",
"ESRT","Empire State Realty Trust, Inc.","15.88","4835103557.52","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/esrt",
"EIG","Employers Holdings Inc","40.32","1323700076.16","n/a","2007","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/eig",
"EDN","Empresa Distribuidora Y Comercializadora Norte S.A. (Edenor)","19.73","871148614.19","n/a","2007","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/edn",
"ENBL","Enable Midstream Partners, LP","14.26","6178110776","n/a","2014","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/enbl",
"ENB","Enbridge Inc","36.61","74066872697.58","n/a","n/a","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/enb",
"ENBA","Enbridge Inc","26.05","0","n/a","2018","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/enba",
"ECA","Encana Corporation","7.2","10734481497.6","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/eca",
"EHC","Encompass Health Corporation","58.33","5759732736.94","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/ehc",
"DAVA","Endava plc","26.95","1429243123","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/dava",
"EXK","Endeavour Silver Corporation","2.41","316713097.43","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/exk",
"ENIA","Enel Americas S.A.","8.78","10241865671.46","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/enia",
"ENIC","Enel Chile S.A.","5.17","7251863644.52","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/enic",
"ENR","Energizer Holdings, Inc.","47.34","3307866972.48","n/a","2015","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/enr",
"ENR^A","Energizer Holdings, Inc.","101.23","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/enr^a",
"EPC","Energizer Holdings, Inc.","43.65","2362229573.4","n/a","n/a","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/epc",
"ET","Energy Transfer L.P.","15.5","40600566498.5","n/a","1996","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/et",
"ETP^C","Energy Transfer Operating, L.P.","25.02","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/etp^c",
"ETP^D","Energy Transfer Operating, L.P.","25.57","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/etp^d",
"ERF","Enerplus Corporation","8.4","2005337056.8","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/erf",
"ENS","Enersys","66.76","2873935017.32","n/a","2004","Consumer Non-Durables","Telecommunications Equipment","https://www.nasdaq.com/symbol/ens",
"E","ENI S.p.A.","35.42","64361422194.3","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/e",
"ENLC","EnLink Midstream, LLC","12.89","7035229297.45","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/enlc",
"EBF","Ennis, Inc.","20.73","541559413.17","n/a","n/a","Consumer Services","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/ebf",
"ENVA","Enova International, Inc.","22.82","768802673.66","n/a","2014","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/enva",
"NPO","EnPro Industries","66.62","1387211005.42","n/a","n/a","Basic Industries","Metal Fabrications","https://www.nasdaq.com/symbol/npo",
"ESV","ENSCO plc","4.18","1828284582.08","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/esv",
"ETM","Entercom Communications Corp.","5.37","744142734.42","n/a","1999","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/etm",
"EAB","Entergy Arkansas, LLC","25.05","0","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/eab",
"EAE","Entergy Arkansas, LLC","25.03","0","n/a","2013","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/eae",
"EAI","Entergy Arkansas, LLC","24.86","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/eai",
"ETR","Entergy Corporation","94.13","17928941758.91","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/etr",
"ELC","Entergy Louisiana, Inc.","24.9986","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/elc",
"ELJ","Entergy Louisiana, Inc.","25.21","0","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/elj",
"ELU","Entergy Louisiana, Inc.","24.5441","0","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/elu",
"EMP","Entergy Mississippi, LLC","24.88","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/emp",
"ENJ","Entergy New Orleans, LLC","24.734","0","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/enj",
"ENO","Entergy New Orleans, LLC","26.7988","0","n/a","2016","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/eno",
"EZT","Entergy Texas Inc","27.08","0","n/a","2014","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ezt",
"EPD","Enterprise Products Partners L.P.","29.47","64388232889.96","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/epd",
"EVC","Entravision Communications Corporation","3.32","295004705.48","n/a","2000","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/evc",
"ENV","Envestnet, Inc","66.72","3212532838.56","n/a","2010","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/env",
"EVA","Enviva Partners, LP","32.97","876101226.63","n/a","2015","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/eva",
"ENZ","Enzo Biochem, Inc.","2.89","136527458.15","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/enz",
"EOG","EOG Resources, Inc.","96.05","55714576566.95","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/eog",
"EPE","EP Energy Corporation","0.2592","66416427.7056","n/a","2014","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/epe",
"EPAM","EPAM Systems, Inc.","170.96","9262175826.24","n/a","2012","Technology","EDP Services","https://www.nasdaq.com/symbol/epam",
"EPR","EPR Properties","78.42","5874099583.02","n/a","1997","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/epr",
"EPR^C","EPR Properties","31.9076","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/epr^c",
"EPR^E","EPR Properties","37.75","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/epr^e",
"EPR^G","EPR Properties","24.2948","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/epr^g",
"EQM","EQM Midstream Partners, LP","47.15","9451577254.5","n/a","2012","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/eqm",
"EQT","EQT Corporation","20.62","5253192440","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/eqt",
"EFX","Equifax, Inc.","120.23","14591711785.86","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/efx",
"EQNR","Equinor ASA","22.27","74184847505.04","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/eqnr",
"ETRN","Equitrans Midstream Corporation","21.56","5482082760","n/a","2018","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/etrn",
"EQC","Equity Commonwealth","32.68","3976649917.52","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/eqc",
"EQC^D","Equity Commonwealth","26.91","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/eqc^d",
"ELS","Equity Lifestyle Properties, Inc.","115.31","10369783213.79","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/els",
"EQR","Equity Residential","75.69","28000285007.67","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/eqr",
"EQS","Equus Total Return, Inc.","1.85","25008570.1","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/eqs",
"ERA","Era Group, Inc.","11.8","257120513.2","n/a","n/a","Transportation","Transportation Services","https://www.nasdaq.com/symbol/era",
"EROS","Eros International PLC","8.86","652201744.1","n/a","2013","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/eros",
"ESE","ESCO Technologies Inc.","68.42","1773388858.78","n/a","n/a","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/ese",
"ESNT","Essent Group Ltd.","45.09","4428877640.13","n/a","2013","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/esnt",
"EPRT","Essential Properties Realty Trust, Inc.","19.53","1129331233.8","n/a","2018","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/eprt",
"ESS","Essex Property Trust, Inc.","291.74","19164062765.08","n/a","1994","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ess",
"EL","Estee Lauder Companies, Inc. (The)","163.22","58948945045.42","n/a","1995","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/el",
"ETH","Ethan Allen Interiors Inc.","18.96","503948154.24","n/a","1993","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/eth",
"EURN","Euronav NV","8.37","1832881834.26","n/a","2015","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/eurn",
"EEA","European Equity Fund, Inc. (The)","8.82","69806772","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/eea",
"EB","Eventbrite, Inc.","20.61","1620030109.41","n/a","2018","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/eb",
"EVR","Evercore Inc.","93.29","3824463664.7","n/a","2006","Finance","Investment Managers","https://www.nasdaq.com/symbol/evr",
"RE","Everest Re Group, Ltd.","214.89","8740698240.69","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/re",
"EVRG","Evergy, Inc.","57.5","14529849742.5","n/a","2018","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/evrg",
"EVRI","Everi Holdings Inc.","10.4","731328291.2","n/a","n/a","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/evri",
"ES","Eversource Energy","70.73","22442788849.8","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/es",
"EVTC","Evertec, Inc.","28.55","2066412170.5","n/a","2013","Technology","EDP Services","https://www.nasdaq.com/symbol/evtc",
"EVH","Evolent Health, Inc","12.45","1027948480.35","n/a","2015","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/evh",
"AQUA","Evoqua Water Technologies Corp.","12.85","1466468239.7","n/a","2017","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/aqua",
"XAN","Exantas Capital Corp.","10.6","337641778.8","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/xan",
"XAN^C","Exantas Capital Corp.","25.93","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/xan^c",
"EXC","Exelon Corporation","50.29","48778894428.14","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/exc",
"EXPR","Express, Inc.","4.28","284648491.96","n/a","2010","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/expr",
"EXTN","Exterran Corporation","17.28","624533448.96","n/a","2015","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/extn",
"EXR","Extra Space Storage Inc","102.09","12995903967.09","n/a","2004","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/exr",
"XOM","Exxon Mobil Corporation","81.38","344628221834.78","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/xom",
"FNB","F.N.B. Corporation","10.94","3542482942.54","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fnb",
"FNB^E","F.N.B. Corporation","28.46","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fnb^e",
"FN","Fabrinet","54.98","2029016942.26","n/a","2010","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/fn",
"FDS","FactSet Research Systems Inc.","250.05","9510769273.5","n/a","1996","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/fds",
"FICO","Fair Isaac Corporation","275.59","8011732559.18","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/fico",
"SFUN","Fang Holdings Limited","1.47","656832015","n/a","2010","Technology","EDP Services","https://www.nasdaq.com/symbol/sfun",
"FPAC","Far Point Acquisition Corporation","9.99","783540675","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/fpac",
"FPAC.U","Far Point Acquisition Corporation","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/fpac.u",
"FPAC.WS","Far Point Acquisition Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fpac.ws",
"FTCH","Farfetch Limited","26.53","7955206210","n/a","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ftch",
"FPI","Farmland Partners Inc.","6.5","208500220.5","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/fpi",
"FPI^B","Farmland Partners Inc.","23.31","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fpi^b",
"FBK","FB Financial Corporation","33.01","1017791487.23","n/a","2016","Finance","Major Banks","https://www.nasdaq.com/symbol/fbk",
"FFG","FBL Financial Group, Inc.","63.45","1564190973","n/a","1996","Finance","Life Insurance","https://www.nasdaq.com/symbol/ffg",
"AGM","Federal Agricultural Mortgage Corporation","73.67","785962465.97","n/a","n/a","Finance","Finance Companies","https://www.nasdaq.com/symbol/agm",
"AGM.A","Federal Agricultural Mortgage Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/agm.a",
"AGM^A","Federal Agricultural Mortgage Corporation","25.6","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/agm^a",
"AGM^B","Federal Agricultural Mortgage Corporation","26.24","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/agm^b",
"AGM^C","Federal Agricultural Mortgage Corporation","26.14","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/agm^c",
"FRT","Federal Realty Investment Trust","137.61","10266698443.32","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/frt",
"FRT^C","Federal Realty Investment Trust","24","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/frt^c",
"FSS","Federal Signal Corporation","25.87","1558770643.69","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/fss",
"FII","Federated Investors, Inc.","29.71","2994814020.79","n/a","1998","Finance","Investment Managers","https://www.nasdaq.com/symbol/fii",
"FMN","Federated Premier Municipal Income Fund","13.43","154401701.68","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/fmn",
"FDX","FedEx Corporation","184.03","47953545846.36","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/fdx",
"RACE","Ferrari N.V.","135.97","33232907674.1","n/a","2015","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/race",
"FGP","Ferrellgas Partners, L.P.","1.31","127269991.15","n/a","1994","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/fgp",
"FOE","Ferro Corporation","17.8","1463091719.2","n/a","n/a","Basic Industries","Paints/Coatings","https://www.nasdaq.com/symbol/foe",
"FG","FGL Holdings","7.97","1767806556.06","n/a","2017","Finance","Life Insurance","https://www.nasdaq.com/symbol/fg",
"FG.WS","FGL Holdings","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fg.ws",
"FCAU","Fiat Chrysler Automobiles N.V.","15.42","24162821947.08","n/a","2014","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/fcau",
"FNF","Fidelity National Financial, Inc.","37.75","10393755065","n/a","2014","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/fnf",
"FIS","Fidelity National Information Services, Inc.","114.12","36876074904","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/fis",
"FMO","Fiduciary/Claymore Energy Infrastructure Fund","10.85","384532332.8","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/fmo",
"FAF","First American Corporation (The)","53.12","5921615903.36","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/faf",
"FBP","First BanCorp.","11.77","2556895603.13","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fbp",
"FCF","First Commonwealth Financial Corporation","13.01","1283265275.39","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fcf",
"FDC","First Data Corporation","26.74","25218939889.5","n/a","2015","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/fdc",
"FHN","First Horizon National Corporation","14.37","4561523088.09","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/fhn",
"FHN^A","First Horizon National Corporation","26","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/fhn^a",
"FR","First Industrial Realty Trust, Inc.","35.68","4516879343.36","n/a","1994","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/fr",
"AG","First Majestic Silver Corp.","6.3","1238744089.8","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/ag",
"FRC","FIRST REPUBLIC BANK","103.7","17338873636.1","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/frc",
"FRC^D","FIRST REPUBLIC BANK","25.42","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/frc^d",
"FRC^F","FIRST REPUBLIC BANK","25.98","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/frc^f",
"FRC^G","FIRST REPUBLIC BANK","25.52","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/frc^g",
"FRC^H","FIRST REPUBLIC BANK","24.74","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/frc^h",
"FRC^I","FIRST REPUBLIC BANK","25.1","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/frc^i",
"FFA","First Trust","15.22","303991556.08","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/ffa",
"FMY","First Trust","13.45","56666396.75","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/fmy",
"FDEU","First Trust Dynamic Europe Equity Income Fund","14.35","247277879.8","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/fdeu",
"FIF","First Trust Energy Infrastructure Fund","15.91","279224254.76","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/fif",
"FSD","First Trust High Income Long Short Fund","14.61","437527963.77","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/fsd",
"FPF","First Trust Intermediate Duration Preferred & Income Fund","22.17","1347182153.49","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/fpf",
"FEI           ","First Trust MLP and Energy Income Fund","11.53","540267021.12","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/fei",
"FPL","First Trust New Opportunities MLP & Energy Fund","9.1401","232150085.4075","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/fpl",
"FIV","First Trust Senior Floating Rate 2022 Target Term Fund","8.8","315317807.2","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/fiv",
"FCT","First Trust Senior Floating Rate Income Fund II","11.96","319295904.72","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/fct",
"FGB","First Trust Specialty Finance and Financial Opportunities Fund","6.1","87533292","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/fgb",
"FEO","First Trust/Aberdeen Emerging Opportunity Fund","13.76","69644932.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/feo",
"FAM","First Trust/Aberdeen Global Opportunity Income Fund","9.96","127193861.28","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/fam",
"FE","FirstEnergy Corp.","41.34","21916490914.5","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/fe",
"FIT","Fitbit, Inc.","5.88","1486031390.76","n/a","2015","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/fit",
"FPH","Five Point Holdings, LLC","7.55","519216044.35","n/a","2017","Finance","Real Estate","https://www.nasdaq.com/symbol/fph",
"FBC","Flagstar Bancorp, Inc.","33.53","1892510821.95","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/fbc",
"DFP","Flaherty & Crumrine Dynamic Preferred and Income Fund Inc.","24.11","461984946.39","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/dfp",
"PFD","Flaherty & Crumrine Preferred Income Fund Incorporated","13.46","150863960.28","n/a","1991","n/a","n/a","https://www.nasdaq.com/symbol/pfd",
"PFO","Flaherty & Crumrine Preferred Income Opportunity Fund Inc","11.2","140842732.8","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/pfo",
"FFC","Flaherty & Crumrine Preferred Securities Income Fund Inc","19.04","842570170.4","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/ffc",
"FLC","Flaherty & Crumrine Total Return Fund Inc","19.34","192589731.36","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/flc",
"FLT","FleetCor Technologies, Inc.","250.1","21473191092.1","n/a","2010","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/flt",
"FND","Floor & Decor Holdings, Inc.","41.34","4050397208.52","n/a","2017","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/fnd",
"FTK","Flotek Industries, Inc.","3.32","190402049.8","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/ftk",
"FLO","Flowers Foods, Inc.","21","4428910500","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/flo",
"FLS","Flowserve Corporation","46.69","6115595242.82","n/a","n/a","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/fls",
"FLR","Fluor Corporation","38.5","5374914622","n/a","n/a","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/flr",
"FLY","Fly Leasing Limited","13.91","454163155.29","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/fly",
"FMC","FMC Corporation","78.96","10391790499.44","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/fmc",
"FMX","Fomento Economico Mexicano S.A.B. de C.V.","92.81","166047590059.35","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/fmx",
"FL","Foot Locker, Inc.","60.65","6846790751.3","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/fl",
"F","Ford Motor Company","9.01","35307189787.13","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/f",
"FELP","Foresight Energy LP","2.35","342826988.75","n/a","2014","Energy","Coal Mining","https://www.nasdaq.com/symbol/felp",
"FOR","Forestar Group Inc","17.47","732968979.02","n/a","2017","Finance","Real Estate","https://www.nasdaq.com/symbol/for",
"FTS","Fortis Inc.","36.9","15814527351.3","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/fts",
"FTV","Fortive Corporation","85.68","28671204214.8","n/a","2016","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/ftv",
"FTV^A","Fortive Corporation","1071.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ftv^a",
"FTAI","Fortress Transportation and Infrastructure Investors LLC","17.16","1448278465.92","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/ftai",
"FSM","Fortuna Silver Mines Inc.","3.2","511806704","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/fsm",
"FBHS","Fortune Brands Home & Security, Inc.","47.56","6699979805.6","n/a","n/a","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/fbhs",
"FET","Forum Energy Technologies, Inc.","5.28","580255410.24","n/a","2012","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/fet",
"FBM","Foundation Building Materials, Inc.","10","429073260","n/a","2017","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/fbm",
"FCPT","Four Corners Property Trust, Inc.","29.67","2027911506.96","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/fcpt",
"FEDU","Four Seasons Education (Cayman) Inc.","1.78","88881063.96","n/a","2017","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/fedu",
"FNV","Franco-Nevada Corporation","74.33","13905643094.93","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/fnv",
"FC","Franklin Covey Company","25.63","357007190.1","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/fc",
"FSB","Franklin Financial Network, Inc.","29.6","431350676.8","n/a","2015","Finance","Major Banks","https://www.nasdaq.com/symbol/fsb",
"BEN","Franklin Resources, Inc.","33.97","17308069850.62","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/ben",
"FT","Franklin Universal Trust","7","175923258","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ft",
"FI","Frank&#39;s International N.V.","6.26","1408148551.08","n/a","2013","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/fi",
"FCX","Freeport-McMoran, Inc.","13.12","19011652571.2","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/fcx",
"FMS","Fresenius Medical Care Corporation","41.2","25286804962.4","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/fms",
"FDP","Fresh Del Monte Produce, Inc.","26.65","1292168876.05","n/a","1997","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/fdp",
"RESI","Front Yard Residential Corporation","9.89","530402717.56","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/resi",
"FRO","Frontline Ltd.","6.77","1149689469.84","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/fro",
"FSK","FS KKR Capital Corp.","6.18","3246556067.46","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/fsk",
"FCN","FTI Consulting, Inc.","77.73","2943146644.68","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/fcn",
"FTSI","FTS International, Inc.","10.16","1115510961.76","n/a","2018","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/ftsi",
"FF","FutureFuel Corp.","13.23","578723104.89","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/ff",
"GCV","Gabelli Convertible and Income Securities Fund, Inc. (The)","5.2","97539124.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gcv",
"GCV^B","Gabelli Convertible and Income Securities Fund, Inc. (The)","26.59","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gcv^b",
"GDV","Gabelli Dividend","21.47","1769824186.22","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/gdv",
"GDV^A","Gabelli Dividend","25.9627","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gdv^a",
"GDV^D","Gabelli Dividend","26.2053","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gdv^d",
"GDV^G","Gabelli Dividend","25.04","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gdv^g",
"GAB","Gabelli Equity Trust, Inc. (The)","6.17","1563095601.91","n/a","1986","n/a","n/a","https://www.nasdaq.com/symbol/gab",
"GAB^D","Gabelli Equity Trust, Inc. (The)","26.03","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gab^d",
"GAB^G","Gabelli Equity Trust, Inc. (The)","23.709","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gab^g",
"GAB^H","Gabelli Equity Trust, Inc. (The)","24.2","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gab^h",
"GAB^J","Gabelli Equity Trust, Inc. (The)","25.9485","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gab^j",
"GGZ","Gabelli Global Small and Mid Cap Value Trust (The)","11.82","114625312.86","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/ggz",
"GGZ^A","Gabelli Global Small and Mid Cap Value Trust (The)","25.2895","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ggz^a",
"GGT","Gabelli Multi-Media Trust Inc. (The)","8.4","206790066","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ggt",
"GGT^B","Gabelli Multi-Media Trust Inc. (The)","26.109","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ggt^b",
"GGT^E","Gabelli Multi-Media Trust Inc. (The)","24.3616","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ggt^e",
"GUT","Gabelli Utility Trust (The)","7.03","376814080.95","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gut",
"GUT^A","Gabelli Utility Trust (The)","26.26","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gut^a",
"GUT^C","Gabelli Utility Trust (The)","25.54","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gut^c",
"GCAP","GAIN Capital Holdings, Inc.","6.46","241510988.92","n/a","2010","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/gcap",
"GBL","Gamco Investors, Inc.","20.68","597870401.48","n/a","1999","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/gbl",
"GNT","GAMCO Natural Resources, Gold & Income Tust ","5.58","116592481.8","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/gnt",
"GNT^A","GAMCO Natural Resources, Gold & Income Tust ","23.685","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gnt^a",
"GME","Gamestop Corporation","10.1","1029872255","n/a","2002","Consumer Services","Electronics Distribution","https://www.nasdaq.com/symbol/gme",
"GPS","Gap, Inc. (The)","25.8","9767833689","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/gps",
"GDI","Gardner Denver Holdings, Inc.","27.83","5577378796.44","n/a","2017","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/gdi",
"GTX","Garrett Motion Inc.","15.86","1173954424.5","n/a","2018","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/gtx",
"IT","Gartner, Inc.","153.1","13734866934.7","n/a","1993","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/it",
"GLOG","GasLog LP.","16.75","1354425870.5","n/a","2012","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/glog",
"GLOG^A","GasLog LP.","26.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/glog^a",
"GLOP","GasLog Partners LP","22.83","1058776065.75","n/a","2014","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/glop",
"GLOP^A","GasLog Partners LP","24.8083","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/glop^a",
"GLOP^B","GasLog Partners LP","24.315","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/glop^b",
"GLOP^C","GasLog Partners LP","24.24","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/glop^c",
"GTES","Gates Industrial Corporation plc","15.53","4502006173.96","n/a","2018","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/gtes",
"GATX","GATX Corporation","76.95","2804957237.7","n/a","n/a","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/gatx",
"GMTA","GATX Corporation","26.2","0","n/a","2016","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/gmta",
"GCP","GCP Applied Technologies Inc.","29.32","2125665519.68","n/a","2016","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/gcp",
"GNK","Genco Shipping & Trading Limited ","7.72","321500002.16","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/gnk",
"GNRC","Generac Holdlings Inc.","52.15","3240059735.15","n/a","2010","Consumer Durables","Metal Fabrications","https://www.nasdaq.com/symbol/gnrc",
"GAM","General American Investors, Inc.","33.59","866622000","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gam",
"GAM^B","General American Investors, Inc.","26.5","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gam^b",
"GD","General Dynamics Corporation","169.94","49073559864.92","n/a","n/a","Capital Goods","Marine Transportation","https://www.nasdaq.com/symbol/gd",
"GE","General Electric Company","10.24","89186692280.32","n/a","n/a","Energy","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/ge",
"GIS","General Mills, Inc.","50.98","30526348917.38","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/gis",
"GM","General Motors Company","37.81","53292398192.06","n/a","2010","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/gm",
"GM.WS.B","General Motors Company","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gm.ws.b",
"GCO","Genesco Inc.","44.61","900789387.84","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/gco",
"GWR","Genesee & Wyoming, Inc.","89.22","5068176449.7","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/gwr",
"GEL","Genesis Energy, L.P.","23.36","2863450532.48","n/a","1996","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/gel",
"GEN           ","Genesis Healthcare, Inc.","1.39","145139377.02","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/gen",
"GNE","Genie Energy Ltd.","8.45","215618675.35","n/a","2011","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/gne",
"GNE^A","Genie Energy Ltd.","8.2","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gne^a",
"G","Genpact Limited","35.47","6720032093.01","n/a","2007","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/g",
"GPC","Genuine Parts Company","112.49","16417214124.85","n/a","n/a","Capital Goods","Automotive Aftermarket","https://www.nasdaq.com/symbol/gpc",
"GNW","Genworth Financial Inc","3.91","1958522386.06","n/a","2004","Finance","Life Insurance","https://www.nasdaq.com/symbol/gnw",
"GEO","Geo Group Inc (The)","19.57","2362633750.25","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/geo",
"GPRK","Geopark Ltd","17.24","1043020000","n/a","2014","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/gprk",
"GPJA","Georgia Power Company","25.02","0","n/a","2017","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/gpja",
"GGB","Gerdau S.A.","4.17","7097905489.53","n/a","n/a","Capital Goods","Steel/Iron Ore","https://www.nasdaq.com/symbol/ggb",
"GTY","Getty Realty Corporation","32.24","1317547372.96","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/gty",
"GIG","GigCapital, Inc.","10.2","188312461.2","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/gig",
"GIG.U","GigCapital, Inc.","n/a","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/gig.u",
"GIG.WS","GigCapital, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gig.ws",
"GIG~","GigCapital, Inc.","0.57","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gig~",
"GIL","Gildan Activewear, Inc.","36.79","7599910253.65","n/a","1998","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/gil",
"GLT","Glatfelter","14.66","645378118.24","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/glt",
"GKOS","Glaukos Corporation","78.35","2832958223.85","n/a","2015","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/gkos",
"GSK","GlaxoSmithKline PLC","41.88","103996171713.96","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/gsk",
"BRSS","Global Brass and Copper Holdings, Inc.","34.63","760220269.5","n/a","2013","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/brss",
"CO","Global Cord Blood Corporation","7.45","905555508.75","n/a","n/a","Finance","Business Services","https://www.nasdaq.com/symbol/co",
"GMRE","Global Medical REIT Inc.","9.86","259364736.4","n/a","2016","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/gmre",
"GMRE^A","Global Medical REIT Inc.","25.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gmre^a",
"GNL","Global Net Lease, Inc.","19.15","1605545632.45","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/gnl",
"GNL^A","Global Net Lease, Inc.","25.71","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gnl^a",
"GLP","Global Partners LP","19.78","672432236.14","n/a","2005","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/glp",
"GLP^A","Global Partners LP","25.44","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/glp^a",
"GPN","Global Payments Inc.","138.8","21909627747.2","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/gpn",
"GSL","Global Ship Lease, Inc.","5.9","58663641","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/gsl",
"GSL^B","Global Ship Lease, Inc.","20.6","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gsl^b",
"GLOB","Globant S.A.","72.64","2643551926.4","n/a","2014","Technology","EDP Services","https://www.nasdaq.com/symbol/glob",
"GMED","Globus Medical, Inc.","47.41","4677160064.5","n/a","2012","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/gmed",
"GMS","GMS Inc.","15.24","618316807.56","n/a","2016","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/gms",
"GNC","GNC Holdings, Inc.","2.49","209075188.11","n/a","2011","Consumer Non-Durables","Food Chains","https://www.nasdaq.com/symbol/gnc",
"GDDY","GoDaddy Inc.","75.8","13292002840.4","n/a","2015","Technology","EDP Services","https://www.nasdaq.com/symbol/gddy",
"GOL","Gol Linhas Aereas Inteligentes S.A.","13.07","298989320","n/a","2004","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/gol",
"GFI","Gold Fields Limited","3.7","3065941015.9","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/gfi",
"GG","Goldcorp Inc.","11.47","9971063271.61","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/gg",
"GSBD","Goldman Sachs BDC, Inc.","20.95","843598175.2","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/gsbd",
"GS","Goldman Sachs Group, Inc. (The)","197.5","72435716792.5","n/a","1999","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/gs",
"GS^A","Goldman Sachs Group, Inc. (The)","19.38","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gs^a",
"GS^B","Goldman Sachs Group, Inc. (The)","27.13","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gs^b",
"GS^C","Goldman Sachs Group, Inc. (The)","20","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gs^c",
"GS^D","Goldman Sachs Group, Inc. (The)","19.579","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gs^d",
"GS^J","Goldman Sachs Group, Inc. (The)","26.24","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gs^j",
"GS^K","Goldman Sachs Group, Inc. (The)","27.63","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gs^k",
"GS^N","Goldman Sachs Group, Inc. (The)","26.37","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gs^n",
"GER","Goldman Sachs MLP Energy Renaissance Fund","5.69","450923538.25","n/a","1986","n/a","n/a","https://www.nasdaq.com/symbol/ger",
"GMZ","Goldman Sachs MLP Income Opportunities Fund","8.19","363868858.08","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/gmz",
"GRC","Gorman-Rupp Company (The)","34.13","891374745.85","n/a","n/a","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/grc",
"GPX","GP Strategies Corporation","12.3","203751517.2","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/gpx",
"GGG","Graco Inc.","50.83","8412887379.91","n/a","n/a","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/ggg",
"GRAF","Graf Industrial Corp.","9.87","300745216.8","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/graf",
"GRAF.U","Graf Industrial Corp.","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/graf.u",
"GRAF.WS","Graf Industrial Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/graf.ws",
"EAF","GrafTech International Ltd.","13.62","3957122275.44","n/a","2018","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/eaf",
"GHM","Graham Corporation","19.97","196386617.54","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/ghm",
"GHC","Graham Holdings Company","683.09","2972106146.57","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/ghc",
"GRAM","Grana y Montero S.A.A.","3.57","520815876","n/a","2018","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/gram",
"GVA","Granite Construction Incorporated","43.79","2044354279.06","n/a","n/a","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/gva",
"GPMT","Granite Point Mortgage Trust Inc.","18.69","955889228.49","n/a","2017","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/gpmt",
"GRP.U","Granite Real Estate Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/grp.u",
"GPK","Graphic Packaging Holding Company","12.72","3759872465.76","n/a","n/a","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/gpk",
"GTN","Gray Television, Inc.","21.8","2050875984","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/gtn",
"GTN.A","Gray Television, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gtn.a",
"AJX","Great Ajax Corp.","13.74","259853037.18","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ajx",
"AJXA","Great Ajax Corp.","25.1","0","n/a","2017","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ajxa",
"GWB","Great Western Bancorp, Inc.","32.42","1845944062.7","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/gwb",
"GDOT","Green Dot Corporation","61.5","3257007958.5","n/a","2010","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/gdot",
"GBX","Greenbrier Companies, Inc. (The)","33.03","1068527502.36","n/a","1994","Capital Goods","Railroads","https://www.nasdaq.com/symbol/gbx",
"GHL","Greenhill & Co., Inc.","22.07","456674845.63","n/a","2004","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/ghl",
"GHG","GreenTree Hospitality Group Ltd.","14.47","1469460464.23","n/a","2018","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/ghg",
"GEF","Greif Bros. Corporation","41.16","2438498927.76","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gef",
"GEF.B","Greif Bros. Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gef.b",
"GFF","Griffon Corporation","18.85","881482550","n/a","n/a","Capital Goods","Building Products","https://www.nasdaq.com/symbol/gff",
"GPI","Group 1 Automotive, Inc.","65.66","1204236048.12","n/a","1997","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/gpi",
"GRUB","GrubHub Inc.","70.58","6422735464.02","n/a","2014","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/grub",
"PAC","Grupo Aeroportuario Del Pacifico, S.A. de C.V.","90.72","5089392000","n/a","2006","Transportation","Aerospace","https://www.nasdaq.com/symbol/pac",
"ASR","Grupo Aeroportuario del Sureste, S.A. de C.V.","160.26","4807800000","n/a","n/a","Transportation","Aerospace","https://www.nasdaq.com/symbol/asr",
"AVAL","Grupo Aval Acciones y Valores S.A.","7.78","8667315667.46","n/a","2014","Finance","Commercial Banks","https://www.nasdaq.com/symbol/aval",
"SUPV","Grupo Supervielle S.A.","6.02","549893673.28","n/a","2016","Finance","Commercial Banks","https://www.nasdaq.com/symbol/supv",
"TV","Grupo Televisa S.A.","10.95","6688059187.95","n/a","1993","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/tv",
"GSAH","GS Acquisition Holdings Corp.","10","862500000","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/gsah",
"GSAH.U","GS Acquisition Holdings Corp.","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/gsah.u",
"GSAH.WS","GS Acquisition Holdings Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gsah.ws",
"GTT","GTT Communications, Inc.","37.29","2080907257.11","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/gtt",
"GSH","Guangshen Railway Company Limited","19.31","2735661989.4","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/gsh",
"GES","Guess?, Inc.","18.69","1527469275.57","n/a","1996","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/ges",
"GGM","Guggenheim Credit Allocation Fund","20.25","149453788.5","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/ggm",
"GPM","Guggenheim Enhanced Equity Income Fund","7.88","379291664.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gpm",
"GOF","Guggenheim Strategic Opportunities Fund","19.69","673097530.6","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gof",
"GBAB","Guggenheim Taxable Municipal Managed Duration Trst","23.04","401333760","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/gbab",
"GWRE","Guidewire Software, Inc.","99.3","8084478021.9","n/a","2012","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/gwre",
"HRB","H&R Block, Inc.","24.44","4968483803.92","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/hrb",
"FUL","H. B. Fuller Company","49.53","2520358864.53","n/a","n/a","Basic Industries","Home Furnishings","https://www.nasdaq.com/symbol/ful",
"HAE","Haemonetics Corporation","88.5","4514145253.5","n/a","1991","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/hae",
"HK","Halcon Resources Corporation","1.38","221161250.88","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/hk",
"HK.WS","Halcon Resources Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hk.ws",
"HAL","Halliburton Company","29.94","26123932689.48","n/a","n/a","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/hal",
"HBB","Hamilton Beach Brands Holding Company","21.06","198662433.84","n/a","2017","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/hbb",
"HBI","Hanesbrands Inc.","17.91","6473942207.1","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/hbi",
"HNGR","Hanger, Inc.","19.5","719414065.5","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/hngr",
"HASI","Hannon Armstrong Sustainable Infrastructure Capital, Inc.","25.37","1595154936.06","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hasi",
"HOG","Harley-Davidson, Inc.","37.78","6027570619.9","n/a","n/a","Consumer Non-Durables","Motor Vehicles","https://www.nasdaq.com/symbol/hog",
"HMY","Harmony Gold Mining Company Limited","1.8","957937458.6","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/hmy",
"HRS","Harris Corporation","161.9","19097867119.6","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/hrs",
"HSC","Harsco Corporation","20.63","1651954697.43","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/hsc",
"HHS","Harte-Hanks, Inc.","3.58","22432745.4","n/a","1993","Technology","Advertising","https://www.nasdaq.com/symbol/hhs",
"HGH","Hartford Financial Services Group, Inc. (The)","28.33","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/hgh",
"HIG","Hartford Financial Services Group, Inc. (The)","49.51","17797379553.51","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/hig",
"HIG.WS","Hartford Financial Services Group, Inc. (The)","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hig.ws",
"HIG^G","Hartford Financial Services Group, Inc. (The)","26.79","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hig^g",
"HVT","Haverty Furniture Companies, Inc.","22.83","469629263.64","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/hvt",
"HVT.A","Haverty Furniture Companies, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hvt.a",
"HE","Hawaiian Electric Industries, Inc.","40.52","4414123269.04","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/he",
"HE^U","Hawaiian Electric Industries, Inc.","26.1823","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/he^u",
"HCHC","HC2 Holdings, Inc.","2.45","110180995.75","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/hchc",
"HCA","HCA Healthcare, Inc.","130.65","44879785705.95","n/a","2011","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/hca",
"HCI","HCI Group, Inc.","42.11","361538268.48","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/hci",
"HCP","HCP, Inc.","31.25","14935236875","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hcp",
"HDB","HDFC Bank Limited","115.59","104929003683.3","n/a","2001","Finance","Commercial Banks","https://www.nasdaq.com/symbol/hdb",
"HR","Healthcare Realty Trust Incorporated","32.19","4038620524.59","n/a","1993","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hr",
"HTA","Healthcare Trust of America, Inc.","28.6","5864837206.8","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hta",
"HL","Hecla Mining Company","2.23","1077062686.96","n/a","n/a","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/hl",
"HL^B","Hecla Mining Company","55.88","0","n/a","n/a","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/hl^b",
"HEI","Heico Corporation","97.75","12997576448.5","n/a","n/a","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/hei",
"HEI.A","Heico Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hei.a",
"HLX","Helix Energy Solutions Group, Inc.","8.01","1191770341.11","n/a","n/a","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/hlx",
"HP","Helmerich & Payne, Inc.","57","6236103582","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/hp",
"HLF","Herbalife Nutrition Ltd.","52.74","8063642112.12","n/a","2004","Health Care","Other Pharmaceuticals","https://www.nasdaq.com/symbol/hlf",
"HRI","Herc Holdings Inc.","39.64","1130694570.84","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/hri",
"HCXY","Hercules Capital, Inc.","24.91","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/hcxy",
"HCXZ","Hercules Capital, Inc.","24.7","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/hcxz",
"HTGC","Hercules Capital, Inc.","12.76","1230662354.68","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/htgc",
"HRTG","Heritage Insurance Holdings, Inc.","14.69","445999535.02","n/a","2014","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/hrtg",
"HT","Hersha Hospitality Trust","17.58","688871456.16","n/a","1999","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ht",
"HT^C","Hersha Hospitality Trust","24.14","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ht^c",
"HT^D","Hersha Hospitality Trust","22.9","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ht^d",
"HT^E","Hersha Hospitality Trust","23.45","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ht^e",
"HSY","Hershey Company (The)","114.75","23927646361.5","n/a","n/a","Consumer Non-Durables","Specialty Foods","https://www.nasdaq.com/symbol/hsy",
"HTZ","Hertz Global Holdings, Inc","17.44","1463628717.6","n/a","2016","Consumer Services","Rental/Leasing Companies","https://www.nasdaq.com/symbol/htz",
"HES","Hess Corporation","60.35","18288117711.7","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/hes",
"HESM","Hess Midstream Partners LP","20.9","1140652716.5","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/hesm",
"HPE","Hewlett Packard Enterprise Company","15.82","21679384500.34","n/a","2015","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/hpe",
"HXL","Hexcel Corporation","70.14","5952679676.16","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/hxl",
"HF","HFF, Inc.","47.74","1899251638.9","n/a","2007","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/hf",
"HCLP","Hi-Crush Partners LP","4.51","455791419.49","n/a","2012","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/hclp",
"PCF","High Income Securities Fund","9.0161","50174650.5966","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pcf",
"HFRO","Highland Floating Rate Opportunities Fund","13.55","972852331","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/hfro",
"HGLB","Highland Global Allocation Fund","12.95","301546590.45","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/hglb",
"HPR","HighPoint Resources Corporation","2.24","0","n/a","2018","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/hpr",
"HIW","Highwoods Properties, Inc.","46.54","4825123251.78","n/a","1994","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hiw",
"HIL","Hill International, Inc.","2.72","151118420.96","n/a","n/a","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/hil",
"HI","Hillenbrand Inc","41.84","2616238715.04","n/a","n/a","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/hi",
"HRC","Hill-Rom Holdings Inc","105.42","7027685461.86","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/hrc",
"HTH","Hilltop Holdings Inc.","18.5","1731815044","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/hth",
"HGV","Hilton Grand Vacations Inc.","31.88","2962436184.24","n/a","2016","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/hgv",
"HLT","Hilton Worldwide Holdings Inc.","85.04","24856884410.32","n/a","2016","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/hlt",
"HNI","HNI Corporation","36.47","1588706942.34","n/a","n/a","Consumer Durables","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/hni",
"HMLP","Hoegh LNG Partners LP","19.46","645940800.68","n/a","2014","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/hmlp",
"HMLP^A","Hoegh LNG Partners LP","25.8","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hmlp^a",
"HEP","Holly Energy Partners, L.P.","27.18","2865864663.18","n/a","2004","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/hep",
"HFC","HollyFrontier Corporation","48.84","8340181354.56","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/hfc",
"HD","Home Depot, Inc. (The)","194.31","214499490445.17","n/a","n/a","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/hd",
"HMC","Honda Motor Company, Ltd.","28","49287710948","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/hmc",
"HON","Honeywell International Inc.","161.04","117296682737.52","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/hon",
"HMN","Horace Mann Educators Corporation","35.45","1452959407.45","n/a","1991","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/hmn",
"HZN","Horizon Global Corporation","1.92","48394767.36","n/a","2015","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/hzn",
"HTFA","Horizon Technology Finance Corporation","25.7039","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/htfa",
"HRL","Hormel Foods Corporation","43.08","23076912516.24","n/a","n/a","Consumer Non-Durables","Meat/Poultry/Fish","https://www.nasdaq.com/symbol/hrl",
"HOS","Hornbeck Offshore Services","1.2","45240736.8","n/a","2004","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/hos",
"HST","Host Hotels & Resorts, Inc.","19.44","14394802332.24","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hst",
"HLI","Houlihan Lokey, Inc.","46.17","3020101404.12","n/a","2015","Finance","Investment Managers","https://www.nasdaq.com/symbol/hli",
"HOV","Hovnanian Enterprises Inc","12.58","74714922.14","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/hov",
"HHC","Howard Hughes Corporation (The)","110.12","4749457209.96","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hhc",
"HPQ","HP Inc.","19.72","30240655870.68","n/a","n/a","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/hpq",
"HSBC","HSBC Holdings plc","42.15","169032147469.35","n/a","n/a","Finance","Savings Institutions","https://www.nasdaq.com/symbol/hsbc",
"HSBC^A","HSBC Holdings plc","25.93","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hsbc^a",
"HMI","Huami Corporation","13.33","792256766.28","n/a","2018","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/hmi",
"HNP","Huaneng Power International, Inc.","23.65","9281497675.45","n/a","1994","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/hnp",
"HUBB","Hubbell Inc","120.17","6549900699.3","n/a","2015","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/hubb",
"HUBS","HubSpot, Inc.","170.9","6769865118","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/hubs",
"HBM","Hudbay Minerals Inc.","7.44","1943864803.44","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/hbm",
"HUD","Hudson Ltd.","13.37","1235201889.6","n/a","2018","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/hud",
"HPP","Hudson Pacific Properties, Inc.","34.64","5345562460.72","n/a","2010","Finance","Real Estate","https://www.nasdaq.com/symbol/hpp",
"HUM","Humana Inc.","262.32","35580494317.68","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/hum",
"HCFT","Hunt Companies Finance Trust, Inc.","3.42","81011810.88","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hcft",
"HII","Huntington Ingalls Industries, Inc.","210.82","8782102809.14","n/a","n/a","Capital Goods","Marine Transportation","https://www.nasdaq.com/symbol/hii",
"HUN","Huntsman Corporation","22.97","5364020944.09","n/a","2005","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/hun",
"HUYA","HUYA Inc.","27.7","5645178506.6","n/a","2018","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/huya",
"H","Hyatt Hotels Corporation","74.65","7899928069.5","n/a","2009","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/h",
"HY","Hyster-Yale Materials Handling, Inc.","64.82","828113160.42","n/a","n/a","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/hy",
"IAG","Iamgold Corporation","3.4","1591098737.8","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/iag",
"IBN","ICICI Bank Limited","11.54","37194490727.36","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/ibn",
"IDA","IDACORP, Inc.","98.65","4970319055.9","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ida",
"IEX","IDEX Corporation","154.82","11734423209.5","n/a","1989","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/iex",
"IDT","IDT Corporation","6.63","174255978.39","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/idt",
"ITW","Illinois Tool Works Inc.","148.74","48625860069.84","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/itw",
"IMAX","Imax Corporation","22.03","1353381965.67","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/imax",
"ICD","Independence Contract Drilling, Inc.","2.8","215819105.6","n/a","2014","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/icd",
"IHC","Independence Holding Company","33.99","508121574.51","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/ihc",
"IRT","Independence Realty Trust, Inc.","10.89","975023637.39","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/irt",
"IFN","India Fund, Inc. (The)","21.44","587240184.96","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ifn",
"IBA","Industrias Bachoco, S.A. de C.V.","45.92","2296000000","n/a","1997","Consumer Non-Durables","Meat/Poultry/Fish","https://www.nasdaq.com/symbol/iba",
"INFY","Infosys Limited","11.18","48512319793.08","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/infy",
"HIFR","InfraREIT, Inc.","21","923951112","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/hifr",
"ING","ING Group, N.V.","12.55","48834330749.15","n/a","1997","Finance","Commercial Banks","https://www.nasdaq.com/symbol/ing",
"ISF","ING Group, N.V.","25.84","0","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/isf",
"ISG","ING Group, N.V.","25.68","0","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/isg",
"IR","Ingersoll-Rand plc (Ireland)","110.26","26701513254.06","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/ir",
"NGVT","Ingevity Corporation","109.92","4589569122.24","n/a","2016","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/ngvt",
"INGR","Ingredion Incorporated","93.17","6211407434.54","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/ingr",
"IIPR","Innovative Industrial Properties, Inc.","76.9","754096318.6","n/a","2016","Finance","Real Estate","https://www.nasdaq.com/symbol/iipr",
"IIPR^A","Innovative Industrial Properties, Inc.","29.94","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iipr^a",
"IPHI","Inphi Corporation","44.8","1993096044.8","n/a","2010","Technology","Semiconductors","https://www.nasdaq.com/symbol/iphi",
"INSI","Insight Select Income Fund","19.17","205311370.95","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/insi",
"NSP","Insperity, Inc.","126.28","5169600885.68","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/nsp",
"INSP","Inspire Medical Systems, Inc.","50.65","1188120804.85","n/a","1998","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/insp",
"IBP","Installed Building Products, Inc.","48.22","1442530762.42","n/a","2014","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/ibp",
"INST","Instructure, Inc.","46.94","1680802219.34","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/inst",
"ITGR","Integer Holdings Corporation","76.5","2487525790.5","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/itgr",
"I","Intelsat S.A.","15.35","2119424019.1","n/a","2013","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/i",
"ICE","Intercontinental Exchange Inc.","77.37","43769984486.76","n/a","2005","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/ice",
"IHG","Intercontinental Hotels Group","62.47","11371619813.71","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/ihg",
"IBM","International Business Machines Corporation","143","127250874608","n/a","n/a","Technology","Computer Manufacturing","https://www.nasdaq.com/symbol/ibm",
"IFF","International Flavors & Fragrances, Inc.","130.53","13919036136.51","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/iff",
"IFFT","International Flavors & Fragrances, Inc.","50.69","0","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/ifft",
"IGT","International Game Technology","13.44","2744448000","n/a","2015","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/igt",
"IP","International Paper Company","47.13","18863128288.47","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/ip",
"INSW","International Seaways, Inc.","17.15","500764119.1","n/a","2016","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/insw",
"INSW^A","International Seaways, Inc.","24.96","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/insw^a",
"IPG","Interpublic Group of Companies, Inc. (The)","21","8083163067","n/a","n/a","Technology","Advertising","https://www.nasdaq.com/symbol/ipg",
"INXN","InterXion Holding N.V.","67.4","4830760200","n/a","2011","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/inxn",
"IPI","Intrepid Potash, Inc","3.7","484111008.1","n/a","2008","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/ipi",
"IVC","Invacare Corporation","8.03","267029876.96","n/a","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/ivc",
"VBF","Invesco Bond Fund","18.23","207403967.87","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vbf",
"VCV","Invesco California Value Municipal Income Trust","12.2","583957074.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vcv",
"VTA","Invesco Credit Opportunities Fund","11.01","815778066.84","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/vta",
"IHIT","Invesco High Income 2023 Target Term Fund","10.2","244202412.6","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/ihit",
"IHTA","Invesco High Income 2024 Target Term Fund","9.899","80181900","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/ihta",
"VLT","Invesco High Income Trust II","14.48","117554851.92","n/a","1989","n/a","n/a","https://www.nasdaq.com/symbol/vlt",
"IVR","INVESCO MORTGAGE CAPITAL INC","15.87","2026527537.39","n/a","2009","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ivr",
"IVR^B","INVESCO MORTGAGE CAPITAL INC","26.36","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ivr^b",
"IVR^C","INVESCO MORTGAGE CAPITAL INC","24.97","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ivr^c",
"IVR^A","Invesco Mortgage Capital Inc.","25.449","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ivr^a",
"OIA","Invesco Municipal Income Opportunities Trust","7.81","370924680.17","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/oia",
"VMO","Invesco Municipal Opportunity Trust","11.97","806951888.19","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vmo",
"VKQ","Invesco Municipal Trust","12.04","666055533.08","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vkq",
"VPV","Invesco Pennsylvania Value Municipal Income Trust","12.46","296916118.24","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vpv",
"IVZ","Invesco Plc","19.85","7975466312.6","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/ivz",
"IQI","Invesco Quality Municipal Income Trust","12.16","643066971.52","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iqi",
"VVR","Invesco Senior Income Trust","4.24","763353318.4","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/vvr",
"VTN","Invesco Trust  for Investment Grade New York Municipal","13.11","255353341.83","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vtn",
"VGM","Invesco Trust for Investment Grade Municipals","12.41","672935923.36","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vgm",
"IIM","Invesco Value Municipal Income Trust","14.47","680907815.46","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iim",
"IRET","Investors Real Estate Trust","61.28","721158237.44","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/iret",
"IRET^C","Investors Real Estate Trust","25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/iret^c",
"NVTA","Invitae Corporation","23.24","1785100700.88","n/a","2015","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/nvta",
"INVH","Invitation Homes Inc.","24.41","12722250121.31","n/a","2017","Finance","Real Estate","https://www.nasdaq.com/symbol/invh",
"IO","Ion Geophysical Corporation","16.05","224950620.75","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/io",
"IQV","IQVIA Holdings, Inc.","144.3","28542435959.7","n/a","2013","Health Care","Biotechnology: Commercial Physical & Biological Resarch","https://www.nasdaq.com/symbol/iqv",
"IRM","Iron Mountain Incorporated","35.78","10246164567.1","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/irm",
"IRS","IRSA Inversiones Y Representaciones S.A.","10.77","623234547.42","n/a","n/a","Consumer Services","Homebuilding","https://www.nasdaq.com/symbol/irs",
"ICL","Israel Chemicals Shs","5.29","6772793067.63","n/a","2014","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/icl",
"STAR          ","iStar Inc.","8.37","570483723.87","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/star",
"STAR^D","iStar Inc.","25.46","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/star^d",
"STAR^G","iStar Inc.","24.8688","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/star^g",
"STAR^I","iStar Inc.","25.15","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/star^i",
"ITCB","Ita? CorpBanca","13.1","4475019028.6","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/itcb",
"ITUB","Itau Unibanco Banco Holding SA","8.77","85260805758.36","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/itub",
"ITT","ITT Inc.","59.33","5185442000","n/a","2011","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/itt",
"IVH","Ivy High Income Opportunities Fund","13.8","228625814.4","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/ivh",
"JPM","J P Morgan Chase & Co","105.14","344253775071.64","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/jpm",
"JPM^A","J P Morgan Chase & Co","25.6768","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/jpm^a",
"JPM^C","J P Morgan Chase & Co","26.57","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jpm^c",
"JPM^D","J P Morgan Chase & Co","25.99","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jpm^d",
"JPM^E","J P Morgan Chase & Co","26.09","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jpm^e",
"JPM^F","J P Morgan Chase & Co","26.02","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jpm^f",
"JPM^G","J P Morgan Chase & Co","26.27","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jpm^g",
"JPM^H","J P Morgan Chase & Co","26.35","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/jpm^h",
"JAX","J. Alexander&#39;s Holdings, Inc.","9.9","145482242.4","n/a","2015","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/jax",
"JILL","J. Jill, Inc.","5.39","235394333.02","n/a","2017","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/jill",
"JCP","J.C. Penney Company, Inc. Holding Company","1.45","458709756.2","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/jcp",
"SJM","J.M. Smucker Company (The)","116.05","13200288984.3","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/sjm",
"JBL","Jabil Inc.","28.31","4379985273.68","n/a","1993","Technology","Electrical Products","https://www.nasdaq.com/symbol/jbl",
"JEC","Jacobs Engineering Group Inc.","76.59","10685595771.27","n/a","n/a","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/jec",
"JAG","Jagged Peak Energy Inc.","10.79","2302138991.88","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/jag",
"JHX","James Hardie Industries plc.","12.98","5740585590.74","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/jhx",
"JHG","Janus Henderson Group plc","25.21","4951565780.44","n/a","2017","Finance","Investment Managers","https://www.nasdaq.com/symbol/jhg",
"JOF","Japan Smaller Capitalization Fund Inc","8.89","251888308.77","n/a","1990","n/a","n/a","https://www.nasdaq.com/symbol/jof",
"JBGS","JBG SMITH Properties","41.96","5144044030.2","n/a","2017","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/jbgs",
"JEF","Jefferies Financial Group Inc.","19.38","5858404657.56","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/jef",
"JELD","JELD-WEN Holding, Inc.","18.05","1820436071.2","n/a","2017","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/jeld",
"JCAP","Jernigan Capital, Inc.","20.91","428581856.82","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/jcap",
"JCAP^B","Jernigan Capital, Inc.","25.1701","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jcap^b",
"JT","Jianpu Technology Inc.","4.86","816564811.86","n/a","2017","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/jt",
"JKS","JinkoSolar Holding Company Limited","19.3","756872351.2","n/a","2010","Technology","Semiconductors","https://www.nasdaq.com/symbol/jks",
"JMP","JMP Group LLC","3.8","80784135.4","n/a","2007","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/jmp",
"JMPB","JMP Group LLC","25.53","0","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/jmpb",
"JMPD","JMP Group LLC","25.065","0","n/a","2017","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/jmpd",
"JBT","John Bean Technologies Corporation","93.46","2946081354.42","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/jbt",
"BTO","John Hancock Financial Opportunities Fund","32.85","613324676.7","n/a","1994","n/a","n/a","https://www.nasdaq.com/symbol/bto",
"HEQ","John Hancock Hedged Equity & Income Fund","14.9","181988063.6","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/heq",
"JHS","John Hancock Income Securities Trust","14.14","164682711.9","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jhs",
"JHI","John Hancock Investors Trust","15.85","138006346.25","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jhi",
"HPF","John Hancock Pfd Income Fund II","22.1701","471869827.2864","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/hpf",
"HPI","John Hancock Preferred Income Fund","22.83","594047695.38","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/hpi",
"HPS","John Hancock Preferred Income Fund III","18.93","597752326.05","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/hps",
"PDT","John Hancock Premium Dividend Fund","16.58","803948216.88","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pdt",
"HTD","John Hancock Tax Advantaged Dividend Income Fund","25","884624025","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/htd",
"HTY","John Hancock Tax-Advantaged Global Shareholder Yield Fund","6.89","76062010.31","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hty",
"JW.A","John Wiley & Sons, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jw.a",
"JW.B","John Wiley & Sons, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jw.b",
"JNJ","Johnson & Johnson","137.71","366690348782.91","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/jnj",
"JCI","Johnson Controls International plc","36.5","33207610319.5","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/jci",
"JLL","Jones Lang LaSalle Incorporated","153.95","7023452555.65","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/jll",
"JMEI","Jumei International Holding Limited","2.28","341737072.68","n/a","2014","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/jmei",
"JNPR","Juniper Networks, Inc.","27.13","9439136339.8","n/a","1999","Technology","Computer Communications Equipment","https://www.nasdaq.com/symbol/jnpr",
"JP","Jupai Holdings Limited","3.7","122188637.2","n/a","2015","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/jp",
"JE","Just Energy Group, Inc.","3.43","512846156.9","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/je",
"JE^A","Just Energy Group, Inc.","20.8987","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/je^a",
"LRN","K12 Inc","34.25","1378114578.5","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/lrn",
"KAI","Kadant Inc","88.5","988937143.5","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/kai",
"KDMN","Kadmon Holdings, Inc.","2.84","360423042.48","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/kdmn",
"KAMN","Kaman Corporation","58.84","1639383781.32","n/a","n/a","Consumer Durables","Industrial Specialties","https://www.nasdaq.com/symbol/kamn",
"KSU","Kansas City Southern","116.83","11793001870.65","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/ksu",
"KSU^","Kansas City Southern","26.45","0","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/ksu^",
"KAR","KAR Auction Services, Inc","52.68","7001227577.4","n/a","2009","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/kar",
"KMF","Kayne Anderson Midstream Energy Fund, Inc","12.09","590941052.91","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/kmf",
"KYN","Kayne Anderson MLP/Midstream Investment Company","16.29","2058031587.06","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/kyn",
"KYN^F","Kayne Anderson MLP/Midstream Investment Company","25.185","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kyn^f",
"KB","KB Financial Group Inc","39.22","15513521868.34","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/kb",
"KBH","KB Home","24.15","2099967886.8","n/a","1986","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/kbh",
"KBR","KBR, Inc.","19.46","2744071257.76","n/a","2006","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/kbr",
"FRAC","Keane Group, Inc.","11.19","1168293303.99","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/frac",
"K","Kellogg Company","56.35","19368561818.2","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/k",
"KEM","Kemet Corporation","17.99","1039584747.88","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/kem",
"KMPA","Kemper Corporation","25.3831","0","n/a","2014","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/kmpa",
"KMPR","Kemper Corporation","77.52","5033647788.24","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/kmpr",
"KMT","Kennametal Inc.","38.14","3136390076.1","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/kmt",
"KW","Kennedy-Wilson Holdings Inc.","21.53","3078369174.62","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/kw",
"KEN","Kenon Holdings Ltd.","19.4","1044238930.6","n/a","2015","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ken",
"KDP","Keurig Dr Pepper Inc.","27.37","38484451229.77","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/kdp",
"KEG","Key Energy Services, Inc.","4.22","85980292.94","n/a","2016","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/keg",
"KEY","KeyCorp","16.47","16614734423.67","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/key",
"KEY^I","KeyCorp","26.65","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/key^i",
"KEY^J","KeyCorp","24.86","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/key^j",
"KEYS","Keysight Technologies Inc.","89.29","16785513076.67","n/a","2014","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/keys",
"KRC","Kilroy Realty Corporation","75.88","7661165013.6","n/a","1997","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/krc",
"KRP","Kimbell Royalty Partners","18.21","683052456.45","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/krp",
"KMB","Kimberly-Clark Corporation","122.65","42205015702.3","n/a","n/a","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/kmb",
"KIM","Kimco Realty Corporation","18.32","7731021038.8","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/kim",
"KIM^I","Kimco Realty Corporation","25.33","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kim^i",
"KIM^J","Kimco Realty Corporation","24.86","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kim^j",
"KIM^K","Kimco Realty Corporation","24.99","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kim^k",
"KIM^L","Kimco Realty Corporation","23.71","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kim^l",
"KIM^M","Kimco Realty Corporation","23.53","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kim^m",
"KMI","Kinder Morgan, Inc.","20.05","45385369432.4","n/a","2011","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/kmi",
"KFS","Kingsway Financial Services, Inc.","2.87","62530779.36","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/kfs",
"KGC","Kinross Gold Corporation","3.36","4207465977.12","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/kgc",
"KEX","Kirby Corporation","75.62","4527766556.24","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/kex",
"KL","Kirkland Lake Gold Ltd.","31.01","6505491303.85","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/kl",
"KRG","Kite Realty Group Trust","16.12","1353022479.64","n/a","2004","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/krg",
"KKR","KKR & Co. Inc.","23.25","19357210371","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/kkr",
"KKR^A","KKR & Co. Inc.","26.86","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kkr^a",
"KKR^B","KKR & Co. Inc.","26.84","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kkr^b",
"KIO","KKR Income Opportunities Fund","15.65","318325929.75","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/kio",
"KREF","KKR Real Estate Finance Trust Inc.","20.01","1185514400.97","n/a","2017","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/kref",
"KNX","Knight Transportation, Inc.","32.52","5626249070.28","n/a","2017","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/knx",
"KNL","Knoll, Inc.","19.03","946972135.01","n/a","2004","Consumer Durables","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/knl",
"KNOP","KNOT Offshore Partners LP","19.12","625111077.28","n/a","2013","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/knop",
"KN","Knowles Corporation","17.66","1593225385.58","n/a","2014","Consumer Non-Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/kn",
"KSS","Kohl&#39;s Corporation","70.87","11563574703.48","n/a","1992","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/kss",
"PHG","Koninklijke Philips N.V.","39.63","36229115367.81","n/a","n/a","Energy","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/phg",
"KOP","Koppers Holdings Inc.","26.42","542897816.48","n/a","2006","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/kop",
"KEP","Korea Electric Power Corporation","13.17","16909333788.18","n/a","1994","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/kep",
"KF","Korea Fund, Inc. (The)","30.05","157566964.65","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/kf",
"KFY","Korn Ferry ","45.71","2579389519.56","n/a","1999","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/kfy",
"KOS","Kosmos Energy Ltd.","6.59","2644251569.65","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/kos",
"KRA","Kraton Corporation","33.32","1063700982.68","n/a","2009","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/kra",
"KR","Kroger Company (The)","23.76","18954374511.6","n/a","n/a","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/kr",
"KRO","Kronos Worldwide Inc","14.17","1642412080.66","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/kro",
"KT","KT Corporation","12.35","6449461657.6","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/kt",
"LB","L Brands, Inc.","27.02","7435820454.16","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/lb",
"SCX","L.S. Starrett Company (The)","7.55","52036298.75","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/scx",
"LLL","L3 Technologies, Inc.","209.52","16629255644.4","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/lll",
"LH","Laboratory Corporation of America Holdings","157.58","15549712331.8","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/lh",
"LADR","Ladder Capital Corp","16.89","2030428225.35","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ladr",
"LAIX","LAIX Inc.","11.11","532749286.41","n/a","2018","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/laix",
"LW","Lamb Weston Holdings, Inc.","74.36","10893148317.48","n/a","2016","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/lw",
"LCI","Lannett Co Inc","7.79","306043735.76","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/lci",
"LPI","Laredo Petroleum, Inc.","3.04","727183075.36","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/lpi",
"LVS","Las Vegas Sands Corp.","64.85","50262120838.15","n/a","2004","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/lvs",
"LTM","LATAM Airlines Group S.A.","10.74","6512818622.82","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/ltm",
"LGI","Lazard Global Total Return and Income Fund","15.56","149457487.72","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/lgi",
"LAZ","Lazard Ltd.","37.37","4273838660.26","n/a","2005","Finance","Investment Managers","https://www.nasdaq.com/symbol/laz",
"LOR","Lazard World Dividend & Income Fund, Inc.","9.96","68526622.68","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/lor",
"LZB","La-Z-Boy Incorporated","32.93","1536496676.4","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/lzb",
"LCII","LCI Industries ","75.83","1885373498.63","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/lcii",
"LEAF","Leaf Group Ltd.","8.13","207634305.75","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/leaf",
"LEA","Lear Corporation","141.89","8856115856.07","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/lea",
"LEE","Lee Enterprises, Incorporated","3.45","199031986.95","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/lee",
"LGC","Legacy Acquisition Corp.","10.0436","301308000","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/lgc",
"LGC.U","Legacy Acquisition Corp.","n/a","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/lgc.u",
"LGC.WS","Legacy Acquisition Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lgc.ws",
"LM","Legg Mason, Inc.","28.3","2420783924.4","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/lm",
"LMHA","Legg Mason, Inc.","26.1999","0","n/a","2016","Finance","Investment Managers","https://www.nasdaq.com/symbol/lmha",
"LMHB","Legg Mason, Inc.","24.24","0","n/a","2016","Finance","Investment Managers","https://www.nasdaq.com/symbol/lmhb",
"LEG","Leggett & Platt, Incorporated","42.47","5572983008.33","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/leg",
"JBK","Lehman ABS Corporation","26.5","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/jbk",
"KTH","Lehman ABS Corporation","31.12","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/kth",
"KTN","Lehman ABS Corporation","31.001","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/ktn",
"KTP","Lehman ABS Corporation","7.4","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/ktp",
"LDOS","Leidos Holdings, Inc.","63.64","9140474655.72","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/ldos",
"LEJU","Leju Holdings Limited","1.6","217222339.2","n/a","2014","Finance","Real Estate","https://www.nasdaq.com/symbol/leju",
"LC","LendingClub Corporation","3.12","1340886190.8","n/a","2014","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/lc",
"LEN","Lennar Corporation","48.86","15815703155.98","n/a","n/a","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/len",
"LEN.B","Lennar Corporation","n/a","0","n/a","n/a","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/len.b",
"LII","Lennox International, Inc.","267.46","10664165654.92","n/a","1999","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/lii",
"LHC","Leo Holdings Corp.","10.1","252500000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/lhc",
"LHC.U","Leo Holdings Corp.","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/lhc.u",
"LHC.WS","Leo Holdings Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lhc.ws",
"LEVI","Levi Strauss & Co","23","843333341","n/a","2019","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/levi",
"LXP","Lexington Realty Trust","9.32","2192835546.88","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lxp",
"LXP^C","Lexington Realty Trust","53.063","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lxp^c",
"LPL","LG Display Co., Ltd.","8.86","6340494204","n/a","2004","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/lpl",
"USA","Liberty All-Star Equity Fund","6.21","1223384444.46","n/a","1986","n/a","n/a","https://www.nasdaq.com/symbol/usa",
"ASG","Liberty All-Star Growth Fund, Inc.","5.62","208519584.98","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/asg",
"LBRT","Liberty Oilfield Services Inc.","15.42","1731883051.92","n/a","2018","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/lbrt",
"LPT","Liberty Property Trust","49.16","7273349226.08","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/lpt",
"LSI","Life Storage, Inc.","97.96","4568139585.88","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/lsi",
"LITB","LightInTheBox Holding Co., Ltd.","1.37","92893909.01","n/a","2013","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/litb",
"LNC","Lincoln National Corporation","61.12","12486437789.44","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/lnc",
"LNC.WS","Lincoln National Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lnc.ws",
"LIN","Linde plc","178.02","97004900452.5","n/a","2018","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/lin",
"LNN","Lindsay Corporation","94.49","1019201172.11","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/lnn",
"LN","LINE Corporation","34.57","8237886635.68","n/a","2016","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/ln",
"LGF.A","Lions Gate Entertainment Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/lgf.a",
"LGF.B","Lions Gate Entertainment Corporation","n/a","0","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/lgf.b",
"LAD","Lithia Motors, Inc.","92.79","2147878609.02","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/lad",
"LAC","Lithium Americas Corp.","4.37","387775826.19","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/lac",
"LYV","Live Nation Entertainment, Inc.","64.77","13659878033.25","n/a","n/a","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/lyv",
"LTHM","Livent Corporation","12.01","1753460000","n/a","2018","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/lthm",
"RAMP","LiveRamp Holdings, Inc.","54.23","3716277995.32","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/ramp",
"LYG","Lloyds Banking Group Plc","3.32","59081558189.24","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/lyg",
"SCD","LMP Capital and Income Fund Inc.","13.04","234502623.2","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/scd",
"LMT","Lockheed Martin Corporation","303.1","85719010232.8","n/a","n/a","Capital Goods","Military/Government/Technical","https://www.nasdaq.com/symbol/lmt",
"L","Loews Corporation","48.19","14996728000","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/l",
"LOMA","Loma Negra Compania Industrial Argentina Sociedad Anonima","10.97","1307624000","n/a","2017","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/loma",
"LPX","Louisiana-Pacific Corporation","24.13","2978495936.57","n/a","n/a","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/lpx",
"LOW","Lowe&#39;s Companies, Inc.","109.91","88253004639.37","n/a","n/a","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/low",
"LXU","Lsb Industries Inc.","6.23","179099797.03","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/lxu",
"LKSD","LSC Communications, Inc.","6.76","225215815.24","n/a","2016","Miscellaneous","Publishing","https://www.nasdaq.com/symbol/lksd",
"LTC","LTC Properties, Inc.","45.82","1819693005.72","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ltc",
"LUB","Luby&#39;s, Inc.","1.37","40775156.56","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/lub",
"LL","Lumber Liquidators Holdings, Inc","10.15","290698679.6","n/a","2007","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/ll",
"LXFR","Luxfer Holdings PLC","25.68","693372788.64","n/a","2012","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/lxfr",
"LXFT","Luxoft Holding, Inc.","58.67","1994363971.03","n/a","2013","Technology","EDP Services","https://www.nasdaq.com/symbol/lxft",
"LDL","Lydall, Inc.","23.7","414854208.9","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/ldl",
"WLH","Lyon William Homes","15.13","513833379.64","n/a","2013","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/wlh",
"LYB","LyondellBasell Industries NV","89.36","33166589341.28","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/lyb",
"MTB","M&T Bank Corporation","161.74","22394727103.72","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mtb",
"MTB^","M&T Bank Corporation","1010.051","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mtb^",
"MTB^C","M&T Bank Corporation","1011.57","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mtb^c",
"MDC","M.D.C. Holdings, Inc.","29.17","1789249908.17","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/mdc",
"MHO","M/I Homes, Inc.","26.62","732617112.48","n/a","1993","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/mho",
"MAC","Macerich Company (The)","43.57","6150397536.01","n/a","1994","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/mac",
"CLI","Mack-Cali Realty Corporation","22.14","1999701272.16","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/cli",
"MFD","Macquarie First Trust Global","10.93","93423541.06","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/mfd",
"MGU","Macquarie Global Infrastructure Total Return Fund Inc.","22.44","279788494.92","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/mgu",
"MIC","Macquarie Infrastructure Corporation ","41.38","3552901324.38","n/a","2004","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/mic",
"BMA","Macro Bank Inc.","44.48","2978661112.96","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/bma",
"M","Macy&#39;s Inc","24.67","7585216810.8","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/m",
"MCN","Madison Covered Call & Equity Strategy Fund","6.8","142439083.2","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/mcn",
"MMP","Magellan Midstream Partners L.P.","61.24","13987425930.72","n/a","n/a","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/mmp",
"MGA","Magna International, Inc.","50.88","16549228596.48","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/mga",
"MX","MagnaChip Semiconductor Corporation","7.76","264549093.28","n/a","2011","Technology","Semiconductors","https://www.nasdaq.com/symbol/mx",
"MGY","Magnolia Oil & Gas Corporation","12.47","3113502841.26","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mgy",
"MGY.WS","Magnolia Oil & Gas Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mgy.ws",
"MH^A","Maiden Holdings, Ltd.","6.97","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mh^a",
"MH^C","Maiden Holdings, Ltd.","5.24","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mh^c",
"MH^D","Maiden Holdings, Ltd.","5.26","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mh^d",
"MHLA","Maiden Holdings, Ltd.","16.03","0","n/a","2016","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/mhla",
"MHNC","Maiden Holdings, Ltd.","20.23","0","n/a","2013","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/mhnc",
"MAIN","Main Street Capital Corporation","37.6","2326999252.8","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/main",
"MMD","MainStay MacKay DefinedTerm Municipal Opportunitie","20.21","557030263.31","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/mmd",
"MNK","Mallinckrodt plc","22.8","1903914182.4","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mnk",
"MANU","Manchester United Ltd.","19.67","3236234091.3","n/a","2012","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/manu",
"MTW","Manitowoc Company, Inc. (The)","16.82","598845218.48","n/a","n/a","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/mtw",
"MN","Manning & Napier, Inc.","2.14","33564986.22","n/a","2011","Finance","Investment Managers","https://www.nasdaq.com/symbol/mn",
"MAN","ManpowerGroup","83.49","5012720898.24","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/man",
"MFC","Manulife Financial Corp","17.42","34215682930.26","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/mfc",
"MRO","Marathon Oil Corporation","17.13","14020981382.67","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mro",
"MPC","Marathon Petroleum Corporation","59.92","40305259005.2","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/mpc",
"MMI","Marcus & Millichap, Inc.","41.43","1616832058.05","n/a","2013","Finance","Real Estate","https://www.nasdaq.com/symbol/mmi",
"MCS","Marcus Corporation (The)","39.37","1214246941.58","n/a","n/a","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/mcs",
"MPX","Marine Products Corporation","13.45","459921889.2","n/a","n/a","Capital Goods","Marine Transportation","https://www.nasdaq.com/symbol/mpx",
"HZO","MarineMax, Inc.","19","433902658","n/a","1998","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/hzo",
"MKL","Markel Corporation","978.74","13570537424.36","n/a","1986","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/mkl",
"VAC","Marriot Vacations Worldwide Corporation","97.26","4386366476.88","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/vac",
"MMC","Marsh & McLennan Companies, Inc.","94.46","47712594250.8","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/mmc",
"MLM","Martin Marietta Materials, Inc.","205.43","12825107475.64","n/a","1994","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/mlm",
"MAS","Masco Corporation","39.58","11648158617.74","n/a","n/a","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/mas",
"DOOR","Masonite International Corporation","50.74","1296929013.12","n/a","n/a","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/door",
"MTZ","MasTec, Inc.","49.01","3726121497.8","n/a","n/a","Basic Industries","Water Supply","https://www.nasdaq.com/symbol/mtz",
"MA","Mastercard Incorporated","239.26","242666498703.44","n/a","2006","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/ma",
"MTDR","Matador Resources Company","19.46","2264916648.82","n/a","2012","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mtdr",
"MTRN","Materion Corporation","56.77","1153404491.96","n/a","n/a","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/mtrn",
"MATX","Matson, Inc.","36.98","1583715353.66","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/matx",
"MLP","Maui Land & Pineapple Company, Inc.","11.3","217246952.2","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/mlp",
"MAXR","Maxar Technologies Inc.","4.44","264533068.8","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/maxr",
"MMS","Maximus, Inc.","70.74","4513068963.72","n/a","1997","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/mms",
"MXL","MaxLinear, Inc","25.97","1806403730.25","n/a","2010","Technology","Semiconductors","https://www.nasdaq.com/symbol/mxl",
"MBI","MBIA, Inc.","9.41","848590337.12","n/a","1987","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/mbi",
"MKC","McCormick & Company, Incorporated","151.01","18491981648.45","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/mkc",
"MKC.V","McCormick & Company, Incorporated","n/a","0","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/mkc.v",
"MDR","McDermott International, Inc.","8.16","1481781988.8","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/mdr",
"MCD","McDonald&#39;s Corporation","188.35","144147519482.2","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/mcd",
"MUX","McEwen Mining Inc.","1.48","531502441.08","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/mux",
"MCK","McKesson Corporation","114.79","22019622972.88","n/a","n/a","Health Care","Other Pharmaceuticals","https://www.nasdaq.com/symbol/mck",
"MDU","MDU Resources Group, Inc.","25.68","5047787941.68","n/a","n/a","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/mdu",
"MTL","Mechel PAO","2.05","512013016.35","n/a","2004","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/mtl",
"MTL^","Mechel PAO","0.73","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mtl^",
"MRT","MedEquities Realty Trust, Inc.","11.04","351520787.04","n/a","2016","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/mrt",
"MPW","Medical Properties Trust, Inc.","18.83","7175697478.39","n/a","2005","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/mpw",
"MED","MEDIFAST INC","129.57","1538053429.08","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/med",
"MCC","Medley Capital Corporation","3.12","169959538.32","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/mcc",
"MCV","Medley Capital Corporation","24.43","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mcv",
"MCX","Medley Capital Corporation","25.18","0","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/mcx",
"MDLQ","Medley LLC","18","0","n/a","2017","Finance","Investment Managers","https://www.nasdaq.com/symbol/mdlq",
"MDLX","Medley LLC","17.5878","0","n/a","2016","Finance","Investment Managers","https://www.nasdaq.com/symbol/mdlx",
"MDLY","Medley Management Inc.","3.23","97976287.68","n/a","2014","Finance","Investment Managers","https://www.nasdaq.com/symbol/mdly",
"MD","Mednax, Inc","27.8","2442757866.4","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/md",
"MDT","Medtronic plc","90.4","121240047688","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/mdt",
"MFAC","Megalith Financial Acquisition Corp.","9.98","211187887.78","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/mfac",
"MFAC.U","Megalith Financial Acquisition Corp.","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/mfac.u",
"MFAC.WS","Megalith Financial Acquisition Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mfac.ws",
"MRK","Merck & Company, Inc.","83.21","214783341828.68","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/mrk",
"MCY","Mercury General Corporation","50","2767003850","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/mcy",
"MDP","Meredith Corporation","56.09","2528399723.41","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/mdp",
"MTH","Meritage Corporation","45.28","1733648581.76","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/mth",
"MTOR","Meritor, Inc.","20.99","1750263240.24","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/mtor",
"MER^K","Merrill Lynch & Co., Inc.","25.9928","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mer^k",
"PIY","Merrill Lynch Depositor, Inc.","11.9238","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/piy",
"MTR","Mesa Royalty Trust","12.49","23276239.1","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mtr",
"MSB","Mesabi Trust","29.8","390976298","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/msb",
"MEI","Methode Electronics, Inc.","29.15","1078169650.8","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/mei",
"MET","MetLife, Inc.","43.93","42052908089.06","n/a","2000","Finance","Life Insurance","https://www.nasdaq.com/symbol/met",
"MET^A","MetLife, Inc.","23.49","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/met^a",
"MET^E","MetLife, Inc.","25.87","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/met^e",
"MCB","Metropolitan Bank Holding Corp.","35.41","292603205.13","n/a","2017","Finance","Major Banks","https://www.nasdaq.com/symbol/mcb",
"MTD","Mettler-Toledo International, Inc.","734.45","18242339607.2","n/a","1997","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/mtd",
"MXE","Mexico Equity and Income Fund, Inc. (The)","10.681","55237838.238","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mxe",
"MXF","Mexico Fund, Inc. (The)","14.04","210673344.96","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mxf",
"MFA","MFA Financial, Inc.","7.31","3292985897.77","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/mfa",
"MFA^B","MFA Financial, Inc.","25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mfa^b",
"MFO","MFA Financial, Inc.","26.02","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/mfo",
"MFCB","MFC Bancorp Ltd.","7.206","90325776.006","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/mfcb",
"MCR","MFS Charter Income Trust","7.93","372629954.58","n/a","1989","n/a","n/a","https://www.nasdaq.com/symbol/mcr",
"MGF","MFS Government Markets Income Trust","4.47","145726992.99","n/a","1987","n/a","n/a","https://www.nasdaq.com/symbol/mgf",
"MIN","MFS Intermediate Income Trust","3.79","446147918.91","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/min",
"MMT","MFS Multimarket Income Trust","5.73","385057403.85","n/a","1987","n/a","n/a","https://www.nasdaq.com/symbol/mmt",
"MFM","MFS Municipal Income Trust","6.84","281723396.04","n/a","1986","n/a","n/a","https://www.nasdaq.com/symbol/mfm",
"MFV","MFS Special Value Trust","5.55","39581390.1","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mfv",
"MTG","MGIC Investment Corporation","13.55","4822786094.15","n/a","1991","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/mtg",
"MGP","MGM Growth Properties LLC","32.39","2930037166.74","n/a","2016","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/mgp",
"MGM","MGM Resorts International","26.77","14373278423.22","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/mgm",
"MFGP","Micro Focus Intl PLC","26.75","10981097185.5","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mfgp",
"MAA","Mid-America Apartment Communities, Inc.","109.94","12520884099.6","n/a","1994","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/maa",
"MAA^I","Mid-America Apartment Communities, Inc.","64.8699","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/maa^i",
"MSL","MidSouth Bancorp","11.86","198230068.06","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/msl",
"MPO","MIDSTATES PETROLEUM COMPANY, INC.","9.75","199034891.25","n/a","2016","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mpo",
"MCRN","Milacron Holdings Corp.","12","842012616","n/a","2015","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/mcrn",
"MLR","Miller Industries, Inc.","31","353403162","n/a","n/a","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/mlr",
"HIE","Miller/Howard High Income Equity Fund","11.48","157719862.72","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/hie",
"MTX","Minerals Technologies Inc.","59.33","2090214766.94","n/a","1992","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/mtx",
"MG","Mistras Group Inc","13.56","387310320.48","n/a","2009","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/mg",
"MUFG","Mitsubishi UFJ Financial Group Inc","5.11","66034026886.94","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/mufg",
"MIXT","MiX Telematics Limited","16.34","372392521.6","n/a","2013","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/mixt",
"MFG","Mizuho Financial Group, Inc.","3.13","39685761225.33","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/mfg",
"MBT","Mobile TeleSystems OJSC","7.86","7409011741.74","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/mbt",
"MODN","Model N, Inc.","17.27","544739527.64","n/a","2013","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/modn",
"MOD","Modine Manufacturing Company","14.24","720948715.04","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/mod",
"MC","Moelis & Company","43.01","1959666479.43","n/a","2014","Finance","Investment Managers","https://www.nasdaq.com/symbol/mc",
"MOGU","MOGU Inc.","13.89","1484785828.92","n/a","2018","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/mogu",
"MHK","Mohawk Industries, Inc.","127.36","9209388481.92","n/a","n/a","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/mhk",
"MOH","Molina Healthcare Inc","142.69","8936610204.12","n/a","2003","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/moh",
"TAP","Molson Coors Brewing  Company","60.15","11791963713.3","n/a","n/a","Consumer Non-Durables","Beverages (Production/Distribution)","https://www.nasdaq.com/symbol/tap",
"TAP.A","Molson Coors Brewing  Company","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tap.a",
"MNR","Monmouth Real Estate Investment Corporation","13.3","1238640039","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/mnr",
"MNR^C","Monmouth Real Estate Investment Corporation","24.03","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mnr^c",
"MR","Montage Resources Corporation","14.95","526146099.05","n/a","2014","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mr",
"MCO","Moody&#39;s Corporation","185.05","34939275325.9","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/mco",
"MOG.A","Moog Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mog.a",
"MOG.B","Moog Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mog.b",
"MS","Morgan Stanley","43.7","74674016677.9","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/ms",
"MS^A","Morgan Stanley","19.56","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ms^a",
"MS^E","Morgan Stanley","28.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ms^e",
"MS^F","Morgan Stanley","27.78","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ms^f",
"MS^G","Morgan Stanley","25.48","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ms^g",
"MS^I","Morgan Stanley","27.11","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ms^i",
"MS^K","Morgan Stanley","25.82","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ms^k",
"APF","Morgan Stanley Asia-Pacific Fund, Inc.","16.45","214260953.9","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/apf",
"CAF","Morgan Stanley China A Share Fund Inc.","23.92","523404642.8","n/a","2006","n/a","n/a","https://www.nasdaq.com/symbol/caf",
"MSD","Morgan Stanley Emerging Markets Debt Fund, Inc.","9.02","183888214.4","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/msd",
"EDD","Morgan Stanley Emerging Markets Domestic Debt Fund, Inc.","6.67","443001470.04","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/edd",
"IIF","Morgan Stanley India Investment Fund, Inc.","21.02","292505869.96","n/a","1994","n/a","n/a","https://www.nasdaq.com/symbol/iif",
"MOSC","Mosaic Acquisition Corp.","9.99","344655000","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/mosc",
"MOSC.U","Mosaic Acquisition Corp.","n/a","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/mosc.u",
"MOSC.WS","Mosaic Acquisition Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mosc.ws",
"MOS","Mosaic Company (The)","27.51","10604293427.49","n/a","n/a","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/mos",
"MSI","Motorola Solutions, Inc.","141.67","23215645370.96","n/a","n/a","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/msi",
"MOV","Movado Group Inc.","33.88","555543878.12","n/a","n/a","Consumer Non-Durables","Consumer Specialties","https://www.nasdaq.com/symbol/mov",
"MPLX","MPLX LP","33.4","26524905523.2","n/a","2012","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/mplx",
"MRC","MRC Global Inc.","18.16","1534670927.76","n/a","2012","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/mrc",
"HJV","MS Structured Asset Corp Saturns GE Cap Corp Series 2002-14","6.5973","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/hjv",
"MSA","MSA Safety Incorporporated","103.92","4003994473.2","n/a","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/msa",
"MSM","MSC Industrial Direct Company, Inc.","83.77","4635859611.64","n/a","1995","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/msm",
"MSCI","MSCI Inc","204.89","17347103435.83","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/msci",
"MSGN","MSG Networks Inc.","22","1647256644","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/msgn",
"MLI","Mueller Industries, Inc.","31.46","1781414068.72","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/mli",
"MWA","Mueller Water Products Inc","10.28","1626413849.92","n/a","2006","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/mwa",
"MVF","MuniVest Fund, Inc.","9.02","584824066.42","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mvf",
"MZA","MuniYield Arizona Fund, Inc.","13.839","64002095.157","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/mza",
"MUR","Murphy Oil Corporation","29.03","5040204798.74","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mur",
"MUSA","Murphy USA Inc.","84.82","2729805233.38","n/a","2013","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/musa",
"MVO","MV Oil Trust","8.64","99360000","n/a","2007","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/mvo",
"MVC","MVC Capital, Inc.","9.145","162096204.11","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mvc",
"MVCD","MVC Capital, Inc.","25.47","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/mvcd",
"MYE","Myers Industries, Inc.","17.16","607260482.4","n/a","n/a","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/mye",
"MYOV","Myovant Sciences Ltd.","24.89","1762524145.49","n/a","2016","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/myov",
"NBR","Nabors Industries Ltd.","3.79","1359821585.25","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/nbr",
"NBR^A","Nabors Industries Ltd.","28.95","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nbr^a",
"NC","NACCO Industries, Inc.","38.02","205978406.66","n/a","n/a","Consumer Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/nc",
"NTP","Nam Tai Property Inc.","9.9","378114570.9","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/ntp",
"NTEST","NASDAQ TEST STOCK","24.99","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ntest",
"NTEST.A","NASDAQ TEST STOCK","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ntest.a",
"NTEST.B","NASDAQ TEST STOCK","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ntest.b",
"NTEST.C","NASDAQ TEST STOCK","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ntest.c",
"NBHC","National Bank Holdings Corporation","34","1049331290","n/a","2012","Finance","Major Banks","https://www.nasdaq.com/symbol/nbhc",
"NFG","National Fuel Gas Company","60.5","5219850460","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/nfg",
"NGG","National Grid Transco, PLC","55.4","37784256466","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/ngg",
"NHI","National Health Investors, Inc.","78.54","3375959590.08","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nhi",
"NOV","National Oilwell Varco, Inc.","27.16","10414049677.36","n/a","n/a","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/nov",
"NPK","National Presto Industries, Inc.","106.95","746627040.75","n/a","n/a","Capital Goods","Ordnance And Accessories","https://www.nasdaq.com/symbol/npk",
"NNN","National Retail Properties","54.06","8730515872.74","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nnn",
"NNN^E","National Retail Properties","25.31","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nnn^e",
"NNN^F","National Retail Properties","24.6","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nnn^f",
"SID","National Steel Company","4.33","5975895988.51","n/a","n/a","Capital Goods","Steel/Iron Ore","https://www.nasdaq.com/symbol/sid",
"NSA","National Storage Affiliates Trust","28.69","1626709831.29","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nsa",
"NSA^A","National Storage Affiliates Trust","24.935","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nsa^a",
"NGS","Natural Gas Services Group, Inc.","18.1","238794096.4","n/a","2002","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/ngs",
"NGVC","Natural Grocers by Vitamin Cottage, Inc.","11.57","259245472.72","n/a","2012","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/ngvc",
"NRP","Natural Resource Partners LP","42.12","516441701.88","n/a","2002","Energy","Coal Mining","https://www.nasdaq.com/symbol/nrp",
"NTZ","Natuzzi, S.p.A.","4.97","54523926.73","n/a","1993","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/ntz",
"NLS","Nautilus Group, Inc. (The)","5.58","165112322.76","n/a","n/a","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/nls",
"NCI","Navigant Consulting, Inc.","19.75","800265971","n/a","n/a","Consumer Services","Professional Services","https://www.nasdaq.com/symbol/nci",
"NVGS","Navigator Holdings Ltd.","11.18","622237478.72","n/a","2013","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/nvgs",
"NNA","Navios Maritime Acquisition Corporation","6.04","80303394.56","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/nna",
"NM","Navios Maritime Holdings Inc.","2.62","3267305.06","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/nm",
"NM^G","Navios Maritime Holdings Inc.","8.78","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nm^g",
"NM^H","Navios Maritime Holdings Inc.","6.4595","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nm^h",
"NMM","Navios Maritime Partners LP","0.9051","151685495.3964","n/a","2007","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/nmm",
"NAV","Navistar International Corporation","32.76","3245385026.52","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/nav",
"NAV^D","Navistar International Corporation","24.7","0","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/nav^d",
"NCS","NCI Building Systems, Inc.","6.19","776695567.21","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/ncs",
"NCR","NCR Corporation","28.67","3410083023.18","n/a","n/a","Miscellaneous","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/ncr",
"NP","Neenah, Inc.","66.22","1116469200","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/np",
"NNI","Nelnet, Inc.","55.56","2233103022.84","n/a","2003","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/nni",
"NPTN","NeoPhotonics Corporation","6.27","291095233.44","n/a","2011","Technology","Semiconductors","https://www.nasdaq.com/symbol/nptn",
"NETS","Netshoes (Cayman) Limited","1.54","47826615.76","n/a","2017","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/nets",
"NVRO","Nevro Corp.","61.77","1876447639.29","n/a","2014","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/nvro",
"HYB","New America High Income Fund, Inc. (The)","8.56","200037938.08","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/hyb",
"NFC","New Frontier Corporation","9.94","402197250","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/nfc",
"NFC.U","New Frontier Corporation","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/nfc.u",
"NFC.WS","New Frontier Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nfc.ws",
"GF","New Germany Fund, Inc. (The)","14.195","220882915.73","n/a","1990","n/a","n/a","https://www.nasdaq.com/symbol/gf",
"NWHM","New Home Company Inc. (The)","4.85","96548906.35","n/a","2014","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/nwhm",
"IRL","New Ireland Fund, Inc. (The)","8.83","43989099.74","n/a","1990","n/a","n/a","https://www.nasdaq.com/symbol/irl",
"NEWM","New Media Investment Group Inc.","10.61","642021943.42","n/a","2014","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/newm",
"NMFC","New Mountain Finance Corporation","13.66","1098521791.52","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/nmfc",
"NMFX","New Mountain Finance Corporation","25.35","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/nmfx",
"EDU","New Oriental Education & Technology Group, Inc.","88.42","13998646442.2","n/a","2006","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/edu",
"NEWR","New Relic, Inc.","95.42","5472476885.72","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/newr",
"NRZ","New Residential Investment Corp.","17.17","6338006415.77","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nrz",
"SNR","New Senior Investment Group Inc.","5.57","457908831.08","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/snr",
"NYCB","New York Community Bancorp, Inc.","11.66","5449113891.98","n/a","n/a","Finance","Banks","https://www.nasdaq.com/symbol/nycb",
"NYCB^A","New York Community Bancorp, Inc.","26.24","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nycb^a",
"NYCB^U","New York Community Bancorp, Inc.","48.2328","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nycb^u",
"NYT","New York Times Company (The)","33.51","5533904365.29","n/a","n/a","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/nyt",
"NJR","NewJersey Resources Corporation","48.98","4348071809.14","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/njr",
"NEU","NewMarket Corporation","429.94","4810222892.44","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/neu",
"NEM","Newmont Mining Corporation","35.83","19155911461.47","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/nem",
"NR","Newpark Resources, Inc.","9.34","843167696.76","n/a","n/a","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/nr",
"NEXA","Nexa Resources S.A.","12.43","1653766627.7","n/a","2017","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/nexa",
"NXRT","NexPoint Residential Trust, Inc.","37.72","889280156.72","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nxrt",
"NHF","NexPoint Strategic Opportunities Fund","21.78","704417820.48","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nhf",
"NEP","NextEra Energy Partners, LP","46.9","2633430872.8","n/a","2014","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/nep",
"NEE","NextEra Energy, Inc.","189.48","90603178847.4","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/nee",
"NEE^I","NextEra Energy, Inc.","24.7355","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nee^i",
"NEE^J","NextEra Energy, Inc.","24.72","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nee^j",
"NEE^K","NextEra Energy, Inc.","25.24","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nee^k",
"NEE^N","NextEra Energy, Inc.","25.28","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nee^n",
"NEE^R","NextEra Energy, Inc.","61.1","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nee^r",
"NGL","NGL ENERGY PARTNERS LP","14.03","1740193133.69","n/a","2011","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/ngl",
"NGL^B","NGL ENERGY PARTNERS LP","23.9499","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ngl^b",
"NMK^B","Niagara Mohawk Holdings, Inc.","94.5","0","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/nmk^b",
"NMK^C","Niagara Mohawk Holdings, Inc.","94.7722","0","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/nmk^c",
"NLSN","Nielsen N.V.","24.25","8619593945.25","n/a","2011","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/nlsn",
"NKE","Nike, Inc.","84.37","132781298871.65","n/a","n/a","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/nke",
"NINE","Nine Energy Service, Inc.","23.67","713523486.78","n/a","2018","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/nine",
"NIO","NIO Inc.","5.39","5530194147.94","n/a","2018","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/nio",
"NI","NiSource, Inc","28.22","10511790980.3","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/ni",
"NI^B","NiSource, Inc","26.33","0","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/ni^b",
"NL","NL Industries, Inc.","3.84","187113538.56","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/nl",
"NOAH","Noah Holdings Ltd.","50.2","2881498373.2","n/a","2010","Finance","Investment Managers","https://www.nasdaq.com/symbol/noah",
"NE","Noble Corporation","3.07","764889582.07","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/ne",
"NBL","Noble Energy Inc.","25.52","12341073581.76","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/nbl",
"NBLX","Noble Midstream Partners LP","37.55","1494056823.2","n/a","2016","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/nblx",
"NOK","Nokia Corporation","5.81","32489700807.2","n/a","1994","Technology","Radio And Television Broadcasting And Communications Equipment","https://www.nasdaq.com/symbol/nok",
"NOMD","Nomad Foods Limited","20.3","3947377122.5","n/a","2016","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/nomd",
"NMR","Nomura Holdings Inc ADR","3.72","12306279769.56","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/nmr",
"OSB","Norbord Inc.","26.57","2169934250.31","n/a","n/a","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/osb",
"NAO","Nordic American Offshore Ltd.","2.8","173563.6","n/a","2014","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/nao",
"NAT","Nordic American Tankers Limited","1.91","271162062.06","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/nat",
"JWN","Nordstrom, Inc.","43.94","6810821054.7","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/jwn",
"NSC","Norfolk Souther Corporation","193","51618877918","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/nsc",
"NOA","North American Construction Group Ltd.","12.41","312572916.21","n/a","2006","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/noa",
"NRT","North European Oil Royality Trust","6.93","63690788.7","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/nrt",
"NOC","Northrop Grumman Corporation","273.33","46454901669.9","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/noc",
"NRE","NorthStar Realty Europe Corp.","17.81","887072750.46","n/a","2015","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/nre",
"NWN","Northwest Natural Holding Company","64.01","1849663108.71","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/nwn",
"NWE","NorthWestern Corporation","70.65","3561416833.05","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/nwe",
"NCLH","Norwegian Cruise Line Holdings Ltd.","56.5","12301623807.5","n/a","n/a","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/nclh",
"NVS","Novartis AG","94.88","219283945183.52","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nvs",
"NVO","Novo Nordisk A/S","52.09","124383919364.45","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/nvo",
"DNOW","NOW Inc.","14.63","1586465773.97","n/a","2014","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/dnow",
"NRG","NRG Energy, Inc.","42.36","11817407093.76","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/nrg",
"NUS","Nu Skin Enterprises, Inc.","48.95","2709920656.3","n/a","1996","Health Care","Other Pharmaceuticals","https://www.nasdaq.com/symbol/nus",
"NUE","Nucor Corporation","59.49","18131488675.74","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/nue",
"NS","Nustar Energy L.P.","27.71","2986063988.11","n/a","n/a","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/ns",
"NS^A","Nustar Energy L.P.","23.97","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ns^a",
"NS^B","Nustar Energy L.P.","21.95","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ns^b",
"NS^C","Nustar Energy L.P.","24.619","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ns^c",
"NSS","NuStar Logistics, L.P.","25.1132","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nss",
"NTR","Nutrien Ltd.","53.37","32223269531.07","n/a","2018","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/ntr",
"JMLP","Nuveen All Cap Energy MLP Opportunities Fund","7.035","94974054.735","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/jmlp",
"NVG","Nuveen AMT-Free Municipal Credit Income Fund","15.15","3068676359.25","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/nvg",
"NUV","Nuveen AMT-Free Municipal Value Fund","9.83","2033585663.67","n/a","1987","n/a","n/a","https://www.nasdaq.com/symbol/nuv",
"NUW","Nuveen AMT-Free Municipal Value Fund","16.09","247772066.06","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/nuw",
"NEA","Nuveen AMT-Free Quality Municipal Income Fund","13.33","3502066224.51","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/nea",
"NAZ","Nuveen Arizona Quality Municipal Income Fund","12.791","148006681.978","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/naz",
"NKX","Nuveen California AMT-Free Quality Municipal Income Fund","13.99","664809472.66","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/nkx",
"NCB","Nuveen California Municipal Value Fund 2","15.995","52799862.885","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ncb",
"NCA","Nuveen California Municipal Value Fund, Inc.","9.62","270235410.38","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nca",
"NAC","Nuveen California Quality Municipal Income Fund","13.88","2008922618.92","n/a","1999","n/a","n/a","https://www.nasdaq.com/symbol/nac",
"NTC","Nuveen Connecticut Quality Municipal Income Fund","12.1","173380609.6","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/ntc",
"JCE","Nuveen Core Equity Alpha Fund","14.09","225842593.57","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/jce",
"JCO","Nuveen Credit Opportunities 2022 Target Term Fund","9.67","267740542.5","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/jco",
"JQC","Nuveen Credit Strategies Income Fund","7.88","1068601205.2","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/jqc",
"JDD","Nuveen Diversified Dividend and Income Fund","10.43","205851872.31","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/jdd",
"DIAX","Nuveen Dow 30SM Dynamic Overwrite Fund","18.05","651842538","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/diax",
"JEMD","Nuveen Emerging Markets Debt 2022 Target Term Fund","8.72","124133996","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/jemd",
"JMF","Nuveen Energy MLP Total Return Fund","9.9","403788735.9","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/jmf",
"NEV","Nuveen Enhanced Municipal Value Fund","13.92","347304946.56","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/nev",
"JFR","Nuveen Floating Rate Income Fund","9.77","556093432.36","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/jfr",
"JRO","Nuveen Floating Rate Income Opportuntiy Fund","9.75","395276875.5","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/jro",
"NKG","Nuveen Georgia Quality Municipal Income Fund ","11.99","124693757.87","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/nkg",
"JGH","Nuveen Global High Income Fund","15.27","353918791.11","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/jgh",
"JHY","Nuveen High Income 2020 Target Term Fund","10.02","158133796.32","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/jhy",
"JHAA","Nuveen High Income 2023 Target Term Fund","10.2564","71794800","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/jhaa",
"JHD","Nuveen High Income December 2019 Target Term Fund","9.89","267664245.7","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/jhd",
"JHB","Nuveen High Income November 2021 Target Term Fund","9.76","545307264.96","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/jhb",
"NXC","Nuveen Insured California Select Tax-Free Income Portfolio","14.14","89788038.48","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/nxc",
"NXN","Nuveen Insured New York Select Tax-Free Income Portfolio","13.4873","52936236.3335","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/nxn",
"NID","Nuveen Intermediate Duration Municipal Term Fund","13.12","615454739.2","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/nid",
"NMY","Nuveen Maryland Quality Municipal Income Fund","12.54","289669786.56","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/nmy",
"NMT","Nuveen Massachusetts Municipal Income Fund","12.68","118212482.68","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/nmt",
"NUM","Nuveen Michigan Quality Municipal Income Fund","13.27","268410790.49","n/a","1991","n/a","n/a","https://www.nasdaq.com/symbol/num",
"NMS","Nuveen Minnesota Quality Municipal Income Fund","13.47","77888739.42","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/nms",
"NOM","Nuveen Missouri Quality Municipal Income Fund","13.2","30947743.2","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/nom",
"JLS","Nuveen Mortgage Opportunity Term Fund","23.23","369101330.62","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/jls",
"JMM","Nuveen Multi-Market Income Fund","7.08","66993438","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jmm",
"NHA","Nuveen Municipal 2021 Target Term Fund","9.6501","83210023.4211","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/nha",
"NZF","Nuveen Municipal Credit Income Fund","15.13","2150364957.78","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/nzf",
"NMZ","Nuveen Municipal High Income Opportunity Fund","13.58","870191937.3","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/nmz",
"NMI","Nuveen Municipal Income Fund, Inc.","10.72","93653479.04","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/nmi",
"NJV","Nuveen New Jersey Municipal Value Fund","13.2","20207299.2","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/njv",
"NXJ","Nuveen New Jersey Quality Municipal Income Fund","13.84","574474581.36","n/a","2001","n/a","n/a","https://www.nasdaq.com/symbol/nxj",
"NRK","Nuveen New York AMT-Free Quality Municipal","12.74","1111377772.96","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/nrk",
"NYV","Nuveen New York Municipal Value Fund 2","14.0327","32971400.3124","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/nyv",
"NNY","Nuveen New York Municipal Value Fund, Inc.","10.07","153251865.92","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/nny",
"NAN","Nuveen New York Quality Municipal Income Fund","13.4818","415931487.7576","n/a","1999","n/a","n/a","https://www.nasdaq.com/symbol/nan",
"NNC","Nuveen North Carolina Quality Municipal Income Fd","12.74","206814891.92","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/nnc",
"NUO","Nuveen Ohio Quality Municipal Income Fund","14.44","264496830.2","n/a","1991","n/a","n/a","https://www.nasdaq.com/symbol/nuo",
"NPN","Nuveen Pennsylvania Municipal Value Fund","13.6516","16642310.6184","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/npn",
"NQP","Nuveen Pennsylvania Quality Municipal Income Fund","13.2599","495699363.3259","n/a","1991","n/a","n/a","https://www.nasdaq.com/symbol/nqp",
"JPC","Nuveen Preferred & Income Opportunities Fund","9.71","1003359050.79","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/jpc",
"JPS","Nuveen Preferred & Income Securities Fund","9.21","1876812584.28","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/jps",
"JPT","Nuveen Preferred and Income 2022 Term Fund","23.23","158695721.77","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/jpt",
"JPI","Nuveen Preferred and Income Term Fund","22.78","518411476.24","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/jpi",
"NAD","Nuveen Quality Municipal Income Fund","13.6","2745355391.2","n/a","1999","n/a","n/a","https://www.nasdaq.com/symbol/nad",
"JRI","Nuveen Real Asset Income and Growth Fund","16.07","441429722.6","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/jri",
"JRS","Nuveen Real Estate Fund","10.43","301348472.53","n/a","2001","n/a","n/a","https://www.nasdaq.com/symbol/jrs",
"BXMX","Nuveen S&P 500 Buy-Write Income Fund","13.22","1371150981.72","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bxmx",
"SPXX","Nuveen S&P 500 Dynamic Overwrite Fund","15.64","258516078.04","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/spxx",
"NIM","Nuveen Select Maturities Municipal Fund","9.96","123955815.48","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/nim",
"NXP","Nuveen Select Tax Free Income Portfolio","14.55","241098010.5","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/nxp",
"NXQ","Nuveen Select Tax Free Income Portfolio II","13.8","244449432.6","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/nxq",
"NXR","Nuveen Select Tax Free Income Portfolio III","14.72","192030643.2","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/nxr",
"NSL","Nuveen Senior Income Fund","5.87","226649340.64","n/a","1999","n/a","n/a","https://www.nasdaq.com/symbol/nsl",
"JSD","Nuveen Short Duration Credit Opportunities Fund","15.71","158602630.08","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/jsd",
"NBB","Nuveen Taxable Municipal Income Fund","20.53","561616442.23","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/nbb",
"JTD","Nuveen Tax-Advantaged Dividend Growth Fund","16.1","233197874","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jtd",
"JTA","Nuveen Tax-Advantaged Total Return Strategy Fund","11.79","163302075.63","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/jta",
"NTX","Nuveen Texas Quality Municipal Income Fund","13.4223","133667451.003","n/a","1991","n/a","n/a","https://www.nasdaq.com/symbol/ntx",
"NPV","Nuveen Virginia Quality Municipal Income Fund","12.7449","227856470.1903","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/npv",
"NIQ","Nuveenn Intermediate Duration Quality Municipal Term Fund","13.08","171310643.52","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/niq",
"JMT","Nuven Mortgage Opportunity Term Fund 2","22.4","109224796.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/jmt",
"NVT","nVent Electric plc","27.67","4914506939.94","n/a","2018","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/nvt",
"NVR","NVR, Inc.","2768","10040142192","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/nvr",
"OAK","Oaktree Capital Group, LLC","49.96","3571244467","n/a","2012","Finance","Investment Managers","https://www.nasdaq.com/symbol/oak",
"OAK^A","Oaktree Capital Group, LLC","25.13","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/oak^a",
"OAK^B","Oaktree Capital Group, LLC","25.11","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/oak^b",
"OSLE","Oaktree Specialty Lending Corporation","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/osle",
"OMP","Oasis Midstream Partners LP","20.29","685704526.84","n/a","2017","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/omp",
"OAS","Oasis Petroleum Inc.","6.03","1942154544.42","n/a","2010","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/oas",
"OBE","Obsidian Energy Ltd.","0.2628","133340882.5944","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/obe",
"OXY","Occidental Petroleum Corporation","66.63","49831082622.36","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/oxy",
"OII","Oceaneering International, Inc.","15.77","1560099275.23","n/a","n/a","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/oii",
"OZM","Och-Ziff Capital Management Group LLC","16.02","327568132.98","n/a","2007","Finance","Investment Managers","https://www.nasdaq.com/symbol/ozm",
"OCN","Ocwen Financial Corporation","1.87","250427955.91","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/ocn",
"OFG","OFG Bancorp","20.05","1028943924.95","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ofg",
"OFG^A","OFG Bancorp","25.2199","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/ofg^a",
"OFG^B","OFG Bancorp","25.0737","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ofg^b",
"OFG^D","OFG Bancorp","25.4956","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ofg^d",
"OGE","OGE Energy Corp","42.72","8532564496.8","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/oge",
"OIBR.C","Oi S.A.","n/a","0","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/oibr.c",
"OIS","Oil States International, Inc.","17.26","1044163428.18","n/a","2001","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/ois",
"ODC","Oil-Dri Corporation Of America","31.06","234912992","n/a","n/a","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/odc",
"ORI","Old Republic International Corporation","20.94","6340109379.48","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/ori",
"OLN","Olin Corporation","23.35","3850145470.95","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/oln",
"OHI","Omega Healthcare Investors, Inc.","37.76","7711699689.6","n/a","1992","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ohi",
"OMC","Omnicom Group Inc.","73.54","16450221284.92","n/a","n/a","Technology","Advertising","https://www.nasdaq.com/symbol/omc",
"OMN","OMNOVA Solutions Inc.","7.42","332748556.98","n/a","n/a","Basic Industries","Specialty Chemicals","https://www.nasdaq.com/symbol/omn",
"ONDK","On Deck Capital, Inc.","5.52","417526948.8","n/a","2014","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/ondk",
"OGS","ONE Gas, Inc.","86.98","4572822763.66","n/a","2014","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/ogs",
"OLP","One Liberty Properties, Inc.","28.34","555158494.8","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/olp",
"OMAD","One Madison Corporation","10.24","422400000","n/a","2018","Capital Goods","Containers/Packaging","https://www.nasdaq.com/symbol/omad",
"OMAD.U","One Madison Corporation","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/omad.u",
"OMAD.WS","One Madison Corporation","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/omad.ws",
"OMF","OneMain Holdings, Inc.","32.78","4457744332.8","n/a","2013","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/omf",
"OKE","ONEOK, Inc.","70.21","28899235130.22","n/a","n/a","Public Utilities","Oil & Gas Production","https://www.nasdaq.com/symbol/oke",
"ONE","OneSmart International Education Group Limited","8.2","1336027549.8","n/a","2018","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/one",
"OOMA","Ooma, Inc.","13.86","278586000","n/a","2015","Technology","EDP Services","https://www.nasdaq.com/symbol/ooma",
"OPY","Oppenheimer Holdings, Inc.","25.85","334675839.85","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/opy",
"ORCL","Oracle Corporation","54.15","185065964100","n/a","1986","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/orcl",
"ORAN","Orange","16.36","43391753841.12","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/oran",
"ORC","Orchid Island Capital, Inc.","6.56","321563190.24","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/orc",
"OEC","Orion Engineered Carbons S.A","19.52","1161801080.96","n/a","2014","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/oec",
"ORN","Orion Group Holdings, Inc.","2.93","84675277.16","n/a","n/a","Basic Industries","Military/Government/Technical","https://www.nasdaq.com/symbol/orn",
"IX","Orix Corp Ads","72.57","18603832932.75","n/a","n/a","Finance","Diversified Financial Services","https://www.nasdaq.com/symbol/ix",
"ORA","Ormat Technologies, Inc.","55.26","2801802135.24","n/a","2004","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ora",
"OSK","Oshkosh Corporation","76.95","5390091564.3","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/osk",
"OR","Osisko Gold Royalties Ltd","11.38","1762913866.1","n/a","2016","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/or",
"OUT","OUTFRONT Media Inc.","23.86","3358480058.16","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/out",
"OSG","Overseas Shipholding Group, Inc.","2.33","198664397.7","n/a","2015","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/osg",
"OMI","Owens & Minor, Inc.","4.09","257758834.8","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/omi",
"OC","Owens Corning Inc","49.26","5397861638.52","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/oc",
"OI","Owens-Illinois, Inc.","19.05","2926503652.95","n/a","n/a","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/oi",
"OXM","Oxford Industries, Inc.","75.3","1276650582.3","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/oxm",
"ROYT","Pacific Coast Oil Trust","2.22","85654610.76","n/a","2012","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/royt",
"PACD","Pacific Drilling S.A.","14.22","1066946223.6","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pacd",
"PCG","Pacific Gas & Electric Co.","17.66","9316734836.14","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/pcg",
"PKG","Packaging Corporation of America","101.56","9597006650.8","n/a","2000","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/pkg",
"PAGS","PagSeguro Digital Ltd.","29.93","9810156728.53","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/pags",
"PANW","Palo Alto Networks, Inc.","240.2","22514655310.6","n/a","2012","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/panw",
"PAM","Pampa Energia S.A.","26.68","2006122560","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/pam",
"PHX","Panhandle Royalty Company","15.77","263147303.52","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/phx",
"PARR","Par Pacific Holdings, Inc.","17.5","862586007.5","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/parr",
"PAR","PAR Technology Corporation","25.77","418591412.97","n/a","n/a","Miscellaneous","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/par",
"PGRE","Paramount Group, Inc.","14.39","3362354794.36","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/pgre",
"PKE","Park Electrochemical Corporation","15.79","320211852.32","n/a","n/a","Technology","Electrical Products","https://www.nasdaq.com/symbol/pke",
"PK","Park Hotels & Resorts Inc.","32.32","6513942576.96","n/a","2016","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/pk",
"PH","Parker-Hannifin Corporation","177.52","22964937819.6","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/ph",
"PE","Parsley Energy, Inc.","18.74","5935150703.42","n/a","2014","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pe",
"PRE^F","PartnerRe Ltd.","25.295","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pre^f",
"PRE^G","PartnerRe Ltd.","26.64","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pre^g",
"PRE^H","PartnerRe Ltd.","27.14","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pre^h",
"PRE^I","PartnerRe Ltd.","26.18","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pre^i",
"PRTY","Party City Holdco Inc.","7.75","725885917.25","n/a","2015","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/prty",
"PAYC","Paycom Software, Inc.","190.72","11152425045.76","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/payc",
"PBF","PBF Energy Inc.","30.43","3646911376.03","n/a","2012","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/pbf",
"PBFX","PBF Logistics LP","21.18","1172253611.28","n/a","2014","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/pbfx",
"BTU","Peabody Energy Corporation","28.11","3041839291.89","n/a","2017","Energy","Coal Mining","https://www.nasdaq.com/symbol/btu",
"PSO","Pearson, Plc","11.17","8728379791.98","n/a","n/a","Consumer Services","Books","https://www.nasdaq.com/symbol/pso",
"PEB","Pebblebrook Hotel Trust","31.49","4110020763.16","n/a","2009","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/peb",
"PEB^C","Pebblebrook Hotel Trust","25.56","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/peb^c",
"PEB^D","Pebblebrook Hotel Trust","26.03","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/peb^d",
"PEB^E","Pebblebrook Hotel Trust","25.96","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/peb^e",
"PEB^F","Pebblebrook Hotel Trust","24.88","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/peb^f",
"PBA","Pembina Pipeline Corp.","37.57","19121886583.28","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pba",
"PEI","Pennsylvania Real Estate Investment Trust","6.21","480312971.64","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/pei",
"PEI^B","Pennsylvania Real Estate Investment Trust","21.5","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pei^b",
"PEI^C","Pennsylvania Real Estate Investment Trust","20.65","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pei^c",
"PEI^D","Pennsylvania Real Estate Investment Trust","21.38","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pei^d",
"PFSI","PennyMac Financial Services, Inc.","22.4","1736777616","n/a","2013","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/pfsi",
"PMT","PennyMac Mortgage Investment Trust","20.91","1420931417.85","n/a","2009","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/pmt",
"PMT^A","PennyMac Mortgage Investment Trust","25.62","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pmt^a",
"PMT^B","PennyMac Mortgage Investment Trust","25.16","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pmt^b",
"PAG","Penske Automotive Group, Inc.","45.06","3791281080.36","n/a","n/a","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/pag",
"PNR","Pentair plc.","45.06","7735509679.2","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/pnr",
"PEN","Penumbra, Inc.","144.44","5005304163.68","n/a","2015","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/pen",
"PFGC","Performance Food Group Company","39.08","4111312723","n/a","2015","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/pfgc",
"PKI","PerkinElmer, Inc.","97.41","10800124513.32","n/a","n/a","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/pki",
"PBT","Permian Basin Royalty Trust","7.5","349565970","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pbt",
"PVL","Permianville Royalty Trust","3.27","107910000","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pvl",
"PRT","PermRock Royalty Trust","8.7","105841868.4","n/a","2018","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/prt",
"PRGO","Perrigo Company","47.54","6459405700.26","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/prgo",
"PRSP","Perspecta Inc.","20.83","3406296530.34","n/a","2018","Technology","EDP Services","https://www.nasdaq.com/symbol/prsp",
"PTR","PetroChina Company Limited","65.92","120647428565.76","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/ptr",
"PBR","Petroleo Brasileiro S.A.- Petrobras","16.02","104486420409.3","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pbr",
"PBR.A","Petroleo Brasileiro S.A.- Petrobras","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pbr.a",
"PFE","Pfizer, Inc.","42.91","238227943538.9","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pfe",
"GHY","PGIM Global High Yield Fund, Inc.","13.94","570478873.26","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/ghy",
"ISD","PGIM High Yield Bond Fund, Inc.","14.22","472910615.28","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/isd",
"PGTI","PGT Innovations, Inc.","13.74","798054140.82","n/a","2006","Capital Goods","Building Products","https://www.nasdaq.com/symbol/pgti",
"PM","Philip Morris International Inc","88.01","136925495595.46","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/pm",
"PSX","Phillips 66","94.52","42945382042.56","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/psx",
"PSXP","Phillips 66 Partners LP","53.25","6608540928.75","n/a","2013","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/psxp",
"FENG","Phoenix New Media Limited","4.13","300534912.72","n/a","2011","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/feng",
"DOC","Physicians Realty Trust","18.62","3396619026.36","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/doc",
"PDM","Piedmont Office Realty Trust, Inc.","21.06","2645051633.64","n/a","n/a","Consumer Services","Building operators","https://www.nasdaq.com/symbol/pdm",
"PIR","Pier 1 Imports, Inc.","0.6876","58450391.0136","n/a","n/a","Consumer Services","Home Furnishings","https://www.nasdaq.com/symbol/pir",
"PCQ","PIMCO California Municipal Income Fund","17.9616","337540296.5664","n/a","2001","n/a","n/a","https://www.nasdaq.com/symbol/pcq",
"PCK","Pimco California Municipal Income Fund II","9.05","289623376.15","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/pck",
"PZC","PIMCO California Municipal Income Fund III","10.98","244871897.4","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/pzc",
"PCM","PIMCO Commercial Mortgage Securities Trust, Inc.","11.13","129012693.81","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/pcm",
"PTY","Pimco Corporate & Income Opportunity Fund","17.54","1524055949.7","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/pty",
"PCN","Pimco Corporate & Income Stategy Fund","17.18","678895703.4","n/a","2001","n/a","n/a","https://www.nasdaq.com/symbol/pcn",
"PCI","PIMCO Dynamic Credit and Mortgage Income Fund","23.65","3249870213.15","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/pci",
"PDI","PIMCO Dynamic Income Fund","32.12","1814140844.12","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/pdi",
"NRGX","PIMCO Energy and Tactical Credit Opportunities Fund","20.5","820000000","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/nrgx",
"PGP","Pimco Global Stocksplus & Income Fund","13.42","145529647.12","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/pgp",
"PHK","Pimco High Income Fund","7.93","1034389263.44","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/phk",
"PKO","Pimco Income Opportunity Fund","26.78","427378618.94","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pko",
"PFL","PIMCO Income Strategy Fund","11.47","301847559.55","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/pfl",
"PFN","PIMCO Income Strategy Fund II","10.35","630831371.85","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/pfn",
"PMF","PIMCO Municipal Income Fund","14.34","369491337.54","n/a","2001","n/a","n/a","https://www.nasdaq.com/symbol/pmf",
"PML","Pimco Municipal Income Fund II","14.21","885878981.61","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/pml",
"PMX","PIMCO Municipal Income Fund III","12.43","409723850.14","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/pmx",
"PNF","PIMCO New York Municipal Income Fund","12.99","101262804.57","n/a","2001","n/a","n/a","https://www.nasdaq.com/symbol/pnf",
"PNI","Pimco New York Municipal Income Fund II","11.45","127821685.7","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/pni",
"PYN","PIMCO New York Municipal Income Fund III","9.9","56569243.5","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/pyn",
"RCS","PIMCO Strategic Income Fund, Inc.","9.55","413495900","n/a","1994","n/a","n/a","https://www.nasdaq.com/symbol/rcs",
"PNW","Pinnacle West Capital Corporation","94.53","10613275021.38","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/pnw",
"PES","Pioneer Energy Services Corp.","1.84","144356929.52","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pes",
"PHD","Pioneer Floating Rate Trust","10.53","260492972.22","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/phd",
"PHT","Pioneer High Income Trust","9.035","264109050.985","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pht",
"MAV","Pioneer Municipal High Income Advantage Trust","10.74","256675474.8","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/mav",
"MHI","Pioneer Municipal High Income Trust","11.93","271662193.57","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/mhi",
"PXD","Pioneer Natural Resources Company","148.18","24948995918.14","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pxd",
"PJC","Piper Jaffray Companies","73.65","1078125230.4","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/pjc",
"PBI","Pitney Bowes Inc.","6.82","1262441531.78","n/a","n/a","Miscellaneous","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/pbi",
"PBI^B","Pitney Bowes Inc.","24.11","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pbi^b",
"PVT","Pivotal Acquisition Corp.","9.9","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/pvt",
"PVT.U","Pivotal Acquisition Corp.","n/a","0","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/pvt.u",
"PVT.WS","Pivotal Acquisition Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pvt.ws",
"PVTL","Pivotal Software, Inc.","21.14","1914287016.46","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/pvtl",
"PJT","PJT Partners Inc.","42","956332692","n/a","2015","Finance","Investment Managers","https://www.nasdaq.com/symbol/pjt",
"PAA","Plains All American Pipeline, L.P.","24.71","17953780680.5","n/a","1998","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/paa",
"PAGP","Plains Group Holdings, L.P.","24.83","3960027150.04","n/a","2013","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/pagp",
"PLNT","Planet Fitness, Inc.","70.58","5918543210.96","n/a","2015","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/plnt",
"PLT","Plantronics, Inc.","47.86","1889050376.68","n/a","1994","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/plt",
"AGS","PlayAGS, Inc.","23.56","833044469.44","n/a","2018","Consumer Durables","Miscellaneous manufacturing industries","https://www.nasdaq.com/symbol/ags",
"PHI","PLDT Inc.","21.43","4630075258.25","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/phi",
"PNC","PNC Financial Services Group, Inc. (The)","126.76","57499923288.72","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pnc",
"PNC^P","PNC Financial Services Group, Inc. (The)","26.88","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pnc^p",
"PNC^Q","PNC Financial Services Group, Inc. (The)","25.11","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pnc^q",
"PNM","PNM Resources, Inc. (Holding Co.)","46.33","3690352399.92","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/pnm",
"PII","Polaris Industries Inc.","85.66","5227955463.22","n/a","n/a","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/pii",
"POL","PolyOne Corporation","29.63","2305664198.22","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/pol",
"POR","Portland General Electric Company","51.56","4606696362.32","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/por",
"PKX","POSCO","59.07","18929723655.48","n/a","1994","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/pkx",
"POST","Post Holdings, Inc.","108.32","7842820560.96","n/a","2012","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/post",
"PPDF","PPDAI Group Inc.","3.97","1193438505.01","n/a","2017","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/ppdf",
"PPG","PPG Industries, Inc.","114.24","26972258893.44","n/a","n/a","Basic Industries","Paints/Coatings","https://www.nasdaq.com/symbol/ppg",
"PPX","PPL Capital Funding, Inc.","25.691","0","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ppx",
"PPL","PPL Corporation","31.72","22868118372.84","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/ppl",
"PYS","PPlus Trust","17.845","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/pys",
"PYT","PPlus Trust","20.05","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/pyt",
"PQG","PQ Group Holdings Inc.","15.19","2061705433.9","n/a","2017","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/pqg",
"PDS","Precision Drilling Corporation","2.5","734454590","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/pds",
"APTS","Preferred Apartment Communities, Inc.","15.39","662398943.13","n/a","2011","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/apts",
"PBH","Prestige Consumer Healthcare Inc.","28.45","1473664024.8","n/a","2005","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/pbh",
"PVG","Pretium Resources, Inc.","8.29","1526919274.39","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/pvg",
"PRI","Primerica, Inc.","125.25","5317400073","n/a","2010","Finance","Life Insurance","https://www.nasdaq.com/symbol/pri",
"PGZ","Principal Real Estate Income Fund","18.73","129233254","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/pgz",
"PRIF^A","Priority Income Fund, Inc.","24.955","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/prif^a",
"PRIF^B","Priority Income Fund, Inc.","25.0044","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/prif^b",
"PRIF^C","Priority Income Fund, Inc.","24.77","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/prif^c",
"PRA","ProAssurance Corporation","35.56","1907444729.68","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/pra",
"PG","Procter & Gamble Company (The)","103.75","259538894808.75","n/a","n/a","Basic Industries","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/pg",
"PGR","Progressive Corporation (The)","72.69","42449928092.76","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/pgr",
"PLD","Prologis, Inc.","73.14","46129413651.96","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/pld",
"PUMP","ProPetro Holding Corp.","22.29","2234742483.54","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/pump",
"PRO","PROS Holdings, Inc.","42.71","1609496495.71","n/a","2007","Technology","EDP Services","https://www.nasdaq.com/symbol/pro",
"PBB","Prospect Capital Corporation","25.15","0","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/pbb",
"PBC","Prospect Capital Corporation","25.24","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/pbc",
"PBY","Prospect Capital Corporation","24.7904","1215479732.7136","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/pby",
"PB","Prosperity Bancshares, Inc.","70.44","4920010353","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/pb",
"PRLB","Proto Labs, Inc.","109.66","2958910490.42","n/a","2012","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/prlb",
"PFS","Provident Financial Services, Inc","26.24","1747389482.88","n/a","2003","Finance","Savings Institutions","https://www.nasdaq.com/symbol/pfs",
"PJH","Prudential Financial, Inc.","25.65","0","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/pjh",
"PRH","Prudential Financial, Inc.","25.57","0","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/prh",
"PRS","Prudential Financial, Inc.","25.74","560782090.44","n/a","2018","Finance","Life Insurance","https://www.nasdaq.com/symbol/prs",
"PRU","Prudential Financial, Inc.","95.09","38828452959.35","n/a","2001","Finance","Life Insurance","https://www.nasdaq.com/symbol/pru",
"PUK","Prudential Public Limited Company","42.1","54586357283.9","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/puk",
"PUK^","Prudential Public Limited Company","26.49","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/puk^",
"PUK^A","Prudential Public Limited Company","26.74","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/puk^a",
"PSB","PS Business Parks, Inc.","157.24","4302416761.24","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psb",
"PSB^U","PS Business Parks, Inc.","25.36","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psb^u",
"PSB^V","PS Business Parks, Inc.","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psb^v",
"PSB^W","PS Business Parks, Inc.","24.32","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psb^w",
"PSB^X","PS Business Parks, Inc.","24.84","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psb^x",
"PSB^Y","PS Business Parks, Inc.","24.12","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psb^y",
"TLK","PT Telekomunikasi Indonesia, Tbk","27.43","27172766013.38","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tlk",
"PEG","Public Service Enterprise Group Incorporated","59.05","29820222600.8","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/peg",
"PSA","Public Storage","219.43","38262291945.27","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psa",
"PSA^A","Public Storage","25.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psa^a",
"PSA^B","Public Storage","25.38","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psa^b",
"PSA^C","Public Storage","24.98","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psa^c",
"PSA^D","Public Storage","24.64","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psa^d",
"PSA^E","Public Storage","24.06","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psa^e",
"PSA^F","Public Storage","24.94","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psa^f",
"PSA^G","Public Storage","25.33","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psa^g",
"PSA^H","Public Storage","25.73","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psa^h",
"PSA^U","Public Storage","25.31","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psa^u",
"PSA^V","Public Storage","25.08","0","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/psa^v",
"PSA^W","Public Storage","24.92","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psa^w",
"PSA^X","Public Storage","24.88","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psa^x",
"PSA^Z","Public Storage","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/psa^z",
"PHM","PulteGroup, Inc.","27.77","7705661227.23","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/phm",
"PSTG","Pure Storage, Inc. ","22.79","5581967348.45","n/a","2015","Technology","Electronic Components","https://www.nasdaq.com/symbol/pstg",
"PMM","Putnam Managed Municipal Income Trust","7.4","373016425","n/a","1989","n/a","n/a","https://www.nasdaq.com/symbol/pmm",
"PIM","Putnam Master Intermediate Income Trust","4.58","243442407.12","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/pim",
"PMO","Putnam Municipal Opportunities Trust","12.35","439123009.65","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/pmo",
"PPT","Putnam Premier Income Trust","5.14","548254928.62","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/ppt",
"NEW","Puxin Limited","7.97","650844163.44","n/a","2018","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/new",
"PVH","PVH Corp.","124.2","9333183997.8","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/pvh",
"PYX","Pyxus International, Inc.","25","227024600","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/pyx",
"PZN","Pzena Investment Management Inc","8.25","580667117.25","n/a","2007","Finance","Investment Managers","https://www.nasdaq.com/symbol/pzn",
"QTWO","Q2 Holdings, Inc.","70.46","3070745937.22","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/qtwo",
"QEP","QEP Resources, Inc.","8.03","1898022657.74","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/qep",
"QGEN","Qiagen N.V.","41.14","9277577503.04","n/a","n/a","Health Care","Biotechnology: Biological Products (No Diagnostic Substances)","https://www.nasdaq.com/symbol/qgen",
"QTS","QTS Realty Trust, Inc.","45.52","2515275288.24","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/qts",
"QTS^A","QTS Realty Trust, Inc.","25.25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qts^a",
"QTS^B","QTS Realty Trust, Inc.","110.21","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/qts^b",
"QUAD","Quad Graphics, Inc","12.31","464823975.08","n/a","n/a","Miscellaneous","Publishing","https://www.nasdaq.com/symbol/quad",
"KWR","Quaker Chemical Corporation","200.95","2679240427.45","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/kwr",
"NX","Quanex Building Products Corporation","16","532680464","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/nx",
"PWR","Quanta Services, Inc.","38.71","5471906747.23","n/a","n/a","Capital Goods","Engineering & Construction","https://www.nasdaq.com/symbol/pwr",
"QD","Qudian Inc.","5.06","1500007085.28","n/a","2017","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/qd",
"DGX","Quest Diagnostics Incorporated","90.92","12207079946.56","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/dgx",
"QES","Quintana Energy Services Inc.","4.5","152583363","n/a","2018","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/qes",
"QHC","Quorum Health Corporation","1.19","37318071.56","n/a","2016","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/qhc",
"QUOT","Quotient Technology Inc.","9.84","925529873.76","n/a","2014","Consumer Services","Advertising","https://www.nasdaq.com/symbol/quot",
"QVCD","QVC, Inc.","24.22","0","n/a","2018","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/qvcd",
"CTAA","Qwest Corporation","25.3","0","n/a","2016","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ctaa",
"CTBB","Qwest Corporation","22.84","0","n/a","2016","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ctbb",
"CTDD","Qwest Corporation","23.88","0","n/a","2017","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ctdd",
"CTV","Qwest Corporation","25.22","0","n/a","2014","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ctv",
"CTY","Qwest Corporation","22.88","0","n/a","2013","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/cty",
"CTZ","Qwest Corporation","23.93","0","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/ctz",
"RRD","R.R. Donnelley & Sons Company","4.74","333906228.48","n/a","n/a","Miscellaneous","Publishing","https://www.nasdaq.com/symbol/rrd",
"RMED","Ra Medical Systems, Inc.","3.81","48346046.31","n/a","2018","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/rmed",
"RDN","Radian Group Inc.","21.36","4563724328.16","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/rdn",
"RL","Ralph Lauren Corporation","127.29","10007788270.08","n/a","1997","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/rl",
"RRC","Range Resources Corporation","10.88","2721761384.96","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/rrc",
"RNGR","Ranger Energy Services, Inc.","8","122517448","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/rngr",
"RJF","Raymond James Financial, Inc.","83.01","11707563134.85","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/rjf",
"RYAM","Rayonier Advanced Materials Inc.","14.25","709631859.75","n/a","2014","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/ryam",
"RYAM^A","Rayonier Advanced Materials Inc.","102.75","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ryam^a",
"RYN","Rayonier Inc.","31.41","4067238842.01","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ryn",
"RTN","Raytheon Company","185.81","52442828590","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/rtn",
"RMAX","RE/MAX Holdings, Inc.","39.76","705915619.92","n/a","2013","Finance","Real Estate","https://www.nasdaq.com/symbol/rmax",
"RC","Ready Capital Corporation","14.36","461314511.76","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rc",
"RCA","Ready Capital Corporation","25.925","0","n/a","2017","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rca",
"RCP","Ready Capital Corporation","25.6","0","n/a","2018","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rcp",
"RLGY","Realogy Holdings Corp.","11.72","1338393211.56","n/a","2012","Finance","Real Estate","https://www.nasdaq.com/symbol/rlgy",
"O","Realty Income Corporation","72.55","22040089068.35","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/o",
"RHT","Red Hat, Inc.","183.1","32364841690.8","n/a","n/a","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/rht",
"RLH","Red Lion Hotels Corporation","8.11","199530986.91","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/rlh",
"RWT","Redwood Trust, Inc.","16.01","1547514592.5","n/a","1995","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rwt",
"RBC","Regal Beloit Corporation","83.76","3585676981.92","n/a","n/a","Consumer Durables","Metal Fabrications","https://www.nasdaq.com/symbol/rbc",
"RWGE","Regalwood Global Energy Ltd.","10.14","304200000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/rwge",
"RWGE.U","Regalwood Global Energy Ltd.","n/a","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/rwge.u",
"RWGE.WS","Regalwood Global Energy Ltd.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rwge.ws",
"RM","Regional Management Corp.","24.45","290506538.1","n/a","2012","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/rm",
"RF","Regions Financial Corporation","14.84","15103191347.44","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/rf",
"RF^A","Regions Financial Corporation","25.54","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rf^a",
"RF^B","Regions Financial Corporation","27.05","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rf^b",
"RGS","Regis Corporation","19.74","794249283.24","n/a","1991","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/rgs",
"RGA","Reinsurance Group of America, Incorporated","143.58","9022549539.66","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/rga",
"RZA","Reinsurance Group of America, Incorporated","26.7426","0","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/rza",
"RZB","Reinsurance Group of America, Incorporated","26.59","0","n/a","2016","Finance","Life Insurance","https://www.nasdaq.com/symbol/rzb",
"RS","Reliance Steel & Aluminum Co.","92","6171188328","n/a","1994","Basic Industries","Metal Fabrications","https://www.nasdaq.com/symbol/rs",
"RELX","RELX PLC","21.74","42589284046.7","n/a","2015","Consumer Services","Publishing","https://www.nasdaq.com/symbol/relx",
"RNR","RenaissanceRe Holdings Ltd.","143.25","6295330538.25","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/rnr",
"RNR^C","RenaissanceRe Holdings Ltd.","26.0864","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rnr^c",
"RNR^E","RenaissanceRe Holdings Ltd.","24.36","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rnr^e",
"RNR^F","RenaissanceRe Holdings Ltd.","25.18","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rnr^f",
"SOL","Renesola Ltd.","1.7089","65054217.221","n/a","2008","Technology","Semiconductors","https://www.nasdaq.com/symbol/sol",
"RENN","Renren Inc.","1.51","103881748.6","n/a","2011","Technology","EDP Services","https://www.nasdaq.com/symbol/renn",
"RSG","Republic Services, Inc.","79.74","25645621724.28","n/a","1998","Public Utilities","Environmental Services","https://www.nasdaq.com/symbol/rsg",
"REZI","Resideo Technologies, Inc.","19.48","2389926981.2","n/a","2018","Capital Goods","Wholesale Distributors","https://www.nasdaq.com/symbol/rezi",
"RMD","ResMed Inc.","105.01","15047933945.09","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/rmd",
"RFP","Resolute Forest Products Inc.","8.06","735143024.72","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/rfp",
"QSR","Restaurant Brands International Inc.","65.44","16551149062.08","n/a","2014","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/qsr",
"RPAI","Retail Properties of America, Inc.","12.3","2625840666.3","n/a","2012","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rpai",
"RVI","Retail Value Inc.","32.73","623281513.98","n/a","2018","Finance","Real Estate","https://www.nasdaq.com/symbol/rvi",
"REVG","REV Group, Inc.","10.93","686475821.03","n/a","2017","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/revg",
"REV","Revlon, Inc.","20.37","1076920365.57","n/a","1996","Consumer Non-Durables","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/rev",
"REX","REX American Resources Corporation","80.2","503208403.8","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/rex",
"REXR","Rexford Industrial Realty, Inc.","36.22","3506652484.08","n/a","2013","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rexr",
"REXR^A","Rexford Industrial Realty, Inc.","24.95","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rexr^a",
"REXR^B","Rexford Industrial Realty, Inc.","25.1","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rexr^b",
"RXN","Rexnord Corporation","25.8","2703082718.4","n/a","2012","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/rxn",
"RXN^A","Rexnord Corporation","54.88","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rxn^a",
"RH","RH","101.25","2073419066.25","n/a","2012","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/rh",
"RNG","Ringcentral, Inc.","110.04","8940244476.24","n/a","2013","Technology","EDP Services","https://www.nasdaq.com/symbol/rng",
"RIO","Rio Tinto Plc","60.98","103560256411.4","n/a","2002","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/rio",
"RBA","Ritchie Bros. Auctioneers Incorporated","34.51","3759907395.93","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/rba",
"RAD","Rite Aid Corporation","0.5681","613494944.5729","n/a","n/a","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/rad",
"RMPL^","RiverNorth Marketplace Lending Corporation","25.5986","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rmpl^",
"RMI","RiverNorth Opportunistic Municipal Income Fund, Inc.","20.6","122570000","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/rmi",
"RIV","RiverNorth Opportunities Fund, Inc.","16.61","88535037.25","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/riv",
"OPP","RiverNorth/DoubleLine Strategic Opportunity Fund, Inc.","16.77","184701207.99","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/opp",
"RLI","RLI Corp.","71.23","3171966137.29","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/rli",
"RLJ","RLJ Lodging Trust","17.91","3110762073.78","n/a","2011","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rlj",
"RLJ^A","RLJ Lodging Trust","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rlj^a",
"RMG","RMG Acquisition Corp.","9.75","0","n/a","2019","Finance","Business Services","https://www.nasdaq.com/symbol/rmg",
"RMG.U","RMG Acquisition Corp.","n/a","0","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/rmg.u",
"RMG.WS","RMG Acquisition Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rmg.ws",
"RRTS","Roadrunner Transportation Systems, Inc","0.4199","394302176.2914","n/a","2010","Transportation","Oil Refining/Marketing","https://www.nasdaq.com/symbol/rrts",
"ROAN","Roan Resources, Inc.","5.9","899983238.8","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/roan",
"RHI","Robert Half International Inc.","66.21","7884186822.9","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/rhi",
"ROK","Rockwell Automation, Inc.","182.07","21765369889.62","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/rok",
"RCI","Rogers Communication, Inc.","54.13","21849988811.02","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/rci",
"ROG","Rogers Corporation","160.83","2980772880.21","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/rog",
"ROL","Rollins, Inc.","41.87","13713716982.59","n/a","n/a","Finance","Diversified Commercial Services","https://www.nasdaq.com/symbol/rol",
"ROP","Roper Technologies, Inc.","348.27","36083482237.14","n/a","1992","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/rop",
"RST","Rosetta Stone","21.21","501424994.91","n/a","2009","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/rst",
"RDC","Rowan Companies plc","11.48","1461342501.64","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/rdc",
"RY","Royal Bank Of Canada","77.23","110864014542.98","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/ry",
"RY^T","Royal Bank Of Canada","31.5","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ry^t",
"RBS","Royal Bank Scotland plc (The)","6.66","40122151226.46","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/rbs",
"RCL","Royal Caribbean Cruises Ltd.","116.26","24320033883.48","n/a","1993","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/rcl",
"RDS.A","Royal Dutch Shell PLC","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rds.a",
"RDS.B","Royal Dutch Shell PLC","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rds.b",
"RGT","Royce Global Value Trust, Inc.","10.24","107335946.24","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/rgt",
"RMT","Royce Micro-Cap Trust, Inc.","8.36","338580660.44","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rmt",
"RVT","Royce Value Trust, Inc.","13.91","1321589433.84","n/a","1986","n/a","n/a","https://www.nasdaq.com/symbol/rvt",
"RES","RPC, Inc.","11.82","2543793771.78","n/a","n/a","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/res",
"RPM","RPM International Inc.","59.08","7777567753.48","n/a","n/a","Basic Industries","Paints/Coatings","https://www.nasdaq.com/symbol/rpm",
"RPT","RPT Realty","12.04","967479280.88","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rpt",
"RPT^D","RPT Realty","50.08","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/rpt^d",
"RTW","RTW Retailwinds, Inc.","2.4","155656804.8","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/rtw",
"RTEC","Rudolph Technologies, Inc.","22.92","708397149.6","n/a","1999","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/rtec",
"RYB","RYB Education, Inc.","6.65","194271776.65","n/a","2017","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/ryb",
"R","Ryder System, Inc.","63.06","3359493564.42","n/a","n/a","Consumer Services","Rental/Leasing Companies","https://www.nasdaq.com/symbol/r",
"RYI","Ryerson Holding Corporation","9.22","345233726.1","n/a","2014","Basic Industries","Metal Fabrications","https://www.nasdaq.com/symbol/ryi",
"RHP","Ryman Hospitality Properties, Inc.","83.31","4276780416.09","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/rhp",
"SPGI","S&P Global Inc.","213.22","52469451161.26","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/spgi",
"SBR","Sabine Royalty Trust","47.07","686249769.15","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sbr",
"SB","Safe Bulkers, Inc","1.46","147799769.74","n/a","2008","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/sb",
"SB^C","Safe Bulkers, Inc","20.58","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sb^c",
"SB^D","Safe Bulkers, Inc","20.38","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sb^d",
"SFE","Safeguard Scientifics, Inc.","10.9","224289016.6","n/a","n/a","Finance","Finance/Investors Services","https://www.nasdaq.com/symbol/sfe",
"SAFE","Safehold Inc.","21.87","399694829.67","n/a","2017","Consumer Services","Real Estate","https://www.nasdaq.com/symbol/safe",
"SAIL","SailPoint Technologies Holdings, Inc.","28.95","2562824254.95","n/a","2017","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/sail",
"CRM","Salesforce.com Inc","160.51","123753210000","n/a","2004","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/crm",
"SMM","Salient Midstream & MLP Fund","9.24","163755428.76","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/smm",
"SBH","Sally Beauty Holdings, Inc.","18.25","2200052446.75","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/sbh",
"SJT","San Juan Basin Royalty Trust","5.29","246560530.84","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sjt",
"SD","SandRidge Energy, Inc.","8.05","287285188.05","n/a","2016","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sd",
"SDT","SandRidge Mississippian Trust I","1.02","28560000","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sdt",
"SDR","SandRidge Mississippian Trust II","1.01","50222250","n/a","2012","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sdr",
"PER","SandRidge Permian Trust","2.37","124425000","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/per",
"SC","Santander Consumer USA Holdings Inc.","21.71","7628143007.68","n/a","2014","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/sc",
"SAP","SAP SE","115.81","138236592371.18","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/sap",
"SAB","Saratoga Investment Corp","25.51","0","n/a","2016","n/a","n/a","https://www.nasdaq.com/symbol/sab",
"SAF","Saratoga Investment Corp","25.5623","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/saf",
"SAR","Saratoga Investment Corp","23.09","174104557.22","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sar",
"SSL","Sasol Ltd.","31.39","19606194000","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/ssl",
"BFS","Saul Centers, Inc.","52.95","1204577235.3","n/a","1993","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/bfs",
"BFS^C","Saul Centers, Inc.","26.14","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bfs^c",
"BFS^D","Saul Centers, Inc.","24.06","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bfs^d",
"SLB","Schlumberger N.V.","44.49","61661921641.35","n/a","n/a","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/slb",
"SNDR","Schneider National, Inc.","21.1","3735218469.2","n/a","2017","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/sndr",
"SWM","Schweitzer-Mauduit International, Inc.","38.51","1189842661.29","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/swm",
"SAIC","SCIENCE APPLICATIONS INTERNATIONAL CORPORATION","76.08","4513108661.28","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/saic",
"SALT","Scorpio Bulkers Inc.","4.07","289854240.06","n/a","2013","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/salt",
"SLTB","Scorpio Bulkers Inc.","25.24","0","n/a","2014","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/sltb",
"SBNA","Scorpio Tankers Inc.","25.33","0","n/a","2014","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/sbna",
"STNG","Scorpio Tankers Inc.","19.59","1006866642.3","n/a","2010","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/stng",
"SMG","Scotts Miracle-Gro Company (The)","80.19","4438572552.81","n/a","1992","Basic Industries","Agricultural Chemicals","https://www.nasdaq.com/symbol/smg",
"KTF","Scudder Municiple Income Trust","11.03","435695346.14","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/ktf",
"KSM","Scudder Strategic Municiple Income Trust","11.29","126492493.89","n/a","1989","n/a","n/a","https://www.nasdaq.com/symbol/ksm",
"SE","Sea Limited","23.3","9636851294.4","n/a","2017","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/se",
"SA","Seabridge Gold, Inc.","11.24","692980248.28","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/sa",
"CKH","SEACOR Holdings, Inc.","42.12","772685545.32","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/ckh",
"SMHI","SEACOR Marine Holdings Inc.","13.97","293971827.6","n/a","2017","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/smhi",
"SDRL","Seadrill Limited","8.96","896000000","n/a","2018","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sdrl",
"SDLP","Seadrill Partners LLC","0.9056","83153640.96","n/a","2012","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sdlp",
"SEE","Sealed Air Corporation","45.82","7131087564.8","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/see",
"SSW","Seaspan Corporation","9.12","1965761799.84","n/a","2005","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/ssw",
"SSW^D","Seaspan Corporation","24.285","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ssw^d",
"SSW^E","Seaspan Corporation","24.98","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ssw^e",
"SSW^G","Seaspan Corporation","25.23","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ssw^g",
"SSW^H","Seaspan Corporation","24.6","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ssw^h",
"SSW^I","Seaspan Corporation","24.84","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ssw^i",
"SSWA","Seaspan Corporation","25.7","0","n/a","2017","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/sswa",
"SSWN","Seaspan Corporation","25.32","0","n/a","2014","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/sswn",
"SEAS","SeaWorld Entertainment, Inc.","24.03","2021559939.18","n/a","2013","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/seas",
"JBN","Select Asset Inc.","6.4","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/jbn",
"JBR","Select Asset Inc.","6.6","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/jbr",
"WTTR","Select Energy Services, Inc.","11.82","1254255423.6","n/a","2017","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/wttr",
"SEM","Select Medical Holdings Corporation","14.02","1896572309.98","n/a","2009","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/sem",
"SEMG","Semgroup Corporation","14.68","1161998541.52","n/a","n/a","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/semg",
"SMI","Semiconductor  Manufacturing International Corporation","5.18","5228345105.76","n/a","2004","Technology","Semiconductors","https://www.nasdaq.com/symbol/smi",
"SRE","Sempra Energy","127.24","34886946945.2","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/sre",
"SRE^A","Sempra Energy","106.79","0","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/sre^a",
"SRE^B","Sempra Energy","107.08","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sre^b",
"ST","Sensata Technologies Holding plc","47.5","7797549127.5","n/a","2010","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/st",
"SXT","Sensient Technologies Corporation","68.53","2898301598.5","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/sxt",
"SQNS","Sequans Communications S.A.","1.09","103099572.76","n/a","2011","Technology","Semiconductors","https://www.nasdaq.com/symbol/sqns",
"SRG","Seritage Growth Properties","46.44","1656399675.24","n/a","2015","Finance","Real Estate","https://www.nasdaq.com/symbol/srg",
"SRG^A","Seritage Growth Properties","25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/srg^a",
"SCI","Service Corporation International","40.45","7375027562.1","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/sci",
"SERV","ServiceMaster Global Holdings, Inc.","47.15","6415096084.15","n/a","2014","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/serv",
"NOW","ServiceNow, Inc.","246.82","44551010000","n/a","2012","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/now",
"SHAK","Shake Shack, Inc.","58.78","2179842956.94","n/a","2015","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/shak",
"SJR","Shaw Communications Inc.","21","10248686574","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/sjr",
"SHLX","Shell Midstream Partners, L.P.","20.75","4644094455.75","n/a","2014","Energy","Natural Gas Distribution","https://www.nasdaq.com/symbol/shlx",
"SHW","Sherwin-Williams Company (The)","437.17","40517182710.87","n/a","n/a","Consumer Services","RETAIL: Building Materials","https://www.nasdaq.com/symbol/shw",
"SHG","Shinhan Financial Group Co Ltd","39.55","18732841165.85","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/shg",
"SFL","Ship Finance International Limited","12.63","1507712880.75","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/sfl",
"SHOP","Shopify Inc.","201.46","19919809374.78","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/shop",
"SSTK","Shutterstock, Inc.","46.83","1642848334.47","n/a","2012","Technology","EDP Services","https://www.nasdaq.com/symbol/sstk",
"SBGL","Sibanye Gold Limited","4.27","2418826191.18","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/sbgl",
"SIG","Signet Jewelers Limited","27.65","1435373961.35","n/a","n/a","Consumer Services","Consumer Specialties","https://www.nasdaq.com/symbol/sig",
"SBOW","SilverBow Resorces, Inc.","22.37","261573573.24","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sbow",
"SPG","Simon Property Group, Inc.","183.29","56633972090.32","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/spg",
"SPG^J","Simon Property Group, Inc.","69.5","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/spg^j",
"SSD","Simpson Manufacturing Company, Inc.","59.02","2665763127.3","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/ssd",
"SHI","SINOPEC Shangai Petrochemical Company, Ltd.","49.45","5352375775.75","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/shi",
"SITC","SITE Centers Corp.","13.92","2511839292","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/sitc",
"SITC^A","SITE Centers Corp.","25.56","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sitc^a",
"SITC^J","SITE Centers Corp.","25.74","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sitc^j",
"SITC^K","SITE Centers Corp.","25.69","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sitc^k",
"SITE","SiteOne Landscape Supply, Inc.","57.15","2340597280.95","n/a","2016","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/site",
"SIX","Six Flags Entertainment Corporation New","50","4211267600","n/a","n/a","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/six",
"SJW","SJW Group","60.79","1728328027.96","n/a","n/a","Public Utilities","Water Supply","https://www.nasdaq.com/symbol/sjw",
"SKM","SK Telecom Co., Ltd.","24.67","15973231119.09","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/skm",
"SKX","Skechers U.S.A., Inc.","34.26","5292302810.88","n/a","1999","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/skx",
"SKY","Skyline Champion Corporation","19.79","1122356088.26","n/a","n/a","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/sky",
"SLG","SL Green Realty Corp","91.15","7686263491.4","n/a","1997","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/slg",
"SLG^I","SL Green Realty Corp","25.7","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/slg^i",
"SM","SM Energy Company","17.65","1981093274.25","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/sm",
"SFS","Smart","5.11","391035437.59","n/a","2014","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/sfs",
"SMAR","Smartsheet Inc.","40.54","1946070038.54","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/smar",
"SNN","Smith & Nephew SNATS, Inc.","40.32","17638352847.36","n/a","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/snn",
"SNAP","Snap Inc.","11.22","14822021653.56","n/a","2017","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/snap",
"SNA","Snap-On Incorporated","159.02","8839196191.74","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/sna",
"IPOA","Social Capital Hedosophia Holdings Corp.","10.205","704145000","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/ipoa",
"IPOA.U","Social Capital Hedosophia Holdings Corp.","n/a","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/ipoa.u",
"IPOA.WS","Social Capital Hedosophia Holdings Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ipoa.ws",
"SQM","Sociedad Quimica y Minera S.A.","38.09","10025155599.16","n/a","1993","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/sqm",
"SOGO","Sogou Inc.","5.88","2335337914.56","n/a","2017","Technology","EDP Services","https://www.nasdaq.com/symbol/sogo",
"SOI","Solaris Oilfield Infrastructure, Inc.","17.03","802599683.34","n/a","2017","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/soi",
"SWI","SolarWinds Corporation","19.8","6136862965.2","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/swi",
"SAH","Sonic Automotive, Inc.","14.88","639705886.56","n/a","1997","Consumer Durables","Automotive Aftermarket","https://www.nasdaq.com/symbol/sah",
"SON","Sonoco Products Company","61.47","6149063670.84","n/a","n/a","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/son",
"SNE","Sony Corp Ord","42.17","53158210290.73","n/a","n/a","Consumer Non-Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/sne",
"BID","Sotheby&#39;s","38.03","1771837779.84","n/a","1988","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/bid",
"SOR","Source Capital, Inc.","36.42","313605372.42","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sor",
"SJI","South Jersey Industries, Inc.","31.68","2925113336.64","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/sji",
"SJIU","South Jersey Industries, Inc.","51.05","0","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/sjiu",
"SCE^G","Southern California Edison Company","21.19","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sce^g",
"SCE^H","Southern California Edison Company","24.25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sce^h",
"SCE^J","Southern California Edison Company","22.25","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sce^j",
"SCE^K","Southern California Edison Company","22.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sce^k",
"SCE^L","Southern California Edison Company","21.02","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sce^l",
"SO","Southern Company (The)","51.64","53424899367.56","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/so",
"SOJA","Southern Company (The)","26.3","0","n/a","2015","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/soja",
"SOJB","Southern Company (The)","25.06","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/sojb",
"SOJC","Southern Company (The)","24.92","0","n/a","2017","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/sojc",
"SCCO","Southern Copper Corporation","39.89","30836743868.41","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/scco",
"LUV","Southwest Airlines Company","52.71","29132229230.79","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/luv",
"SWX","Southwest Gas Holdings, Inc.","81.63","4335225794.46","n/a","n/a","Public Utilities","Oil & Gas Production","https://www.nasdaq.com/symbol/swx",
"SWN","Southwestern Energy Company","4.6","2490068747.8","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/swn",
"SPAQ","Spartan Energy Acquisition Corp","9.83","542616000","n/a","2018","Finance","Business Services","https://www.nasdaq.com/symbol/spaq",
"SPAQ.U","Spartan Energy Acquisition Corp","n/a","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/spaq.u",
"SPAQ.WS","Spartan Energy Acquisition Corp","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/spaq.ws",
"SPE","Special Opportunities Fund Inc.","13.59","115528155.12","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/spe",
"SPE^B","Special Opportunities Fund Inc.","25.1853","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/spe^b",
"SPB           ","Spectrum Brands Holdings, Inc.","56.55","2782046014.8","n/a","n/a","Miscellaneous","Industrial Machinery/Components","https://www.nasdaq.com/symbol/spb",
"TRK","Speedway Motorsports, Inc.","14.07","574187835.9","n/a","1995","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/trk",
"SR","Spire Inc.","81.04","4111992048.08","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/sr",
"SPR","Spirit Aerosystems Holdings, Inc.","92.49","9773547323.55","n/a","2006","Capital Goods","Military/Government/Technical","https://www.nasdaq.com/symbol/spr",
"SAVE","Spirit Airlines, Inc.","53.82","3677465542.14","n/a","n/a","Transportation","Air Freight/Delivery Services","https://www.nasdaq.com/symbol/save",
"SMTA","Spirit MTA REIT","6.48","279195666.48","n/a","2018","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/smta",
"SRC","Spirit Realty Capital, Inc.","39.76","3416113158.64","n/a","2013","Consumer Services","Building operators","https://www.nasdaq.com/symbol/src",
"SRC^A","Spirit Realty Capital, Inc.","23.98","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/src^a",
"SPOT","Spotify Technology S.A.","142.55","25781034346.55","n/a","2018","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/spot",
"SRLP","Sprague Resources LP","18.54","421487933.58","n/a","2013","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/srlp",
"S","Sprint Corporation","5.62","22920140213.68","n/a","2013","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/s",
"SPXC","SPX Corporation","35.42","1553852518.68","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/spxc",
"FLOW","SPX FLOW, Inc.","32.87","1398041664.37","n/a","2015","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/flow",
"SQ","Square, Inc.","75.6","31728897169.2","n/a","2015","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/sq",
"JOE","St. Joe Company (The)","16.59","1006549044.06","n/a","n/a","Consumer Services","Homebuilding","https://www.nasdaq.com/symbol/joe",
"STAG","Stag Industrial, Inc.","29.55","3485376756.6","n/a","2011","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/stag",
"STAG^C","Stag Industrial, Inc.","26.39","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/stag^c",
"SSI","Stage Stores, Inc.","1","29736642","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/ssi",
"SMP","Standard Motor Products, Inc.","49.74","1115903320.98","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/smp",
"SXI","Standex International Corporation","73.39","928614825.28","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/sxi",
"SWJ","Stanley Black & Decker, Inc.","25.7","0","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/swj",
"SWK","Stanley Black & Decker, Inc.","139.3","21084028567.7","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/swk",
"SWP","Stanley Black & Decker, Inc.","99.99","0","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/swp",
"STN","Stantec Inc","24.02","2686086485.62","n/a","n/a","Consumer Services","Military/Government/Technical","https://www.nasdaq.com/symbol/stn",
"SGU","Star Group, L.P.","9.61","499460568.44","n/a","n/a","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/sgu",
"SRT","StarTek, Inc.","8.02","301048528.46","n/a","1997","Technology","Professional Services","https://www.nasdaq.com/symbol/srt",
"STWD","STARWOOD PROPERTY TRUST, INC.","22.51","6297584207.9","n/a","2009","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/stwd",
"STT","State Street Corporation","67.21","25449722671.23","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/stt",
"STT^C","State Street Corporation","24.9","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/stt^c",
"STT^D","State Street Corporation","26.56","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/stt^d",
"STT^E","State Street Corporation","25.82","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/stt^e",
"STT^G","State Street Corporation","25.99","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/stt^g",
"SPLP","Steel Partners Holdings LP","13.85","343323037.95","n/a","n/a","Capital Goods","Industrial Specialties","https://www.nasdaq.com/symbol/splp",
"SPLP^A","Steel Partners Holdings LP","21.5","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/splp^a",
"SCS","Steelcase Inc.","14.96","1747006808.8","n/a","1998","Consumer Durables","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/scs",
"SCA","Stellus Capital Investment Corporation","25.19","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sca",
"SCM","Stellus Capital Investment Corporation","14.22","226863178.2","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/scm",
"SCL","Stepan Company","87.8","1985520175","n/a","n/a","Basic Industries","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/scl",
"STE","STERIS plc","126.55","10695223794.45","n/a","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/ste",
"STL","Sterling Bancorp","19.44","4134991809.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/stl",
"STL^A","Sterling Bancorp","26.64","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/stl^a",
"STC","Stewart Information Services Corporation","43.46","1031088673.84","n/a","n/a","Finance","Specialty Insurers","https://www.nasdaq.com/symbol/stc",
"SF","Stifel Financial Corporation","54.8","3938950951.6","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/sf",
"SF^A","Stifel Financial Corporation","26.79","0","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/sf^a",
"SF^B","Stifel Financial Corporation","25.7","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sf^b",
"SFB","Stifel Financial Corporation","24.44","0","n/a","2017","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/sfb",
"STM","STMicroelectronics N.V.","15.83","14160431998.68","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/stm",
"EDF","Stone Harbor Emerging Markets Income Fund","13.35","215855028.6","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/edf",
"EDI","Stone Harbor Emerging Markets Total Income Fund","13","126105109","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/edi",
"STON","StoneMor Partners L.P.","3.78","143483678.1","n/a","2004","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/ston",
"SRI","Stoneridge, Inc.","29.14","830167565.9","n/a","1997","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/sri",
"STOR","STORE Capital Corporation","33.38","7397436766.1","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/stor",
"GJH","STRATS Trust","9.384","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/gjh",
"GJO","STRATS Trust","23.05","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/gjo",
"GJS","STRATS Trust","20.2045","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/gjs",
"SYK","Stryker Corporation","195.17","72818946763.25","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/syk",
"MSC","Studio City International Holdings Limited","16.5","1225454076","n/a","2018","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/msc",
"RGR","Sturm, Ruger & Company, Inc.","52.53","917068740","n/a","n/a","Capital Goods","Ordnance And Accessories","https://www.nasdaq.com/symbol/rgr",
"SPH","Suburban Propane Partners, L.P.","22.75","1402847514.25","n/a","1996","Consumer Services","Other Specialty Stores","https://www.nasdaq.com/symbol/sph",
"SMFG","Sumitomo Mitsui Financial Group Inc","7.25","50590452005","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/smfg",
"INN","Summit Hotel Properties, Inc.","11.63","1218628371.77","n/a","2011","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/inn",
"INN^D","Summit Hotel Properties, Inc.","25.2","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/inn^d",
"INN^E","Summit Hotel Properties, Inc.","23.39","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/inn^e",
"SUM","Summit Materials, Inc.","16.24","1813552240.64","n/a","2015","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/sum",
"SMLP","Summit Midstream Partners, LP","9.83","808146456.82","n/a","2012","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/smlp",
"SUI","Sun Communities, Inc.","120.46","10403449601","n/a","1993","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/sui",
"SLF","Sun Life Financial Inc.","39.13","23340488297.49","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/slf",
"SXCP","SunCoke Energy Partners, L.P.","12.88","595405666.24","n/a","2013","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/sxcp",
"SXC","SunCoke Energy, Inc.","8.8","572834143.2","n/a","2011","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/sxc",
"SU","Suncor Energy  Inc.","32.94","51978089921.58","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/su",
"STG","Sunlands Online Education Group","3.67","629861548","n/a","2018","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/stg",
"SUN","Sunoco LP","31.66","2619079895.32","n/a","2012","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/sun",
"SHO","Sunstone Hotel Investors, Inc.","14.75","3371675743.5","n/a","2004","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/sho",
"SHO^E","Sunstone Hotel Investors, Inc.","26.7","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sho^e",
"SHO^F","Sunstone Hotel Investors, Inc.","25.7724","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sho^f",
"STI","SunTrust Banks, Inc.","61.86","27419759743.68","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/sti",
"STI^A","SunTrust Banks, Inc.","21.62","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/sti^a",
"SPN","Superior Energy Services, Inc.","4.82","751591560.38","n/a","n/a","Energy","Oilfield Services/Equipment","https://www.nasdaq.com/symbol/spn",
"SUP","Superior Industries International, Inc.","5.7","142609650.9","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/sup",
"SUZ","Suzano Papel e Celulose S.A.","24.82","16743839807.8","n/a","n/a","Basic Industries","Paper","https://www.nasdaq.com/symbol/suz",
"SWZ","Swiss Helvetia Fund, Inc. (The)","7.6318","101251930.098","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/swz",
"SWCH","Switch, Inc.","10.57","587455760.5","n/a","2017","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/swch",
"SYF","Synchrony Financial","32.42","23013736738.6","n/a","2014","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/syf",
"SNX","Synnex Corporation","98.88","5015193600","n/a","2003","Technology","Retail: Computer Software & Peripheral Equipment","https://www.nasdaq.com/symbol/snx",
"SNV","Synovus Financial Corp.","35.16","5595564183.24","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/snv",
"SNV^D","Synovus Financial Corp.","25.7","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/snv^d",
"GJP","Synthetic Fixed-Income Securities, Inc.","21.75","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gjp",
"GJR","Synthetic Fixed-Income Securities, Inc.","22.5","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gjr",
"GJT","Synthetic Fixed-Income Securities, Inc.","20.265","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/gjt",
"GJV","Synthetic Fixed-Income Securities, Inc.","25.8714","0","n/a","n/a","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/gjv",
"SYY","Sysco Corporation","66.33","34057978304.13","n/a","n/a","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/syy",
"SYX","Systemax Inc.","23.11","864921700.56","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/syx",
"DATA","Tableau Software, Inc.","129.5","11148155518.5","n/a","2013","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/data",
"TLRD","Tailored Brands, Inc.","7.91","396930381.12","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/tlrd",
"TWN","Taiwan Fund, Inc. (The)","17.7765","144205972.2285","n/a","1986","n/a","n/a","https://www.nasdaq.com/symbol/twn",
"TSM","Taiwan Semiconductor Manufacturing Company Ltd.","41.27","214029356520","n/a","1997","Technology","Semiconductors","https://www.nasdaq.com/symbol/tsm",
"TAK","Takeda Pharmaceutical Company Limited","20.28","62933946828.48","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/tak",
"TAL","TAL Education Group","36.37","20617188031.16","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/tal",
"TGE","Tallgrass Energy, LP","25.35","7104125928.9","n/a","2015","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/tge",
"TALO","Talos Energy, Inc.","26.78","1450292457.9","n/a","2018","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/talo",
"SKT","Tanger Factory Outlet Centers, Inc.","20.11","1889169256.13","n/a","1993","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/skt",
"TPR","Tapestry, Inc.","33.24","9638869085.64","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/tpr",
"NGLS^A","Targa Resources Partners LP","27.06","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ngls^a",
"TRGP","Targa Resources, Inc.","42.25","9822033893.75","n/a","2010","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/trgp",
"TGT","Target Corporation","79.46","41027837104.98","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/tgt",
"TARO","Taro Pharmaceutical Industries Ltd.","107.93","4211360712.03","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/taro",
"TTM","Tata Motors Ltd","14.41","9786842769.33","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/ttm",
"TCO","Taubman Centers, Inc.","53.68","3281044634.56","n/a","1992","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/tco",
"TCO^J","Taubman Centers, Inc.","25.52","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tco^j",
"TCO^K","Taubman Centers, Inc.","25.58","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tco^k",
"TMHC","Taylor Morrison Home Corporation","17.51","1924632767.06","n/a","2013","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/tmhc",
"TCP","TC PipeLines, LP","36.97","2706440460.12","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/tcp",
"TCF","TCF Financial Corporation","21.29","3490856237.76","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/tcf",
"TCF^D","TCF Financial Corporation","24.57","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tcf^d",
"TSI","TCW Strategic Income Fund, Inc.","5.49","261801393.93","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tsi",
"TEL","TE Connectivity Ltd.","84.32","28521948709.6","n/a","n/a","Consumer Non-Durables","Electronic Components","https://www.nasdaq.com/symbol/tel",
"TISI","Team, Inc.","17.57","531440563.08","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/tisi",
"FTI","TechnipFMC plc","23.96","10776996672.8","n/a","n/a","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/fti",
"TECK","Teck Resources Ltd","23.56","13173686569.68","n/a","n/a","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/teck",
"TK","Teekay Corporation","4.13","414796946.48","n/a","n/a","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/tk",
"TGP","Teekay LNG Partners L.P.","15.2","1211249984.8","n/a","2005","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/tgp",
"TGP^A","Teekay LNG Partners L.P.","25.14","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tgp^a",
"TGP^B","Teekay LNG Partners L.P.","24.3099","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tgp^b",
"TOO","Teekay Offshore Partners L.P.","1.19","488274822.63","n/a","2006","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/too",
"TOO^A","Teekay Offshore Partners L.P.","17.95","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/too^a",
"TOO^B","Teekay Offshore Partners L.P.","18.89","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/too^b",
"TOO^E","Teekay Offshore Partners L.P.","19.18","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/too^e",
"TNK","Teekay Tankers Ltd.","0.9555","256647300","n/a","2007","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/tnk",
"GCI","TEGNA Inc.","10.71","1225931513.31","n/a","2015","Consumer Services","Newspapers/Magazines","https://www.nasdaq.com/symbol/gci",
"TGNA","TEGNA Inc.","14.13","3053387830.41","n/a","n/a","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/tgna",
"TRC","Tejon Ranch Co","17.48","454917139.84","n/a","n/a","Finance","Real Estate","https://www.nasdaq.com/symbol/trc",
"HQH","Tekla Healthcare Investors","20.6","872222334","n/a","1987","n/a","n/a","https://www.nasdaq.com/symbol/hqh",
"THQ","Tekla Healthcare Opportunies Fund","17.44","723108790.4","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/thq",
"HQL","Tekla Life Sciences Investors","17.23","392080418.09","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/hql",
"THW","Tekla World Healthcare Fund","12.81","386297693.88","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/thw",
"TDOC","Teladoc Health, Inc.","55.52","3928971514.56","n/a","2015","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/tdoc",
"TLRA","Telaria, Inc.","6.96","317108200.08","n/a","2013","Technology","Advertising","https://www.nasdaq.com/symbol/tlra",
"TEO","Telecom Argentina Stet - France Telecom S.A.","14.4","948988800","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/teo",
"TI","Telecom Italia S.P.A.","6.04","12724564573.56","n/a","n/a","Consumer Services","Telecommunications Equipment","https://www.nasdaq.com/symbol/ti",
"TI.A","Telecom Italia S.P.A.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ti.a",
"TDY","Teledyne Technologies Incorporated","240.78","8721537975.6","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tdy",
"TFX","Teleflex Incorporated","302.73","13947171006.33","n/a","n/a","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/tfx",
"VIV","Telefonica Brasil S.A.","12.17","20551403253.92","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/viv",
"TEF","Telefonica SA","8.39","43561984845.54","n/a","1988","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tef",
"TDA","Telephone and Data Systems, Inc.","23.21","0","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tda",
"TDE","Telephone and Data Systems, Inc.","25.36","0","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tde",
"TDI","Telephone and Data Systems, Inc.","26.53","0","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tdi",
"TDJ","Telephone and Data Systems, Inc.","25.36","0","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tdj",
"TDS","Telephone and Data Systems, Inc.","30.8","3505776120","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tds",
"TU","TELUS Corporation","37.23","22347468110.22","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tu",
"TDF","Templeton Dragon Fund, Inc.","20.17","686617418.06","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tdf",
"EMF","Templeton Emerging Markets Fund","14.98","254476854.52","n/a","1987","n/a","n/a","https://www.nasdaq.com/symbol/emf",
"TEI","Templeton Emerging Markets Income Fund, Inc.","10.23","491023816.14","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/tei",
"GIM","Templeton Global Income Fund, Inc.","6.34","850473961.72","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/gim",
"TPX","Tempur Sealy International, Inc.","58.22","3185540019.64","n/a","2003","Consumer Durables","Home Furnishings","https://www.nasdaq.com/symbol/tpx",
"TS","Tenaris S.A.","28.41","16769525670.15","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/ts",
"TME","Tencent Music Entertainment Group","18.86","30844597674.76","n/a","2018","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/tme",
"THC","Tenet Healthcare Corporation","29.89","3076645849.2","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/thc",
"TNC","Tennant Company","59.59","1081806751.94","n/a","n/a","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tnc",
"TEN","Tenneco Inc.","22.9","1308188308.3","n/a","n/a","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/ten",
"TVC","Tennessee Valley Authority","26.68","0","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/tvc",
"TVE","Tennessee Valley Authority","25.83","0","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/tve",
"TDC","Teradata Corporation","43.75","5144066900","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/tdc",
"TEX","Terex Corporation","32.68","2300672000","n/a","n/a","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/tex",
"TX","Ternium S.A.","27.48","5509034973.12","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/tx",
"TRNO","Terreno Realty Corporation","42.4","2637113664.8","n/a","2010","Finance","Real Estate","https://www.nasdaq.com/symbol/trno",
"TTI","Tetra Technologies, Inc.","2.36","296479028.52","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/tti",
"TEVA","Teva Pharmaceutical Industries Limited","15.03","16376905574.28","n/a","n/a","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/teva",
"TPL","Texas Pacific Land Trust","797.25","6186990061.5","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/tpl",
"TGH","Textainer Group Holdings Limited","9.68","555652947.52","n/a","2007","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/tgh",
"TXT","Textron Inc.","50.86","11893481001.84","n/a","n/a","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/txt",
"AES","The AES Corporation","18.01","11929897859.01","n/a","n/a","Basic Industries","Electric Utilities: Central","https://www.nasdaq.com/symbol/aes",
"BX","The Blackstone Group L.P.","34.63","41441027291.84","n/a","2007","Finance","Investment Managers","https://www.nasdaq.com/symbol/bx",
"CEE","The Central and Eastern Europe Fund, Inc.","24.33","166481236.56","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/cee",
"SCHW","The Charles Schwab Corporation","44.38","59212730953.46","n/a","n/a","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/schw",
"SCHW^C","The Charles Schwab Corporation","26.59","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/schw^c",
"SCHW^D","The Charles Schwab Corporation","26.43","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/schw^d",
"COO","The Cooper Companies, Inc. ","297.59","14693249429.83","n/a","n/a","Health Care","Ophthalmic Goods","https://www.nasdaq.com/symbol/coo",
"GRX","The Gabelli Healthcare & Wellness Trust","10.52","196490224.56","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/grx",
"GRX^A","The Gabelli Healthcare & Wellness Trust","25.6153","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/grx^a",
"GRX^B","The Gabelli Healthcare & Wellness Trust","25.89","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/grx^b",
"GDL","The GDL Fund","9.55","174275581.6","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/gdl",
"GDL^C","The GDL Fund","50.5007","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/gdl^c",
"THG","The Hanover Insurance Group, Inc.","114.14","4644327037.74","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/thg",
"THGA","The Hanover Insurance Group, Inc.","25.75","0","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/thga",
"MSG","The Madison Square Garden Company","297.4","7065780874","n/a","2015","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/msg",
"RUBI","The Rubicon Project, Inc.","6.24","322821807.36","n/a","2014","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/rubi",
"TRV","The Travelers Companies, Inc.","136.81","36034527361.54","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/trv",
"VAM","The Vivaldi Opportunities Fund","14.32","80602182.08","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/vam",
"TMO","Thermo Fisher Scientific Inc","274.81","109650201575.61","n/a","n/a","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/tmo",
"THR","Thermon Group Holdings, Inc.","24.55","800391006.75","n/a","2011","Energy","Industrial Machinery/Components","https://www.nasdaq.com/symbol/thr",
"TPRE","Third Point Reinsurance Ltd.","10.57","996676100.98","n/a","2013","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/tpre",
"TSLF","THL Credit Senior Loan Fund","15.5801","115588606.099","n/a","2013","n/a","n/a","https://www.nasdaq.com/symbol/tslf",
"TCRW","THL Credit, Inc.","25.6759","0","n/a","2018","n/a","n/a","https://www.nasdaq.com/symbol/tcrw",
"TCRZ","THL Credit, Inc.","25.28","0","n/a","2015","n/a","n/a","https://www.nasdaq.com/symbol/tcrz",
"TRI","Thomson Reuters Corp","58.95","29572410217.95","n/a","n/a","Consumer Services","Publishing","https://www.nasdaq.com/symbol/tri",
"THO","Thor Industries, Inc.","61.09","3363827565.57","n/a","n/a","Consumer Non-Durables","Homebuilding","https://www.nasdaq.com/symbol/tho",
"TDW","Tidewater Inc.","23.41","872952181.33","n/a","2017","Consumer Services","Marine Transportation","https://www.nasdaq.com/symbol/tdw",
"TDW.WS.A","Tidewater Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tdw.ws.a",
"TDW.WS.B","Tidewater Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tdw.ws.b",
"TIER","TIER REIT, Inc.","28.76","1596770299","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/tier",
"TIF","Tiffany & Co.","106.21","12899649732.32","n/a","1987","Consumer Services","Consumer Specialties","https://www.nasdaq.com/symbol/tif",
"TLYS","Tilly&#39;s, Inc.","11.12","241948381.76","n/a","2012","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/tlys",
"TSU","TIM Participacoes S.A.","15.11","7316360139.45","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tsu",
"TKR","Timken Company (The)","45.63","3472902494.1","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/tkr",
"TMST","TimkenSteel Corporation","11.31","506287003.95","n/a","2014","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/tmst",
"TWI","Titan International, Inc.","5.89","353084219.43","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/twi",
"TJX","TJX Companies, Inc. (The)","53.08","131376058894.24","n/a","n/a","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/tjx",
"TOL","Toll Brothers, Inc.","36.01","5255299400","n/a","n/a","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/tol",
"TR","Tootsie Roll Industries, Inc.","37.45","1440683261.85","n/a","n/a","Consumer Non-Durables","Specialty Foods","https://www.nasdaq.com/symbol/tr",
"BLD","TopBuild Corp.","64.98","2259055172.16","n/a","2015","Basic Industries","Engineering & Construction","https://www.nasdaq.com/symbol/bld",
"TMK","Torchmark Corporation","83.87","9251978819.36","n/a","n/a","Finance","Life Insurance","https://www.nasdaq.com/symbol/tmk",
"TMK^C","Torchmark Corporation","26.51","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tmk^c",
"TTC","Toro Company (The)","69.02","7323738082.5","n/a","n/a","Capital Goods","Tools/Hardware","https://www.nasdaq.com/symbol/ttc",
"TD","Toronto Dominion Bank (The)","55.65","101696745785.25","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/td",
"SHLL.U","Tortoise Acquisition Corp.","n/a","0","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/shll.u",
"NDP","Tortoise Energy Independence Fund, Inc.","8.45","123647996.55","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/ndp",
"TYG","Tortoise Energy Infrastructure Corporation","24.01","1287777646.54","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/tyg",
"TEAF","Tortoise Essential Assets Income Term Fund","20.025","0","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/teaf",
"NTG","Tortoise Midstream Energy Fund, Inc.","14.33","905776042.41","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/ntg",
"TTP","Tortoise Pipeline & Energy Fund, Inc.","15.55","155755222.15","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/ttp",
"TPZ","Tortoise Power and Energy Infrastructure Fund, Inc","18.79","130615547.07","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/tpz",
"TOT","Total S.A.","55.96","145614277335.8","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/tot",
"TSS","Total System Services, Inc.","95.87","17007436266.75","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/tss",
"TOWR","Tower International, Inc.","22.18","457172762.66","n/a","2010","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/towr",
"TSQ","Townsquare Media, Inc.","5.87","111207390.67","n/a","2014","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/tsq",
"TM","Toyota Motor Corp Ltd Ord","120.65","173708271613.75","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/tm",
"TPGH","TPG Pace Holdings Corp.","10.26","577125000","n/a","2017","Finance","Business Services","https://www.nasdaq.com/symbol/tpgh",
"TPGH.U","TPG Pace Holdings Corp.","n/a","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/tpgh.u",
"TPGH.WS","TPG Pace Holdings Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tpgh.ws",
"TRTX","TPG RE Finance Trust, Inc.","19.65","1415154937.95","n/a","2017","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/trtx",
"TSLX","TPG Specialty Lending, Inc.","20.14","1321700288.9","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/tslx",
"TAC","TransAlta Corporation","7.49","2131945862.83","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/tac",
"TRP","TransCanada Corporation","45.78","42263877904.08","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/trp",
"TCI","Transcontinental Realty Investors, Inc.","31.5","274609660.5","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/tci",
"TDG","Transdigm Group Incorporated","461.31","24401986573.05","n/a","2006","Capital Goods","Military/Government/Technical","https://www.nasdaq.com/symbol/tdg",
"RIG","Transocean Ltd.","9.11","5560395770.25","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/rig",
"TGS","Transportadora De Gas Sa Ord B","12.62","1970977718","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/tgs",
"TRU","TransUnion","68.01","12736125312.21","n/a","2015","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/tru",
"TVPT","Travelport Worldwide Limited","15.73","1990038825.06","n/a","2014","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/tvpt",
"TREC","Trecora Resources","9.19","226871967.7","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/trec",
"TG","Tredegar Corporation","16.77","556742785.95","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/tg",
"THS","Treehouse Foods, Inc.","62.54","3501547181.88","n/a","n/a","Consumer Non-Durables","Packaged Foods","https://www.nasdaq.com/symbol/ths",
"TREX","Trex Company, Inc.","65.61","3862215909.09","n/a","n/a","Basic Industries","Forest Products","https://www.nasdaq.com/symbol/trex",
"TY","Tri Continental Corporation","26.62","716788381.32","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ty",
"TY^","Tri Continental Corporation","52.625","0","n/a","n/a","Consumer Services","Miscellaneous","https://www.nasdaq.com/symbol/ty^",
"TPH","TRI Pointe Group, Inc.","12.71","1807490968.37","n/a","2013","Capital Goods","Homebuilding","https://www.nasdaq.com/symbol/tph",
"TRCO","Tribune Media Company","46.09","4067781215.41","n/a","2014","Consumer Services","Broadcasting","https://www.nasdaq.com/symbol/trco",
"TRNE.U","Trine Acquisition Corp.","n/a","0","n/a","2019","n/a","n/a","https://www.nasdaq.com/symbol/trne.u",
"TNET","TriNet Group, Inc.","60.4","4233870940.4","n/a","2014","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/tnet",
"TRN","Trinity Industries, Inc.","22.32","2976259842","n/a","n/a","Capital Goods","Railroads","https://www.nasdaq.com/symbol/trn",
"TSE","Trinseo S.A.","47.58","1964570063.82","n/a","2014","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/tse",
"TPVG","TriplePoint Venture Growth BDC Corp.","13.88","343949495.24","n/a","2014","n/a","n/a","https://www.nasdaq.com/symbol/tpvg",
"TPVY","TriplePoint Venture Growth BDC Corp.","25.4038","0","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/tpvy",
"GTS","Triple-S Management Corporation","23.26","515910614.64","n/a","2007","Finance","Accident &Health Insurance","https://www.nasdaq.com/symbol/gts",
"TRTN","Triton International Limited","31.78","2501010204.7","n/a","2016","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/trtn",
"TRTN^A","Triton International Limited","26.05","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/trtn^a",
"TGI","Triumph Group, Inc.","19.63","978926134.03","n/a","1996","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/tgi",
"TROX","Tronox Holdings plc","13.24","1248453341.16","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/trox",
"TBI","TrueBlue, Inc.","23.56","944143440","n/a","n/a","Technology","Professional Services","https://www.nasdaq.com/symbol/tbi",
"TNP","Tsakos Energy Navigation Ltd","3.14","274236462.42","n/a","2002","Transportation","Marine Transportation","https://www.nasdaq.com/symbol/tnp",
"TNP^B","Tsakos Energy Navigation Ltd","25.35","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tnp^b",
"TNP^C","Tsakos Energy Navigation Ltd","25.3524","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tnp^c",
"TNP^D","Tsakos Energy Navigation Ltd","21.9123","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tnp^d",
"TNP^E","Tsakos Energy Navigation Ltd","22.18","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tnp^e",
"TNP^F","Tsakos Energy Navigation Ltd","22.57","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/tnp^f",
"TUP","Tupperware Brands Corporation","25.68","1249763526.72","n/a","n/a","Consumer Non-Durables","Plastic Products","https://www.nasdaq.com/symbol/tup",
"TKC","Turkcell Iletisim Hizmetleri AS","5.36","4698717064.48","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/tkc",
"TPB","Turning Point Brands, Inc.","46","899590352","n/a","2016","Consumer Non-Durables","Tobacco","https://www.nasdaq.com/symbol/tpb",
"TRQ","Turquoise Hill Resources Ltd.","1.69","3400811452.61","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/trq",
"TPC","Tutor Perini Corporation","17.76","889837183.2","n/a","n/a","Basic Industries","General Bldg Contractors - Nonresidential Bldgs","https://www.nasdaq.com/symbol/tpc",
"TWLO","Twilio Inc.","129.79","16039594732.91","n/a","2016","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/twlo",
"TRWH","Twin River Worldwide Holdings, Inc.","31","0","n/a","2019","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/trwh",
"TWTR","Twitter, Inc.","33.75","25880328562.5","n/a","2013","Technology","Computer Software: Programming, Data Processing","https://www.nasdaq.com/symbol/twtr",
"TWO","Two Harbors Investments Corp","13.64","3721304028.64","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/two",
"TWO^A","Two Harbors Investments Corp","27.22","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/two^a",
"TWO^B","Two Harbors Investments Corp","25.56","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/two^b",
"TWO^C","Two Harbors Investments Corp","24.72","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/two^c",
"TWO^D","Two Harbors Investments Corp","24.99","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/two^d",
"TWO^E","Two Harbors Investments Corp","24.48","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/two^e",
"TYL","Tyler Technologies, Inc.","207.24","7948062262.8","n/a","n/a","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/tyl",
"TSN","Tyson Foods, Inc.","69.26","25298419708.44","n/a","n/a","Consumer Non-Durables","Meat/Poultry/Fish","https://www.nasdaq.com/symbol/tsn",
"USB","U.S. Bancorp","49.14","78636747702.24","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/usb",
"USB^A","U.S. Bancorp","794","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/usb^a",
"USB^H","U.S. Bancorp","19.14","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/usb^h",
"USB^M","U.S. Bancorp","26.9","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/usb^m",
"USB^O","U.S. Bancorp","24.9","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/usb^o",
"USB^P","U.S. Bancorp","25.6","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/usb^p",
"USPH","U.S. Physical Therapy, Inc.","104.89","1338510939.88","n/a","1992","Health Care","Medical/Nursing Services","https://www.nasdaq.com/symbol/usph",
"SLCA","U.S. Silica Holdings, Inc.","16.35","1201223905.2","n/a","2012","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/slca",
"USX","U.S. Xpress Enterprises, Inc.","6.94","228305804.6","n/a","2018","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/usx",
"UBS","UBS AG","12.41","47873494727.72","n/a","2014","Finance","Major Banks","https://www.nasdaq.com/symbol/ubs",
"UDR","UDR, Inc.","45.7","12849850686.4","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/udr",
"UGI","UGI Corporation","51.32","8921679212","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/ugi",
"UGP","Ultrapar Participacoes S.A.","12.01","6521609513.47","n/a","n/a","Public Utilities","Oil/Gas Transmission","https://www.nasdaq.com/symbol/ugp",
"UMH","UMH Properties, Inc.","13.9","539015159.1","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/umh",
"UMH^B","UMH Properties, Inc.","26.07","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/umh^b",
"UMH^C","UMH Properties, Inc.","25.52","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/umh^c",
"UMH^D","UMH Properties, Inc.","23.75","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/umh^d",
"UA","Under Armour, Inc.","19.03","8539794176.76","n/a","2016","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/ua",
"UAA","Under Armour, Inc.","21.33","4007948166.9","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/uaa",
"UFI","Unifi, Inc.","19.41","356863583.73","n/a","n/a","Consumer Non-Durables","Textiles","https://www.nasdaq.com/symbol/ufi",
"UNF","Unifirst Corporation","153.98","2948078444.94","n/a","n/a","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/unf",
"UN","Unilever NV","57.94","151468777348.5","n/a","n/a","Basic Industries","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/un",
"UL","Unilever PLC","57.54","151286783423.16","n/a","n/a","Basic Industries","Package Goods/Cosmetics","https://www.nasdaq.com/symbol/ul",
"UNP","Union Pacific Corporation","169.78","120727482774.86","n/a","n/a","Transportation","Railroads","https://www.nasdaq.com/symbol/unp",
"UIS","Unisys Corporation","11.82","603228983.82","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/uis",
"UNT","Unit Corporation","14.53","809555514.2","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/unt",
"UMC","United Microelectronics Corporation","1.87","4453681750.65","n/a","n/a","Technology","Semiconductors","https://www.nasdaq.com/symbol/umc",
"UNFI","United Natural Foods, Inc.","13.24","672855396.56","n/a","1996","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/unfi",
"UPS","United Parcel Service, Inc.","113.68","79192531327.28","n/a","1999","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/ups",
"URI","United Rentals, Inc.","118.53","9339446063.79","n/a","1997","Technology","Diversified Commercial Services","https://www.nasdaq.com/symbol/uri",
"USM","United States Cellular Corporation","46.11","3979551216","n/a","1988","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/usm",
"UZA","United States Cellular Corporation","25.35","0","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/uza",
"UZB","United States Cellular Corporation","26.25","0","n/a","2014","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/uzb",
"UZC","United States Cellular Corporation","26.63","0","n/a","2015","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/uzc",
"X","United States Steel Corporation","19.93","3454756821.71","n/a","n/a","Basic Industries","Steel/Iron Ore","https://www.nasdaq.com/symbol/x",
"UTX","United Technologies Corporation","131.9","113741629974.3","n/a","n/a","Capital Goods","Aerospace","https://www.nasdaq.com/symbol/utx",
"UNH","UnitedHealth Group Incorporated","244.41","234520808451.15","n/a","n/a","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/unh",
"UTL","UNITIL Corporation","54.03","805686553.11","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/utl",
"UNVR","Univar Inc.","22.27","3779205459.84","n/a","2015","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/unvr",
"UVV","Universal Corporation","58.21","1453433789.79","n/a","n/a","Consumer Services","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/uvv",
"UHT","Universal Health Realty Income Trust","77.04","1059055552.08","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/uht",
"UHS","Universal Health Services, Inc.","133.75","12142461115","n/a","n/a","Health Care","Hospital/Nursing Management","https://www.nasdaq.com/symbol/uhs",
"UVE","UNIVERSAL INSURANCE HOLDINGS INC","31.9","1113379510.1","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/uve",
"UTI","Universal Technical Institute Inc","3.44","87257024.16","n/a","2003","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/uti",
"UNM","Unum Group","34.2","7340199282","n/a","n/a","Finance","Accident &Health Insurance","https://www.nasdaq.com/symbol/unm",
"UNMA","Unum Group","25.7091","0","n/a","2018","Finance","Accident &Health Insurance","https://www.nasdaq.com/symbol/unma",
"UE","Urban Edge Properties","19.35","2323928575.8","n/a","2015","Finance","Real Estate","https://www.nasdaq.com/symbol/ue",
"UBA","Urstadt Biddle Properties Inc.","20.95","835075484.75","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/uba",
"UBP","Urstadt Biddle Properties Inc.","16.55","659689702.75","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ubp",
"UBP^G","Urstadt Biddle Properties Inc.","25.9699","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ubp^g",
"UBP^H","Urstadt Biddle Properties Inc.","26.169","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ubp^h",
"USFD","US Foods Holding Corp.","34.65","7541200532.25","n/a","2016","Consumer Non-Durables","Food Distributors","https://www.nasdaq.com/symbol/usfd",
"USAC","USA Compression Partners, LP","15.65","1508636039.85","n/a","2013","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/usac",
"USNA","USANA Health Sciences, Inc.","84.15","1962755412.75","n/a","n/a","Consumer Durables","Specialty Chemicals","https://www.nasdaq.com/symbol/usna",
"USDP","USD Partners LP","10.86","287798492.52","n/a","2014","Transportation","Railroads","https://www.nasdaq.com/symbol/usdp",
"USG","USG Corporation","43.35","6073312024.5","n/a","n/a","Capital Goods","Building Materials","https://www.nasdaq.com/symbol/usg",
"BIF","USLIFE Income Fund, Inc.","10.95","1156948442.4","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/bif",
"VFC","V.F. Corporation","86.79","34334596484.76","n/a","n/a","Consumer Non-Durables","Apparel","https://www.nasdaq.com/symbol/vfc",
"EGY","VAALCO Energy, Inc. ","2.34","139454036.28","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/egy",
"MTN","Vail Resorts, Inc.","220.69","8883588832.31","n/a","1997","Consumer Services","Services-Misc. Amusement & Recreation","https://www.nasdaq.com/symbol/mtn",
"VALE","VALE S.A.","13.47","69075754821.06","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/vale",
"VLO","Valero Energy Corporation","84.45","35267448420.9","n/a","n/a","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/vlo",
"VHI","Valhi, Inc.","2.23","756351216.27","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/vhi",
"VMI","Valmont Industries, Inc.","131.36","2883609071.52","n/a","n/a","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/vmi",
"VVV","Valvoline Inc.","18.77","3532149430.29","n/a","2016","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/vvv",
"VAPO","Vapotherm, Inc.","19.78","343110011.8","n/a","2018","Health Care","Medical/Dental Instruments","https://www.nasdaq.com/symbol/vapo",
"VAR","Varian Medical Systems, Inc.","141.98","12888590443.86","n/a","n/a","Health Care","Biotechnology: Electromedical & Electrotherapeutic Apparatus","https://www.nasdaq.com/symbol/var",
"VGR","Vector Group Ltd.","10.69","1506377522.98","n/a","n/a","Consumer Non-Durables","Farming/Seeds/Milling","https://www.nasdaq.com/symbol/vgr",
"VEC","Vectrus, Inc.","27.6","310966605.6","n/a","2014","Consumer Services","Diversified Commercial Services","https://www.nasdaq.com/symbol/vec",
"VEDL","Vedanta  Limited","10.85","671148450","n/a","2013","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/vedl",
"VEEV","Veeva Systems Inc.","128.7","16240790709","n/a","2013","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/veev",
"VNTR","Venator Materials PLC","5.79","616758350.16","n/a","2017","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/vntr",
"VTR","Ventas, Inc.","63.61","22686329918.64","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/vtr",
"VNE","Veoneer, Inc.","23.86","2084044446.56","n/a","2018","Capital Goods","Auto Parts:O.E.M.","https://www.nasdaq.com/symbol/vne",
"VER","VEREIT Inc.","8.42","8152772767.58","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/ver",
"VER^F","VEREIT Inc.","25.325","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ver^f",
"VRTV","Veritiv Corporation","26.33","418684283.28","n/a","2014","Consumer Services","Paper","https://www.nasdaq.com/symbol/vrtv",
"VZ","Verizon Communications Inc.","58.53","241728900000","n/a","n/a","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/vz",
"VET","Vermilion Energy Inc.","24.83","3796374308.48","n/a","n/a","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/vet",
"VRS","Verso Corporation","21.75","750029022.75","n/a","2016","Basic Industries","Paper","https://www.nasdaq.com/symbol/vrs",
"VSM","Versum Materials, Inc.","50.37","5497580962.98","n/a","2016","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/vsm",
"VVI","Viad Corp","56.52","1141788610.44","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/vvi",
"VICI","VICI Properties Inc.","21.79","8828757758.92","n/a","2018","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/vici",
"VNCE","Vince Holding Corp.","13.04","151550097.6","n/a","2013","Consumer Services","Clothing/Shoe/Accessory Stores","https://www.nasdaq.com/symbol/vnce",
"VIPS","Vipshop Holdings Limited","8.04","5330226057.6","n/a","2012","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/vips",
"ZTR","Virtus Global Dividend & Income Fund Inc.","10.919","268258821.844","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/ztr",
"VGI","Virtus Global Multi-Sector Income Fund","12.43","140511603.76","n/a","2012","n/a","n/a","https://www.nasdaq.com/symbol/vgi",
"ZF","Virtus Total Return Fund Inc.","10.14","218287714.32","n/a","1986","n/a","n/a","https://www.nasdaq.com/symbol/zf",
"V","Visa Inc.","157.78","357314198656.8","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/v",
"VSH","Vishay Intertechnology, Inc.","19.31","2555455488.81","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/vsh",
"VPG","Vishay Precision Group, Inc.","34.43","464500191.21","n/a","n/a","Capital Goods","Electrical Products","https://www.nasdaq.com/symbol/vpg",
"VSTO","Vista Outdoor Inc.","7.84","451514122.08","n/a","2015","Capital Goods","Ordnance And Accessories","https://www.nasdaq.com/symbol/vsto",
"DYNC","Vistra Energy Corp.","99.39","0","n/a","2016","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/dync",
"VST","Vistra Energy Corp.","26.32","12788740818.56","n/a","n/a","Public Utilities","Electric Utilities: Central","https://www.nasdaq.com/symbol/vst",
"VST.WS.A","Vistra Energy Corp.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vst.ws.a",
"VSI","Vitamin Shoppe, Inc","7.23","173566488.9","n/a","2009","Consumer Non-Durables","Food Chains","https://www.nasdaq.com/symbol/vsi",
"VSLR","Vivint Solar, Inc.","5.1","612985845.3","n/a","2014","Capital Goods","Building Products","https://www.nasdaq.com/symbol/vslr",
"VMW","Vmware, Inc.","185.05","20437106679.9","n/a","2007","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/vmw",
"VOC","VOC Energy Trust","5.98","101660000","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/voc",
"VCRA","Vocera Communications, Inc.","31.91","982980625.53","n/a","2012","Capital Goods","Telecommunications Equipment","https://www.nasdaq.com/symbol/vcra",
"VG","Vonage Holdings Corp.","9.99","2396242608.75","n/a","2006","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/vg",
"VNO","Vornado Realty Trust","68.58","13066924521.42","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/vno",
"VNO^K","Vornado Realty Trust","25.4","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vno^k",
"VNO^L","Vornado Realty Trust","24.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vno^l",
"VNO^M","Vornado Realty Trust","23.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/vno^m",
"VJET","voxeljet AG","2.25","54405000","n/a","2013","Capital Goods","Industrial Machinery/Components","https://www.nasdaq.com/symbol/vjet",
"IAE","Voya Asia Pacific High Dividend Equity Income Fund","9.16","108993502.64","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/iae",
"IHD","Voya Emerging Markets High Income Dividend Equity Fund","7.98","151933526.22","n/a","2011","n/a","n/a","https://www.nasdaq.com/symbol/ihd",
"VOYA","Voya Financial, Inc.","50.75","7406261997.75","n/a","2013","Finance","Life Insurance","https://www.nasdaq.com/symbol/voya",
"IGA","Voya Global Advantage and Premium Opportunity Fund","10.42","190737745.72","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/iga",
"IGD","Voya Global Equity Dividend and Premium Opportunity Fund","6.44","625178591.24","n/a","2005","n/a","n/a","https://www.nasdaq.com/symbol/igd",
"IDE","Voya Infrastructure, Industrials and Materials Fund","12.36","238284472.44","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/ide",
"IID","Voya International High Dividend Equity Income Fund","6.04","50879981.52","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/iid",
"IRR","Voya Natural Resources Equity Income Fund","5.27","119419643.98","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/irr",
"PPR","Voya Prime Rate Trust","4.81","710858793.71","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/ppr",
"VMC","Vulcan Materials Company","120.57","15923441653.68","n/a","n/a","Basic Industries","Mining & Quarrying of Nonmetallic Minerals (No Fuels)","https://www.nasdaq.com/symbol/vmc",
"WTI","W&T Offshore, Inc.","6.99","983101790.67","n/a","2005","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/wti",
"WPC","W.P. Carey Inc.","78.57","13046744925","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/wpc",
"WRB","W.R. Berkley Corporation","84.55","10316251655.55","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/wrb",
"WRB^B","W.R. Berkley Corporation","25.54","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wrb^b",
"WRB^C","W.R. Berkley Corporation","25.86","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wrb^c",
"WRB^D","W.R. Berkley Corporation","25.27","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wrb^d",
"WRB^E","W.R. Berkley Corporation","25.08","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wrb^e",
"GRA","W.R. Grace & Co.","78.32","5236298431.76","n/a","n/a","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/gra",
"GWW","W.W. Grainger, Inc.","311.27","17307632965.6","n/a","n/a","Consumer Services","Office Equipment/Supplies/Services","https://www.nasdaq.com/symbol/gww",
"WNC","Wabash National Corporation","13.78","759980435.5","n/a","1991","Capital Goods","Construction/Ag Equipment/Trucks","https://www.nasdaq.com/symbol/wnc",
"WBC","Wabco Holdings Inc.","131.8","6771428103.8","n/a","n/a","Capital Goods","Auto Manufacturing","https://www.nasdaq.com/symbol/wbc",
"WDR","Waddell & Reed Financial, Inc.","17.43","1326891762.42","n/a","1998","Finance","Investment Bankers/Brokers/Service","https://www.nasdaq.com/symbol/wdr",
"WAGE","WageWorks, Inc.","38.95","1552268780.15","n/a","2012","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/wage",
"WD","Walker & Dunlop, Inc.","50.78","1556230184.04","n/a","2010","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/wd",
"WMT","Walmart Inc.","96.94","278187189256.2","n/a","n/a","Consumer Services","Department/Specialty Retail Stores","https://www.nasdaq.com/symbol/wmt",
"DIS","Walt Disney Company (The)","111.96","201261691720.08","n/a","n/a","Consumer Services","Television Services","https://www.nasdaq.com/symbol/dis",
"HCC","Warrior Met Coal, Inc.","31.02","1599246553.74","n/a","2017","Energy","Coal Mining","https://www.nasdaq.com/symbol/hcc",
"WPG","Washington Prime Group Inc.","5.61","1046006328.51","n/a","2014","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/wpg",
"WPG^H","Washington Prime Group Inc.","21.9588","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wpg^h",
"WPG^I","Washington Prime Group Inc.","19.77","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wpg^i",
"WRE","Washington Real Estate Investment Trust","28.99","2319552721.33","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wre",
"WCN","Waste Connections, Inc.","87.3","23017933373.4","n/a","n/a","Public Utilities","Environmental Services","https://www.nasdaq.com/symbol/wcn",
"WM","Waste Management, Inc.","104","44166899192","n/a","n/a","Public Utilities","Environmental Services","https://www.nasdaq.com/symbol/wm",
"WAT","Waters Corporation","250.63","17923150556.33","n/a","1995","Capital Goods","Biotechnology: Laboratory Analytical Instruments","https://www.nasdaq.com/symbol/wat",
"WSO","Watsco, Inc.","146.22","5488348691.4","n/a","n/a","Consumer Durables","Industrial Machinery/Components","https://www.nasdaq.com/symbol/wso",
"WSO.B","Watsco, Inc.","n/a","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wso.b",
"WTS","Watts Water Technologies, Inc.","81.27","2254347717.3","n/a","1986","Capital Goods","Metal Fabrications","https://www.nasdaq.com/symbol/wts",
"W","Wayfair Inc.","149.39","13609970986.92","n/a","2014","Consumer Services","Catalog/Specialty Distribution","https://www.nasdaq.com/symbol/w",
"WFT","Weatherford International plc","0.7619","764273873.9251","n/a","n/a","Energy","Metal Fabrications","https://www.nasdaq.com/symbol/wft",
"WBS","Webster Financial Corporation","52.8","4871604249.6","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wbs",
"WBS^F","Webster Financial Corporation","23.83","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wbs^f",
"WEC","WEC Energy Group, Inc.","78.25","24683988948.5","n/a","n/a","Public Utilities","Power Generation","https://www.nasdaq.com/symbol/wec",
"WEI","Weidai Ltd.","11.23","791121797.71","n/a","2018","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/wei",
"WRI","Weingarten Realty Investors","29.53","3798976709.79","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/wri",
"WMK","Weis Markets, Inc.","40.54","1090462879.22","n/a","n/a","Consumer Services","Food Chains","https://www.nasdaq.com/symbol/wmk",
"WBT","Welbilt, Inc.","16.47","2317240144.35","n/a","2016","Technology","Industrial Machinery/Components","https://www.nasdaq.com/symbol/wbt",
"WCG","WellCare Health Plans, Inc.","273.83","13774255533.45","n/a","2004","Health Care","Medical Specialities","https://www.nasdaq.com/symbol/wcg",
"WFC","Wells Fargo & Company","48.21","218967497242.2","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/wfc",
"WFC^L","Wells Fargo & Company","1302","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^l",
"WFC^N","Wells Fargo & Company","24.53","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^n",
"WFC^O","Wells Fargo & Company","24.45","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^o",
"WFC^P","Wells Fargo & Company","24.64","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^p",
"WFC^Q","Wells Fargo & Company","26.22","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^q",
"WFC^R","Wells Fargo & Company","27.85","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^r",
"WFC^T","Wells Fargo & Company","25.6","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^t",
"WFC^V","Wells Fargo & Company","26.22","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^v",
"WFC^W","Wells Fargo & Company","25.745","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^w",
"WFC^X","Wells Fargo & Company","25.33","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^x",
"WFC^Y","Wells Fargo & Company","25.5","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfc^y",
"WFE^A","Wells Fargo & Company","25.68","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/wfe^a",
"EOD","Wells Fargo Global Dividend Opportunity Fund","5.26","237627953.42","n/a","2007","n/a","n/a","https://www.nasdaq.com/symbol/eod",
"WELL","Welltower Inc.","77.64","31027373045.04","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/well",
"WAIR","Wesco Aircraft Holdings, Inc.","8.84","881764063.44","n/a","2011","Capital Goods","Wholesale Distributors","https://www.nasdaq.com/symbol/wair",
"WCC","WESCO International, Inc.","54.18","2448697228.74","n/a","1999","Consumer Non-Durables","Telecommunications Equipment","https://www.nasdaq.com/symbol/wcc",
"WST","West Pharmaceutical Services, Inc.","111.27","8204769288.33","n/a","n/a","Basic Industries","Specialty Chemicals","https://www.nasdaq.com/symbol/wst",
"WAL","Western Alliance Bancorporation","42.42","4466692546.68","n/a","2005","Finance","Major Banks","https://www.nasdaq.com/symbol/wal",
"WALA","Western Alliance Bancorporation","25.96","0","n/a","2016","Finance","Major Banks","https://www.nasdaq.com/symbol/wala",
"WEA","Western Asset Bond Fund","13.13","156309367.5","n/a","2002","n/a","n/a","https://www.nasdaq.com/symbol/wea",
"TLI","Western Asset Corporate Loan Fund Inc","9.56","95016476.72","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/tli",
"EMD","Western Asset Emerging Markets Debt Fund Inc","13.88","843154646.56","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/emd",
"GDO","Western Asset Global Corporate Defined Opportunity Fund Inc.","16.65","248759991","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/gdo",
"EHI","Western Asset Global High Income Fund Inc","9.54","423570857.94","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/ehi",
"HIX","Western Asset High Income Fund II Inc.","6.58","560327901.28","n/a","1998","n/a","n/a","https://www.nasdaq.com/symbol/hix",
"HIO","Western Asset High Income Opportunity Fund, Inc.","4.87","623114235.45","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/hio",
"HYI","Western Asset High Yield Defined Opportunity Fund Inc.","14.8","337193861.2","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/hyi",
"SBI","Western Asset Intermediate Muni Fund Inc","8.79","123783548.85","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/sbi",
"IGI","Western Asset Investment Grade Defined Opportunity Trust Inc.","20.58","222784529.94","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/igi",
"PAI","Western Asset Investment Grade Income Fund Inc.","14.83","140631421.83","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/pai",
"MMU","Western Asset Managed Municipals Fund, Inc.","13.28","574874387.52","n/a","1992","n/a","n/a","https://www.nasdaq.com/symbol/mmu",
"WMC","Western Asset Mortgage Capital Corporation","10.23","492230557.17","n/a","2012","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/wmc",
"DMO","Western Asset Mortgage Defined Opportunity Fund Inc","20.79","217721133.63","n/a","2010","n/a","n/a","https://www.nasdaq.com/symbol/dmo",
"MTT","Western Asset Municipal Defined Opportunity Trust Inc","20.95","255103226.75","n/a","2009","n/a","n/a","https://www.nasdaq.com/symbol/mtt",
"MHF","Western Asset Municipal High Income Fund, Inc.","7.31","158136747.54","n/a","1988","n/a","n/a","https://www.nasdaq.com/symbol/mhf",
"MNP","Western Asset Municipal Partners Fund, Inc.","14.42","140148888.46","n/a","1993","n/a","n/a","https://www.nasdaq.com/symbol/mnp",
"GFY","Western Asset Variable Rate Strategic Fund Inc.","15.9982","74686108.8674","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/gfy",
"WIW","Western Asset/Claymore U.S Treasury Inflation Prot Secs Fd 2","10.73","656505757.82","n/a","2004","n/a","n/a","https://www.nasdaq.com/symbol/wiw",
"WIA","Western Asset/Claymore U.S. Treasury Inflation Prot Secs Fd","11.0901","323307689.082","n/a","2003","n/a","n/a","https://www.nasdaq.com/symbol/wia",
"WES","Western Midstream Partners, LP","32.09","14534773905.73","n/a","2012","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/wes",
"WU","Western Union Company (The)","18.93","8251413203.67","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/wu",
"WAB","Westinghouse Air Brake Technologies Corporation","74.76","12140690047.08","n/a","n/a","Capital Goods","Railroads","https://www.nasdaq.com/symbol/wab",
"WLK","Westlake Chemical Corporation","70.59","9069004084.14","n/a","2004","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/wlk",
"WLKP","Westlake Chemical Partners LP","22.78","801586945.42","n/a","2014","Basic Industries","Major Chemicals","https://www.nasdaq.com/symbol/wlkp",
"WBK","Westpac Banking Corporation","18.76","64324724282.56","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/wbk",
"WRK","Westrock Company","38.95","9946768963.05","n/a","2015","Consumer Durables","Containers/Packaging","https://www.nasdaq.com/symbol/wrk",
"WHG","Westwood Holdings Group Inc","35.58","321461813.16","n/a","n/a","Finance","Investment Managers","https://www.nasdaq.com/symbol/whg",
"WEX","WEX Inc.","196.96","8495945429.6","n/a","n/a","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/wex",
"WY","Weyerhaeuser Company","26.58","19842607920","n/a","n/a","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/wy",
"WPM","Wheaton Precious Metals Corp.","23.61","10490781483.21","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/wpm",
"WHR","Whirlpool Corporation","134.59","8562779865.21","n/a","n/a","Consumer Durables","Consumer Electronics/Appliances","https://www.nasdaq.com/symbol/whr",
"WTM","White Mountains Insurance Group, Ltd.","924.28","2927597746.08","n/a","n/a","Finance","Property-Casualty Insurers","https://www.nasdaq.com/symbol/wtm",
"WSR","Whitestone REIT","12.13","482364491.2","n/a","2010","Consumer Services","Real Estate Investment Trusts","https://www.nasdaq.com/symbol/wsr",
"WLL","Whiting Petroleum Corporation","27.17","2495225907.46","n/a","2003","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/wll",
"WOW","WideOpenWest, Inc.","9.43","779506073.66","n/a","2017","Consumer Services","Television Services","https://www.nasdaq.com/symbol/wow",
"WMB","Williams Companies, Inc. (The)","29.35","35564459935.4","n/a","n/a","Public Utilities","Natural Gas Distribution","https://www.nasdaq.com/symbol/wmb",
"WSM","Williams-Sonoma, Inc.","57.64","4542781320","n/a","n/a","Consumer Services","Home Furnishings","https://www.nasdaq.com/symbol/wsm",
"WGO","Winnebago Industries, Inc.","31.11","991584398.34","n/a","n/a","Consumer Non-Durables","Homebuilding","https://www.nasdaq.com/symbol/wgo",
"WIT","Wipro Limited","4.05","24349961569.5","n/a","n/a","Technology","EDP Services","https://www.nasdaq.com/symbol/wit",
"WNS","WNS (Holdings) Limited","53.42","2669363745.4","n/a","2006","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/wns",
"WWW","Wolverine World Wide, Inc.","35.5","3195227484","n/a","n/a","Consumer Non-Durables","Shoe Manufacturing","https://www.nasdaq.com/symbol/www",
"WF","Woori Bank","37.64","0","n/a","n/a","Finance","Commercial Banks","https://www.nasdaq.com/symbol/wf",
"WK","Workiva Inc.","51.43","2278590309.56","n/a","2014","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/wk",
"INT","World Fuel Services Corporation","29.2","1961415859.2","n/a","n/a","Energy","Oil Refining/Marketing","https://www.nasdaq.com/symbol/int",
"WWE","World Wrestling Entertainment, Inc.","87.45","6824847232.5","n/a","n/a","Consumer Services","Movies/Entertainment","https://www.nasdaq.com/symbol/wwe",
"WP","Worldpay, Inc.","114.4","34412847040","n/a","2012","Miscellaneous","Business Services","https://www.nasdaq.com/symbol/wp",
"WOR","Worthington Industries, Inc.","38.16","2143866960","n/a","n/a","Capital Goods","Steel/Iron Ore","https://www.nasdaq.com/symbol/wor",
"WPP","WPP plc","54.64","13789209065.76","n/a","n/a","Technology","Advertising","https://www.nasdaq.com/symbol/wpp",
"WPX","WPX Energy, Inc.","13.35","5637042079.05","n/a","2011","Energy","Oil & Gas Production","https://www.nasdaq.com/symbol/wpx",
"WYND","Wyndham Destinations, Inc.","41.1","3882429135.6","n/a","n/a","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/wynd",
"WH","Wyndham Hotels & Resorts, Inc.","50.37","4930658654.52","n/a","2018","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/wh",
"XYF","X Financial","5.65","857710391.85","n/a","2018","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/xyf",
"XFLT","XAI Octagon Floating Rate & Alternative Income Term Trust","8.7","72640293.3","n/a","2017","n/a","n/a","https://www.nasdaq.com/symbol/xflt",
"XHR","Xenia Hotels & Resorts, Inc.","21.67","2440900630.41","n/a","2015","Consumer Services","Hotels/Resorts","https://www.nasdaq.com/symbol/xhr",
"XRX","Xerox Corporation","32.95","7529290888.4","n/a","n/a","Technology","Computer peripheral equipment","https://www.nasdaq.com/symbol/xrx",
"XIN","Xinyuan Real Estate Co Ltd","5.01","322760778.09","n/a","2007","Basic Industries","Homebuilding","https://www.nasdaq.com/symbol/xin",
"XPO","XPO Logistics, Inc.","55.31","6039573790.7","n/a","n/a","Consumer Services","Transportation Services","https://www.nasdaq.com/symbol/xpo",
"XYL","Xylem Inc.","80.04","14371397947.92","n/a","2011","Capital Goods","Fluid Controls","https://www.nasdaq.com/symbol/xyl",
"AUY","Yamana Gold Inc.","2.52","2393299623.96","n/a","n/a","Basic Industries","Precious Metals","https://www.nasdaq.com/symbol/auy",
"YELP","Yelp Inc.","35.36","2900404813.28","n/a","2012","Consumer Services","Other Consumer Services","https://www.nasdaq.com/symbol/yelp",
"YETI","YETI Holdings, Inc.","30.65","2580609821.35","n/a","2018","Consumer Non-Durables","Recreational Products/Toys","https://www.nasdaq.com/symbol/yeti",
"YEXT","Yext, Inc.","22.01","2250474980.41","n/a","2017","Technology","EDP Services","https://www.nasdaq.com/symbol/yext",
"YRD","Yirendai Ltd.","13.66","828775585.92","n/a","2015","Finance","Finance: Consumer Services","https://www.nasdaq.com/symbol/yrd",
"YPF","YPF Sociedad Anonima","14.32","5632239195.76","n/a","1993","Energy","Integrated oil Companies","https://www.nasdaq.com/symbol/ypf",
"YUMC","Yum China Holdings, Inc.","45.42","17212464123.24","n/a","2016","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/yumc",
"YUM","Yum! Brands, Inc.","100.18","30696572051.5","n/a","n/a","Consumer Services","Restaurants","https://www.nasdaq.com/symbol/yum",
"ZAYO","Zayo Group Holdings, Inc.","27.99","6574240957.95","n/a","2014","Public Utilities","Telecommunications Equipment","https://www.nasdaq.com/symbol/zayo",
"ZEN","Zendesk, Inc.","86.27","9348120146.25","n/a","2014","Technology","EDP Services","https://www.nasdaq.com/symbol/zen",
"ZBH","Zimmer Biomet Holdings, Inc.","127.5","26083894920","n/a","n/a","Health Care","Industrial Specialties","https://www.nasdaq.com/symbol/zbh",
"ZB^A","Zions Bancorporation N.A.","23.7302","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/zb^a",
"ZB^G","Zions Bancorporation N.A.","26.765","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/zb^g",
"ZB^H","Zions Bancorporation N.A.","25.78","0","n/a","n/a","n/a","n/a","https://www.nasdaq.com/symbol/zb^h",
"ZBK","Zions Bancorporation N.A.","29.2788","0","n/a","n/a","Finance","Major Banks","https://www.nasdaq.com/symbol/zbk",
"ZTS","Zoetis Inc.","102.04","48853886206.6","n/a","2013","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/zts",
"ZTO","ZTO Express (Cayman) Inc.","18.25","14334715426.75","n/a","2016","Transportation","Trucking Freight/Courier Services","https://www.nasdaq.com/symbol/zto",
"ZUO","Zuora, Inc.","20.25","2197177650","n/a","2018","Technology","Computer Software: Prepackaged Software","https://www.nasdaq.com/symbol/zuo",
"ZYME","Zymeworks Inc.","15.65","501195929.35","n/a","2017","Health Care","Major Pharmaceuticals","https://www.nasdaq.com/symbol/zyme",
